{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {
    "kernel": "SoS"
   },
   "source": [
    "# Code example"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "kernel": "SoS"
   },
   "source": [
    "***"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "kernel": "SoS"
   },
   "source": [
    "This code example is a Jupyter notebook with [Script of Scripts](https://vatlab.github.io/sos-docs/) (SoS) workflow. It reproduces interactive figures for the highlighted paper by first author **Nan-kuei Chen** and second author **Pei-Hsin Wu**. \n",
    "\n",
    "\n",
    "The calculations are written using *Julia* (from this fetched from [repo](https://github.com/nankueichen/Fourier_space_phase_unwrapping)), and the interactive figures are written in *Python 3.8.6* with the ploting library [Plotly](https://plotly.com/).  "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "kernel": "Julia",
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "%use Julia\n",
    "\n",
    "###### define the parameters in the next 7 lines\n",
    "magnitude_nii_file = string(\"data/magnitude.nii\");\n",
    "phase_nii_file = string(\"data/phase.nii\");\n",
    "partiallyUnwrapped_nii_file = string(\"data/partiallyUnwrappedMap.nii\");\n",
    "criticalROI_nii_file = string(\"data/criticalROI.nii\");\n",
    "ChooseThisSlice = Int64(5); # process data in a chosen slice; e.g., slice #5 in this case\n",
    "criticalROILabel = Int64(1); # unwrap phase values inside a critical ROI labeled with an integer number; e.g., 1 in this case\n",
    "output_nii_file = string(\"data/output.nii\");"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "kernel": "Julia"
   },
   "source": [
    "```{admonition} Julia code cell\n",
    ":class: tip\n",
    "The main program and the calculation are in the code bellow, you could use different value of patchsize.\n",
    "\n",
    "If you wish to see the code cell, try clicking the button to the right of the empty spot bellow!\n",
    "```"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "kernel": "Julia",
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "%use Julia \n",
    "\n",
    "###### The main program starts here; no need to modify the code below (although you could use different value of patchsize)\n",
    "push!(LOAD_PATH,\"juliafunction\");\n",
    "using PyPlot\n",
    "using Read_NIfTI1\n",
    "using myFun\n",
    "using Distributed\n",
    "@everywhere using FFTW\n",
    "@everywhere using LinearAlgebra\n",
    "@everywhere using SharedArrays\n",
    "\n",
    "function julia_main(magnitude_nii_file::String,phase_nii_file::String,partiallyUnwrapped_nii_file::String,criticalROI_nii_file::String,ChooseThisSlice::Int64,criticalROILabel::Int64)\n",
    "    headerinfo1 = load_nii_header(magnitude_nii_file);\n",
    "    data001 = load_nii_data(magnitude_nii_file, headerinfo1);\n",
    "    headerinfo1 = load_nii_header(phase_nii_file);\n",
    "    data002 = load_nii_data(phase_nii_file, headerinfo1);\n",
    "    imagedata_noise = data001 .* exp.(complex(0,1)*data002);\n",
    "\n",
    "    imgsn = imagedata_noise[:,:,ChooseThisSlice];\n",
    "    ksn = ifftshift(ifft(ifftshift(imgsn)));\n",
    "\n",
    "    @everywhere function sidm(kdata::Array{Complex{Float32},2})\n",
    "        kabs = abs.(kdata);\n",
    "        pxpy = findall(kabs .== maximum(kabs));\n",
    "        px = pxpy[1][1];\n",
    "        py = pxpy[1][2];\n",
    "        return (px,py);\n",
    "    end\n",
    "\n",
    "    datasize1,datasize2 = size(imgsn)\n",
    "\n",
    "    pxmap = SharedArray{Float64,2}((datasize1,datasize2));\n",
    "    pymap = SharedArray{Float64,2}((datasize1,datasize2));\n",
    "\n",
    "    patchsize = 7;\n",
    "    patchsize = patchsize + div(1 + (-1).^patchsize,2)\n",
    "    ps1 = max(div((patchsize-1),2),1);\n",
    "\n",
    "    @time @sync @distributed for cntx = 1:datasize1\n",
    "        @inbounds @fastmath @simd for cnty = 1:datasize2\n",
    "            tmp1 = zeros(ComplexF32,(datasize1,datasize2));\n",
    "            startingx = max(1,cntx-ps1);\n",
    "            startingy = max(1,cnty-ps1);\n",
    "            endingx = min(cntx+ps1,datasize1);\n",
    "            endingy = min(cnty+ps1,datasize2);\n",
    "            tmp1[startingx:endingx,startingy:endingy] = imgsn[startingx:endingx,startingy:endingy];\n",
    "            tmp2 = ifftshift(ifft(ifftshift(tmp1)));\n",
    "            px,py = sidm(tmp2);\n",
    "            pxmap[cntx,cnty]=px;\n",
    "            pymap[cntx,cnty]=py;\n",
    "        end\n",
    "    end\n",
    "\n",
    "    pxmap2a = pxmap.-(datasize1/2);\n",
    "    pymap2a = pymap.-(datasize2/2);\n",
    "    pxmap_radppixel = -pxmap2a*2*π/datasize1;\n",
    "    pymap_radppixel = -pymap2a*2*π/datasize2;\n",
    "\n",
    "    headerinfo4 = load_nii_header(partiallyUnwrapped_nii_file);\n",
    "    preludephasemap_all = load_nii_data(partiallyUnwrapped_nii_file, headerinfo4);\n",
    "    preludephasemap = preludephasemap_all[:,:,ChooseThisSlice];\n",
    "\n",
    "    preludemask = ones(datasize1,datasize2);\n",
    "    L = findall(preludephasemap.==0);\n",
    "    preludemask[L].=0;\n",
    "    preludephasemap_cpe = closest_point_estimation(preludephasemap,preludemask);\n",
    "\n",
    "    headerinfo5 = load_nii_header(criticalROI_nii_file);\n",
    "    criticalROI_all = load_nii_data(criticalROI_nii_file, headerinfo5);\n",
    "    criticalROI = criticalROI_all[:,:,ChooseThisSlice];\n",
    "\n",
    "    L2 = findall(criticalROI.==criticalROILabel);\n",
    "\n",
    "    if length(L2)>0\n",
    "        xcoordarray = zeros(Int64,length(L2));\n",
    "        ycoordarray = zeros(Int64,length(L2));\n",
    "        for cnt = 1:length(L2)\n",
    "            xcoordarray[cnt] = L2[cnt][1];\n",
    "            ycoordarray[cnt] = L2[cnt][2];\n",
    "        end\n",
    "\n",
    "        roiStartX = minimum(xcoordarray)-1;\n",
    "        roiEndX = maximum(xcoordarray)+1;\n",
    "        roiStartY = minimum(ycoordarray)-1;\n",
    "        roiEndY = maximum(ycoordarray)+1;\n",
    "        xdim = roiEndX-roiStartX+1;\n",
    "        ydim = roiEndY-roiStartY+1;\n",
    "\n",
    "        boundaryConditionMap = convert(Array{Float64},preludephasemap_cpe[roiStartX:roiEndX,roiStartY:roiEndY]);\n",
    "        mask = ones(xdim,ydim)-criticalROI[roiStartX:roiEndX,roiStartY:roiEndY];\n",
    "        snr_ref = abs.(imgsn)[roiStartX:roiEndX,roiStartY:roiEndY].*mask;\n",
    "        λmap = snr_ref ./maximum(snr_ref[:]);\n",
    "        λmap[:,1].=2.;\n",
    "        λmap[:,end].=2.;\n",
    "        λmap[1,:].=2.;\n",
    "        λmap[end,:].=2.;\n",
    "        Mgv = pxmap_radppixel[roiStartX:roiEndX,roiStartY:roiEndY];\n",
    "        Mgh = pymap_radppixel[roiStartX:roiEndX,roiStartY:roiEndY];\n",
    "\n",
    "        M_recovered = twoDimIntegration(mask,boundaryConditionMap,λmap,Mgv,Mgh);\n",
    "\n",
    "        newPhaseMap = deepcopy(preludephasemap_cpe);\n",
    "        newPhaseMap[roiStartX:roiEndX,roiStartY:roiEndY]= M_recovered;\n",
    "        newPhaseMapMask = newPhaseMap.*preludemask;\n",
    "    else\n",
    "        newPhaseMap = preludephasemap;\n",
    "        newPhaseMapMask = newPhaseMap.*preludemask;\n",
    "    end\n",
    "\n",
    "    headerinfo4[\"datatype\"] = Int16(16);\n",
    "    output_all = convert(Array{Float32,3}, preludephasemap_all);\n",
    "    newPhaseMapMask = convert(Array{Float32,2}, newPhaseMapMask);\n",
    "    output_all[:,:,ChooseThisSlice] = newPhaseMapMask;\n",
    "    write_nii_header(output_nii_file, headerinfo4);\n",
    "    fid = open(output_nii_file,\"a\");\n",
    "    write(fid, output_all);\n",
    "    close(fid);\n",
    "\n",
    "#     figure(1,figsize=(10,5));imshow(reverse(permutedims(vcat(preludephasemap,newPhaseMapMask),[2,1]),dims=1),cmap=\"hot\",interpolation=\"none\"); axis(\"off\");\n",
    "#     figure(2,figsize=(10,5));imshow(reverse(permutedims(vcat(preludephasemap_cpe,newPhaseMap),[2,1]),dims=1),cmap=\"hot\",interpolation=\"none\"); axis(\"off\");\n",
    "\n",
    "end\n",
    "# julia_main(magnitude_nii_file,phase_nii_file,partiallyUnwrapped_nii_file,criticalROI_nii_file,ChooseThisSlice,criticalROILabel);"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "kernel": "Julia",
    "scrolled": true,
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "#1 Slice:\n",
      "  4.561267 seconds (2.99 M allocations: 3.540 GiB, 4.62% gc time)\n",
      "#2 Slice:\n",
      "  4.281980 seconds (967.44 k allocations: 3.446 GiB, 6.89% gc time)\n",
      "#3 Slice:\n",
      "  4.529378 seconds (967.43 k allocations: 3.446 GiB, 10.00% gc time)\n",
      "#4 Slice:\n",
      "  4.524528 seconds (967.46 k allocations: 3.446 GiB, 11.44% gc time)\n",
      "#5 Slice:\n",
      "  4.473395 seconds (967.47 k allocations: 3.446 GiB, 12.07% gc time)\n",
      "#6 Slice:\n",
      "  4.240320 seconds (967.32 k allocations: 3.446 GiB, 11.24% gc time)\n",
      "#7 Slice:\n",
      "  4.415801 seconds (967.43 k allocations: 3.446 GiB, 4.53% gc time)\n",
      "#8 Slice:\n",
      "  4.265675 seconds (967.29 k allocations: 3.446 GiB, 4.70% gc time)\n",
      "#9 Slice:\n",
      "  4.065691 seconds (967.44 k allocations: 3.446 GiB, 4.39% gc time)\n"
     ]
    }
   ],
   "source": [
    "%use Julia \n",
    "###### Save multiple slices using julia_main function\n",
    "for i=1:9\n",
    "    println(\"#\", i, \" Slice:\")\n",
    "    output_nii_file = \"data/output\"*string(i)*\".nii\";\n",
    "    julia_main(magnitude_nii_file,phase_nii_file,partiallyUnwrapped_nii_file,criticalROI_nii_file,Int64(i),criticalROILabel);\n",
    "end"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "kernel": "Julia"
   },
   "source": [
    "```{admonition} Python code cell\n",
    ":class: tip\n",
    "Now lets try plotting the “output_nii_file” heatmap with a slider for navigating through slices.\n",
    "\n",
    "You can zoom in and out if you wish to explore the phenomenon!\n",
    "```"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "kernel": "Python3",
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-latest.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>                        <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.58.4\n",
       "* Copyright 2012-2020, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}((function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,(function(t){return i(e[o][1][t]||t)}),u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans', verdana, arial, sans-serif;position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":778}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1365}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":929}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":942}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":952}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":641}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":961}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":980}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":994}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":1001}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":1007}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":1022}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":1033}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":755}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":1041}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1366}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":1051}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":1060}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1367}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1073}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1083}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1095}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1101}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1105}],25:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/image\")},{\"../src/traces/image\":1113}],26:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./image\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./treemap\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./image\":25,\"./indicator\":27,\"./isosurface\":28,\"./mesh3d\":29,\"./ohlc\":30,\"./parcats\":31,\"./parcoords\":32,\"./pie\":33,\"./pointcloud\":34,\"./sankey\":35,\"./scatter3d\":36,\"./scattercarpet\":37,\"./scattergeo\":38,\"./scattergl\":39,\"./scattermapbox\":40,\"./scatterpolar\":41,\"./scatterpolargl\":42,\"./scatterternary\":43,\"./sort\":44,\"./splom\":45,\"./streamtube\":46,\"./sunburst\":47,\"./surface\":48,\"./table\":49,\"./treemap\":50,\"./violin\":51,\"./volume\":52,\"./waterfall\":53}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1121}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1127}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1132}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1137}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1146}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1156}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1167}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1176}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1182}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1220}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1227}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1235}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1248}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1258}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1266}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1273}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1281}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1369}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1290}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1298}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1306}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1315}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1323}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/treemap\")},{\"../src/traces/treemap\":1332}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1344}],52:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1352}],53:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1360}],54:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),f=i(),h=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),new o({turntable:u,orbit:f,matrix:h},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map((function(e){return t[e]})),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach((function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))})),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":480,\"orbit-camera-controller\":501,\"turntable-camera-controller\":581}],55:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)}(this,(function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return f(t.source,e.source)||t.index-e.index}function u(t,e){return f(t.target,e.target)||t.index-e.index}function f(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function h(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function m(t){return t.index}function v(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}function _(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort((function(t,e){return t.length-e.length}));var f={};for(o=0;o<u.length;o++){var h=u[o].slice(-2);f[h[0]]||(f[h[0]]={}),f[h[0]][h[1]]=!0}t.links.forEach((function(t){var e=t.target.index,r=t.source.index;e===r||f[r]&&f[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1}))}else t.links.forEach((function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)}))}function w(t,e){var r=0,n=0;t.links.forEach((function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach((function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)})))})),t.links.forEach((function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),H(t,e)&&(t.circularLinkType=t.source.circularLinkType))}))}function T(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function k(t,e){var r=0;t.sourceLinks.forEach((function(t){r=t.circular&&!H(t,e)?r+1:r}));var n=0;return t.targetLinks.forEach((function(t){n=t.circular&&!H(t,e)?n+1:n})),r+n}function M(t){var e=t.source.sourceLinks,r=0;e.forEach((function(t){r=t.circular?r+1:r}));var n=t.target.targetLinks,i=0;return n.forEach((function(t){i=t.circular?i+1:i})),!(r>1||i>1)}function A(t,e,r){return t.sort(E),t.forEach((function(n,i){var a,o,s=0;if(H(n,r)&&M(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}})),t}function S(t,r,i,a){var o=e.min(t.links,(function(t){return t.source.y0}));t.links.forEach((function(t){t.circular&&(t.circularPathData={})})),A(t.links.filter((function(t){return\"top\"==t.circularLinkType})),r,a),A(t.links.filter((function(t){return\"bottom\"==t.circularLinkType})),r,a),t.links.forEach((function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+10,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,H(e,a)&&M(e))e.circularPathData.leftSmallArcRadius=10+e.width/2,e.circularPathData.leftLargeArcRadius=10+e.width/2,e.circularPathData.rightSmallArcRadius=10+e.width/2,e.circularPathData.rightLargeArcRadius=10+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter((function(t){return t.source.column==s&&t.circularLinkType==l}));\"bottom\"==e.circularLinkType?c.sort(L):c.sort(C);var u=0;c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=10+e.width/2+u,e.circularPathData.leftLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),s=e.target.column,c=t.links.filter((function(t){return t.target.column==s&&t.circularLinkType==l})),\"bottom\"==e.circularLinkType?c.sort(P):c.sort(I),u=0,c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=10+e.width/2+u,e.circularPathData.rightLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var f=n.linkHorizontal().source((function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]})).target((function(t){return[t.target.x0,t.y1]}));e.path=f(e)}}))}function E(t,e){return z(t)==z(e)?\"bottom\"==t.circularLinkType?L(t,e):C(t,e):z(e)-z(t)}function C(t,e){return t.y0-e.y0}function L(t,e){return e.y0-t.y0}function I(t,e){return t.y1-e.y1}function P(t,e){return e.y1-t.y1}function z(t){return t.target.column-t.source.column}function O(t){return t.target.x0-t.source.x1}function D(t,e){var r=T(t),n=O(e)/Math.tan(r);return\"up\"==q(t)?t.y1+n:t.y1-n}function R(t,e){var r=T(t),n=O(e)/Math.tan(r);return\"up\"==q(t)?t.y1-n:t.y1+n}function F(t,e,r,n){t.links.forEach((function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach((function(o){if(o.column==a){var c,u=s/(l+1),f=Math.pow(1-u,3),h=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=f*i.y0+h*i.y0+p*i.y1+d*i.y1,m=g-i.width/2,v=g+i.width/2;m>o.y0&&m<o.y1?(c=o.y1-m+10,c=\"bottom\"==o.circularLinkType?c:-c,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&B(o,t)&&N(t,c,e,r)}))):(v>o.y0&&v<o.y1||m<o.y0&&v>o.y1)&&(c=v-o.y0+10,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&N(t,c,e,r)})))}}))}}))}function B(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function N(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach((function(t){t.y1=t.y1+e})),t.sourceLinks.forEach((function(t){t.y0=t.y0+e}))),t}function j(t,e,r,n){t.nodes.forEach((function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter((function(t){return b(t.source,r)==b(i,r)})),o=a.length;o>1&&a.sort((function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!V(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=R(e,t);return t.y1-r}if(e.target.column>t.target.column)return R(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0}));var s=i.y0;a.forEach((function(t){t.y0=s+t.width/2,s+=t.width})),a.forEach((function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}}))}))}function U(t,e,r){t.nodes.forEach((function(e){var n=t.links.filter((function(t){return b(t.target,r)==b(e,r)})),i=n.length;i>1&&n.sort((function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!V(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=D(e,t);return t.y0-r}if(t.source.column<e.source.column)return D(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0}));var a=e.y0;n.forEach((function(t){t.y1=a+t.width/2,a+=t.width})),n.forEach((function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}}))}))}function V(t,e){return q(t)==q(e)}function q(t){return t.y0-t.y1>0?\"up\":\"down\"}function H(t,e){return b(t.source,e)==b(t.target,e)}function G(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach((function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)})),0==o||0==s){var l=e.min(i,(function(t){return t.y0})),c=(n-r)/(e.max(i,(function(t){return t.y1}))-l);i.forEach((function(t){var e=(t.y1-t.y0)*c;t.y0=(t.y0-l)*c,t.y1=t.y0+e})),a.forEach((function(t){t.y0=(t.y0-l)*c,t.y1=(t.y1-l)*c,t.width=t.width*c}))}}t.sankeyCircular=function(){var t,n,i=0,a=0,b=1,T=1,M=24,A=m,E=o,C=v,L=y,I=32,P=2,z=null;function O(){var t={nodes:C.apply(null,arguments),links:L.apply(null,arguments)};D(t),_(t,A,z),R(t),B(t),w(t,A),N(t,I,A),V(t);for(var e=4,r=0;r<e;r++)j(t,T,A),U(t,T,A),F(t,a,T,A),j(t,T,A),U(t,T,A);return G(t,a,T),S(t,P,T,A),t}function D(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,A);return t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})),t}function R(t){t.nodes.forEach((function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,h),e.sum(t.targetLinks,h)),t.sourceLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})),t.targetLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}))}))}function B(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.depth=n,t.sourceLinks.forEach((function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)}))}));for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.height=n,t.targetLinks.forEach((function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)}))}));t.nodes.forEach((function(t){t.column=Math.floor(E.call(null,t,n))}))}function N(o,s,l){var c=r.nest().key((function(t){return t.column})).sortKeys(e.ascending).entries(o.nodes).map((function(t){return t.values}));!function(r){if(n){var s=1/0;c.forEach((function(t){var e=T*n/(t.length+1);s=e<s?e:s})),t=s}var l=e.min(c,(function(r){return(T-a-(r.length-1)*t)/e.sum(r,h)}));l*=.3,o.links.forEach((function(t){t.width=t.value*l}));var u=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,(function(t){return t.column}));return t.links.forEach((function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))})),{top:r=r>0?r+25+10:r,bottom:n=n>0?n+25+10:n,left:a=a>0?a+25+10:a,right:i=i>0?i+25+10:i}}(o),f=function(t,r){var n=e.max(t.nodes,(function(t){return t.column})),o=b-i,s=T-a,l=o/(o+r.right+r.left),c=s/(s+r.top+r.bottom);return i=i*l+r.left,b=0==r.right?b:b*l,a=a*c+r.top,T*=c,t.nodes.forEach((function(t){t.x0=i+t.column*((b-i-M)/n),t.x1=t.x0+M})),c}(o,u);l*=f,o.links.forEach((function(t){t.width=t.value*l})),c.forEach((function(t){var e=t.length;t.forEach((function(t,n){t.depth==c.length-1&&1==e||0==t.depth&&1==e?(t.y0=T/2-t.value*l,t.y1=t.y0+t.value*l):t.partOfCycle?0==k(t,r)?(t.y0=T/2+n,t.y1=t.y0+t.value*l):\"top\"==t.circularLinkType?(t.y0=a+n,t.y1=t.y0+t.value*l):(t.y0=T-t.value*l-n,t.y1=t.y0+t.value*l):0==u.top||0==u.bottom?(t.y0=(T-a)/e*n,t.y1=t.y0+t.value*l):(t.y0=(T-a)/2-e/2+n,t.y1=t.y0+t.value*l)}))}))}(l),y();for(var u=1,m=s;m>0;--m)v(u*=.99,l),y();function v(t,r){var n=c.length;c.forEach((function(i){var a=i.length,o=i[0].depth;i.forEach((function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&k(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=T/2-s/2,i.y1=T/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=T/2-s/2,i.y1=T/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}}))}))}function y(){c.forEach((function(e){var r,n,i,o=a,s=e.length;for(e.sort(f),i=0;i<s;++i)(n=o-(r=e[i]).y0)>0&&(r.y0+=n,r.y1+=n),o=r.y1+t;if((n=o-t-T)>0)for(o=r.y0-=n,r.y1-=n,i=s-2;i>=0;--i)(n=(r=e[i]).y1+t-o)>0&&(r.y0-=n,r.y1-=n),o=r.y0}))}}function V(t){t.nodes.forEach((function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)})),t.nodes.forEach((function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach((function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)})),t.targetLinks.forEach((function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)}))}))}return O.nodeId=function(t){return arguments.length?(A=\"function\"==typeof t?t:s(t),O):A},O.nodeAlign=function(t){return arguments.length?(E=\"function\"==typeof t?t:s(t),O):E},O.nodeWidth=function(t){return arguments.length?(M=+t,O):M},O.nodePadding=function(e){return arguments.length?(t=+e,O):t},O.nodes=function(t){return arguments.length?(C=\"function\"==typeof t?t:s(t),O):C},O.links=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),O):L},O.size=function(t){return arguments.length?(i=a=0,b=+t[0],T=+t[1],O):[b-i,T-a]},O.extent=function(t){return arguments.length?(i=+t[0][0],b=+t[1][0],a=+t[0][1],T=+t[1][1],O):[[i,a],[b,T]]},O.iterations=function(t){return arguments.length?(I=+t,O):I},O.circularLinkGap=function(t){return arguments.length?(P=+t,O):P},O.nodePaddingRatio=function(t){return arguments.length?(n=+t,O):n},O.sortNodes=function(t){return arguments.length?(z=t,O):z},O.update=function(t){return w(t,A),V(t),t.links.forEach((function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<T?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)})),j(t,T,A,!1),U(t,T,A),S(t,P,T,A),t},O},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":156,\"d3-collection\":157,\"d3-shape\":165,\"elementary-circuits-directed-graph\":179}],56:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)}(this,(function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function f(t){return(t.y0+t.y1)/2}function h(t){return f(t.source)*t.value}function p(t){return f(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function m(t){return t.links}function v(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,T=g,k=m,M=32;function A(){var t={nodes:T.apply(null,arguments),links:k.apply(null,arguments)};return S(t),E(t),C(t),L(t),I(t),t}function S(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,_);t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=v(e,n)),\"object\"!=typeof i&&(i=t.target=v(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)}))}function E(t){t.nodes.forEach((function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))}))}function C(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach((function(t){t.depth=a,t.sourceLinks.forEach((function(t){n.indexOf(t.target)<0&&n.push(t.target)}))}));for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach((function(t){t.height=a,t.targetLinks.forEach((function(t){n.indexOf(t.source)<0&&n.push(t.source)}))}));var o=(i-t-x)/(a-1);e.nodes.forEach((function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x}))}function L(t){var i=r.nest().key((function(t){return t.x0})).sortKeys(e.ascending).entries(t.nodes).map((function(t){return t.values}));!function(){var r=e.max(i,(function(t){return t.length})),a=2/3*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,(function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)}));i.forEach((function(t){t.forEach((function(t,e){t.y1=(t.y0=e)+t.value*o}))})),t.links.forEach((function(t){t.width=t.value*o}))}(),d();for(var a=1,o=M;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach((function(r){r.forEach((function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,h)/e.sum(r.targetLinks,u)-f(r))*t;r.y0+=n,r.y1+=n}}))}))}function l(t){i.slice().reverse().forEach((function(r){r.forEach((function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-f(r))*t;r.y0+=n,r.y1+=n}}))}))}function d(){i.forEach((function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)(r=a-(e=t[i]).y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)(r=(e=t[i]).y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0}))}}function I(t){t.nodes.forEach((function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)})),t.nodes.forEach((function(t){var e=t.y0,r=e;t.sourceLinks.forEach((function(t){t.y0=e+t.width/2,e+=t.width})),t.targetLinks.forEach((function(t){t.y1=r+t.width/2,r+=t.width}))}))}return A.update=function(t){return I(t),t},A.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),A):_},A.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),A):w},A.nodeWidth=function(t){return arguments.length?(x=+t,A):x},A.nodePadding=function(t){return arguments.length?(b=+t,A):b},A.nodes=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),A):T},A.links=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),A):k},A.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],A):[i-t,y-n]},A.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],A):[[t,n],[i,y]]},A.iterations=function(t){return arguments.length?(M=+t,A):M},A},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":156,\"d3-collection\":157,\"d3-shape\":165}],57:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":58}],58:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),f=t(\"dtype\"),h=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(f(e.dtype))(m):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=m));for(var v=0;v<m;++v)d[v]=v;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]),c=b[o]||(b[o]=[]),u=x[o]||(x[o]=[]),f=l.length;if(++o>r||s>1073741824){for(var h=0;h<a.length;h++)l.push(a[h]),c.push(s),u.push(null,null,null,null);return f}if(l.push(a[0]),c.push(s),a.length<=1)return u.push(null,null,null,null),f;for(var p=.5*i,d=e+p,m=n+p,v=[],_=[],w=[],T=[],k=1,M=a.length;k<M;k++){var A=a[k],S=g[2*A],E=g[2*A+1];S<d?E<m?v.push(A):_.push(A):E<m?w.push(A):T.push(A)}return s<<=2,u.push(t(e,n,p,v,o,s),t(e,m,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,m,p,T,o,s+3)),f}(0,0,1,d,0,1);for(var w=0,T=0;T<y.length;T++){var k=y[T];if(d.set)d.set(k,w);else for(var M=0,A=k.length;M<A;M++)d[M+w]=k[M];var S=w+y[T].length;_[T]=[w,S],w=S}return d.range=function(){var e,r=[],n=arguments.length;for(;n--;)r[n]=arguments[n];if(u(r[r.length-1])){var o=r.pop();r.length||null==o.x&&null==o.l&&null==o.left||(r=[o],e={}),e=s(o,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var c=a.apply(void 0,r),f=[Math.min(c.x,c.x+c.width),Math.min(c.y,c.y+c.height),Math.max(c.x,c.x+c.width),Math.max(c.y,c.y+c.height)],d=f[0],g=f[1],m=f[2],v=f[3],b=p([d,g,m,v],i),_=b[0],w=b[1],T=b[2],k=b[3],M=l(e.level,y.length);if(null!=e.d){var A;\"number\"==typeof e.d?A=[e.d,e.d]:e.d.length&&(A=e.d),M=Math.min(Math.max(Math.ceil(-h(Math.abs(A[0])/(i[2]-i[0]))),Math.ceil(-h(Math.abs(A[1])/(i[3]-i[1])))),M)}if(M=Math.min(M,y.length),e.lod)return E(_,w,T,k,M);var S=[];function C(e,r,n,i,a,o){if(null!==a&&null!==o&&!(_>e+n||w>r+n||T<e||k<r||i>=M||a===o)){var s=y[i];void 0===o&&(o=s.length);for(var l=a;l<o;l++){var c=s[l],u=t[2*c],f=t[2*c+1];u>=d&&u<=m&&f>=g&&f<=v&&S.push(c)}var h=x[i],p=h[4*a+0],b=h[4*a+1],A=h[4*a+2],E=h[4*a+3],I=L(h,a+1),P=.5*n,z=i+1;C(e,r,P,z,p,b||A||E||I),C(e,r+P,P,z,b,A||E||I),C(e+P,r,P,z,A,E||I),C(e+P,r+P,P,z,E,I)}}function L(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}return C(0,0,1,0,0,1),S},d;function E(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=C(t,e,s),f=C(r,i,s),h=n.ge(l,u),p=n.gt(l,f,h,l.length-1);o[s]=[h+c,p+c]}return o}function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":70,\"binary-search-bounds\":96,clamp:120,defined:170,dtype:175,\"flatten-vertex-data\":244,\"is-obj\":468,\"math-log2\":479,\"parse-rect\":504,\"pick-by-alias\":511}],59:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");function i(t){var e=0;if(t&&t.length>0){e+=Math.abs(a(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(a(t[r]))}return e}function a(t){var e,r,n,i,a,s,l=0,c=t.length;if(c>2){for(s=0;s<c;s++)s===c-2?(n=c-2,i=c-1,a=0):s===c-1?(n=c-1,i=0,a=1):(n=s,i=s+1,a=s+2),e=t[n],r=t[i],l+=(o(t[a][0])-o(e[0]))*Math.sin(o(r[1]));l=6378137*l*6378137/2}return l}function o(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,(function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return i(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=i(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)}),0)}},{\"@turf/meta\":63}],60:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");r.default=function(t){var e=[1/0,1/0,-1/0,-1/0];return n.coordEach(t,(function(t){e[0]>t[0]&&(e[0]=t[0]),e[1]>t[1]&&(e[1]=t[1]),e[2]<t[0]&&(e[2]=t[0]),e[3]<t[1]&&(e[3]=t[1])})),e}},{\"@turf/meta\":63}],61:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,(function(t){r+=t[0],a+=t[1],o++})),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":62,\"@turf/meta\":63}],62:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:386e-9,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return i(t,e)})),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return a(t,e)})),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return o(t,e)})),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=f,r.lengthToRadians=h,r.lengthToDegrees=function(t,e){return p(h(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return f(h(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach((function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")}))},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],63:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,f,h=0,p=0,d=t.type,g=\"FeatureCollection\"===d,m=\"Feature\"===d,v=g?t.features.length:1,y=0;y<v;y++){l=(f=!!(u=g?t.features[y].geometry:m?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=f?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(h=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-h;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-h;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,f,h=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,f=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,h,c,u,f))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],h,c,u,f))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,h,c,u,f))return!1;h++}}function l(t,e){s(t,(function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}}))}function c(t,e){l(t,(function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,f=0;return!1!==i(t,(function(i,s,h,p,d){if(void 0===l||r>c||p>u||d>f)return l=i,c=r,u=p,f=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i}))&&void 0}}}))}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,(function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}}))}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,(function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)}),n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.coordAll=function(t){var e=[];return i(t,(function(t){e.push(t)})),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,(function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)})),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,(function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)})),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,(function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0})),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,(function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)})),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":62}],64:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":259,\"gl-vao\":358,\"weak-map\":602}],65:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map((function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t}))}},{}],66:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map((function(t,i){var o=i+e,s=String(o).length;return n(o,a-s)+r+t})).join(\"\\n\")}},{\"pad-left\":502}],67:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":548}],68:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter((function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1}))};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:119,\"delaunay-triangulate\":171}],69:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":68,\"simplicial-complex-boundary\":555}],70:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],71:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)isNaN(t[s])||(t[s]=0===c?.5:(t[s]-o)/c)}}return t}},{\"array-bounds\":70}],72:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],73:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"object-assign\");\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>\n",
       " * @license  MIT\n",
       " */function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function f(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var h=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function m(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function v(t,e,r,n,i){throw new h.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||v(t,!0,e,\"==\",h.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(f(t)&&f(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=T(t),f=T(e);if(u.length!==f.length)return!1;for(u.sort(),f.sort(),c=u.length-1;c>=0;c--)if(u[c]!==f[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&v(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&v(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}h.AssertionError=function(t){this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=function(t){return g(m(t.actual),128)+\" \"+t.operator+\" \"+g(m(t.expected),128)}(this),this.generatedMessage=!0);var e=t.stackStartFunction||v;if(Error.captureStackTrace)Error.captureStackTrace(this,e);else{var r=new Error;if(r.stack){var n=r.stack,i=d(e),a=n.indexOf(\"\\n\"+i);if(a>=0){var o=n.indexOf(\"\\n\",a+1);n=n.substring(o+1)}this.stack=n}}},o.inherits(h.AssertionError,Error),h.fail=v,h.ok=y,h.equal=function(t,e,r){t!=e&&v(t,e,r,\"==\",h.equal)},h.notEqual=function(t,e,r){t==e&&v(t,e,r,\"!=\",h.notEqual)},h.deepEqual=function(t,e,r){x(t,e,!1)||v(t,e,r,\"deepEqual\",h.deepEqual)},h.deepStrictEqual=function(t,e,r){x(t,e,!0)||v(t,e,r,\"deepStrictEqual\",h.deepStrictEqual)},h.notDeepEqual=function(t,e,r){x(t,e,!1)&&v(t,e,r,\"notDeepEqual\",h.notDeepEqual)},h.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&v(e,r,n,\"notDeepStrictEqual\",t)},h.strictEqual=function(t,e,r){t!==e&&v(t,e,r,\"===\",h.strictEqual)},h.notStrictEqual=function(t,e,r){t===e&&v(t,e,r,\"!==\",h.notStrictEqual)},h.throws=function(t,e,r){w(!0,t,e,r)},h.doesNotThrow=function(t,e,r){w(!1,t,e,r)},h.ifError=function(t){if(t)throw t},h.strict=n((function t(e,r){e||v(e,!0,r,\"==\",t)}),h,{equal:h.strictEqual,deepEqual:h.deepStrictEqual,notEqual:h.notStrictEqual,notDeepEqual:h.notDeepStrictEqual}),h.strict.strict=h.strict;var T=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":499,\"util/\":76}],74:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],75:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],76:[function(t,e,r){(function(e,n){(function(){var i=/%[sdj%]/g;r.format=function(t){if(!v(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,(function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}})),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&T(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return v(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(v(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(m(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach((function(t,r){e[t]=!0})),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return f(e);if(0===o.length){if(T(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return f(e)}var c,b=\"\",k=!1,M=[\"{\",\"}\"];(p(e)&&(k=!0,M=[\"[\",\"]\"]),T(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+f(e)),0!==o.length||k&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=k?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)E(e,String(o))?a.push(h(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach((function(i){i.match(/^\\d+$/)||a.push(h(t,e,r,n,i,!0))})),a}(t,e,n,s,o):o.map((function(r){return h(t,e,n,s,r,k)})),t.seen.pop(),function(t,e,r){if(t.reduce((function(t,e){return e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1}),0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,M)):M[0]+b+M[1]}function f(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function h(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),E(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map((function(t){return\"  \"+t})).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map((function(t){return\"   \"+t})).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function m(t){return\"number\"==typeof t}function v(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===k(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===k(t)}function w(t){return b(t)&&(\"[object Error]\"===k(t)||t instanceof Error)}function T(t){return\"function\"==typeof t}function k(t){return Object.prototype.toString.call(t)}function M(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=m,r.isString=v,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=T,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var A=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(){var t=new Date,e=[M(t.getHours()),M(t.getMinutes()),M(t.getSeconds())].join(\":\");return[t.getDate(),A[t.getMonth()],e].join(\" \")}function E(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){console.log(\"%s - %s\",S(),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":75,_process:526,inherits:74}],77:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],78:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(o=0;o<=r;++o)a[r][o]=1;var c=new Array(r+1);for(o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),f=i(u[r+1]);0===f&&(f=1);var h=new Array(r+1);for(o=0;o<=r;++o)h[o]=i(u[o])/f;return h};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":547}],79:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){var e,r,n=c(t),o=n[0],s=n[1],l=new a(function(t,e,r){return 3*(e+r)/4-r}(0,o,s)),u=0,f=s>0?o-4:o;for(r=0;r<f;r+=4)e=i[t.charCodeAt(r)]<<18|i[t.charCodeAt(r+1)]<<12|i[t.charCodeAt(r+2)]<<6|i[t.charCodeAt(r+3)],l[u++]=e>>16&255,l[u++]=e>>8&255,l[u++]=255&e;2===s&&(e=i[t.charCodeAt(r)]<<2|i[t.charCodeAt(r+1)]>>4,l[u++]=255&e);1===s&&(e=i[t.charCodeAt(r)]<<10|i[t.charCodeAt(r+1)]<<4|i[t.charCodeAt(r+2)]>>2,l[u++]=e>>8&255,l[u++]=255&e);return l},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],80:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],81:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],82:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":90}],83:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c,u,f=0;if(i(e))c=e.clone();else if(\"string\"==typeof e)c=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))c=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),f-=256;c=a(e)}}if(n(r))c.mul(r[1]),u=r[0].clone();else if(i(r))u=r.clone();else if(\"string\"==typeof r)u=o(r);else if(r)if(r===Math.floor(r))u=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),f+=256;u=a(r)}else u=a(1);f>0?c=c.ushln(f):f<0&&(u=u.ushln(-f));return s(c,u)}},{\"./div\":82,\"./is-rat\":84,\"./lib/is-bn\":88,\"./lib/num-to-bn\":89,\"./lib/rationalize\":90,\"./lib/str-to-bn\":91}],84:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":88}],85:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":99}],86:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":85}],87:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":97,\"double-bits\":173}],88:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":99}],89:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":99,\"double-bits\":173}],90:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":85,\"./num-to-bn\":89}],91:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":99}],92:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],93:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":85}],94:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],95:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,f=n(l.ushln(u).divRound(r));return c*(s+f*Math.pow(2,-u))}var h=r.bitLength()-l.bitLength()+53;f=n(l.ushln(h).divRound(r));return h<1023?c*f*Math.pow(2,-h):(f*=Math.pow(2,-1023),c*f*Math.pow(2,1023-h))}},{\"./lib/bn-to-num\":86,\"./lib/ctz\":87}],96:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],97:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],98:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,f,h,p,d,g,m=null==e.cutoff?.25:e.cutoff,v=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(f=(h=t).getContext(\"2d\"),r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(h=t.canvas,f=t,r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),T=Array(s+1),k=Array(s);for(d=0,g=r*o;d<g;d++){var M=l[d];x[d]=1===M?0:0===M?i:Math.pow(Math.max(0,.5-M),2),b[d]=1===M?i:0===M?0:Math.pow(Math.max(0,M-.5),2)}a(x,r,o,_,w,k,T),a(b,r,o,_,w,k,T);var A=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)A[d]=n(1-((x[d]-b[d])/v+m),0,1);return A};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:120}],99:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var f=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)f*=e;this.imuln(f),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],f=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function h(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,f=67108863&l,h=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=h;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+f)/67108864|0,f=67108863&o}r.words[c]=0|f,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var h=u[t],p=f[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[h-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],f=8191&u,h=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,m=0|o[2],v=8191&m,y=m>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],T=8191&w,k=w>>>13,M=0|o[5],A=8191&M,S=M>>>13,E=0|o[6],C=8191&E,L=E>>>13,I=0|o[7],P=8191&I,z=I>>>13,O=0|o[8],D=8191&O,R=O>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,Q=0|s[4],$=8191&Q,tt=Q>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ft=8191&ut,ht=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var mt=(c+(n=Math.imul(f,U))|0)+((8191&(i=(i=Math.imul(f,V))+Math.imul(h,U)|0))<<13)|0;c=((a=Math.imul(h,V))+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var vt=(c+(n=n+Math.imul(f,H)|0)|0)+((8191&(i=(i=i+Math.imul(f,G)|0)+Math.imul(h,H)|0))<<13)|0;c=((a=a+Math.imul(h,G)|0)+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(v,U),i=(i=Math.imul(v,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(f,W)|0)|0)+((8191&(i=(i=i+Math.imul(f,X)|0)+Math.imul(h,W)|0))<<13)|0;c=((a=a+Math.imul(h,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(v,H)|0,i=(i=i+Math.imul(v,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(f,J)|0)|0)+((8191&(i=(i=i+Math.imul(f,K)|0)+Math.imul(h,J)|0))<<13)|0;c=((a=a+Math.imul(h,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(T,U),i=(i=Math.imul(T,V))+Math.imul(k,U)|0,a=Math.imul(k,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(v,W)|0,i=(i=i+Math.imul(v,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(f,$)|0)|0)+((8191&(i=(i=i+Math.imul(f,tt)|0)+Math.imul(h,$)|0))<<13)|0;c=((a=a+Math.imul(h,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(A,U),i=(i=Math.imul(A,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(T,H)|0,i=(i=i+Math.imul(T,G)|0)+Math.imul(k,H)|0,a=a+Math.imul(k,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(v,J)|0,i=(i=i+Math.imul(v,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,$)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,$)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(f,rt)|0)|0)+((8191&(i=(i=i+Math.imul(f,nt)|0)+Math.imul(h,rt)|0))<<13)|0;c=((a=a+Math.imul(h,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(A,H)|0,i=(i=i+Math.imul(A,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(T,W)|0,i=(i=i+Math.imul(T,X)|0)+Math.imul(k,W)|0,a=a+Math.imul(k,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(v,$)|0,i=(i=i+Math.imul(v,tt)|0)+Math.imul(y,$)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(f,at)|0)|0)+((8191&(i=(i=i+Math.imul(f,ot)|0)+Math.imul(h,at)|0))<<13)|0;c=((a=a+Math.imul(h,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(P,U),i=(i=Math.imul(P,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(A,W)|0,i=(i=i+Math.imul(A,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(T,J)|0,i=(i=i+Math.imul(T,K)|0)+Math.imul(k,J)|0,a=a+Math.imul(k,K)|0,n=n+Math.imul(b,$)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,$)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(v,rt)|0,i=(i=i+Math.imul(v,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var Tt=(c+(n=n+Math.imul(f,lt)|0)|0)+((8191&(i=(i=i+Math.imul(f,ct)|0)+Math.imul(h,lt)|0))<<13)|0;c=((a=a+Math.imul(h,ct)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(P,H)|0,i=(i=i+Math.imul(P,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(A,J)|0,i=(i=i+Math.imul(A,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(T,$)|0,i=(i=i+Math.imul(T,tt)|0)+Math.imul(k,$)|0,a=a+Math.imul(k,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(v,at)|0,i=(i=i+Math.imul(v,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var kt=(c+(n=n+Math.imul(f,ft)|0)|0)+((8191&(i=(i=i+Math.imul(f,ht)|0)+Math.imul(h,ft)|0))<<13)|0;c=((a=a+Math.imul(h,ht)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(P,W)|0,i=(i=i+Math.imul(P,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(A,$)|0,i=(i=i+Math.imul(A,tt)|0)+Math.imul(S,$)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(T,rt)|0,i=(i=i+Math.imul(T,nt)|0)+Math.imul(k,rt)|0,a=a+Math.imul(k,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(v,lt)|0,i=(i=i+Math.imul(v,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ft)|0,i=(i=i+Math.imul(d,ht)|0)+Math.imul(g,ft)|0,a=a+Math.imul(g,ht)|0;var Mt=(c+(n=n+Math.imul(f,dt)|0)|0)+((8191&(i=(i=i+Math.imul(f,gt)|0)+Math.imul(h,dt)|0))<<13)|0;c=((a=a+Math.imul(h,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(P,J)|0,i=(i=i+Math.imul(P,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,$)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,$)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(A,rt)|0,i=(i=i+Math.imul(A,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(T,at)|0,i=(i=i+Math.imul(T,ot)|0)+Math.imul(k,at)|0,a=a+Math.imul(k,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(v,ft)|0,i=(i=i+Math.imul(v,ht)|0)+Math.imul(y,ft)|0,a=a+Math.imul(y,ht)|0;var At=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(P,$)|0,i=(i=i+Math.imul(P,tt)|0)+Math.imul(z,$)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(A,at)|0,i=(i=i+Math.imul(A,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(T,lt)|0,i=(i=i+Math.imul(T,ct)|0)+Math.imul(k,lt)|0,a=a+Math.imul(k,ct)|0,n=n+Math.imul(b,ft)|0,i=(i=i+Math.imul(b,ht)|0)+Math.imul(_,ft)|0,a=a+Math.imul(_,ht)|0;var St=(c+(n=n+Math.imul(v,dt)|0)|0)+((8191&(i=(i=i+Math.imul(v,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,$)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,$)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(P,rt)|0,i=(i=i+Math.imul(P,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(A,lt)|0,i=(i=i+Math.imul(A,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(T,ft)|0,i=(i=i+Math.imul(T,ht)|0)+Math.imul(k,ft)|0,a=a+Math.imul(k,ht)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,$),i=(i=Math.imul(B,tt))+Math.imul(N,$)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(P,at)|0,i=(i=i+Math.imul(P,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(A,ft)|0,i=(i=i+Math.imul(A,ht)|0)+Math.imul(S,ft)|0,a=a+Math.imul(S,ht)|0;var Ct=(c+(n=n+Math.imul(T,dt)|0)|0)+((8191&(i=(i=i+Math.imul(T,gt)|0)+Math.imul(k,dt)|0))<<13)|0;c=((a=a+Math.imul(k,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(P,lt)|0,i=(i=i+Math.imul(P,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ft)|0,i=(i=i+Math.imul(C,ht)|0)+Math.imul(L,ft)|0,a=a+Math.imul(L,ht)|0;var Lt=(c+(n=n+Math.imul(A,dt)|0)|0)+((8191&(i=(i=i+Math.imul(A,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(P,ft)|0,i=(i=i+Math.imul(P,ht)|0)+Math.imul(z,ft)|0,a=a+Math.imul(z,ht)|0;var It=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(It>>>26)|0,It&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ft)|0,i=(i=i+Math.imul(D,ht)|0)+Math.imul(R,ft)|0,a=a+Math.imul(R,ht)|0;var Pt=(c+(n=n+Math.imul(P,dt)|0)|0)+((8191&(i=(i=i+Math.imul(P,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,ft),i=(i=Math.imul(B,ht))+Math.imul(N,ft)|0,a=Math.imul(N,ht);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var Ot=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,l[0]=mt,l[1]=vt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=Tt,l[8]=kt,l[9]=Mt,l[10]=At,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=It,l[16]=Pt,l[17]=zt,l[18]=Ot,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=h),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?h(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,f=(0|t.words[u])*(0|e.words[c]),h=67108863&f;s=67108863&(h=h+s|0),i+=(o=(o=o+(f/67108864|0)|0)+(h>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var f=l,h=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],m=r[u+p+o],v=n[u+p+o],y=f*m-h*v;v=f*v+h*m,m=y,r[u+p]=d+m,n[u+p]=g+v,r[u+p+o]=d-m,n[u+p+o]=g-v,p!==s&&(y=l*f-c*h,h=l*h+c*f,f=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),f=new Array(n),h=r.words;h.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,f,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*f[p];l[p]=s[p]*f[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,h,a,n,i),this.conjugate(h,a,n),this.normalize13b(h,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var f=0|this.words[c];this.words[c]=u<<26-a|f>>>a,u=f&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var f=l-1;f>=0;f--){var h=67108864*(0|n.words[i.length+f])+(0|n.words[i.length+f-1]);for(h=Math.min(h/o|0,67108863),n._ishlnsubmul(i,h,f);0!==n.negative;)h--,n.negative=0,n._ishlnsubmul(i,1,f),n.isZero()||(n.negative^=1);s&&(s.words[f]=h)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),f=e.clone();!e.isZero();){for(var h=0,p=1;0==(e.words[0]&p)&&h<26;++h,p<<=1);if(h>0)for(e.iushrn(h);h-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(f)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(f)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var f=0,h=1;0==(r.words[0]&h)&&f<26;++f,h<<=1);if(f>0)for(r.iushrn(f);f-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var m={k256:null,p224:null,p192:null,p25519:null};function v(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){v.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){v.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){v.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){v.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function T(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}v.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},v.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},v.prototype.split=function(t,e){t.iushrn(this.n,0,e)},v.prototype.imulK=function(t){return t.imul(this.k)},i(y,v),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,v),i(b,v),i(_,v),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(m[t])return m[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return m[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var f=this.pow(u,i),h=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,m=0;0!==g.cmp(s);m++)g=g.redSqr();n(m<d);var v=this.pow(f,new a(1).iushln(d-m-1));h=h.redMul(v),f=v.redSqr(),p=p.redMul(f),d=m}return h},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var f=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==f||0!==o?(o<<=1,o|=f,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new T(t)},i(T,w),T.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},T.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},T.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},T.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},T.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:108}],100:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),f=0;for(n=0;n<c;++n)n!==r&&(u[f++]=l[n]);if(1&r){var h=u[1];u[1]=u[0],u[0]=h}}}return o}},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return f(t);case 2:return\"function\"==typeof e?c(t,t,e,!0):h(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var f,h=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,h,p))>0){if(1===u&&n)a.init(s),f=a.sweepComplete(u,r,0,s,h,p,0,s,h,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),f=1===u?a.sweepBipartite(u,r,0,s,h,p,0,c,d,g):o(u,r,n,s,h,p,c,d,g),i.free(d),i.free(g))}i.free(h),i.free(p)}return f}}}function u(t,e){n.push([t,e])}function f(t){return n=[],c(t,t,u,!0),n}function h(t,e){return n=[],c(t,e,u,!1),n}},{\"./lib/intersect\":103,\"./lib/sweep\":107,\"typedarray-pool\":595}],102:[function(t,e,r){\"use strict\";var n=[\"d\",\"ax\",\"vv\",\"rs\",\"re\",\"rb\",\"ri\",\"bs\",\"be\",\"bb\",\"bi\"];function i(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],i=n.slice();t||i.splice(3,0,\"fp\");var a=[\"function \"+e+\"(\"+i.join()+\"){\"];function o(e,i){var o=function(t,e,r){var i=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),a=[\"function \",i,\"(\",n.join(),\"){\",\"var \",\"es\",\"=2*\",\"d\",\";\"],o=\"for(var i=rs,rp=es*rs;i<re;++i,rp+=es){var x0=rb[ax+rp],x1=rb[ax+rp+d],xi=ri[i];\",s=\"for(var j=bs,bp=es*bs;j<be;++j,bp+=es){var y0=bb[ax+bp],\"+(r?\"y1=bb[ax+bp+d],\":\"\")+\"yi=bi[j];\";return t?a.push(o,\"Q\",\":\",s):a.push(s,\"Q\",\":\",o),r?a.push(\"if(y1<x0||x1<y0)continue;\"):e?a.push(\"if(y0<=x0||x1<y0)continue;\"):a.push(\"if(y0<x0||x1<y0)continue;\"),a.push(\"for(var k=ax+1;k<d;++k){var r0=rb[k+rp],r1=rb[k+d+rp],b0=bb[k+bp],b1=bb[k+d+bp];if(r1<b0||b1<r0)continue Q;}var rv=vv(\"),e?a.push(\"yi,xi\"):a.push(\"xi,yi\"),a.push(\");if(rv!==void 0)return rv;}}}\"),{name:i,code:a.join(\"\")}}(e,i,t);r.push(o.code),a.push(\"return \"+o.name+\"(\"+n.join()+\");\")}a.push(\"if(re-rs>be-bs){\"),t?(o(!0,!1),a.push(\"}else{\"),o(!1,!1)):(a.push(\"if(fp){\"),o(!0,!0),a.push(\"}else{\"),o(!0,!1),a.push(\"}}else{if(fp){\"),o(!1,!0),a.push(\"}else{\"),o(!1,!1),a.push(\"}\")),a.push(\"}}return \"+e);var s=r.join(\"\")+a.join(\"\");return new Function(s)()}r.partial=i(!1),r.full=i(!0)},{}],103:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,w,T,k,M){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(6*r);v.length<a&&(n.free(v),v=n.mallocInt32(a));var o=i.nextPow2(2*r);y.length<o&&(n.free(y),y=n.mallocDouble(o))}(t,a+T);var A,S=0,E=2*t;x(S++,0,0,a,0,T,r?16:0,-1/0,1/0),r||x(S++,0,0,T,0,a,1,-1/0,1/0);for(;S>0;){var C=6*(S-=1),L=v[C],I=v[C+1],P=v[C+2],z=v[C+3],O=v[C+4],D=v[C+5],R=2*S,F=y[R],B=y[R+1],N=1&D,j=!!(16&D),U=u,V=w,q=k,H=M;if(N&&(U=k,V=M,q=u,H=w),!(2&D&&(P=p(t,L,I,P,U,V,B),I>=P)||4&D&&(I=d(t,L,I,P,U,V,F))>=P)){var G=P-I,Y=O-z;if(j){if(t*G*(G+Y)<1<<22){if(void 0!==(A=l.scanComplete(t,L,e,I,P,U,V,z,O,q,H)))return A;continue}}else{if(t*Math.min(G,Y)<128){if(void 0!==(A=o(t,L,e,N,I,P,U,V,z,O,q,H)))return A;continue}if(t*G*Y<1<<22){if(void 0!==(A=l.scanBipartite(t,L,e,N,I,P,U,V,z,O,q,H)))return A;continue}}var W=f(t,L,I,P,U,V,F,B);if(I<W)if(t*(W-I)<128){if(void 0!==(A=s(t,L+1,e,I,W,U,V,z,O,q,H)))return A}else if(L===t-2){if(void 0!==(A=N?l.sweepBipartite(t,e,z,O,q,H,I,W,U,V):l.sweepBipartite(t,e,I,W,U,V,z,O,q,H)))return A}else x(S++,L+1,I,W,z,O,N,-1/0,1/0),x(S++,L+1,z,O,I,W,1^N,-1/0,1/0);if(W<P){var X=c(t,L,z,O,q,H),Z=q[E*X+L],J=h(t,L,X,O,q,H,Z);if(J<O&&x(S++,L,W,P,J,O,(4|N)+(j?16:0),Z,B),z<X&&x(S++,L,W,P,z,X,(2|N)+(j?16:0),F,Z),X+1===J){if(void 0!==(A=j?_(t,L,e,W,P,U,V,X,q,H[X]):b(t,L,e,N,W,P,U,V,X,q,H[X])))return A}else if(X<J){var K;if(j){if(K=g(t,L,W,P,U,V,Z),W<K){var Q=h(t,L,W,K,U,V,Z);if(L===t-2){if(W<Q&&void 0!==(A=l.sweepComplete(t,e,W,Q,U,V,X,J,q,H)))return A;if(Q<K&&void 0!==(A=l.sweepBipartite(t,e,Q,K,U,V,X,J,q,H)))return A}else W<Q&&x(S++,L+1,W,Q,X,J,16,-1/0,1/0),Q<K&&(x(S++,L+1,Q,K,X,J,0,-1/0,1/0),x(S++,L+1,X,J,Q,K,1,-1/0,1/0))}}else K=N?m(t,L,W,P,U,V,Z):g(t,L,W,P,U,V,Z),W<K&&(L===t-2?A=N?l.sweepBipartite(t,e,X,J,q,H,W,K,U,V):l.sweepBipartite(t,e,W,K,U,V,X,J,q,H):(x(S++,L+1,W,K,X,J,N,-1/0,1/0),x(S++,L+1,X,J,W,K,1^N,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),f=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),h=u(\"lo===p0\",[\"p0\"]),p=u(\"lo<p0\",[\"p0\"]),d=u(\"hi<=p0\",[\"p0\"]),g=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),m=u(\"lo<p0&&p0<=hi\",[\"p0\"]),v=n.mallocInt32(1024),y=n.mallocDouble(1024);function x(t,e,r,n,i,a,o,s,l){var c=6*t;v[c]=e,v[c+1]=r,v[c+2]=n,v[c+3]=i,v[c+4]=a,v[c+5]=o;var u=2*t;y[u]=s,y[u+1]=l}function b(t,e,r,n,i,a,o,s,l,c,u){var f=2*t,h=l*f,p=c[h+e];t:for(var d=i,g=i*f;d<a;++d,g+=f){var m=o[g+e],v=o[g+e+t];if(!(p<m||v<p)&&(!n||p!==m)){for(var y,x=s[d],b=e+1;b<t;++b){m=o[g+b],v=o[g+b+t];var _=c[h+b],w=c[h+b+t];if(v<_||w<m)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function _(t,e,r,n,i,a,o,s,l,c){var u=2*t,f=s*u,h=l[f+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var m=a[d+e],v=a[d+e+t];if(!(h<m||v<h)){for(var y=e+1;y<t;++y){m=a[d+y],v=a[d+y+t];var x=l[f+y],b=l[f+y+t];if(v<x||b<m)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":102,\"./median\":104,\"./partition\":105,\"./sweep\":107,\"bit-twiddle\":97,\"typedarray-pool\":595}],104:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,o,s){if(a<=r+1)return r;var l=r,c=a,u=a+r>>>1,f=2*t,h=u,p=o[f*u+e];for(;l<c;){if(c-l<8){i(t,e,l,c,o,s),p=o[f*u+e];break}var d=c-l,g=Math.random()*d+l|0,m=o[f*g+e],v=Math.random()*d+l|0,y=o[f*v+e],x=Math.random()*d+l|0,b=o[f*x+e];m<=y?b>=y?(h=v,p=y):m>=b?(h=g,p=m):(h=x,p=b):y>=b?(h=v,p=y):b>=m?(h=g,p=m):(h=x,p=b);for(var _=f*(c-1),w=f*h,T=0;T<f;++T,++_,++w){var k=o[_];o[_]=o[w],o[w]=k}var M=s[c-1];s[c-1]=s[h],s[h]=M,h=n(t,e,l,c-1,o,s,p);for(_=f*(c-1),w=f*h,T=0;T<f;++T,++_,++w){k=o[_];o[_]=o[w],o[w]=k}M=s[c-1];if(s[c-1]=s[h],s[h]=M,u<h){for(c=h-1;l<c&&o[f*(c-1)+e]===p;)c-=1;c+=1}else{if(!(h<u))break;for(l=h+1;l<c&&o[f*l+e]===p;)l+=1}}return n(t,e,r,u,o,s,o[f*u+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]);function i(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,f=o*(l-1);u>r&&i[f+e]>c;--u,f-=o){for(var h=f,p=f+o,d=0;d<o;++d,++h,++p){var g=i[h];i[h]=i[p],i[p]=g}var m=a[u];a[u]=a[u-1],a[u-1]=m}}},{\"./partition\":105}],105:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),n=[];t.indexOf(\"lo\")>=0&&n.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&n.push(\"hi=e[k+o]\");return r.push(\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\".replace(\"_\",n.join()).replace(\"$\",t)),Function.apply(void 0,r)}},{}],106:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=128?n(0,e-1,t):function t(e,r,u){var f=(r-e+1)/6|0,h=e+f,p=r-f,d=e+r>>1,g=d-f,m=d+f,v=h,y=g,x=d,b=m,_=p,w=e+1,T=r-1,k=0;l(v,y,u)&&(k=v,v=y,y=k);l(b,_,u)&&(k=b,b=_,_=k);l(v,x,u)&&(k=v,v=x,x=k);l(y,x,u)&&(k=y,y=x,x=k);l(v,b,u)&&(k=v,v=b,b=k);l(x,b,u)&&(k=x,x=b,b=k);l(y,_,u)&&(k=y,y=_,_=k);l(y,x,u)&&(k=y,y=x,x=k);l(b,_,u)&&(k=b,b=_,_=k);for(var M=u[2*y],A=u[2*y+1],S=u[2*b],E=u[2*b+1],C=2*v,L=2*x,I=2*_,P=2*h,z=2*d,O=2*p,D=0;D<2;++D){var R=u[C+D],F=u[L+D],B=u[I+D];u[P+D]=R,u[z+D]=F,u[O+D]=B}a(g,e,u),a(m,r,u);for(var N=w;N<=T;++N)if(c(N,M,A,u))N!==w&&i(N,w,u),++w;else if(!c(N,S,E,u))for(;;){if(c(T,S,E,u)){c(T,M,A,u)?(o(N,w,T,u),++w,--T):(i(N,T,u),--T);break}if(--T<N)break}s(e,w-1,M,A,u),s(r,T+1,S,E,u),w-2-e<=32?n(e,w-2,u):t(e,w-2,u);r-(T+2)<=32?n(T+2,r,u):t(T+2,r,u);T-w<=32?n(w,T,u):t(w,T,u)}(0,e-1,t)};function n(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function i(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function a(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function o(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function s(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function l(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function c(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],107:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);o.length<e&&(n.free(o),o=n.mallocInt32(e));s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;h.length<r&&(n.free(h),h=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,u,f,g,m,v){for(var y=0,x=2*t,b=t-1,_=x-1,w=r;w<n;++w){var T=u[w],k=x*w;h[y++]=i[k+b],h[y++]=-(T+1),h[y++]=i[k+_],h[y++]=T}for(w=f;w<g;++w){T=v[w]+(1<<28);var M=x*w;h[y++]=m[M+b],h[y++]=-T,h[y++]=m[M+_],h[y++]=T}var A=y>>>1;a(h,A);var S=0,E=0;for(w=0;w<A;++w){var C=0|h[2*w+1];if(C>=1<<28)p(l,c,E--,C=C-(1<<28)|0);else if(C>=0)p(o,s,S--,C);else if(C<=-(1<<28)){C=-C-(1<<28)|0;for(var L=0;L<S;++L){if(void 0!==(I=e(o[L],C)))return I}d(l,c,E++,C)}else{C=-C-1|0;for(L=0;L<E;++L){var I;if(void 0!==(I=e(C,l[L])))return I}d(o,s,S++,C)}}},sweepComplete:function(t,e,r,n,i,g,m,v,y,x){for(var b=0,_=2*t,w=t-1,T=_-1,k=r;k<n;++k){var M=g[k]+1<<1,A=_*k;h[b++]=i[A+w],h[b++]=-M,h[b++]=i[A+T],h[b++]=M}for(k=m;k<v;++k){M=x[k]+1<<1;var S=_*k;h[b++]=y[S+w],h[b++]=1|-M,h[b++]=y[S+T],h[b++]=1|M}var E=b>>>1;a(h,E);var C=0,L=0,I=0;for(k=0;k<E;++k){var P=0|h[2*k+1],z=1&P;if(k<E-1&&P>>1==h[2*k+3]>>1&&(z=2,k+=1),P<0){for(var O=-(P>>1)-1,D=0;D<I;++D){if(void 0!==(R=e(u[D],O)))return R}if(0!==z)for(D=0;D<C;++D){if(void 0!==(R=e(o[D],O)))return R}if(1!==z)for(D=0;D<L;++D){var R;if(void 0!==(R=e(l[D],O)))return R}0===z?d(o,s,C++,O):1===z?d(l,c,L++,O):2===z&&d(u,f,I++,O)}else{O=(P>>1)-1;0===z?p(o,s,C--,O):1===z?p(l,c,L--,O):2===z&&p(u,f,I--,O)}}},scanBipartite:function(t,e,r,n,i,l,c,u,f,g,m,v){var y=0,x=2*t,b=e,_=e+t,w=1,T=1;n?T=1<<28:w=1<<28;for(var k=i;k<l;++k){var M=k+w,A=x*k;h[y++]=c[A+b],h[y++]=-M,h[y++]=c[A+_],h[y++]=M}for(k=f;k<g;++k){M=k+T;var S=x*k;h[y++]=m[S+b],h[y++]=-M}var E=y>>>1;a(h,E);var C=0;for(k=0;k<E;++k){var L=0|h[2*k+1];if(L<0){var I=!1;if((M=-L)>=1<<28?(I=!n,M-=1<<28):(I=!!n,M-=1),I)d(o,s,C++,M);else{var P=v[M],z=x*M,O=m[z+e+1],D=m[z+e+1+t];t:for(var R=0;R<C;++R){var F=o[R],B=x*F;if(!(D<c[B+e+1]||c[B+e+1+t]<O)){for(var N=e+2;N<t;++N)if(m[z+N+t]<c[B+N]||c[B+N+t]<m[z+N])continue t;var j,U=u[F];if(void 0!==(j=n?r(P,U):r(U,P)))return j}}}}else p(o,s,C--,L-w)}},scanComplete:function(t,e,r,n,i,s,l,c,u,f,p){for(var d=0,g=2*t,m=e,v=e+t,y=n;y<i;++y){var x=y+(1<<28),b=g*y;h[d++]=s[b+m],h[d++]=-x,h[d++]=s[b+v],h[d++]=x}for(y=c;y<u;++y){x=y+1;var _=g*y;h[d++]=f[_+m],h[d++]=-x}var w=d>>>1;a(h,w);var T=0;for(y=0;y<w;++y){var k=0|h[2*y+1];if(k<0){if((x=-k)>=1<<28)o[T++]=x-(1<<28);else{var M=p[x-=1],A=g*x,S=f[A+e+1],E=f[A+e+1+t];t:for(var C=0;C<T;++C){var L=o[C],I=l[L];if(I===M)break;var P=g*L;if(!(E<s[P+e+1]||s[P+e+1+t]<S)){for(var z=e+2;z<t;++z)if(f[A+z+t]<s[P+z]||s[P+z+t]<f[A+z])continue t;var O=r(I,M);if(void 0!==O)return O}}}}else{for(x=k-(1<<28),C=T-1;C>=0;--C)if(o[C]===x){for(z=C+1;z<T;++z)o[z-1]=o[z];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=n.mallocInt32(1024),s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),f=n.mallocInt32(1024),h=n.mallocDouble(8192);function p(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function d(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":106,\"bit-twiddle\":97,\"typedarray-pool\":595}],108:[function(t,e,r){},{}],109:[function(t,e,r){arguments[4][108][0].apply(r,arguments)},{dup:108}],110:[function(t,e,r){\"use strict\";var n,i=\"object\"==typeof Reflect?Reflect:null,a=i&&\"function\"==typeof i.apply?i.apply:function(t,e,r){return Function.prototype.apply.call(t,e,r)};n=i&&\"function\"==typeof i.ownKeys?i.ownKeys:Object.getOwnPropertySymbols?function(t){return Object.getOwnPropertyNames(t).concat(Object.getOwnPropertySymbols(t))}:function(t){return Object.getOwnPropertyNames(t)};var o=Number.isNaN||function(t){return t!=t};function s(){s.init.call(this)}e.exports=s,e.exports.once=function(t,e){return new Promise((function(r,n){function i(){void 0!==a&&t.removeListener(\"error\",a),r([].slice.call(arguments))}var a;\"error\"!==e&&(a=function(r){t.removeListener(e,i),n(r)},t.once(\"error\",a)),t.once(e,i)}))},s.EventEmitter=s,s.prototype._events=void 0,s.prototype._eventsCount=0,s.prototype._maxListeners=void 0;var l=10;function c(t){if(\"function\"!=typeof t)throw new TypeError('The \"listener\" argument must be of type Function. Received type '+typeof t)}function u(t){return void 0===t._maxListeners?s.defaultMaxListeners:t._maxListeners}function f(t,e,r,n){var i,a,o,s;if(c(r),void 0===(a=t._events)?(a=t._events=Object.create(null),t._eventsCount=0):(void 0!==a.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),a=t._events),o=a[e]),void 0===o)o=a[e]=r,++t._eventsCount;else if(\"function\"==typeof o?o=a[e]=n?[r,o]:[o,r]:n?o.unshift(r):o.push(r),(i=u(t))>0&&o.length>i&&!o.warned){o.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+o.length+\" \"+String(e)+\" listeners added. Use emitter.setMaxListeners() to increase limit\");l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=o.length,s=l,console&&console.warn&&console.warn(s)}return t}function h(){if(!this.fired)return this.target.removeListener(this.type,this.wrapFn),this.fired=!0,0===arguments.length?this.listener.call(this.target):this.listener.apply(this.target,arguments)}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=h.bind(n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(void 0===n)return[];var i=n[e];return void 0===i?[]:\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):m(i,i.length)}function g(t){var e=this._events;if(void 0!==e){var r=e[t];if(\"function\"==typeof r)return 1;if(void 0!==r)return r.length}return 0}function m(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}Object.defineProperty(s,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||o(t))throw new RangeError('The value of \"defaultMaxListeners\" is out of range. It must be a non-negative number. Received '+t+\".\");l=t}}),s.init=function(){void 0!==this._events&&this._events!==Object.getPrototypeOf(this)._events||(this._events=Object.create(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0},s.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||o(t))throw new RangeError('The value of \"n\" is out of range. It must be a non-negative number. Received '+t+\".\");return this._maxListeners=t,this},s.prototype.getMaxListeners=function(){return u(this)},s.prototype.emit=function(t){for(var e=[],r=1;r<arguments.length;r++)e.push(arguments[r]);var n=\"error\"===t,i=this._events;if(void 0!==i)n=n&&void 0===i.error;else if(!n)return!1;if(n){var o;if(e.length>0&&(o=e[0]),o instanceof Error)throw o;var s=new Error(\"Unhandled error.\"+(o?\" (\"+o.message+\")\":\"\"));throw s.context=o,s}var l=i[t];if(void 0===l)return!1;if(\"function\"==typeof l)a(l,this,e);else{var c=l.length,u=m(l,c);for(r=0;r<c;++r)a(u[r],this,e)}return!0},s.prototype.addListener=function(t,e){return f(this,t,e,!1)},s.prototype.on=s.prototype.addListener,s.prototype.prependListener=function(t,e){return f(this,t,e,!0)},s.prototype.once=function(t,e){return c(e),this.on(t,p(this,t,e)),this},s.prototype.prependOnceListener=function(t,e){return c(e),this.prependListener(t,p(this,t,e)),this},s.prototype.removeListener=function(t,e){var r,n,i,a,o;if(c(e),void 0===(n=this._events))return this;if(void 0===(r=n[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=Object.create(null):(delete n[t],n.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(i=-1,a=r.length-1;a>=0;a--)if(r[a]===e||r[a].listener===e){o=r[a].listener,i=a;break}if(i<0)return this;0===i?r.shift():function(t,e){for(;e+1<t.length;e++)t[e]=t[e+1];t.pop()}(r,i),1===r.length&&(n[t]=r[0]),void 0!==n.removeListener&&this.emit(\"removeListener\",t,o||e)}return this},s.prototype.off=s.prototype.removeListener,s.prototype.removeAllListeners=function(t){var e,r,n;if(void 0===(r=this._events))return this;if(void 0===r.removeListener)return 0===arguments.length?(this._events=Object.create(null),this._eventsCount=0):void 0!==r[t]&&(0==--this._eventsCount?this._events=Object.create(null):delete r[t]),this;if(0===arguments.length){var i,a=Object.keys(r);for(n=0;n<a.length;++n)\"removeListener\"!==(i=a[n])&&this.removeAllListeners(i);return this.removeAllListeners(\"removeListener\"),this._events=Object.create(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(void 0!==e)for(n=e.length-1;n>=0;n--)this.removeListener(t,e[n]);return this},s.prototype.listeners=function(t){return d(this,t,!0)},s.prototype.rawListeners=function(t){return d(this,t,!1)},s.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},s.prototype.listenerCount=g,s.prototype.eventNames=function(){return this._eventsCount>0?n(this._events):[]}},{}],111:[function(t,e,r){(function(e){(function(){\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "\"use strict\";var e=t(\"base64-js\"),n=t(\"ieee754\");r.Buffer=a,r.SlowBuffer=function(t){+t!=t&&(t=0);return a.alloc(+t)},r.INSPECT_MAX_BYTES=50;function i(t){if(t>2147483647)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var e=new Uint8Array(t);return e.__proto__=a.prototype,e}function a(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return l(t)}return o(t,e,r)}function o(t,e,r){if(\"string\"==typeof t)return function(t,e){\"string\"==typeof e&&\"\"!==e||(e=\"utf8\");if(!a.isEncoding(e))throw new TypeError(\"Unknown encoding: \"+e);var r=0|f(t,e),n=i(r),o=n.write(t,e);o!==r&&(n=n.slice(0,o));return n}(t,e);if(ArrayBuffer.isView(t))return c(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(B(t,ArrayBuffer)||t&&B(t.buffer,ArrayBuffer))return function(t,e,r){if(e<0||t.byteLength<e)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<e+(r||0))throw new RangeError('\"length\" is outside of buffer bounds');var n;n=void 0===e&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,e):new Uint8Array(t,e,r);return n.__proto__=a.prototype,n}(t,e,r);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var n=t.valueOf&&t.valueOf();if(null!=n&&n!==t)return a.from(n,e,r);var o=function(t){if(a.isBuffer(t)){var e=0|u(t.length),r=i(e);return 0===r.length||t.copy(r,0,0,e),r}if(void 0!==t.length)return\"number\"!=typeof t.length||N(t.length)?i(0):c(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return c(t.data)}(t);if(o)return o;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return a.from(t[Symbol.toPrimitive](\"string\"),e,r);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function s(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function l(t){return s(t),i(t<0?0:0|u(t))}function c(t){for(var e=t.length<0?0:0|u(t.length),r=i(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function u(t){if(t>=2147483647)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+2147483647..toString(16)+\" bytes\");return 0|t}function f(t,e){if(a.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||B(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var r=t.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===r)return 0;for(var i=!1;;)switch(e){case\"ascii\":case\"latin1\":case\"binary\":return r;case\"utf8\":case\"utf-8\":return D(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*r;case\"hex\":return r>>>1;case\"base64\":return R(t).length;default:if(i)return n?-1:D(t).length;e=(\"\"+e).toLowerCase(),i=!0}}function h(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return A(this,e,r);case\"utf8\":case\"utf-8\":return T(this,e,r);case\"ascii\":return k(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return S(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,e,r,n,i){if(0===t.length)return-1;if(\"string\"==typeof r?(n=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),N(r=+r)&&(r=i?0:t.length-1),r<0&&(r=t.length+r),r>=t.length){if(i)return-1;r=t.length-1}else if(r<0){if(!i)return-1;r=0}if(\"string\"==typeof e&&(e=a.from(e,n)),a.isBuffer(e))return 0===e.length?-1:g(t,e,r,n,i);if(\"number\"==typeof e)return e&=255,\"function\"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,e,r):Uint8Array.prototype.lastIndexOf.call(t,e,r):g(t,[e],r,n,i);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var f=!0,h=0;h<l;h++)if(c(t,a+h)!==c(e,h)){f=!1;break}if(f)return a}return-1}function m(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(N(s))return o;t[r+o]=s}return o}function v(t,e,r,n){return F(D(e,t.length-r),t,r,n)}function y(t,e,r,n){return F(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return F(R(e),t,r,n)}function _(t,e,r,n){return F(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,r,n){return 0===r&&n===t.length?e.fromByteArray(t):e.fromByteArray(t.slice(r,n))}function T(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,f=c>239?4:c>223?3:c>191?2:1;if(i+f<=r)switch(f){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,f=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=f}return function(t){var e=t.length;if(e<=4096)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=4096));return r}(n)}r.kMaxLength=2147483647,a.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),a.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(a.prototype,\"parent\",{enumerable:!0,get:function(){if(a.isBuffer(this))return this.buffer}}),Object.defineProperty(a.prototype,\"offset\",{enumerable:!0,get:function(){if(a.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&a[Symbol.species]===a&&Object.defineProperty(a,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),a.poolSize=8192,a.from=function(t,e,r){return o(t,e,r)},a.prototype.__proto__=Uint8Array.prototype,a.__proto__=Uint8Array,a.alloc=function(t,e,r){return function(t,e,r){return s(t),t<=0?i(t):void 0!==e?\"string\"==typeof r?i(t).fill(e,r):i(t).fill(e):i(t)}(t,e,r)},a.allocUnsafe=function(t){return l(t)},a.allocUnsafeSlow=function(t){return l(t)},a.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==a.prototype},a.compare=function(t,e){if(B(t,Uint8Array)&&(t=a.from(t,t.offset,t.byteLength)),B(e,Uint8Array)&&(e=a.from(e,e.offset,e.byteLength)),!a.isBuffer(t)||!a.isBuffer(e))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===e)return 0;for(var r=t.length,n=e.length,i=0,o=Math.min(r,n);i<o;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0},a.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},a.concat=function(t,e){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return a.alloc(0);var r;if(void 0===e)for(e=0,r=0;r<t.length;++r)e+=t[r].length;var n=a.allocUnsafe(e),i=0;for(r=0;r<t.length;++r){var o=t[r];if(B(o,Uint8Array)&&(o=a.from(o)),!a.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(n,i),i+=o.length}return n},a.byteLength=f,a.prototype._isBuffer=!0,a.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},a.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},a.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},a.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?T(this,0,t):h.apply(this,arguments)},a.prototype.toLocaleString=a.prototype.toString,a.prototype.equals=function(t){if(!a.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===a.compare(this,t)},a.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},a.prototype.compare=function(t,e,r,n,i){if(B(t,Uint8Array)&&(t=a.from(t,t.offset,t.byteLength)),!a.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===e&&(e=0),void 0===r&&(r=t?t.length:0),void 0===n&&(n=0),void 0===i&&(i=this.length),e<0||r>t.length||n<0||i>this.length)throw new RangeError(\"out of range index\");if(n>=i&&e>=r)return 0;if(n>=i)return-1;if(e>=r)return 1;if(this===t)return 0;for(var o=(i>>>=0)-(n>>>=0),s=(r>>>=0)-(e>>>=0),l=Math.min(o,s),c=this.slice(n,i),u=t.slice(e,r),f=0;f<l;++f)if(c[f]!==u[f]){o=c[f],s=u[f];break}return o<s?-1:s<o?1:0},a.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},a.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},a.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},a.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return m(this,t,e,r);case\"utf8\":case\"utf-8\":return v(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},a.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};function k(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function A(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=O(t[a]);return i}function S(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function E(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function C(t,e,r,n,i,o){if(!a.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(e>i||e<o)throw new RangeError('\"value\" argument is out of bounds');if(r+n>t.length)throw new RangeError(\"Index out of range\")}function L(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function I(t,e,r,i,a){return e=+e,r>>>=0,a||L(t,0,r,4),n.write(t,e,r,i,23,4),r+4}function P(t,e,r,i,a){return e=+e,r>>>=0,a||L(t,0,r,8),n.write(t,e,r,i,52,8),r+8}a.prototype.slice=function(t,e){var r=this.length;(t=~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),(e=void 0===e?r:~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),e<t&&(e=t);var n=this.subarray(t,e);return n.__proto__=a.prototype,n},a.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},a.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},a.prototype.readUInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),this[t]},a.prototype.readUInt16LE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]|this[t+1]<<8},a.prototype.readUInt16BE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]<<8|this[t+1]},a.prototype.readUInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},a.prototype.readUInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},a.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},a.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},a.prototype.readInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},a.prototype.readInt16LE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},a.prototype.readInt16BE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},a.prototype.readInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},a.prototype.readInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},a.prototype.readFloatLE=function(t,e){return t>>>=0,e||E(t,4,this.length),n.read(this,t,!0,23,4)},a.prototype.readFloatBE=function(t,e){return t>>>=0,e||E(t,4,this.length),n.read(this,t,!1,23,4)},a.prototype.readDoubleLE=function(t,e){return t>>>=0,e||E(t,8,this.length),n.read(this,t,!0,52,8)},a.prototype.readDoubleBE=function(t,e){return t>>>=0,e||E(t,8,this.length),n.read(this,t,!1,52,8)},a.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||C(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},a.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||C(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},a.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,1,255,0),this[e]=255&t,e+1},a.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},a.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},a.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},a.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},a.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);C(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},a.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);C(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},a.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},a.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},a.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},a.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},a.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},a.prototype.writeFloatLE=function(t,e,r){return I(this,t,e,!0,r)},a.prototype.writeFloatBE=function(t,e,r){return I(this,t,e,!1,r)},a.prototype.writeDoubleLE=function(t,e,r){return P(this,t,e,!0,r)},a.prototype.writeDoubleBE=function(t,e,r){return P(this,t,e,!1,r)},a.prototype.copy=function(t,e,r,n){if(!a.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(r||(r=0),n||0===n||(n=this.length),e>=t.length&&(e=t.length),e||(e=0),n>0&&n<r&&(n=r),n===r)return 0;if(0===t.length||0===this.length)return 0;if(e<0)throw new RangeError(\"targetStart out of bounds\");if(r<0||r>=this.length)throw new RangeError(\"Index out of range\");if(n<0)throw new RangeError(\"sourceEnd out of bounds\");n>this.length&&(n=this.length),t.length-e<n-r&&(n=t.length-e+r);var i=n-r;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(e,r,n);else if(this===t&&r<e&&e<n)for(var o=i-1;o>=0;--o)t[o+e]=this[o+r];else Uint8Array.prototype.set.call(t,this.subarray(r,n),e);return i},a.prototype.fill=function(t,e,r,n){if(\"string\"==typeof t){if(\"string\"==typeof e?(n=e,e=0,r=this.length):\"string\"==typeof r&&(n=r,r=this.length),void 0!==n&&\"string\"!=typeof n)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof n&&!a.isEncoding(n))throw new TypeError(\"Unknown encoding: \"+n);if(1===t.length){var i=t.charCodeAt(0);(\"utf8\"===n&&i<128||\"latin1\"===n)&&(t=i)}}else\"number\"==typeof t&&(t&=255);if(e<0||this.length<e||this.length<r)throw new RangeError(\"Out of range index\");if(r<=e)return this;var o;if(e>>>=0,r=void 0===r?this.length:r>>>0,t||(t=0),\"number\"==typeof t)for(o=e;o<r;++o)this[o]=t;else{var s=a.isBuffer(t)?t:a.from(t,n),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<r-e;++o)this[o+e]=s[o%l]}return this};var z=/[^+/0-9A-Za-z-_]/g;function O(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function D(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function R(t){return e.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(z,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function F(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function B(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function N(t){return t!=t}}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":79,buffer:111,ieee754:442}],112:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),f=!!c(r,\"interior\",!0),h=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!f&&!h||0===t.length)return[];var d=n(t,e);if(u||f!==h||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),m=0;m<d.length;++m){var v=d[m];g.addTriangle(v[0],v[1],v[2])}return u&&a(t,g),h?f?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":113,\"./lib/filter\":114,\"./lib/monotone\":115,\"./lib/triangulation\":116}],113:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){if(!((p=l[c])<s)&&!e.isConstraint(s,p)){for(var u=l[c-1],f=-1,h=1;h<l.length;h+=2)if(l[h-1]===p){f=l[h];break}f<0||n(t[s],t[p],t[u],t[f])<0&&r.push(s,p)}}for(;r.length>0;){for(var p=r.pop(),d=(s=r.pop(),u=-1,f=-1,l=o[s],1);d<l.length;d+=2){var g=l[d-1],m=l[d];g===p?f=m:m===p&&(u=g)}u<0||f<0||(n(t[s],t[p],t[u],t[f])>=0||(e.flip(s,p),i(t,e,r,u,s,f),i(t,e,r,s,f,u),i(t,e,r,f,p,u),i(t,e,r,p,u,f)))}}},{\"binary-search-bounds\":96,\"robust-in-sphere\":546}],114:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=(v=r[i])[0],l=v[1],c=v[2];l<c?l<s&&(v[0]=l,v[1]=c,v[2]=s):c<s&&(v[0]=c,v[1]=s,v[2]=l)}r.sort(o);var u=new Array(n);for(i=0;i<u.length;++i)u[i]=0;var f=[],h=[],p=new Array(3*n),d=new Array(3*n),g=null;e&&(g=[]);var m=new a(r,p,d,u,f,h,g);for(i=0;i<n;++i)for(var v=r[i],y=0;y<3;++y){s=v[y],l=v[(y+1)%3];var x=p[3*i+y]=m.locate(l,s,t.opposite(l,s)),b=d[3*i+y]=t.isConstraint(s,l);x<0&&(b?h.push(i):(f.push(i),u[i]=1),e&&g.push([l,s,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,f=n.constraint,h=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=h[3*p+d];g>=0&&0===c[g]&&(f[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var m=l;l=s,s=m,l.length=0,i=-i}var v=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return v.concat(n.boundary);return v},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":96}],115:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3];function a(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function o(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function s(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(0!==t.type&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function l(t,e){return i(t.a,t.b,e)}function c(t,e,r,a,o){for(var s=n.lt(e,a,l),c=n.gt(e,a,l),u=s;u<c;++u){for(var f=e[u],h=f.lowerIds,p=h.length;p>1&&i(r[h[p-2]],r[h[p-1]],a)>0;)t.push([h[p-1],h[p-2],o]),p-=1;h.length=p,h.push(o);var d=f.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function u(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function f(t,e,r){var i=n.le(t,r,u),o=t[i],s=o.upperIds,l=s[s.length-1];o.upperIds=[l],t.splice(i+1,0,new a(r.a,r.b,r.idx,[l],s))}function h(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,u),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],l=0;l<r;++l)i.push(new o(t[l],null,0,l));for(l=0;l<n;++l){var u=e[l],p=t[u[0]],d=t[u[1]];p[0]<d[0]?i.push(new o(p,d,2,l),new o(d,p,1,l)):p[0]>d[0]&&i.push(new o(d,p,2,l),new o(p,d,1,l))}i.sort(s);for(var g=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),m=[new a([g,1],[g,0],-1,[],[],[],[])],v=[],y=(l=0,i.length);l<y;++l){var x=i[l],b=x.type;0===b?c(v,m,t,x.a,x.idx):2===b?f(m,t,x):h(m,t,x)}return v}},{\"binary-search-bounds\":96,\"robust-orientation\":548}],116:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":96}],117:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],118:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,f=c[e+1];for(s=0;s<f.length;++s)u+=f[s];var h=new Array(e);for(s=0;s<e;++s){f=c[s];var p=0;for(l=0;l<f.length;++l)p+=f[l];h[s]=p/u}return h}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:176,\"robust-linear-solve\":547}],119:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:118}],120:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],121:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return v(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(a=0;a<e.length;++a){o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),f=t(\"./lib/rat-seg-intersect\");function h(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],f=h(c[0]),p=h(c[1]);s.push([u(f[0],-1/0),u(p[0],-1/0),u(f[1],1/0),u(p[1],1/0)])}i(s,(function(t,e){o.link(t,e)}));var d=!0,g=new Array(a);for(l=0;l<a;++l){(v=o.find(l))!==l&&(d=!1,t[v]=[Math.min(t[l][0],t[v][0]),Math.min(t[l][1],t[v][1])])}if(d)return null;var m=0;for(l=0;l<a;++l){var v;(v=o.find(l))===l?(g[l]=m,t[m++]=t[l]):g[l]=-1}t.length=m;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function m(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function v(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(m):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),h=function(t,e,r){var n=[];return i(r,(function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],f=t[s[1]];a(l,c,u,f)&&n.push([r,i])}})),n}(t,e,n),g=p(t),m=function(t,e,r,n){var o=[];return i(r,n,(function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}})),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,h=t.map((function(t){return[o(t[0]),o(t[1])]}));for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],m=e[d],v=f(c(t[g[0]]),c(t[g[1]]),c(t[m[0]]),c(t[m[1]]));if(v){var y=t.length;t.push([l(v[0]),l(v[1])]),h.push(v),n.push([u,y],[d,y])}}for(n.sort((function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=h[t[1]],n=h[e[1]];return s(r[0],n[0])||s(r[1],n[1])})),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],T=t[_];if((w[0]-T[0]||w[1]-T[1])<0){var k=b;b=_,_=k}x[0]=b;var M,A=x[1]=S[1];for(i&&(M=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([A,E,M]):e.push([A,E]),A=E}i?e.push([A,_,M]):e.push([A,_])}return h}(t,e,h,m,r));return v(e,y,r),!!y||(h.length>0||m.length>0)}},{\"./lib/rat-seg-intersect\":122,\"big-rat\":83,\"big-rat/cmp\":81,\"big-rat/to-float\":95,\"box-intersect\":101,nextafter:496,\"rat-vec\":530,\"robust-segment-intersect\":551,\"union-find\":596}],122:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),f=s(n,r),h=u(a,f);if(0===o(h))return null;var p=s(t,r),d=u(f,p),g=i(d,h),m=c(a,g);return l(t,m)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":82,\"big-rat/mul\":92,\"big-rat/sign\":93,\"big-rat/sub\":94,\"rat-vec/add\":529,\"rat-vec/muls\":531,\"rat-vec/sub\":532}],123:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:120}],124:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],125:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:120,\"color-rgba\":127,dtype:175}],126:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=(p=t.slice(1)).length;c=1,u<=4?(l=[parseInt(p[0]+p[0],16),parseInt(p[1]+p[1],16),parseInt(p[2]+p[2],16)],4===u&&(c=parseInt(p[3]+p[3],16)/255)):(l=[parseInt(p[0]+p[1],16),parseInt(p[2]+p[3],16),parseInt(p[4]+p[5],16)],8===u&&(c=parseInt(p[6]+p[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var f=e[1],h=\"rgb\"===f,p=f.replace(/a$/,\"\");s=p;u=\"cmyk\"===p?4:\"gray\"===p?1:3;l=e[2].trim().split(/\\s*,\\s*/).map((function(t,e){if(/%$/.test(t))return e===u?parseFloat(t)/100:\"rgb\"===p?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===p[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)})),f===p&&l.push(1),c=h||void 0===l[u]?1:l[u],l=l.slice(0,u)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map((function(t){return parseFloat(t)})),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var d=a(t.r,t.red,t.R,null);null!==d?(s=\"rgb\",l=[d,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":124,defined:170,\"is-plain-obj\":469}],127:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:120,\"color-parse\":126,\"color-space/hsl\":128}],128:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":129}],129:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],130:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],131:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,f,h,p,d,g;t||(t={});p=(t.nshades||72)-1,h=t.format||\"hex\",(f=t.colormap)||(f=\"jet\");if(\"string\"==typeof f){if(f=f.toLowerCase(),!n[f])throw Error(f+\" not a supported colorscale\");u=n[f]}else{if(!Array.isArray(f))throw Error(\"unsupported colormap option\",f);u=f.slice()}if(u.length>p+1)throw new Error(f+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map((function(t){return Math.round(t.index*p)})),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var m=u.map((function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1||(n[3]=d[0]+(d[1]-d[0])*r),n})),v=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=m[g],l=m[g+1];for(var y=0;y<c;y++){var x=y/c;v.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}v.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===h?v=v.map(o):\"rgbaString\"===h?v=v.map(s):\"float\"===h&&(v=v.map(a));return v}},{\"./colorScale\":130,lerp:472}],132:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),f=l(t,e,a);return u===f?0:u?1:-1}return 0}return 0===c?s>0||l(t,e,a)?-1:1:0===s?c>0||l(t,e,r)?1:-1:i(c-s)}var h=n(t,e,r);return h>0?o>0&&n(t,e,a)>0?1:-1:h<0?o>0||n(t,e,a)>0?1:-1:n(t,e,a)>0||l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":548,\"robust-product\":549,\"robust-sum\":553,signum:554,\"two-sum\":583}],133:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],f=t[1],h=t[2],p=t[3],d=e[0],g=e[1],m=e[2],v=e[3];return u+f+h+p-(d+g+m+v)||n(u,f,h,p)-n(d,g,m,v,d)||n(u+f,u+h,u+p,f+h,f+p,h+p)-n(d+g,d+m,d+v,g+m,g+v,m+v)||n(u+f+h,u+f+p,u+h+p,f+h+p)-n(d+g+m,d+g+v,d+m+v,g+m+v);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],134:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":117,\"compare-cell\":133}],135:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":136,\"./lib/ch2d\":137,\"./lib/chnd\":138}],136:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],137:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":482}],138:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(o){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];var a=e.length;for(i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(n(a,!0),r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":67,\"incremental-convex-hull\":459}],139:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],140:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],141:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],142:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],143:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],144:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":146,\"./stringify\":147}],145:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":140}],146:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=h;var f=h.cache={};function h(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(f[t])return f[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return f[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},h=c(t,/\\s+/);e=h.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach((function(t){r[t]=e})),f[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===h[0]&&(h.shift(),r.lineHeight=p(h.shift())),!h.length)throw new Error(\"Missing required font-family.\");return r.family=c(h.join(\" \"),/\\s*,\\s*/).map(n),f[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":145,\"css-font-stretch-keywords\":141,\"css-font-style-keywords\":142,\"css-font-weight-keywords\":143,\"css-global-keywords\":148,\"css-system-font-keywords\":149,\"string-split-by\":568,unquote:598}],147:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},f={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},h=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=h),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map((function(t){return f[t]?t:'\"'+t+'\"'})).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":145,\"css-font-stretch-keywords\":141,\"css-font-style-keywords\":142,\"css-font-weight-keywords\":143,\"css-global-keywords\":148,\"css-system-font-keywords\":149,\"pick-by-alias\":511}],148:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],149:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],150:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,f=s*(3-2*i),h=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+f*r[p]+h*n[p];return a}return c*t+u*e+f*r+h*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],151:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":153}],152:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,f=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)f=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",f,\"*t\",i,\"p\",f,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(f=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",f,\"]-=s\",f].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var f=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[f].array,c=\"+q\"+f;case\"array\":c=\"p\"+u+c;var h=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):(i.push([\"var \",h,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\"[\",c,\"]=\",h].join(\"\")));else{for(var d=[s.name],g=[c],m=0;m<Math.abs(e.arrayBlockIndices[u]);m++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(m+1)+\"*t\"+u+\"b\"+m);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}function o(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,s=new Array(t.arrayArgs.length),l=new Array(t.arrayArgs.length),c=0;c<t.arrayArgs.length;++c)l[c]=e[2*c],s[c]=e[2*c+1];var u=[],f=[],h=[],p=[],d=[];for(c=0;c<t.arrayArgs.length;++c){t.arrayBlockIndices[c]<0?(h.push(0),p.push(r),u.push(r),f.push(r+t.arrayBlockIndices[c])):(h.push(t.arrayBlockIndices[c]),p.push(t.arrayBlockIndices[c]+r),u.push(0),f.push(t.arrayBlockIndices[c]));for(var g=[],m=0;m<s[c].length;m++)h[c]<=s[c][m]&&s[c][m]<p[c]&&g.push(s[c][m]-h[c]);d.push(g)}var v=[\"SS\"],y=[\"'use strict'\"],x=[];for(m=0;m<r;++m)x.push([\"s\",m,\"=SS[\",m,\"]\"].join(\"\"));for(c=0;c<t.arrayArgs.length;++c){v.push(\"a\"+c),v.push(\"t\"+c),v.push(\"p\"+c);for(m=0;m<r;++m)x.push([\"t\",c,\"p\",m,\"=t\",c,\"[\",h[c]+m,\"]\"].join(\"\"));for(m=0;m<Math.abs(t.arrayBlockIndices[c]);++m)x.push([\"t\",c,\"b\",m,\"=t\",c,\"[\",u[c]+m,\"]\"].join(\"\"))}for(c=0;c<t.scalarArgs.length;++c)v.push(\"Y\"+c);if(t.shapeArgs.length>0&&x.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var b=new Array(r);for(c=0;c<r;++c)b[c]=\"0\";x.push([\"index=[\",b.join(\",\"),\"]\"].join(\"\"))}for(c=0;c<t.offsetArgs.length;++c){var _=t.offsetArgs[c],w=[];for(m=0;m<_.offset.length;++m)0!==_.offset[m]&&(1===_.offset[m]?w.push([\"t\",_.array,\"p\",m].join(\"\")):w.push([_.offset[m],\"*t\",_.array,\"p\",m].join(\"\")));0===w.length?x.push(\"q\"+c+\"=0\"):x.push([\"q\",c,\"=\",w.join(\"+\")].join(\"\"))}var T=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((x=x.concat(T)).length>0&&y.push(\"var \"+x.join(\",\")),c=0;c<t.arrayArgs.length;++c)y.push(\"p\"+c+\"|=0\");t.pre.body.length>3&&y.push(a(t.pre,t,l));var k=a(t.body,t,l),M=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(d);M<r?y.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var f=[\"offset\"+u],h=t;h<a;++h)f.push([\"j\",h,\"*t\",u,\"p\",e[h]].join(\"\"));c.push([\"p\",u,\"=(\",f.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(M,d[0],t,k)):y.push(i(d[0],t,k)),t.post.body.length>3&&y.push(a(t.post,t,l)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+y.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",s[0].join(\"s\"),\"m\",M,o(l)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",y.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:597}],153:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var f=t.arrayArgs[u];r.push([\"t\",f,\"=array\",f,\".dtype,\",\"r\",f,\"=array\",f,\".order\"].join(\"\")),a.push(\"t\"+f),a.push(\"r\"+f),o.push(\"t\"+f),o.push(\"r\"+f+\".join()\"),s.push(\"array\"+f+\".data\"),s.push(\"array\"+f+\".stride\"),s.push(\"array\"+f+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+f+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+f+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":152}],154:[function(t,e,r){\"use strict\";var n,i=t(\"type/value/is\"),a=t(\"type/value/ensure\"),o=t(\"type/plain-function/ensure\"),s=t(\"es5-ext/object/copy\"),l=t(\"es5-ext/object/normalize-options\"),c=t(\"es5-ext/object/map\"),u=Function.prototype.bind,f=Object.defineProperty,h=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,i=a(e)&&o(e.value);return delete(n=s(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&h.call(this,t)?i:(e.value=u.call(i,r.resolveContext?r.resolveContext(this):this),f(this,t,e),this[t])},n},e.exports=function(t){var e=l(arguments[1]);return i(e.resolveContext)&&o(e.resolveContext),c(t,(function(t,r){return n(r,t,e)}))}},{\"es5-ext/object/copy\":196,\"es5-ext/object/map\":204,\"es5-ext/object/normalize-options\":205,\"type/plain-function/ensure\":589,\"type/value/ensure\":593,\"type/value/is\":594}],155:[function(t,e,r){\"use strict\";var n=t(\"type/value/is\"),i=t(\"type/plain-function/is\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/normalize-options\"),s=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,i,l,c,u;return arguments.length<2||\"string\"!=typeof t?(c=e,e=t,t=null):c=arguments[2],n(t)?(r=s.call(t,\"c\"),i=s.call(t,\"e\"),l=s.call(t,\"w\")):(r=l=!0,i=!1),u={value:e,configurable:r,enumerable:i,writable:l},c?a(o(c),u):u}).gs=function(t,e,r){var l,c,u,f;return\"string\"!=typeof t?(u=r,r=e,e=t,t=null):u=arguments[3],n(e)?i(e)?n(r)?i(r)||(u=r,r=void 0):r=void 0:(u=e,e=r=void 0):e=void 0,n(t)?(l=s.call(t,\"c\"),c=s.call(t,\"e\")):(l=!0,c=!1),f={get:e,set:r,configurable:l,enumerable:c},u?a(o(u),f):f}},{\"es5-ext/object/assign\":193,\"es5-ext/object/normalize-options\":205,\"es5-ext/string/#/contains\":212,\"type/plain-function/is\":590,\"type/value/is\":594}],156:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&\"undefined\"!=typeof e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var f=Array.prototype,h=f.slice,p=f.map;function d(t){return function(){return t}}function g(t){return t}function m(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var v=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=v?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=v?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=v?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function T(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function k(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function M(t){if(!(i=t.length))return[];for(var e=-1,r=k(t,A),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function A(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],f=c[1],h=r(l,u,f);Array.isArray(h)||(h=_(u,f,h),h=m(Math.ceil(u/h)*h,f,h));for(var p=h.length;h[0]<=u;)h.shift(),--p;for(;h[p-1]>f;)h.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?h[a-1]:u,d.x1=a<p?h[a]:f;for(a=0;a<s;++a)u<=(o=l[a])&&o<=f&&g[i(h,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(h.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(T(t,.75)-T(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return T(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=k,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=T,t.range=m,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)===(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=M,t.variance=l,t.zip=function(){return M(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],157:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&\"undefined\"!=typeof e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each((function(t,e){n.set(e,t)}));else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each((function(t){r.add(t)}));else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each},t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,f,h=-1,p=n.length,d=l[i++],g=r(),m=a();++h<p;)(f=g.get(s=d(c=n[h])+\"\"))?f.push(c):g.set(s,[c]);return g.each((function(t,e){o(m,e,u(t,i,a,o))})),m}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each((function(e,r){i.push({key:r,values:t(e,n)})}))),null!=a?i.sort((function(t,e){return a(t.key,e.key)})):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],158:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3,8})$/,l=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),c=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),u=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),h=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),p=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),d={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function g(){return this.rgb().formatHex()}function m(){return this.rgb().formatRgb()}function v(t){var e,r;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?(r=e[1].length,e=parseInt(e[1],16),6===r?y(e):3===r?new w(e>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):8===r?x(e>>24&255,e>>16&255,e>>8&255,(255&e)/255):4===r?x(e>>12&15|e>>8&240,e>>8&15|e>>4&240,e>>4&15|240&e,((15&e)<<4|15&e)/255):null):(e=l.exec(t))?new w(e[1],e[2],e[3],1):(e=c.exec(t))?new w(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=u.exec(t))?x(e[1],e[2],e[3],e[4]):(e=f.exec(t))?x(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=h.exec(t))?A(e[1],e[2]/100,e[3]/100,1):(e=p.exec(t))?A(e[1],e[2]/100,e[3]/100,e[4]):d.hasOwnProperty(t)?y(d[t]):\"transparent\"===t?new w(NaN,NaN,NaN,0):null}function y(t){return new w(t>>16&255,t>>8&255,255&t,1)}function x(t,e,r,n){return n<=0&&(t=e=r=NaN),new w(t,e,r,n)}function b(t){return t instanceof n||(t=v(t)),t?new w((t=t.rgb()).r,t.g,t.b,t.opacity):new w}function _(t,e,r,n){return 1===arguments.length?b(t):new w(t,e,r,null==n?1:n)}function w(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function T(){return\"#\"+M(this.r)+M(this.g)+M(this.b)}function k(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}function M(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function A(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new C(t,e,r,n)}function S(t){if(t instanceof C)return new C(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new C;if(t instanceof C)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new C(s,l,c,t.opacity)}function E(t,e,r,n){return 1===arguments.length?S(t):new C(t,e,r,null==n?1:n)}function C(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function L(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{copy:function(t){return Object.assign(new this.constructor,this,t)},displayable:function(){return this.rgb().displayable()},hex:g,formatHex:g,formatHsl:function(){return S(this).formatHsl()},formatRgb:m,toString:m}),e(w,_,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:T,formatHex:T,formatRgb:k,toString:k})),e(C,E,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new C(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new C(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new w(L(t>=240?t-240:t+120,i,n),L(t,i,n),L(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"hsl(\":\"hsla(\")+(this.h||0)+\", \"+100*(this.s||0)+\"%, \"+100*(this.l||0)+\"%\"+(1===t?\")\":\", \"+t+\")\")}}));var I=Math.PI/180,P=180/Math.PI,z=6/29,O=3*z*z;function D(t){if(t instanceof F)return new F(t.l,t.a,t.b,t.opacity);if(t instanceof H)return G(t);t instanceof w||(t=b(t));var e,r,n=U(t.r),i=U(t.g),a=U(t.b),o=B((.2225045*n+.7168786*i+.0606169*a)/1);return n===i&&i===a?e=r=o:(e=B((.4360747*n+.3850649*i+.1430804*a)/.96422),r=B((.0139322*n+.0971045*i+.7141733*a)/.82521)),new F(116*o-16,500*(e-o),200*(o-r),t.opacity)}function R(t,e,r,n){return 1===arguments.length?D(t):new F(t,e,r,null==n?1:n)}function F(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function B(t){return t>.008856451679035631?Math.pow(t,1/3):t/O+4/29}function N(t){return t>z?t*t*t:O*(t-4/29)}function j(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function U(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function V(t){if(t instanceof H)return new H(t.h,t.c,t.l,t.opacity);if(t instanceof F||(t=D(t)),0===t.a&&0===t.b)return new H(NaN,0<t.l&&t.l<100?0:NaN,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*P;return new H(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function q(t,e,r,n){return 1===arguments.length?V(t):new H(t,e,r,null==n?1:n)}function H(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}function G(t){if(isNaN(t.h))return new F(t.l,0,0,t.opacity);var e=t.h*I;return new F(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}e(F,R,r(n,{brighter:function(t){return new F(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new F(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new w(j(3.1338561*(e=.96422*N(e))-1.6168667*(t=1*N(t))-.4906146*(r=.82521*N(r))),j(-.9787684*e+1.9161415*t+.033454*r),j(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(H,q,r(n,{brighter:function(t){return new H(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new H(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return G(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,Q=J*W,$=W*X-Z*Y;function tt(t){if(t instanceof rt)return new rt(t.h,t.s,t.l,t.opacity);t instanceof w||(t=b(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=($*n+K*e-Q*r)/($+K-Q),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*P-120:NaN;return new rt(l<0?l+360:l,s,i,t.opacity)}function et(t,e,r,n){return 1===arguments.length?tt(t):new rt(t,e,r,null==n?1:n)}function rt(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(rt,et,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*I,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new w(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.cubehelix=et,t.gray=function(t,e){return new F(t,0,0,null==e?1:e)},t.hcl=q,t.hsl=E,t.lab=R,t.lch=function(t,e,r,n){return 1===arguments.length?V(t):new H(r,e,t,null==n?1:n)},t.rgb=_,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],159:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i||/[\\s.]/.test(t))throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){return t.trim().split(/^|\\s+/).map((function(t){var r=\"\",n=t.indexOf(\".\");if(n>=0&&(r=t.slice(n+1),t=t.slice(0,n)),t&&!e.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:r}}))}function a(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function o(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n=this._,s=i(t+\"\",n),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)n[r]=o(n[r],t.name,e);else if(null==e)for(r in n)n[r]=o(n[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=a(n[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],160:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)}(this,(function(t,e,r,n,i){\"use strict\";function a(t){return function(){return t}}function o(){return 1e-6*(Math.random()-.5)}function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function f(t){return t.x}function h(t){return t.y}var p=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,h,p,d,g,m=r.length,v=0;v<c;++v)for(a=e.quadtree(r,s,l).visitAfter(f),t=0;t<m;++t)u=r[t],d=n[u.index],g=d*d,h=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>h+c||n<h-c||r>p+c||a<p-c;if(s.index>u.index){var f=h-s.x-s.vx,m=p-s.y-s.vy,v=f*f+m*m;v<c*c&&(0===f&&(v+=(f=o())*f),0===m&&(v+=(m=o())*m),v=(c-(v=Math.sqrt(v)))/v*i,u.vx+=(f*=v)*(c=(l*=l)/(g+l)),u.vy+=(m*=v)*c,s.vx-=f*(c=1-c),s.vy-=m*c)}}}function f(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function h(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,h()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),h(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,f=c,h=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,f,h,p,g,m=0;m<a;++m)c=(s=t[m]).source,f=(u=s.target).x+u.vx-c.x-c.vx||o(),h=u.y+u.vy-c.y-c.vy||o(),f*=p=((p=Math.sqrt(f*f+h*h))-n[m])/p*r*e[m],h*=p,u.vx-=f*(g=l[m]),u.vy-=h*g,c.vx+=f*(g=1-g),c.vy+=h*g}function m(){if(i){var a,o,c=i.length,h=t.length,p=r.map(i,f);for(a=0,s=new Array(c);a<h;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(h);a<h;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(h),v(),n=new Array(h),y()}}function v(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+h(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,m()},g.links=function(e){return arguments.length?(t=e,m(),g):t},g.id=function(t){return arguments.length?(f=t,g):f},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(h=\"function\"==typeof t?t:a(+t),v(),g):h},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,f,h).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(m)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function m(t,e,a,s){if(!t.value)return!0;var f=t.x-r.x,h=t.y-r.y,p=s-e,d=f*f+h*h;if(p*p/u<d)return d<c&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)),r.vx+=f*t.value*n/d,r.vy+=h*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=f*p,r.vy+=h*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,f=Math.sqrt(c*c+u*u),h=(o[a]-f)*i[a]*t/f;l.vx+=c*h,l.vy+=u*h}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),f=i.timer(d),h=n.dispatch(\"tick\",\"end\");function d(){g(),h.call(\"tick\",e),a<o&&(f.stop(),h.call(\"end\",e))}function g(r){var n,i,o=t.length;void 0===r&&(r=1);for(var f=0;f<r;++f)for(a+=(l-a)*s,u.each((function(t){t(a)})),n=0;n<o;++n)null==(i=t[n]).fx?i.x+=i.vx*=c:(i.x=i.fx,i.vx=0),null==i.fy?i.y+=i.vy*=c:(i.y=i.fy,i.vy=0);return e}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,null!=e.fx&&(e.x=e.fx),null!=e.fy&&(e.y=e.fy),isNaN(e.x)||isNaN(e.y)){var i=10*Math.sqrt(r),a=r*p;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function v(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:g,restart:function(){return f.restart(d),e},stop:function(){return f.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(v),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,v(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(h.on(t,r),e):h.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-collection\":157,\"d3-dispatch\":159,\"d3-quadtree\":164,\"d3-timer\":168}],161:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),f=+t.value&&(u.value=t.value),h=[u];for(null==e&&(e=o);r=h.pop();)if(f&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)h.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter((function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r}))},sort:function(t){return this.eachBefore((function(e){e.children&&e.children.sort(t)}))},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;t=r.pop(),e=n.pop();for(;t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each((function(e){t.push(e)})),t},leaves:function(){var t=[];return this.eachBefore((function(e){e.children||t.push(e)})),t},links:function(){var t=this,e=[];return t.each((function(r){r!==t&&e.push({source:r.parent,target:r})})),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function f(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=m(a=h(a,e)),n=0);return r}function h(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(v(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(v(t[r],t[n]),e)&&p(v(t[r],e),t[n])&&p(v(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function m(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return v(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function v(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,f=Math.sqrt(l*l+c*c);return{x:(r+a+l/f*u)/2,y:(n+o+c/f*u)/2,r:(f+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,f=r.r,h=n-o,p=n-c,d=i-s,g=i-u,m=l-a,v=f-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+f*f,_=p*d-h*g,w=(d*b-g*x)/(2*_)-n,T=(g*m-d*v)/_,k=(p*x-h*b)/(2*_)-i,M=(h*v-p*m)/_,A=T*T+M*M-1,S=2*(a+w*T+k*M),E=w*w+k*k-a*a,C=-(A?(S+Math.sqrt(S*S-4*A*E))/(2*A):E/S);return{x:n+w+T*C,y:i+k+M*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function T(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,h;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,h=e._.r;do{if(u<=h){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}h+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=f(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function k(t){return null==t?null:M(t)}function M(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function S(t){return function(){return t}}function E(t){return Math.sqrt(t.value)}function C(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function L(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=T(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function I(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function z(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var O={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,f,h,p,d,g,m,v=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(f=h=u,m=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(h/m,m/f);b<_;++b){if(u+=s=y[b].value,s<f&&(f=s),s>h&&(h=s),m=u*u*g,(p=Math.max(h/m,m/f))>d){u-=s;break}d=p}v.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?z(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return v}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,f=-1,h=o.length,p=t.value;++f<h;){for(l=(s=o[f]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?z(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter((function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)}));var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),f=c.x-t(c,u)/2,h=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-f)/(h-f)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(C(t)).eachAfter(L(n,.5)).eachBefore(I(1)):i.eachBefore(C(E)).eachAfter(L(A,1)).eachAfter(L(n,i.r/Math.min(e,r))).eachBefore(I(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=k(e),i):t},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:S(+t),i):n},i},t.packEnclose=f,t.packSiblings=function(t){return T(t),t},t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&z(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,f,h=r.length,p=new Array(h),d={};for(i=0;i<h;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[f=\"$\"+(s.id=u)]=f in d?D:s);for(i=0;i<h;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[\"$\"+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=O,a.eachBefore((function(t){t.depth=t.parent.depth+1,--h})).eachBefore(l),a.parent=null,h>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=M(e),r):t},r.parentId=function(t){return arguments.length?(e=M(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,f=i;i.eachBefore((function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>f.depth&&(f=t)}));var h=c===u?1:t(c,u)/2,p=h-c.x,d=e/(u.x+h+p),g=r/(f.depth||1);i.eachBefore((function(t){t.x=(t.x+p)*d,t.y=t.depth*g}))}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+f-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=f-u),a&&!N(l)&&(l.t=a,l.m+=c-h,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(f),i=[0],e&&t.eachBefore(P),t}function f(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,f=e.x1-r,h=e.y1-r;f<n&&(n=f=(n+f)/2),h<u&&(u=h=(u+h)/2),e.x0=n,e.y0=u,e.x1=f,e.y1=h,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(f-=s(e)-r)<n&&(n=f=(n+f)/2),(h-=l(e)-r)<u&&(u=h=(u+h)/2),t(e,n,u,f,h))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=M(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:S(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:S(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:S(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:S(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:S(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}var f=c[e],h=n/2+f,p=e+1,d=r-1;for(;p<d;){var g=p+d>>>1;c[g]<h?p=g+1:d=g}h-c[p-1]<c[p]-h&&e+1<p&&--p;var m=c[p]-f,v=n-m;if(o-i>l-a){var y=(i*v+o*m)/n;t(e,p,m,i,a,y,l),t(p,r,v,y,a,o,l)}else{var x=(a*v+l*m)/n;t(e,p,m,i,a,o,x),t(p,r,v,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=z,t.treemapResquarify=X,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:z)(t,e,r,n,i)},t.treemapSquarify=W,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],162:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function f(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var h=f(n),p=f(i);function d(t,e){e||(e=[]);var r,n=t?Math.min(e.length,t.length):0,i=e.slice();return function(a){for(r=0;r<n;++r)i[r]=t[r]*(1-a)+e[r]*a;return i}}function g(t){return ArrayBuffer.isView(t)&&!(t instanceof DataView)}function m(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=T(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function v(t,e){var r=new Date;return t=+t,e=+e,function(n){return r.setTime(t*(1-n)+e*n),r}}function y(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function x(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=T(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var b=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,_=new RegExp(b.source,\"g\");function w(t,e){var r,n,i,a=b.lastIndex=_.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=b.exec(t))&&(n=_.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:y(r,n)})),a=_.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function T(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?y:\"string\"===i?(n=e.color(r))?(r=n,u):w:r instanceof e.color?u:r instanceof Date?v:g(r)?d:Array.isArray(r)?m:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?x:y)(t,r)}var k,M,A,S,E=180/Math.PI,C={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function L(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*E,skewX:Math.atan(l)*E,scaleX:o,scaleY:s}}function I(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:y(t,i)},{i:l-2,x:y(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:y(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:y(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:y(t,r)},{i:s-2,x:y(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var P=I((function(t){return\"none\"===t?C:(k||(k=document.createElement(\"DIV\"),M=document.documentElement,A=document.defaultView),k.style.transform=t,t=A.getComputedStyle(M.appendChild(k),null).getPropertyValue(\"transform\"),M.removeChild(k),L(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))}),\"px, \",\"px)\",\"deg)\"),z=I((function(t){return null==t?C:(S||(S=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),S.setAttribute(\"transform\",t),(t=S.transform.baseVal.consolidate())?L((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):C)}),\", \",\")\",\")\"),O=Math.SQRT2;function D(t){return((t=Math.exp(t))+1/t)/2}function R(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var F=R(s),B=R(c);function N(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var j=N(s),U=N(c);function V(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var q=V(s),H=V(c);t.interpolate=T,t.interpolateArray=function(t,e){return(g(e)?d:m)(t,e)},t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateCubehelix=q,t.interpolateCubehelixLong=H,t.interpolateDate=v,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHcl=j,t.interpolateHclLong=U,t.interpolateHsl=F,t.interpolateHslLong=B,t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateNumber=y,t.interpolateNumberArray=d,t.interpolateObject=x,t.interpolateRgb=u,t.interpolateRgbBasis=h,t.interpolateRgbBasisClosed=p,t.interpolateRound=function(t,e){return t=+t,e=+e,function(r){return Math.round(t*(1-r)+e*r)}},t.interpolateString=w,t.interpolateTransformCss=P,t.interpolateTransformSvg=z,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<1e-12)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*f,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),g=(c*c-o*o-4*h)/(2*c*2*p),m=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(g*g+1)-g);n=(v-m)/O,r=function(t){var e,r=t*n,s=D(m),l=o/(2*p)*(s*(e=O*r+m,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(m));return[i+l*u,a+l*f,o*s/D(O*r+m)]}}return r.duration=1e3*n,r},t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-color\":158}],163:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,f=s-r,h=u*u+f*f;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(h>1e-6)if(Math.abs(f*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,m=p*p+d*d,v=Math.sqrt(g),y=Math.sqrt(h),x=a*Math.tan((e-Math.acos((g+h-m)/(2*v*y)))/2),b=x/y,_=x/v;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*f)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(f*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i,l=!!l;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),f=t+c,h=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+f+\",\"+h:(Math.abs(this._x1-f)>1e-6||Math.abs(this._y1-h)>1e-6)&&(this._+=\"L\"+f+\",\"+h),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=f)+\",\"+(this._y1=h):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],164:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,f,h,p=t._root,d={data:n},g=t._x0,m=t._y0,v=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+v)/2))?g=a:v=a,(u=r>=(o=(m+y)/2))?m=o:y=o,i=p,!(p=p[f=u<<1|c]))return i[f]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[f]=d:t._root=d,t;do{i=i?i[f]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+v)/2))?g=a:v=a,(u=r>=(o=(m+y)/2))?m=o:y=o}while((f=u<<1|c)==(h=(l>=o)<<1|s>=a));return i[h]=p,i[f]=d,t}function r(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i}function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,f=-1/0,h=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>f&&(f=i),a<u&&(u=a),a>h&&(h=a));if(c>f||u>h)return this;for(this.cover(c,u).cover(f,h),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{for(var o,s,l=i-r,c=this._root;r>t||t>=i||n>e||e>=a;)switch(s=(e<n)<<1|t<r,(o=new Array(4))[s]=c,c=o,l*=2,s){case 0:i=r+l,a=n+l;break;case 1:r=i-l,a=n+l;break;case 2:i=r+l,n=a-l;break;case 3:r=i-l,n=a-l}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit((function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)})),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,f=this._x0,h=this._y0,p=this._x1,d=this._y1,g=[],m=this._root;for(m&&g.push(new r(m,f,h,p,d)),null==n?n=1/0:(f=t-n,h=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(m=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<f||(l=c.y1)<h))if(m.length){var v=(a+s)/2,y=(o+l)/2;g.push(new r(m[3],v,y,s,l),new r(m[2],a,y,v,l),new r(m[1],v,o,s,y),new r(m[0],a,o,v,y)),(u=(e>=y)<<1|t>=v)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,m.data),b=e-+this._y.call(null,m.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);f=t-w,h=e-w,p=t+w,d=e+w,i=m.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,f,h,p=this._root,d=this._x0,g=this._y0,m=this._x1,v=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+m)/2))?d=s:m=s,(u=o>=(l=(g+v)/2))?g=l:v=l,e=p,!(p=p[f=u<<1|c]))return this;if(!p.length)break;(e[f+1&3]||e[f+2&3]||e[f+3&3])&&(r=e,h=f)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[f]=i:delete e[f],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[h]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit((function(e){if(!e.length)do{++t}while(e=e.next)})),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,f=(a+s)/2;(n=c[3])&&l.push(new r(n,u,f,o,s)),(n=c[2])&&l.push(new r(n,i,f,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,f)),(n=c[0])&&l.push(new r(n,i,a,u,f))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,f=(s+c)/2,h=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,f,h)),(o=a[1])&&n.push(new r(o,f,l,c,h)),(o=a[2])&&n.push(new r(o,s,h,f,u)),(o=a[3])&&n.push(new r(o,f,h,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],165:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=Math.PI,f=u/2,h=2*u;function p(t){return t>1?0:t<-1?u:Math.acos(t)}function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function m(t){return t.outerRadius}function v(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,u=o-i,f=s-a,h=f*l-u*c;if(!(h*h<1e-12))return[t+(h=(u*(e-a)-f*(t-i))/h)*l,e+h*c]}function _(t,e,r,n,i,a,s){var l=t-r,u=e-n,f=(s?a:-a)/c(l*l+u*u),h=f*u,p=-f*l,d=t+h,g=e+p,m=r+h,v=n+p,y=(d+m)/2,x=(g+v)/2,b=m-d,_=v-g,w=b*b+_*_,T=i-a,k=d*v-m*g,M=(_<0?-1:1)*c(o(0,T*T*w-k*k)),A=(k*_-b*M)/w,S=(-k*b-_*M)/w,E=(k*_+b*M)/w,C=(-k*b+_*M)/w,L=A-y,I=S-x,P=E-y,z=C-x;return L*L+I*I>P*P+z*z&&(A=E,S=C),{cx:A,cy:S,x01:-h,y01:-p,x11:A*(i/T-1),y11:S*(i/T-1)}}function w(t){this._context=t}function T(t){return new w(t)}function k(t){return t[0]}function M(t){return t[1]}function A(){var t=k,n=M,i=r(!0),a=null,o=T,s=null;function l(r){var l,c,u,f=r.length,h=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=f;++l)!(l<f&&i(c=r[l],l,r))===h&&((h=!h)?s.lineStart():s.lineEnd()),h&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function S(){var t=k,n=null,i=r(0),a=M,o=r(!0),s=null,l=T,c=null;function u(r){var u,f,h,p,d,g=r.length,m=!1,v=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===m)if(m=!m)f=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),h=u-1;h>=f;--h)c.point(v[h],y[h]);c.lineEnd(),c.areaEnd()}m&&(v[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):v[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function f(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return f().x(t).y(i)},u.lineY1=function(){return f().x(t).y(a)},u.lineX1=function(){return f().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function E(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function C(t){return t}w.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var L=P(T);function I(t){this._curve=t}function P(t){function e(e){return new I(t(e))}return e._curve=t,e}function z(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function O(){return z(A().curve(L))}function D(){var t=S().curve(L),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return z(r())},delete t.lineX0,t.lineEndAngle=function(){return z(n())},delete t.lineX1,t.lineInnerRadius=function(){return z(i())},delete t.lineY0,t.lineOuterRadius=function(){return z(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function R(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}I.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var F=Array.prototype.slice;function B(t){return t.source}function N(t){return t.target}function j(t){var n=B,i=N,a=k,o=M,s=null;function l(){var r,l=F.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function V(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function q(t,e,r,n,i){var a=R(e,r),o=R(e,r=(r+i)/2),s=R(n,r),l=R(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var H={draw:function(t,e){var r=Math.sqrt(e/u);t.moveTo(r,0),t.arc(0,0,r,0,h)}},G={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},Y=Math.sqrt(1/3),W=2*Y,X={draw:function(t,e){var r=Math.sqrt(e/W),n=r*Y;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},Z=Math.sin(u/10)/Math.sin(7*u/10),J=Math.sin(h/10)*Z,K=-Math.cos(h/10)*Z,Q={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=J*r,i=K*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=h*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},tt=Math.sqrt(3),et={draw:function(t,e){var r=-Math.sqrt(e/(3*tt));t.moveTo(0,2*r),t.lineTo(-tt*r,-r),t.lineTo(tt*r,-r),t.closePath()}},rt=-.5,nt=Math.sqrt(3)/2,it=1/Math.sqrt(12),at=3*(it/2+1),ot={draw:function(t,e){var r=Math.sqrt(e/at),n=r/2,i=r*it,a=n,o=r*it+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(rt*n-nt*i,nt*n+rt*i),t.lineTo(rt*a-nt*o,nt*a+rt*o),t.lineTo(rt*s-nt*l,nt*s+rt*l),t.lineTo(rt*n+nt*i,rt*i-nt*n),t.lineTo(rt*a+nt*o,rt*o-nt*a),t.lineTo(rt*s+nt*l,rt*l-nt*s),t.closePath()}},st=[H,G,X,$,Q,et,ot];function lt(){}function ct(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ut(t){this._context=t}function ft(t){this._context=t}function ht(t){this._context=t}function pt(t,e){this._basis=new ut(t),this._beta=e}ut.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:ct(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},pt.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var dt=function t(e){function r(t){return 1===e?new ut(t):new pt(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function gt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:gt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function yt(t,e){this._context=t,this._k=(1-e)/6}yt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var xt=function t(e){function r(t){return new yt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function bt(t,e){this._context=t,this._k=(1-e)/6}bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var _t=function t(e){function r(t){return new bt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function wt(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>1e-12){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>1e-12){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,u=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/u,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/u}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Mt(t,e):new yt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function St(t,e){this._context=t,this._alpha=e}St.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var Et=function t(e){function r(t){return e?new St(t,e):new bt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Ct(t){this._context=t}function Lt(t){return t<0?-1:1}function It(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Lt(a)+Lt(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function zt(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function Ot(t){this._context=t}function Dt(t){this._context=new Rt(t)}function Rt(t){this._context=t}function Ft(t){this._context=t}function Bt(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Nt(t,e){this._context=t,this._t=e}function jt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function Ut(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Vt(t,e){return t[e]}function qt(t){var e=t.map(Ht);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Ht(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Gt(t){var e=t.map(Yt);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Yt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Ct.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},Ot.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:zt(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,zt(this,Pt(this,r=It(this,t,e)),r);break;default:zt(this,this._t0,r=It(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(Dt.prototype=Object.create(Ot.prototype)).point=function(t,e){Ot.prototype.point.call(this,e,t)},Rt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Ft.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Bt(t),i=Bt(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Nt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=m,w=r(0),T=null,k=v,M=y,A=x,S=null;function E(){var r,g,m=+t.apply(this,arguments),v=+o.apply(this,arguments),y=k.apply(this,arguments)-f,x=M.apply(this,arguments)-f,E=n(x-y),C=x>y;if(S||(S=r=e.path()),v<m&&(g=v,v=m,m=g),v>1e-12)if(E>h-1e-12)S.moveTo(v*a(y),v*l(y)),S.arc(0,0,v,y,x,!C),m>1e-12&&(S.moveTo(m*a(x),m*l(x)),S.arc(0,0,m,x,y,C));else{var L,I,P=y,z=x,O=y,D=x,R=E,F=E,B=A.apply(this,arguments)/2,N=B>1e-12&&(T?+T.apply(this,arguments):c(m*m+v*v)),j=s(n(v-m)/2,+w.apply(this,arguments)),U=j,V=j;if(N>1e-12){var q=d(N/m*l(B)),H=d(N/v*l(B));(R-=2*q)>1e-12?(O+=q*=C?1:-1,D-=q):(R=0,O=D=(y+x)/2),(F-=2*H)>1e-12?(P+=H*=C?1:-1,z-=H):(F=0,P=z=(y+x)/2)}var G=v*a(P),Y=v*l(P),W=m*a(D),X=m*l(D);if(j>1e-12){var Z,J=v*a(z),K=v*l(z),Q=m*a(O),$=m*l(O);if(E<u&&(Z=b(G,Y,Q,$,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(p((tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(v-at)/(it+1))}}F>1e-12?V>1e-12?(L=_(Q,$,G,Y,v,V,C),I=_(J,K,W,X,v,V,C),S.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?S.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(I.y01,I.x01),!C):(S.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),S.arc(0,0,v,i(L.cy+L.y11,L.cx+L.x11),i(I.cy+I.y11,I.cx+I.x11),!C),S.arc(I.cx,I.cy,V,i(I.y11,I.x11),i(I.y01,I.x01),!C))):(S.moveTo(G,Y),S.arc(0,0,v,P,z,!C)):S.moveTo(G,Y),m>1e-12&&R>1e-12?U>1e-12?(L=_(W,X,J,K,m,-U,C),I=_(G,Y,Q,$,m,-U,C),S.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?S.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(I.y01,I.x01),!C):(S.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),S.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(I.cy+I.y11,I.cx+I.x11),C),S.arc(I.cx,I.cy,U,i(I.y11,I.x11),i(I.y01,I.x01),!C))):S.arc(0,0,m,D,O,C):S.lineTo(W,X)}else S.moveTo(0,0);if(S.closePath(),r)return S=null,r+\"\"||null}return E.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +M.apply(this,arguments))/2-u/2;return[a(r)*e,l(r)*e]},E.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),E):t},E.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),E):o},E.cornerRadius=function(t){return arguments.length?(w=\"function\"==typeof t?t:r(+t),E):w},E.padRadius=function(t){return arguments.length?(T=null==t?null:\"function\"==typeof t?t:r(+t),E):T},E.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),E):k},E.endAngle=function(t){return arguments.length?(M=\"function\"==typeof t?t:r(+t),E):M},E.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),E):A},E.context=function(t){return arguments.length?(S=null==t?null:t,E):S},E},t.area=S,t.areaRadial=D,t.curveBasis=function(t){return new ut(t)},t.curveBasisClosed=function(t){return new ft(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBundle=dt,t.curveCardinal=vt,t.curveCardinalClosed=xt,t.curveCardinalOpen=_t,t.curveCatmullRom=kt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=Et,t.curveLinear=T,t.curveLinearClosed=function(t){return new Ct(t)},t.curveMonotoneX=function(t){return new Ot(t)},t.curveMonotoneY=function(t){return new Dt(t)},t.curveNatural=function(t){return new Ft(t)},t.curveStep=function(t){return new Nt(t,.5)},t.curveStepAfter=function(t){return new Nt(t,1)},t.curveStepBefore=function(t){return new Nt(t,0)},t.line=A,t.lineRadial=O,t.linkHorizontal=function(){return j(U)},t.linkRadial=function(){var t=j(q);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.linkVertical=function(){return j(V)},t.pie=function(){var t=C,e=E,n=null,i=r(0),a=r(h),o=r(0);function s(r){var s,l,c,u,f,p=r.length,d=0,g=new Array(p),m=new Array(p),v=+i.apply(this,arguments),y=Math.min(h,Math.max(-h,a.apply(this,arguments)-v)),x=Math.min(Math.abs(y)/p,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<p;++s)(f=m[g[s]=s]=+t(r[s],s,r))>0&&(d+=f);for(null!=e?g.sort((function(t,r){return e(m[t],m[r])})):null!=n&&g.sort((function(t,e){return n(r[t],r[e])})),s=0,c=d?(y-p*b)/d:0;s<p;++s,v=u)l=g[s],u=v+((f=m[l])>0?f*c:0)+b,m[l]={data:r[l],index:s,value:f,startAngle:v,endAngle:u,padAngle:x};return m}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.pointRadial=R,t.radialArea=D,t.radialLine=O,t.stack=function(){var t=r([]),e=Ut,n=jt,i=Vt;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var f,h=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=f=[0,+i(r[d],h,d,r)],f.data=r[d];p.key=h}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(F.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?Ut:\"function\"==typeof t?t:r(F.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?jt:t,a):n},a},t.stackOffsetDiverging=function(t,e){if((s=t.length)>0)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):(n[0]=0,n[1]=i)},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}jt(t,e)}},t.stackOffsetNone=jt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}jt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],f=u[o][1]||0,h=(f-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];h+=(d[o][1]||0)-(d[o-1][1]||0)}l+=f,c+=h*f}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,jt(t,e)}},t.stackOrderAppearance=qt,t.stackOrderAscending=Gt,t.stackOrderDescending=function(t){return Gt(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Yt),a=qt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=Ut,t.stackOrderReverse=function(t){return Ut(t).reverse()},t.symbol=function(){var t=r(H),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbolCircle=H,t.symbolCross=G,t.symbolDiamond=X,t.symbolSquare=$,t.symbolStar=Q,t.symbolTriangle=et,t.symbolWye=ot,t.symbols=st,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-path\":163}],166:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-time\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){if(0<=t.y&&t.y<100){var e=new Date(-1,t.m,t.d,t.H,t.M,t.S,t.L);return e.setFullYear(t.y),e}return new Date(t.y,t.m,t.d,t.H,t.M,t.S,t.L)}function n(t){if(0<=t.y&&t.y<100){var e=new Date(Date.UTC(-1,t.m,t.d,t.H,t.M,t.S,t.L));return e.setUTCFullYear(t.y),e}return new Date(Date.UTC(t.y,t.m,t.d,t.H,t.M,t.S,t.L))}function i(t,e,r){return{y:t,m:e,d:r,H:0,M:0,S:0,L:0}}function a(t){var a=t.dateTime,o=t.date,l=t.time,c=t.periods,u=t.days,f=t.shortDays,h=t.months,yt=t.shortMonths,xt=p(c),bt=d(c),_t=p(u),wt=d(u),Tt=p(f),kt=d(f),Mt=p(h),At=d(h),St=p(yt),Et=d(yt),Ct={a:function(t){return f[t.getDay()]},A:function(t){return u[t.getDay()]},b:function(t){return yt[t.getMonth()]},B:function(t){return h[t.getMonth()]},c:null,d:D,e:D,f:j,H:R,I:F,j:B,L:N,m:U,M:V,p:function(t){return c[+(t.getHours()>=12)]},q:function(t){return 1+~~(t.getMonth()/3)},Q:mt,s:vt,S:q,u:H,U:G,V:Y,w:W,W:X,x:null,X:null,y:Z,Y:J,Z:K,\"%\":gt},Lt={a:function(t){return f[t.getUTCDay()]},A:function(t){return u[t.getUTCDay()]},b:function(t){return yt[t.getUTCMonth()]},B:function(t){return h[t.getUTCMonth()]},c:null,d:Q,e:Q,f:nt,H:$,I:tt,j:et,L:rt,m:it,M:at,p:function(t){return c[+(t.getUTCHours()>=12)]},q:function(t){return 1+~~(t.getUTCMonth()/3)},Q:mt,s:vt,S:ot,u:st,U:lt,V:ct,w:ut,W:ft,x:null,X:null,y:ht,Y:pt,Z:dt,\"%\":gt},It={a:function(t,e,r){var n=Tt.exec(e.slice(r));return n?(t.w=kt[n[0].toLowerCase()],r+n[0].length):-1},A:function(t,e,r){var n=_t.exec(e.slice(r));return n?(t.w=wt[n[0].toLowerCase()],r+n[0].length):-1},b:function(t,e,r){var n=St.exec(e.slice(r));return n?(t.m=Et[n[0].toLowerCase()],r+n[0].length):-1},B:function(t,e,r){var n=Mt.exec(e.slice(r));return n?(t.m=At[n[0].toLowerCase()],r+n[0].length):-1},c:function(t,e,r){return Ot(t,a,e,r)},d:M,e:M,f:I,H:S,I:S,j:A,L:L,m:k,M:E,p:function(t,e,r){var n=xt.exec(e.slice(r));return n?(t.p=bt[n[0].toLowerCase()],r+n[0].length):-1},q:T,Q:z,s:O,S:C,u:m,U:v,V:y,w:g,W:x,x:function(t,e,r){return Ot(t,o,e,r)},X:function(t,e,r){return Ot(t,l,e,r)},y:_,Y:b,Z:w,\"%\":P};function Pt(t,e){return function(r){var n,i,a,o=[],l=-1,c=0,u=t.length;for(r instanceof Date||(r=new Date(+r));++l<u;)37===t.charCodeAt(l)&&(o.push(t.slice(c,l)),null!=(i=s[n=t.charAt(++l)])?n=t.charAt(++l):i=\"e\"===n?\" \":\"0\",(a=e[n])&&(n=a(r,i)),o.push(n),c=l+1);return o.push(t.slice(c,l)),o.join(\"\")}}function zt(t,a){return function(o){var s,l,c=i(1900,void 0,1);if(Ot(c,t,o+=\"\",0)!=o.length)return null;if(\"Q\"in c)return new Date(c.Q);if(\"s\"in c)return new Date(1e3*c.s+(\"L\"in c?c.L:0));if(a&&!(\"Z\"in c)&&(c.Z=0),\"p\"in c&&(c.H=c.H%12+12*c.p),void 0===c.m&&(c.m=\"q\"in c?c.q:0),\"V\"in c){if(c.V<1||c.V>53)return null;\"w\"in c||(c.w=1),\"Z\"in c?(l=(s=n(i(c.y,0,1))).getUTCDay(),s=l>4||0===l?e.utcMonday.ceil(s):e.utcMonday(s),s=e.utcDay.offset(s,7*(c.V-1)),c.y=s.getUTCFullYear(),c.m=s.getUTCMonth(),c.d=s.getUTCDate()+(c.w+6)%7):(l=(s=r(i(c.y,0,1))).getDay(),s=l>4||0===l?e.timeMonday.ceil(s):e.timeMonday(s),s=e.timeDay.offset(s,7*(c.V-1)),c.y=s.getFullYear(),c.m=s.getMonth(),c.d=s.getDate()+(c.w+6)%7)}else(\"W\"in c||\"U\"in c)&&(\"w\"in c||(c.w=\"u\"in c?c.u%7:\"W\"in c?1:0),l=\"Z\"in c?n(i(c.y,0,1)).getUTCDay():r(i(c.y,0,1)).getDay(),c.m=0,c.d=\"W\"in c?(c.w+6)%7+7*c.W-(l+5)%7:c.w+7*c.U-(l+6)%7);return\"Z\"in c?(c.H+=c.Z/100|0,c.M+=c.Z%100,n(c)):r(c)}}function Ot(t,e,r,n){for(var i,a,o=0,l=e.length,c=r.length;o<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(o++))){if(i=e.charAt(o++),!(a=It[i in s?e.charAt(o++):i])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}return Ct.x=Pt(o,Ct),Ct.X=Pt(l,Ct),Ct.c=Pt(a,Ct),Lt.x=Pt(o,Lt),Lt.X=Pt(l,Lt),Lt.c=Pt(a,Lt),{format:function(t){var e=Pt(t+=\"\",Ct);return e.toString=function(){return t},e},parse:function(t){var e=zt(t+=\"\",!1);return e.toString=function(){return t},e},utcFormat:function(t){var e=Pt(t+=\"\",Lt);return e.toString=function(){return t},e},utcParse:function(t){var e=zt(t+=\"\",!0);return e.toString=function(){return t},e}}}var o,s={\"-\":\"\",_:\" \",0:\"0\"},l=/^\\s*\\d+/,c=/^%/,u=/[\\\\^$*+?|[\\]().{}]/g;function f(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function h(t){return t.replace(u,\"\\\\$&\")}function p(t){return new RegExp(\"^(?:\"+t.map(h).join(\"|\")+\")\",\"i\")}function d(t){for(var e={},r=-1,n=t.length;++r<n;)e[t[r].toLowerCase()]=r;return e}function g(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function m(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.u=+n[0],r+n[0].length):-1}function v(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.U=+n[0],r+n[0].length):-1}function y(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.V=+n[0],r+n[0].length):-1}function x(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.W=+n[0],r+n[0].length):-1}function b(t,e,r){var n=l.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function _(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.y=+n[0]+(+n[0]>68?1900:2e3),r+n[0].length):-1}function w(t,e,r){var n=/^(Z)|([+-]\\d\\d)(?::?(\\d\\d))?/.exec(e.slice(r,r+6));return n?(t.Z=n[1]?0:-(n[2]+(n[3]||\"00\")),r+n[0].length):-1}function T(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.q=3*n[0]-3,r+n[0].length):-1}function k(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function M(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function A(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.m=0,t.d=+n[0],r+n[0].length):-1}function S(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function E(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function C(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function L(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function I(t,e,r){var n=l.exec(e.slice(r,r+6));return n?(t.L=Math.floor(n[0]/1e3),r+n[0].length):-1}function P(t,e,r){var n=c.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function z(t,e,r){var n=l.exec(e.slice(r));return n?(t.Q=+n[0],r+n[0].length):-1}function O(t,e,r){var n=l.exec(e.slice(r));return n?(t.s=+n[0],r+n[0].length):-1}function D(t,e){return f(t.getDate(),e,2)}function R(t,e){return f(t.getHours(),e,2)}function F(t,e){return f(t.getHours()%12||12,e,2)}function B(t,r){return f(1+e.timeDay.count(e.timeYear(t),t),r,3)}function N(t,e){return f(t.getMilliseconds(),e,3)}function j(t,e){return N(t,e)+\"000\"}function U(t,e){return f(t.getMonth()+1,e,2)}function V(t,e){return f(t.getMinutes(),e,2)}function q(t,e){return f(t.getSeconds(),e,2)}function H(t){var e=t.getDay();return 0===e?7:e}function G(t,r){return f(e.timeSunday.count(e.timeYear(t)-1,t),r,2)}function Y(t,r){var n=t.getDay();return t=n>=4||0===n?e.timeThursday(t):e.timeThursday.ceil(t),f(e.timeThursday.count(e.timeYear(t),t)+(4===e.timeYear(t).getDay()),r,2)}function W(t){return t.getDay()}function X(t,r){return f(e.timeMonday.count(e.timeYear(t)-1,t),r,2)}function Z(t,e){return f(t.getFullYear()%100,e,2)}function J(t,e){return f(t.getFullYear()%1e4,e,4)}function K(t){var e=t.getTimezoneOffset();return(e>0?\"-\":(e*=-1,\"+\"))+f(e/60|0,\"0\",2)+f(e%60,\"0\",2)}function Q(t,e){return f(t.getUTCDate(),e,2)}function $(t,e){return f(t.getUTCHours(),e,2)}function tt(t,e){return f(t.getUTCHours()%12||12,e,2)}function et(t,r){return f(1+e.utcDay.count(e.utcYear(t),t),r,3)}function rt(t,e){return f(t.getUTCMilliseconds(),e,3)}function nt(t,e){return rt(t,e)+\"000\"}function it(t,e){return f(t.getUTCMonth()+1,e,2)}function at(t,e){return f(t.getUTCMinutes(),e,2)}function ot(t,e){return f(t.getUTCSeconds(),e,2)}function st(t){var e=t.getUTCDay();return 0===e?7:e}function lt(t,r){return f(e.utcSunday.count(e.utcYear(t)-1,t),r,2)}function ct(t,r){var n=t.getUTCDay();return t=n>=4||0===n?e.utcThursday(t):e.utcThursday.ceil(t),f(e.utcThursday.count(e.utcYear(t),t)+(4===e.utcYear(t).getUTCDay()),r,2)}function ut(t){return t.getUTCDay()}function ft(t,r){return f(e.utcMonday.count(e.utcYear(t)-1,t),r,2)}function ht(t,e){return f(t.getUTCFullYear()%100,e,2)}function pt(t,e){return f(t.getUTCFullYear()%1e4,e,4)}function dt(){return\"+0000\"}function gt(){return\"%\"}function mt(t){return+t}function vt(t){return Math.floor(+t/1e3)}function yt(e){return o=a(e),t.timeFormat=o.format,t.timeParse=o.parse,t.utcFormat=o.utcFormat,t.utcParse=o.utcParse,o}yt({dateTime:\"%x, %X\",date:\"%-m/%-d/%Y\",time:\"%-I:%M:%S %p\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});var xt=Date.prototype.toISOString?function(t){return t.toISOString()}:t.utcFormat(\"%Y-%m-%dT%H:%M:%S.%LZ\");var bt=+new Date(\"2000-01-01T00:00:00.000Z\")?function(t){var e=new Date(t);return isNaN(e)?null:e}:t.utcParse(\"%Y-%m-%dT%H:%M:%S.%LZ\");t.isoFormat=xt,t.isoParse=bt,t.timeFormatDefaultLocale=yt,t.timeFormatLocale=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-time\":167}],167:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=new Date,r=new Date;function n(t,i,a,o){function s(e){return t(e=0===arguments.length?new Date:new Date(+e)),e}return s.floor=function(e){return t(e=new Date(+e)),e},s.ceil=function(e){return t(e=new Date(e-1)),i(e,1),t(e),e},s.round=function(t){var e=s(t),r=s.ceil(t);return t-e<r-t?e:r},s.offset=function(t,e){return i(t=new Date(+t),null==e?1:Math.floor(e)),t},s.range=function(e,r,n){var a,o=[];if(e=s.ceil(e),n=null==n?1:Math.floor(n),!(e<r&&n>0))return o;do{o.push(a=new Date(+e)),i(e,n),t(e)}while(a<e&&e<r);return o},s.filter=function(e){return n((function(r){if(r>=r)for(;t(r),!e(r);)r.setTime(r-1)}),(function(t,r){if(t>=t)if(r<0)for(;++r<=0;)for(;i(t,-1),!e(t););else for(;--r>=0;)for(;i(t,1),!e(t););}))},a&&(s.count=function(n,i){return e.setTime(+n),r.setTime(+i),t(e),t(r),Math.floor(a(e,r))},s.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?s.filter(o?function(e){return o(e)%t==0}:function(e){return s.count(0,e)%t==0}):s:null}),s}var i=n((function(){}),(function(t,e){t.setTime(+t+e)}),(function(t,e){return e-t}));i.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?n((function(e){e.setTime(Math.floor(e/t)*t)}),(function(e,r){e.setTime(+e+r*t)}),(function(e,r){return(r-e)/t})):i:null};var a=i.range,o=n((function(t){t.setTime(t-t.getMilliseconds())}),(function(t,e){t.setTime(+t+1e3*e)}),(function(t,e){return(e-t)/1e3}),(function(t){return t.getUTCSeconds()})),s=o.range,l=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds())}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getMinutes()})),c=l.range,u=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds()-6e4*t.getMinutes())}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getHours()})),f=u.range,h=n((function(t){t.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/864e5}),(function(t){return t.getDate()-1})),p=h.range;function d(t){return n((function(e){e.setDate(e.getDate()-(e.getDay()+7-t)%7),e.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+7*e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/6048e5}))}var g=d(0),m=d(1),v=d(2),y=d(3),x=d(4),b=d(5),_=d(6),w=g.range,T=m.range,k=v.range,M=y.range,A=x.range,S=b.range,E=_.range,C=n((function(t){t.setDate(1),t.setHours(0,0,0,0)}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t,e){return e.getMonth()-t.getMonth()+12*(e.getFullYear()-t.getFullYear())}),(function(t){return t.getMonth()})),L=C.range,I=n((function(t){t.setMonth(0,1),t.setHours(0,0,0,0)}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t,e){return e.getFullYear()-t.getFullYear()}),(function(t){return t.getFullYear()}));I.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setFullYear(Math.floor(e.getFullYear()/t)*t),e.setMonth(0,1),e.setHours(0,0,0,0)}),(function(e,r){e.setFullYear(e.getFullYear()+r*t)})):null};var P=I.range,z=n((function(t){t.setUTCSeconds(0,0)}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getUTCMinutes()})),O=z.range,D=n((function(t){t.setUTCMinutes(0,0,0)}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getUTCHours()})),R=D.range,F=n((function(t){t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+e)}),(function(t,e){return(e-t)/864e5}),(function(t){return t.getUTCDate()-1})),B=F.range;function N(t){return n((function(e){e.setUTCDate(e.getUTCDate()-(e.getUTCDay()+7-t)%7),e.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+7*e)}),(function(t,e){return(e-t)/6048e5}))}var j=N(0),U=N(1),V=N(2),q=N(3),H=N(4),G=N(5),Y=N(6),W=j.range,X=U.range,Z=V.range,J=q.range,K=H.range,Q=G.range,$=Y.range,tt=n((function(t){t.setUTCDate(1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCMonth(t.getUTCMonth()+e)}),(function(t,e){return e.getUTCMonth()-t.getUTCMonth()+12*(e.getUTCFullYear()-t.getUTCFullYear())}),(function(t){return t.getUTCMonth()})),et=tt.range,rt=n((function(t){t.setUTCMonth(0,1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCFullYear(t.getUTCFullYear()+e)}),(function(t,e){return e.getUTCFullYear()-t.getUTCFullYear()}),(function(t){return t.getUTCFullYear()}));rt.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setUTCFullYear(Math.floor(e.getUTCFullYear()/t)*t),e.setUTCMonth(0,1),e.setUTCHours(0,0,0,0)}),(function(e,r){e.setUTCFullYear(e.getUTCFullYear()+r*t)})):null};var nt=rt.range;t.timeDay=h,t.timeDays=p,t.timeFriday=b,t.timeFridays=S,t.timeHour=u,t.timeHours=f,t.timeInterval=n,t.timeMillisecond=i,t.timeMilliseconds=a,t.timeMinute=l,t.timeMinutes=c,t.timeMonday=m,t.timeMondays=T,t.timeMonth=C,t.timeMonths=L,t.timeSaturday=_,t.timeSaturdays=E,t.timeSecond=o,t.timeSeconds=s,t.timeSunday=g,t.timeSundays=w,t.timeThursday=x,t.timeThursdays=A,t.timeTuesday=v,t.timeTuesdays=k,t.timeWednesday=y,t.timeWednesdays=M,t.timeWeek=g,t.timeWeeks=w,t.timeYear=I,t.timeYears=P,t.utcDay=F,t.utcDays=B,t.utcFriday=G,t.utcFridays=Q,t.utcHour=D,t.utcHours=R,t.utcMillisecond=i,t.utcMilliseconds=a,t.utcMinute=z,t.utcMinutes=O,t.utcMonday=U,t.utcMondays=X,t.utcMonth=tt,t.utcMonths=et,t.utcSaturday=Y,t.utcSaturdays=$,t.utcSecond=o,t.utcSeconds=s,t.utcSunday=j,t.utcSundays=W,t.utcThursday=H,t.utcThursdays=K,t.utcTuesday=V,t.utcTuesdays=Z,t.utcWednesday=q,t.utcWednesdays=J,t.utcWeek=j,t.utcWeeks=W,t.utcYear=rt,t.utcYears=nt,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],168:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=0,s=0,l=0,c=\"object\"==typeof performance&&performance.now?performance:Date,u=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return s||(u(h),s=c.now()+l)}function h(){s=0}function p(){this._call=this._time=this._next=null}function d(t,e,r){var n=new p;return n.restart(t,e,r),n}function g(){f(),++n;for(var t,r=e;r;)(t=s-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){s=(o=c.now())+l,n=i=0;try{g()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,y(a)}(),s=0}}function v(){var t=c.now(),e=t-o;e>1e3&&(l-=e,o=t)}function y(t){n||(i&&(i=clearTimeout(i)),t-s>24?(t<1/0&&(i=setTimeout(m,t-c.now()-l)),a&&(a=clearInterval(a))):(a||(o=c.now(),a=setInterval(v,1e3)),n=1,u(m)))}p.prototype=d.prototype={constructor:p,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,y()},stop:function(){this._call&&(this._call=null,this._time=1/0,y())}},t.interval=function(t,e,r){var n=new p,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart((function a(o){o+=i,n.restart(a,i+=e,r),t(o)}),e,r),n)},t.now=f,t.timeout=function(t,e,r){var n=new p;return e=null==e?0:+e,n.restart((function(r){n.stop(),t(r+e)}),e,r),n},t.timer=d,t.timerFlush=g,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],169:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,f=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){f.call(this,t,e+\"\",r)}}function h(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=h,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(h),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var m=g(h);function v(t){return t.length}t.bisectLeft=m.left,t.bisect=t.bisectRight=m.right,t.bisector=function(t){return g(1===t.length?function(e,r){return h(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,v),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t){for(var e=1;t*e%1;)e*=10;return e}function b(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function _(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=x(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new _;if(t instanceof _)t.forEach((function(t,e){r.set(t,e)}));else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};function w(t){return\"__proto__\"==(t+=\"\")||\"\\0\"===t[0]?\"\\0\"+t:t}function T(t){return\"\\0\"===(t+=\"\")[0]?t.slice(1):t}function k(t){return w(t)in this._}function M(t){return(t=w(t))in this._&&delete this._[t]}function A(){var t=[];for(var e in this._)t.push(T(e));return t}function S(){var t=0;for(var e in this._)++t;return t}function E(){for(var t in this._)return!1;return!0}function C(){this._=Object.create(null)}function L(t){return t}function I(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function P(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=z.length;r<n;++r){var i=z[r]+e;if(i in t)return i}}b(_,{has:k,get:function(t){return this._[w(t)]},set:function(t,e){return this._[w(t)]=e},remove:M,keys:A,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,f,h=-1,p=a.length,d=i[s++],g=new _;++h<p;)(f=g.get(l=d(c=a[h])))?f.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach((function(e,i){n.push({key:e,values:t(i,r)})})),o?n.sort((function(t,e){return o(t.key,e.key)})):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new C;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},b(C,{has:k,add:function(t){return this._[w(t+=\"\")]=!0,t},remove:M,values:A,size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=I(t,e,e[r]);return t};var z=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function O(){}function D(){}function R(t){var e=[],r=new _;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function F(){t.event.preventDefault()}function B(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function N(e){for(var r=new D,n=0,i=arguments.length;++n<i;)r[arguments[n]]=R(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new D,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=R(t);return t},D.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(j,\"\\\\$&\")};var j=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,U={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function V(t){return U(t,Y),t}var q=function(t,e){return e.querySelector(t)},H=function(t,e){return e.querySelectorAll(t)},G=function(t,e){var r=t.matches||t[P(t,\"matchesSelector\")];return(G=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(q=function(t,e){return Sizzle(t,e)[0]||null},H=Sizzle,G=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var Y=t.selection.prototype=[];function W(t){return\"function\"==typeof t?t:function(){return q(t,this)}}function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}Y.select=function(t){var e,r,n,i,a=[];t=W(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return V(a)},Y.selectAll=function(t){var e,r,i=[];t=X(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return V(i)};var Z=\"http://www.w3.org/1999/xhtml\",J={svg:\"http://www.w3.org/2000/svg\",xhtml:Z,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function K(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function $(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function tt(t){return(t+\"\").trim().split(/^|\\s+/)}function et(t,e){var r=(t=tt(t).map(rt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function rt(t){var e=$(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function nt(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function it(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function at(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===Z&&t.documentElement.namespaceURI===Z?t.createElement(e):t.createElementNS(r,e)}}function ot(){var t=this.parentNode;t&&t.removeChild(this)}function st(t){return{__data__:t}}function lt(t){return function(){return G(this,t)}}function ct(t){return arguments.length||(t=h),function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ft(t){return U(t,ht),t}t.ns={prefix:J,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),J.hasOwnProperty(r)?{space:J[r],local:t}:t}},Y.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each(K(r,e[r]));return this}return this.each(K(e,r))},Y.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=tt(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!$(t[i]).test(e))return!1;return!0}for(e in t)this.each(et(e,t[e]));return this}return this.each(et(t,e))},Y.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(nt(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(nt(t,e,r))},Y.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(it(e,t[e]));return this}return this.each(it(t,e))},Y.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},Y.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},Y.append=function(t){return t=at(t),this.select((function(){return this.appendChild(t.apply(this,arguments))}))},Y.insert=function(t,e){return t=at(t),e=W(e),this.select((function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)}))},Y.remove=function(){return this.each(ot)},Y.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,f=Math.min(o,u),h=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,m=new _,v=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(m.has(g=e.call(i,i.__data__,n))?d[n]=i:m.set(g,i),v[n]=g);for(n=-1;++n<u;)(i=m.get(g=e.call(r,a=r[n],n)))?!0!==i&&(h[n]=i,i.__data__=a):p[n]=st(a),m.set(g,!0);for(n=-1;++n<o;)n in v&&!0!==m.get(v[n])&&(d[n]=t[n])}else{for(n=-1;++n<f;)i=t[n],a=r[n],i?(i.__data__=a,h[n]=i):p[n]=st(a);for(;n<u;++n)p[n]=st(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=h,p.parentNode=h.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(h),c.push(d)}var s=ft([]),l=V([]),c=V([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},Y.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},Y.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=lt(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return V(i)},Y.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},Y.sort=function(t){t=ct.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},Y.each=function(t){return ut(this,(function(e,r,n){t.call(e,e.__data__,r,n)}))},Y.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},Y.empty=function(){return!this.node()},Y.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},Y.size=function(){var t=0;return ut(this,(function(){++t})),t};var ht=[];function pt(t){var e,r;return function(n,i,a){var o,s=t[a].update,l=s.length;for(a!=r&&(r=a,e=0),i>=e&&(e=i+1);!(o=s[e])&&++e<l;);return o}}function dt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=mt;o>0&&(e=e.slice(0,o));var l=gt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?O:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ft,t.selection.enter.prototype=ht,ht.append=Y.append,ht.empty=Y.empty,ht.node=Y.node,ht.call=Y.call,ht.size=Y.size,ht.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return V(o)},ht.insert=function(t,e){return arguments.length<2&&(e=pt(this)),Y.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[q(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),V([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(H(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,V([e])},Y.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(dt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(dt(t,e,r))};var gt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function mt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=mt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&gt.forEach((function(t){\"on\"+t in i&&gt.remove(t)}));var yt,xt=0;function bt(e){var r=\".dragsuppress-\"+ ++xt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,F).on(\"dragstart\"+r,F).on(\"selectstart\"+r,F);if(null==yt&&(yt=!(\"onselectstart\"in e)&&P(e.style,\"userSelect\")),yt){var s=a(e).style,l=s[yt];s[yt]=\"none\"}return function(t){if(i.on(r,null),yt&&(s[yt]=l),t){var e=function(){i.on(n,null)};i.on(n,(function(){F(),e()}),!0),setTimeout(e,0)}}}t.mouse=function(t){return wt(t,B())};var _t=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function wt(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(_t<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();_t=!(s.f||s.e),n.remove()}}return _t?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function Tt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=B().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return wt(t,n)},t.behavior.drag=function(){var e=N(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(O,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(Tt,t.touch,L,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=this,u=t.event.target.correspondingElement||t.event.target,f=c.parentNode,h=e.of(c,arguments),p=0,d=n(),g=\".drag\"+(null==d?\"\":\"-\"+d),m=t.select(a(u)).on(o+g,x).on(s+g,b),v=bt(u),y=i(f,d);function x(){var t,e,r=i(f,d);r&&(t=r[0]-y[0],e=r[1]-y[1],p|=t|e,y=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e}))}function b(){i(f,d)&&(m.on(o+g,null).on(s+g,null),v(p),h({type:\"dragend\"}))}l=r?[(l=r.apply(c,arguments)).x-y[0],l.y-y[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=B().touches),e?n(e).map((function(e){var r=wt(t,e);return r.identifier=e.identifier,r})):[]};var kt=1e-6,Mt=1e-12,At=Math.PI,St=2*At,Et=St-kt,Ct=At/2,Lt=At/180,It=180/At;function Pt(t){return t>0?1:t<0?-1:0}function zt(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function Ot(t){return t>1?0:t<-1?At:Math.acos(t)}function Dt(t){return t>1?Ct:t<-1?-Ct:Math.asin(t)}function Rt(t){return((t=Math.exp(t))+1/t)/2}function Ft(t){return(t=Math.sin(t/2))*t}var Bt=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<Mt)n=Math.log(c/o)/Bt,r=function(t){return[i+t*u,a+t*f,o*Math.exp(Bt*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),g=(c*c-o*o-4*h)/(2*c*2*p),m=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(g*g+1)-g);n=(v-m)/Bt,r=function(t){var e,r=t*n,s=Rt(m),l=o/(2*p)*(s*(e=Bt*r+m,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(m));return[i+l*u,a+l*f,o*s/Rt(Bt*r+m)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,f,h={x:0,y:0,k:1},p=[960,500],d=Ut,g=250,m=0,v=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=N(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(v,I).on(jt+\".zoom\",z).on(\"dblclick.zoom\",O).on(b,P)}function T(t){return[(t[0]-h.x)/h.k,(t[1]-h.y)/h.k]}function k(t){h.k=Math.max(d[0],Math.min(d[1],t))}function M(t,e){e=function(t){return[t[0]*h.k+h.x,t[1]*h.k+h.y]}(e),h.x+=t[0]-e[0],h.y+=t[1]-e[1]}function A(e,n,i,a){e.__chart__={x:h.x,y:h.y,k:h.k},k(Math.pow(2,a)),M(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map((function(t){return(t-h.x)/h.k})).map(l.invert)),f&&f.domain(u.range().map((function(t){return(t-h.y)/h.k})).map(u.invert))}function E(t){m++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:h.k,translate:[h.x,h.y]})}function L(t){--m||(t({type:\"zoomend\"}),r=null)}function I(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,l).on(x,c),a=T(t.mouse(e)),s=bt(e);function l(){n=1,M(t.mouse(e),a),C(r)}function c(){i.on(y,null).on(x,null),s(n),L(r)}vs.call(e),E(r)}function P(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],f=t.select(r),p=bt(r);function d(){var n=t.touches(r);return e=h.k,n.forEach((function(t){t.identifier in i&&(i[t.identifier]=T(t))})),n}function g(){var e=t.event.target;t.select(e).on(l,m).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,f=n.length;o<f;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var v=p[0];A(r,v,i[v.identifier],Math.floor(Math.log(h.k)/Math.LN2)+1),F()}s=g}else if(p.length>1){v=p[0];var x=p[1],b=v[0]-x[0],_=v[1]-x[1];a=b*b+_*_}}function m(){var o,l,c,u,f=t.touches(r);vs.call(r);for(var h=0,p=f.length;h<p;++h,u=null)if(c=f[h],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],k(g*e)}s=null,M(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),f.on(v,I).on(b,P),p(),L(n)}g(),E(n),f.on(v,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(vs.call(this),e=T(r=n||t.mouse(this)),E(i)),a=setTimeout((function(){a=null,L(i)}),50),F(),k(Math.pow(2,.002*Nt())*h.k),M(r,e),C(i)}function O(){var e=t.mouse(this),r=Math.log(h.k)/Math.LN2;A(this,e,T(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return jt||(jt=\"onwheel\"in i?(Nt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Nt=function(){return t.event.wheelDelta},\"mousewheel\"):(Nt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each((function(){var e=_.of(this,arguments),n=h;bs?t.select(this).transition().each(\"start.zoom\",(function(){h=this.__chart__||{x:0,y:0,k:1},E(e)})).tween(\"zoom:zoom\",(function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-h.x)/h.k,(s-h.y)/h.k,i/h.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=h={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}})).each(\"interrupt.zoom\",(function(){L(e)})).each(\"end.zoom\",(function(){L(e)})):(this.__chart__=h,E(e),C(e),L(e))}))},w.translate=function(t){return arguments.length?(h={x:+t[0],y:+t[1],k:h.k},S(),w):[h.x,h.y]},w.scale=function(t){return arguments.length?(h={x:h.x,y:h.y,k:null},k(+t),S(),w):h.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?Ut:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),h={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(f=t,u=t.copy(),h={x:0,y:0,k:1},w):f},t.rebind(w,_,\"on\")};var Nt,jt,Ut=[0,1/0];function Vt(){}function qt(t,e,r){return this instanceof qt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof qt?new qt(t.h,t.s,t.l):le(\"\"+t,ce,qt):new qt(t,e,r)}t.color=Vt,Vt.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=qt;var Ht=qt.prototype=new Vt;function Gt(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)||e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ne(a(t+120),a(t),a(t-120))}function Yt(e,r,n){return this instanceof Yt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Yt?new Yt(e.h,e.c,e.l):$t(e instanceof Zt?e.l:(e=ue((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Yt(e,r,n)}Ht.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,this.l/t)},Ht.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,t*this.l)},Ht.rgb=function(){return Gt(this.h,this.s,this.l)},t.hcl=Yt;var Wt=Yt.prototype=new Vt;function Xt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Zt(r,Math.cos(t*=Lt)*e,Math.sin(t)*e)}function Zt(t,e,r){return this instanceof Zt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Zt?new Zt(t.l,t.a,t.b):t instanceof Yt?Xt(t.h,t.c,t.l):ue((t=ne(t)).r,t.g,t.b):new Zt(t,e,r)}Wt.brighter=function(t){return new Yt(this.h,this.c,Math.min(100,this.l+Jt*(arguments.length?t:1)))},Wt.darker=function(t){return new Yt(this.h,this.c,Math.max(0,this.l-Jt*(arguments.length?t:1)))},Wt.rgb=function(){return Xt(this.h,this.c,this.l).rgb()},t.lab=Zt;var Jt=18,Kt=Zt.prototype=new Vt;function Qt(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ne(re(3.2404542*(i=.95047*te(i))-1.5371385*(n=1*te(n))-.4985314*(a=1.08883*te(a))),re(-.969266*i+1.8760108*n+.041556*a),re(.0556434*i-.2040259*n+1.0572252*a))}function $t(t,e,r){return t>0?new Yt(Math.atan2(r,e)*It,Math.sqrt(e*e+r*r),t):new Yt(NaN,NaN,t)}function te(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ee(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function re(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ne(t,e,r){return this instanceof ne?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ne?new ne(t.r,t.g,t.b):le(\"\"+t,ne,Gt):new ne(t,e,r)}function ie(t){return new ne(t>>16,t>>8&255,255&t)}function ae(t){return ie(t)+\"\"}Kt.brighter=function(t){return new Zt(Math.min(100,this.l+Jt*(arguments.length?t:1)),this.a,this.b)},Kt.darker=function(t){return new Zt(Math.max(0,this.l-Jt*(arguments.length?t:1)),this.a,this.b)},Kt.rgb=function(){return Qt(this.l,this.a,this.b)},t.rgb=ne;var oe=ne.prototype=new Vt;function se(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function le(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(he(i[0]),he(i[1]),he(i[2]))}return(a=pe.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function ce(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new qt(n,i,l)}function ue(t,e,r){var n=ee((.4124564*(t=fe(t))+.3575761*(e=fe(e))+.1804375*(r=fe(r)))/.95047),i=ee((.2126729*t+.7151522*e+.072175*r)/1);return Zt(116*i-16,500*(n-i),200*(i-ee((.0193339*t+.119192*e+.9503041*r)/1.08883)))}function fe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function he(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}oe.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ne(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ne(i,i,i)},oe.darker=function(t){return new ne((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},oe.hsl=function(){return ce(this.r,this.g,this.b)},oe.toString=function(){return\"#\"+se(this.r)+se(this.g)+se(this.b)};var pe=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function de(t){return\"function\"==typeof t?t:function(){return t}}function ge(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),me(e,r,t,n)}}function me(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function f(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return this.XDomainRequest&&!(\"withCredentials\"in c)&&/^(http(s)?:)?\\/\\//.test(e)&&(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=f:c.onreadystatechange=function(){c.readyState>3&&f()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach((function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}})),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",(function(t){i(null,t)})),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}pe.forEach((function(t,e){pe.set(t,ie(e))})),t.functor=de,t.xhr=ge(L),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=me(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,(function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map((function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"})).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i}))},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function f(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=f())!==o;){for(var h=[];r!==a&&r!==o;)h.push(r),r=f();e&&null==(h=e(h,u++))||s.push(h)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new C,n=[];return e.forEach((function(t){for(var e in t)r.has(e)||n.push(r.add(e))})),[n.map(l).join(t)].concat(e.map((function(e){return n.map((function(t){return l(e[t])})).join(t)}))).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var ve,ye,xe,be,_e=this[P(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function we(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i=r+e,a={c:t,t:i,n:null};return ye?ye.n=a:ve=a,ye=a,xe||(be=clearTimeout(be),xe=1,_e(Te)),a}function Te(){var t=ke(),e=Me()-t;e>24?(isFinite(e)&&(clearTimeout(be),be=setTimeout(Te,e)),xe=0):(xe=1,_e(Te))}function ke(){for(var t=Date.now(),e=ve;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Me(){for(var t,e=ve,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:ve=e.n;return ye=t,r}function Ae(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){we.apply(this,arguments)},t.timer.flush=function(){ke(),Me()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Se=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map((function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}}));function Ee(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:L;return function(e){var n=Ce.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],f=+n[6],h=n[7],p=n[8],d=n[9],g=1,m=\"\",v=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":h=!0,d=\"g\";break;case\"%\":g=100,v=\"%\",d=\"f\";break;case\"p\":g=100,v=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(m=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(m=a[0],v=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Le.get(d)||Ie;var b=u&&h;return function(e){var n=v;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+v}else e*=g;var _,w,T=(e=d(e,p)).lastIndexOf(\".\");if(T<0){var k=x?e.lastIndexOf(\"e\"):-1;k<0?(_=e,w=\"\"):(_=e.substring(0,k),w=e.substring(k))}else _=e.substring(0,T),w=r+e.substring(T+1);!u&&h&&(_=o(_,1/0));var M=m.length+_.length+w.length+(b?0:a.length),A=M<f?new Array(M=f-M+1).join(i):\"\";return b&&(_=o(A+_,A.length?f-w.length:1/0)),a+=m,e=_+w,(\"<\"===s?a+e+A:\">\"===s?A+a+e:\"^\"===s?A.substring(0,M>>=1)+a+e+A.substring(M):a+(b?e:A+e))+n}}}t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ae(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Se[8+n/3]};var Ce=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Le=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ae(e,r))).toFixed(Math.max(0,Math.min(20,Ae(e*(1+1e-15),r))))}});function Ie(t){return t+\"\"}var Pe=t.time={},ze=Date;function Oe(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}Oe.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){De.setUTCDate.apply(this._,arguments)},setDay:function(){De.setUTCDay.apply(this._,arguments)},setFullYear:function(){De.setUTCFullYear.apply(this._,arguments)},setHours:function(){De.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){De.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){De.setUTCMinutes.apply(this._,arguments)},setMonth:function(){De.setUTCMonth.apply(this._,arguments)},setSeconds:function(){De.setUTCSeconds.apply(this._,arguments)},setTime:function(){De.setTime.apply(this._,arguments)}};var De=Date.prototype;function Re(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new ze(r-1)),1),r}function a(t,r){return e(t=new ze(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Fe(t);return s.floor=s,s.round=Fe(n),s.ceil=Fe(i),s.offset=Fe(a),s.range=function(t,e,r){try{ze=Oe;var n=new Oe;return n._=t,o(n,e,r)}finally{ze=Date}},t}function Fe(t){return function(e,r){try{ze=Oe;var n=new Oe;return n._=e,t(n,r)._}finally{ze=Date}}}function Be(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(f(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&ze!==Oe,i=new(n?Oe:ze);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function f(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(ze=Oe);return r._=t,e(r)}finally{ze=Date}}return r.parse=function(t){try{ze=Oe;var r=e.parse(t);return r&&r._}finally{ze=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var h=t.map(),p=qe(o),d=He(o),g=qe(s),m=He(s),v=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach((function(t,e){h.set(t.toLowerCase(),e)}));var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+Pe.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(Pe.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(Pe.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=m.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){v.lastIndex=0;var n=v.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return f(t,_.c.toString(),e,r)},d:Qe,e:Qe,H:tr,I:tr,j:$e,L:nr,m:Ke,M:er,p:function(t,e,r){var n=h.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return f(t,_.x.toString(),e,r)},X:function(t,e,r){return f(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}Pe.year=Re((function(t){return(t=Pe.day(t)).setMonth(0,1),t}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t){return t.getFullYear()})),Pe.years=Pe.year.range,Pe.years.utc=Pe.year.utc.range,Pe.day=Re((function(t){var e=new ze(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t){return t.getDate()-1})),Pe.days=Pe.day.range,Pe.days.utc=Pe.day.utc.range,Pe.dayOfYear=function(t){var e=Pe.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach((function(t,e){e=7-e;var r=Pe[t]=Re((function(t){return(t=Pe.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t}),(function(t,e){t.setDate(t.getDate()+7*Math.floor(e))}),(function(t){var r=Pe.year(t).getDay();return Math.floor((Pe.dayOfYear(t)+(r+e)%7)/7)-(r!==e)}));Pe[t+\"s\"]=r.range,Pe[t+\"s\"].utc=r.utc.range,Pe[t+\"OfYear\"]=function(t){var r=Pe.year(t).getDay();return Math.floor((Pe.dayOfYear(t)+(r+e)%7)/7)}})),Pe.week=Pe.sunday,Pe.weeks=Pe.sunday.range,Pe.weeks.utc=Pe.sunday.utc.range,Pe.weekOfYear=Pe.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new _,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(t){return{numberFormat:Ee(t),timeFormat:Be(t)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function fr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&hr.hasOwnProperty(t.type)?hr[t.type](t,e):fr(t,e)};var hr={Feature:function(t,e){fr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)fr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)fr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return mr=0,t.geo.stream(e,Cr),mr};var mr,vr,yr,xr,br,_r,wr,Tr,kr,Mr,Ar,Sr,Er=new lr,Cr={sphere:function(){mr+=4*At},point:O,lineStart:O,lineEnd:O,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;mr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=O}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Lt/2+At/4;var a=(t*=Lt)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,f=n*l+u*Math.cos(s),h=u*o*Math.sin(s);Er.add(Math.atan2(h,f)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Lt,n=Math.cos(s=(e=s)*Lt/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Ir(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Pr(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Or(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),Dt(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,f,h={point:p,lineStart:g,lineEnd:m,polygonStart:function(){h.point=v,h.lineStart=x,h.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),h.point=p,h.lineStart=g,h.lineEnd=m,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),f[0]=e,f[1]=n}};function p(t,a){u.push(f=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Ir([t*Lt,o*Lt]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var f=t-a,h=f>0?1:-1,d=u[0]*It*h,g=y(f)>180;if(g^(h*a<d&&d<h*t))(m=u[1]*It)>i&&(i=m);else if(g^(h*a<(d=(d+360)%360-180)&&d<h*t)){var m;(m=-u[1]*It)<r&&(r=m)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){h.point=d}function m(){f[0]=e,f[1]=n,h.point=p,l=null}function v(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){v(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),f[0]=e,f[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function T(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,h),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)T((p=u[o])[0],g)||T(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=f=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){vr=yr=xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,Nr);var r=Mr,n=Ar,i=Sr,a=r*r+n*n+i*i;return a<Mt&&(r=wr,n=Tr,i=kr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Mt)?[NaN,NaN]:[Math.atan2(n,r)*It,Dt(i/Math.sqrt(a))*It]};var Nr={sphere:O,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Lt;var r=Math.cos(e*=Lt);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){++vr,xr+=(t-xr)/vr,br+=(e-br)/vr,_r+=(r-_r)/vr}function Vr(){var t,e,r;function n(n,i){n*=Lt;var a=Math.cos(i*=Lt),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),Tr+=c*(e+(e=s)),kr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Lt;var o=Math.cos(a*=Lt);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Lt;var a=Math.cos(e*=Lt),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,f=r*s-n*o,h=Math.sqrt(c*c+u*u+f*f),p=r*o+n*s+i*l,d=h&&-Ot(p)/h,g=Math.atan2(h,p);Mr+=d*c,Ar+=d*u,Sr+=d*f,yr+=g,wr+=g*(r+(r=o)),Tr+=g*(n+(n=s)),kr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Lt;var l=Math.cos(s*=Lt);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach((function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}})),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,f,h=a[0];;){for(var p=h,d=!0;p.v;)if((p=p.n)===h)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((f=u[s])[0],f[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((f=u[s])[0],f[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:f,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=f,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var f=c[0],h=f[0],p=f[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),m=1;;){m===u&&(m=0);var v=(t=c[m])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=v-h,w=_>=0?1:-1,T=w*_,k=T>At,M=d*x;if(Er.add(Math.atan2(M*w*Math.sin(T),g*b+M*Math.cos(T))),a+=k?_+w*St:_,k^h>=r^v>=r){var A=zr(Ir(f),Ir(t));Rr(A);var S=zr(i,A);Rr(S);var E=(k^_>=0?-1:1)*Dt(S[2]);(n>E||n===E&&(A[0]||A[1]))&&(o+=k^_>=0?1:-1)}if(!m++)break;h=v,d=x,g=b,f=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,$r,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function f(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function h(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=h,l.lineStart()}function d(){u.point=f,l.lineEnd()}var g,m,v=Qr(),y=r(v),x=!1;function b(t,e){m.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),m=[]}function w(){b(m[0][0],m[0][1]),y.lineEnd();var t,e=y.clean(),r=v.buffer(),n=r.length;if(m.pop(),g.push(m),m=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function Qr(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:O,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function $r(t,e){return((t=t.x)[0]<0?t[1]-Ct-kt:Ct-t[1])-((e=e.x)[0]<0?e[1]-Ct-kt:Ct-e[1])}var tn=Jr(Yr,(function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Ct:-Ct),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}}),(function(t,e,r,n){var i;if(null==t)i=r*Ct,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])}),[-At,-At/2]);function en(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,(function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(f,h){var p,d=[f,h],g=i(f,h),m=r?g?0:o(f,h):g?o(f+(f<0?At:-At),h):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var v;m&s||!(v=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(v[0][0],v[0][1]),t.point(v[1][0],v[1][1]),t.lineEnd()):(t.point(v[1][0],v[1][1]),t.lineEnd(),t.lineStart(),t.point(v[0][0],v[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=m},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}}),Bn(t,6*Lt),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Ir(t),Ir(r)),o=Pr(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,f=zr(i,a),h=Dr(i,c);Or(h,Dr(a,u));var p=f,d=Pr(h,p),g=Pr(p,p),m=d*d-g*(Pr(h,h)-1);if(!(m<0)){var v=Math.sqrt(m),x=Dr(p,(-d-v)/g);if(Or(x,h),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],T=t[1],k=r[1];w<_&&(b=_,_=w,w=b);var M=w-_,A=y(M-At)<kt;if(!A&&k<T&&(b=T,T=k,k=b),A||M<kt?A?T+k>0^x[1]<(y(x[0]-_)<kt?T:k):T<=x[1]&&x[1]<=k:M>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+v)/g);return Or(S,h),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}function rn(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,f=1,h=s.x-l,p=s.y-c;if(a=t-l,h||!(a>0)){if(a/=h,h<0){if(a<u)return;a<f&&(f=a)}else if(h>0){if(a>f)return;a>u&&(u=a)}if(a=r-l,h||!(a<0)){if(a/=h,h<0){if(a>f)return;a>u&&(u=a)}else if(h>0){if(a<u)return;a<f&&(f=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<f&&(f=a)}else if(p>0){if(a>f)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>f)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<f&&(f=a)}return u>0&&(i.a={x:l+u*h,y:c+u*p}),f<1&&(i.b={x:l+f*h,y:c+f*p}),i}}}}}}function nn(e,r,n,i){return function(l){var c,u,f,h,p,d,g,m,v,y,x,b=l,_=Qr(),w=rn(e,r,n,i),T={point:A,lineStart:function(){T.point=S,u&&u.push(f=[]);y=!0,v=!1,g=m=NaN},lineEnd:function(){c&&(S(h,p),d&&v&&_.rejoin(),c.push(_.buffer()));T.point=A,v&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&zt(c,a,t)>0&&++e:a[1]<=n&&zt(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),k(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,k,l),l.polygonEnd()),c=u=f=null}};function k(t,o,l,c){var u=0,f=0;if(null==t||(u=a(t,l))!==(f=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==f);else c.point(o[0],o[1])}function M(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function A(t,e){M(t,e)&&l.point(t,e)}function S(t,e){var r=M(t=Math.max(-1e9,Math.min(1e9,t)),e=Math.max(-1e9,Math.min(1e9,e)));if(u&&f.push([t,e]),y)h=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&v)l.point(t,e);else{var n={a:{x:g,y:m},b:{x:t,y:e}};w(n)?(v||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,m=e,v=r}return T};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Ln(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,Dt((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],f=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,f-.238*e],[u+.455*e,f+.238*e]]).stream(l).point,n=o.translate([u-.307*e,f+.201*e]).clipExtent([[u-.425*e+kt,f+.12*e+kt],[u-.214*e-kt,f+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,f+.212*e]).clipExtent([[u-.214*e+kt,f+.166*e+kt],[u-.115*e-kt,f+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,fn,hn,pn={point:O,lineStart:O,lineEnd:O,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=O,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>fn&&(fn=t);e<un&&(un=e);e>hn&&(hn=e)},lineStart:O,lineEnd:O,polygonStart:O,polygonEnd:O};function mn(){var t=vn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=vn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function vn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=Tn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,Tr+=o*(e+n)/2,kr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function Tn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,Tr+=o*(n+e)/2,kr+=o,Mr+=(o=n*t-r*e)*(r+t),Ar+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function kn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:O};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,St)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function Mn(t){var e=.5,r=Math.cos(30*Lt),n=16;function i(t){return(n?o:a)(t)}function a(e){return En(e,(function(r,n){r=t(r,n),e.point(r[0],r[1])}))}function o(e){var r,i,a,o,l,c,u,f,h,p,d,g,m={point:v,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),m.lineStart=_},polygonEnd:function(){e.polygonEnd(),m.lineStart=y}};function v(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){f=NaN,m.point=x,e.lineStart()}function x(r,i){var a=Ir([r,i]),o=t(r,i);s(f,h,u,p,d,g,f=o[0],h=o[1],u=r,p=a[0],d=a[1],g=a[2],n,e),e.point(f,h)}function b(){m.point=v,e.lineEnd()}function _(){y(),m.point=w,m.lineEnd=T}function w(t,e){x(r=t,e),i=f,a=h,o=p,l=d,c=g,m.point=x}function T(){s(f,h,u,p,d,g,i,a,r,o,l,c,n,e),m.lineEnd=b,b()}return m}function s(n,i,a,o,l,c,u,f,h,p,d,g,m,v){var x=u-n,b=f-i,_=x*x+b*b;if(_>4*e&&m--){var w=o+p,T=l+d,k=c+g,M=Math.sqrt(w*w+T*T+k*k),A=Math.asin(k/=M),S=y(y(k)-1)<kt||y(a-h)<kt?(a+h)/2:Math.atan2(T,w),E=t(S,A),C=E[0],L=E[1],I=C-n,P=L-i,z=b*I-x*P;(z*z/_>e||y((x*I+b*P)/_-.5)>.3||o*p+l*d+c*g<r)&&(s(n,i,a,o,l,c,C,L,S,w/=M,T/=M,k,m,v),v.point(C,L),s(C,L,S,w,T,k,u,f,h,p,d,g,m,v))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function An(t){var e=Mn((function(e,r){return t([e*It,r*It])}));return function(t){return In(e(t))}}function Sn(t){this.stream=t}function En(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function Cn(t){return Ln((function(){return t}))()}function Ln(e){var r,n,i,a,o,s,l=Mn((function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]})),c=150,u=480,f=250,h=0,p=0,d=0,g=0,m=0,v=tn,y=L,x=null,b=null;function _(t){return[(t=i(t[0]*Lt,t[1]*Lt))[0]*c+a,o-t[1]*c]}function w(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*It,t[1]*It]}function T(){i=Gr(n=On(d,g,m),r);var t=r(h,p);return a=u-t[0]*c,o=f+t[1]*c,k()}function k(){return s&&(s.valid=!1,s=null),_}return _.stream=function(t){return s&&(s.valid=!1),(s=In(v(n,l(y(t))))).valid=!0,s},_.clipAngle=function(t){return arguments.length?(v=null==t?(x=t,tn):en((x=+t)*Lt),k()):x},_.clipExtent=function(t){return arguments.length?(b=t,y=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):L,k()):b},_.scale=function(t){return arguments.length?(c=+t,T()):c},_.translate=function(t){return arguments.length?(u=+t[0],f=+t[1],T()):[u,f]},_.center=function(t){return arguments.length?(h=t[0]%360*Lt,p=t[1]%360*Lt,T()):[h*It,p*It]},_.rotate=function(t){return arguments.length?(d=t[0]%360*Lt,g=t[1]%360*Lt,m=t.length>2?t[2]%360*Lt:0,T()):[d*It,g*It,m*It]},t.rebind(_,l,\"precision\"),function(){return r=e.apply(this,arguments),_.invert=r.invert&&w,T()}}function In(t){return En(t,(function(e,r){t.point(e*Lt,r*Lt)}))}function Pn(t,e){return[t,e]}function zn(t,e){return[t>At?t-St:t<-At?t+St:t,e]}function On(t,e,r){return t?e||r?Gr(Rn(t),Fn(e,r)):Rn(t):e||r?Fn(e,r):zn}function Dn(t){return function(e,r){return[(e+=t)>At?e-St:e<-At?e+St:e,r]}}function Rn(t){var e=Dn(t);return e.invert=Dn(-t),e}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),Dt(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),Dt(u*r-s*n)]},o}function Bn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Nn(r,i),a=Nn(r,a),(o>0?i<a:i>a)&&(i+=o*St)):(i=t+o*St,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Nn(t,e){var r=Ir(e);r[0]-=t,Rr(r);var n=Ot(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map((function(e){return[t,e]}))}}function Un(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map((function(e){return[e,t]}))}}function Vn(t){return t.source}function qn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,n(xn)),Sr?[Mr/Sr,Ar/Sr]:kr?[wr/kr,Tr/kr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return fn=hn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[fn,hn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||An(t):L,l()):e},s.context=function(t){return arguments.length?(i=null==(r=t)?new mn:new kn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Sn(e);for(var n in t)r[n]=t[n];return r}}},Sn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=Cn,t.geo.projectionMutator=Ln,(t.geo.equirectangular=function(){return Cn(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Lt,e[1]*Lt))[0]*=It,e[1]*=It,e}return t=On(t[0]%360*Lt,t[1]*Lt,t.length>2?t[2]*Lt:0),e.invert=function(e){return(e=t.invert(e[0]*Lt,e[1]*Lt))[0]*=It,e[1]*=It,e},e},zn.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=On(-t[0]*Lt,-t[1]*Lt,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=It,t[1]*=It}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Bn((t=+r)*Lt,n*Lt),i):t},i.precision=function(r){return arguments.length?(e=Bn(t*Lt,(n=+r)*Lt),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Lt,i=t[1]*Lt,a=e[1]*Lt,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),f=Math.cos(a);return Math.atan2(Math.sqrt((r=f*o)*r+(r=c*u-l*f*s)*r),l*u+c*f*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,f,h,p=10,d=p,g=90,m=360,v=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(f).concat(t.range(Math.ceil(l/m)*m,s,m).map(h)).concat(t.range(Math.ceil(r/p)*p,e,p).filter((function(t){return y(t%g)>kt})).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter((function(t){return y(t%m)>kt})).map(u))}return x.lines=function(){return b().map((function(t){return{type:\"LineString\",coordinates:t}}))},x.outline=function(){return{type:\"Polygon\",coordinates:[f(i).concat(h(s).slice(1),f(n).reverse().slice(1),h(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(v)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(v)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],m=+t[1],x):[g,m]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(v=+t,c=jn(o,a,90),u=Un(r,e,v),f=jn(l,s,90),h=Un(i,n,v),x):v},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Vn,i=qn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Lt,n=t[1]*Lt,i=e[0]*Lt,a=e[1]*Lt,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),f=o*Math.sin(r),h=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Ft(a-n)+o*l*Ft(i-r))),g=1/Math.sin(d),(m=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*h,i=r*f+e*p,a=r*s+e*c;return[Math.atan2(i,n)*It,Math.atan2(a,Math.sqrt(n*n+i*i))*It]}:function(){return[r*It,n*It]}).distance=d,m;var r,n,i,a,o,s,l,c,u,f,h,p,d,g,m},t.geo.length=function(e){return yn=0,t.geo.stream(e,Hn),yn};var Hn={sphere:O,point:O,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Lt),o=Math.cos(i),s=y((n*=Lt)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}Hn.point=function(i,a){t=i*Lt,e=Math.sin(a*=Lt),r=Math.cos(a),Hn.point=n},Hn.lineEnd=function(){Hn.point=Hn.lineEnd=O}},lineEnd:O,polygonStart:O,polygonEnd:O};function Gn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Yn=Gn((function(t){return Math.sqrt(2/(1+t))}),(function(t){return 2*Math.asin(t/2)}));(t.geo.azimuthalEqualArea=function(){return Cn(Yn)}).raw=Yn;var Wn=Gn((function(t){var e=Math.acos(t);return e&&e/Math.sin(e)}),L);function Xn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Kn;function o(t,e){a>0?e<-Ct+kt&&(e=-Ct+kt):e>Ct-kt&&(e=Ct-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Ct]},o}function Zn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return Cn(Wn)}).raw=Wn,(t.geo.conicConformal=function(){return an(Xn)}).raw=Xn,(t.geo.conicEquidistant=function(){return an(Zn)}).raw=Zn;var Jn=Gn((function(t){return 1/t}),Math.atan);function Kn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Qn(t){var e,r=Cn(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return Cn(Jn)}).raw=Jn,Kn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Ct]},(t.geo.mercator=function(){return Qn(Kn)}).raw=Kn;var $n=Gn((function(){return 1}),Math.asin);(t.geo.orthographic=function(){return Cn($n)}).raw=$n;var ti=Gn((function(t){return 1/(1+t)}),(function(t){return 2*Math.atan(t)}));function ei(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ri(t){return t[0]}function ni(t){return t[1]}function ii(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&zt(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ai(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return Cn(ti)}).raw=ti,ei.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Ct]},(t.geo.transverseMercator=function(){var t=Qn(ei),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ei,t.geom={},t.geom.hull=function(t){var e=ri,r=ni;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=de(e),a=de(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ai),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ii(s),u=ii(l),f=u[0]===c[0],h=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+f;n<u.length-h;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return U(t,oi),t};var oi=t.geom.polygon.prototype=[];function si(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function li(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,f=n[1]-c,h=(s*(l-c)-f*(i-a))/(f*o-s*u);return[i+h*o,l+h*u]}function ci(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}oi.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},oi.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},oi.clip=function(t){for(var e,r,n,i,a,o,s=ci(t),l=-1,c=this.length-ci(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)si(o=e[r],u,i)?(si(a,u,i)||t.push(li(a,o,u,i)),t.push(o)):si(a,u,i)&&t.push(li(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ui,fi,hi,pi,di,gi=[],mi=[];function vi(){Ri(this),this.edge=this.site=this.circle=null}function yi(t){var e=gi.pop()||new vi;return e.site=t,e}function xi(t){Ei(t),hi.remove(t),gi.push(t),Ri(t)}function bi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];xi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),xi(l),l=a;s.unshift(l),Ei(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),xi(c),c=o;s.push(c),Ei(c);var u,f=s.length;for(u=1;u<f;++u)c=s[u],l=s[u-1],zi(c.edge,l.site,c.site,i);l=s[0],(c=s[f-1]).edge=Ii(l.site,c.site,null,i),Si(l),Si(c)}function _i(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=wi(s,o)-a)>kt)s=s.L;else{if(!((i=a-Ti(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=yi(t);if(hi.insert(e,l),e||r){if(e===r)return Ei(e),r=yi(e.site),hi.insert(l,r),l.edge=r.edge=Ii(e.site,l.site),Si(e),void Si(r);if(r){Ei(e),Ei(r);var c=e.site,u=c.x,f=c.y,h=t.x-u,p=t.y-f,d=r.site,g=d.x-u,m=d.y-f,v=2*(h*m-p*g),y=h*h+p*p,x=g*g+m*m,b={x:(m*y-p*x)/v+u,y:(h*x-g*y)/v+f};zi(r.edge,c,d,b),l.edge=Ii(c,t,null,b),r.edge=Ii(t,d,null,b),Si(e),Si(r)}else l.edge=Ii(e.site,l.site)}}function wi(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,f=1/a-1/c,h=u/c;return f?(-h+Math.sqrt(h*h-2*f*(u*u/(-2*c)-l+c/2+i-a/2)))/f+n:(n+s)/2}function Ti(t,e){var r=t.N;if(r)return wi(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Mi(t,e){return e.angle-t.angle}function Ai(){Ri(this),this.x=this.y=this.arc=this.site=this.cy=null}function Si(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,f=2*(l*(m=a.y-s)-c*u);if(!(f>=-Mt)){var h=l*l+c*c,p=u*u+m*m,d=(m*h-c*p)/f,g=(l*p-u*h)/f,m=g+s,v=mi.pop()||new Ai;v.arc=t,v.site=i,v.x=d+o,v.y=m+Math.sqrt(d*d+g*g),v.cy=m,t.circle=v;for(var y=null,x=di._;x;)if(v.y<x.y||v.y===x.y&&v.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}di.insert(y,v),y||(pi=v)}}}}function Ei(t){var e=t.circle;e&&(e.P||(pi=e.N),di.remove(e),mi.push(e),Ri(e),t.circle=null)}function Ci(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,f=t.r,h=u.x,p=u.y,d=f.x,g=f.y,m=(h+d)/2,v=(p+g)/2;if(g===p){if(m<o||m>=s)return;if(h>d){if(a){if(a.y>=c)return}else a={x:m,y:l};r={x:m,y:c}}else{if(a){if(a.y<l)return}else a={x:m,y:c};r={x:m,y:l}}}else if(i=v-(n=(h-d)/(g-p))*m,n<-1||n>1)if(h>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Li(t,e){this.l=t,this.r=e,this.a=this.b=null}function Ii(t,e,r,n){var i=new Li(t,e);return ui.push(i),r&&zi(i,t,e,r),n&&zi(i,e,t,n),fi[t.i].edges.push(new Oi(i,t,e)),fi[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r){var n=new Li(t,null);return n.a=e,n.b=r,ui.push(n),n}function zi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function Di(){this._=null}function Ri(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Fi(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Bi(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Ni(t){for(;t.L;)t=t.L;return t}function ji(t,e){var r,n,i,a=t.sort(Ui).pop();for(ui=[],fi=new Array(t.length),hi=new Di,di=new Di;;)if(i=pi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(fi[a.i]=new ki(a),_i(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;bi(i.arc)}e&&(function(t){for(var e,r=ui,n=rn(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ci(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,f=t[0][0],h=t[1][0],p=t[0][1],d=t[1][1],g=fi,m=g.length;m--;)if((a=g[m])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi(Pi(a.site,u,y(n-f)<kt&&d-i>kt?{x:f,y:y(e-f)<kt?r:d}:y(i-d)<kt&&h-n>kt?{x:y(r-d)<kt?e:h,y:d}:y(n-h)<kt&&i-p>kt?{x:h,y:y(e-h)<kt?r:p}:y(i-p)<kt&&n-f>kt?{x:y(r-p)<kt?e:f,y:p}:null),a.site,null)),++l)}(e));var o={cells:fi,edges:ui};return hi=di=ui=fi=null,o}function Ui(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Mi),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},Di.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Ni(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Fi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Bi(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Bi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Fi(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Ni(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Fi(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Bi(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Fi(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Bi(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Fi(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Bi(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ri,r=ni,n=e,i=r,a=Vi;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return ji(s(t),a).cells.forEach((function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map((function(t){var e=t.start();return[e.x,e.y]})):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]})),e}function s(t){return t.map((function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}}))}return o.links=function(t){return ji(s(t)).edges.filter((function(t){return t.l&&t.r})).map((function(e){return{source:t[e.l.i],target:t[e.r.i]}}))},o.triangles=function(t){var e=[];return ji(s(t)).cells.forEach((function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Mi),u=-1,f=c.length,h=c[f-1].edge,p=h.l===l?h.r:h.l;++u<f;)h,i=p,p=(h=c[u].edge).l===l?h.r:h.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])})),e},o.x=function(t){return arguments.length?(n=de(e=t),o):e},o.y=function(t){return arguments.length?(i=de(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?Vi:t,o):a===Vi?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===Vi?null:a&&a[1]},o};var Vi=[[-1e6,-1e6],[1e6,1e6]];function qi(t){return t.x}function Hi(t){return t.y}function Gi(t,e,r,n,i,a){if(!t(e,r,n,i,a)){var o=.5*(r+i),s=.5*(n+a),l=e.nodes;l[0]&&Gi(t,l[0],r,n,o,s),l[1]&&Gi(t,l[1],o,n,i,s),l[2]&&Gi(t,l[2],r,s,o,a),l[3]&&Gi(t,l[3],o,s,i,a)}}function Yi(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,f,h,p){if(!(u>a||f>o||h<n||p<i)){if(d=c.point){var d,g=e-c.x,m=r-c.y,v=g*g+m*m;if(v<l){var y=Math.sqrt(l=v);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+h),_=.5*(f+p),w=(r>=_)<<1|e>=b,T=w+4;w<T;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,f,b,_);break;case 1:t(c,b,f,h,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,h,p)}}}(t,n,i,a,o),s}function Wi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+se(Math.round(n+o*t))+se(Math.round(i+s*t))+se(Math.round(a+l*t))}}function Xi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=$i(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Zi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Ji(t,e){var r,n,i,a=Ki.lastIndex=Qi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Ki.exec(t))&&(n=Qi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Zi(r,n)})),a=Qi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ri,s=ni;if(a=arguments.length)return o=qi,s=Hi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,f,h,p,d,g,m,v=de(o),x=de(s);if(null!=e)p=e,d=r,g=n,m=i;else if(g=m=-(p=d=1/0),c=[],u=[],h=t.length,a)for(f=0;f<h;++f)(l=t[f]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>m&&(m=l.y),c.push(l.x),u.push(l.y);else for(f=0;f<h;++f){var b=+v(l=t[f],f),_=+x(l,f);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>m&&(m=_),c.push(b),u.push(_)}var w=g-p,T=m-d;function k(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)M(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,M(t,u,l,c,i,a,o,s),M(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else M(t,e,r,n,i,a,o,s)}function M(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,f=n>=c,h=f<<1|u;t.leaf=!1,u?i=l:o=l,f?a=c:s=c,k(t=t.nodes[h]||(t.nodes[h]={leaf:!0,nodes:[],point:null,x:null,y:null}),e,r,n,i,a,o,s)}w>T?m=d+w:g=p+T;var A={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){k(A,t,+v(t,++f),+x(t,f),p,d,g,m)},visit:function(t){Gi(t,A,p,d,g,m)},find:function(t){return Yi(A,t[0],t[1],p,d,g,m)}};if(f=-1,null==e){for(;++f<h;)k(A,t[f],c[f],u[f],p,d,g,m);--f}else t.forEach(A.add);return c=u=t=l=null,A}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=Wi,t.interpolateObject=Xi,t.interpolateNumber=Zi,t.interpolateString=Ji;var Ki=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Qi=new RegExp(Ki.source,\"g\");function $i(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function ta(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push($i(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=$i,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?pe.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?Wi:Ji:e instanceof Vt?Wi:Array.isArray(e)?ta:\"object\"===r&&isNaN(e)?Xi:Zi)(t,e)}],t.interpolateArray=ta;var ea=function(){return L},ra=t.map({linear:ea,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return sa},cubic:function(){return la},sin:function(){return ua},exp:function(){return fa},circle:function(){return ha},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/St*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*St/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return pa}}),na=t.map({in:L,out:aa,\"in-out\":oa,\"out-in\":function(t){return oa(aa(t))}});function ia(t){return function(e){return e<=0?0:e>=1?1:t(e)}}function aa(t){return function(e){return 1-t(1-e)}}function oa(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function sa(t){return t*t}function la(t){return t*t*t}function ca(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function ua(t){return 1-Math.cos(t*Ct)}function fa(t){return Math.pow(2,10*(t-1))}function ha(t){return 1-Math.sqrt(1-t*t)}function pa(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function da(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ga(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=va(i),s=ma(i,a),l=va(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*It,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*It:0}function ma(t,e){return t[0]*e[0]+t[1]*e[1]}function va(t){var e=Math.sqrt(ma(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e=t.indexOf(\"-\"),n=e>=0?t.slice(0,e):t,i=e>=0?t.slice(e+1):\"in\";return n=ra.get(n)||ea,ia((i=na.get(i)||L)(n.apply(null,r.call(arguments,1))))},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Xt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Gt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return Qt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=da,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ga(e?e.matrix:ya)})(e)},ga.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var ya={a:1,b:0,c:0,d:1,e:0,f:0};function xa(t){return t.length?t.pop()+\",\":\"\"}function ba(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Zi(t[0],e[0])},{i:i-2,x:Zi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(xa(r)+\"rotate(\",null,\")\")-2,x:Zi(t,e)})):e&&r.push(xa(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(xa(r)+\"skewX(\",null,\")\")-2,x:Zi(t,e)}):e&&r.push(xa(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(xa(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Zi(t[0],e[0])},{i:i-2,x:Zi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(xa(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function _a(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function wa(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function Ta(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=ka(t),n=ka(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function ka(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function Ma(t){t.fixed|=2}function Aa(t){t.fixed&=-7}function Sa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function Ea(t){t.fixed&=-5}t.interpolateTransform=ba,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(Ta(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,h,p,d,g={},m=[],v=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];m.push(u),y.push(t.range(i)),l+=u}for(a&&v.sort((function(t,e){return a(m[t],m[e])})),o&&y.forEach((function(t,e){t.sort((function(t,r){return o(n[e][t],n[e][r])}))})),l=(St-c*i)/l,u=0,p=-1;++p<i;){for(h=u,d=-1;++d<i;){var x=v[p],b=y[x][d],_=n[x][b],w=u,T=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:T,value:_}}r[x]={index:x,startAngle:h,endAngle:u,value:m[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var k=g[p+\"-\"+d],M=g[d+\"-\"+p];(k.value||M.value)&&e.push(k.value<M.value?{source:M,target:k}:{source:k,target:M})}s&&f()}function f(){e.sort((function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)}))}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&f(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,f=Ca,h=La,p=-30,d=Ia,g=.1,m=.64,v=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/m<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,f,h,d,m,b,_,w,T=v.length,k=y.length;for(s=0;s<k;++s)h=(f=y[s]).source,(m=(_=(d=f.target).x-h.x)*_+(w=d.y-h.y)*w)&&(_*=m=n*a[s]*((m=Math.sqrt(m))-i[s])/m,w*=m,d.x-=_*(b=h.weight+d.weight?h.weight/(h.weight+d.weight):.5),d.y-=w*b,h.x+=_*(b=1-b),h.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<T;)(f=v[s]).x+=(_-f.x)*b,f.y+=(w-f.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;if(e.charge=0,!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge,e.cy=a/e.charge}(r=t.geom.quadtree(v),n,o),s=-1;++s<T;)(f=v[s]).fixed||r.visit(x(f));for(s=-1;++s<T;)(f=v[s]).fixed?(f.x=f.px,f.y=f.py):(f.x-=(f.px-(f.px=f.x))*u,f.y-=(f.py-(f.py=f.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(v=t,s):v},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(m=t*t,s):Math.sqrt(m)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=we(s.tick)),s):n},s.start=function(){var t,e,r,n=v.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=v[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=v[r.source]),\"number\"==typeof r.target&&(r.target=v[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=v[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof f)for(t=0;t<l;++t)i[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=f;if(a=[],\"function\"==typeof h)for(t=0;t<l;++t)a[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=h;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,v[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(L).on(\"dragstart.force\",Ma).on(\"drag.force\",b).on(\"dragend.force\",Aa)),!arguments.length)return r;this.on(\"mouseover.force\",Sa).on(\"mouseout.force\",Ea).call(r)},t.rebind(s,l,\"on\")};var Ca=20,La=1,Ia=1/0;function Pa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=Ba,e}function za(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Oa(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function Da(t){return t.children}function Ra(t){return t.value}function Fa(t,e){return e.value-t.value}function Ba(e){return t.merge(e.map((function(t){return(t.children||[]).map((function(e){return{source:t,target:e}}))})))}t.layout.hierarchy=function(){var t=Fa,e=Da,r=Ra;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Oa(i,(function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)})),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(za(t,(function(t){t.children&&(t.value=0)})),Oa(t,(function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)}))),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Pa(n,e)},t.layout.pie=function(){var e=Number,r=Na,n=0,i=St,a=0;function o(s){var l,c=s.length,u=s.map((function(t,r){return+e.call(o,t,r)})),f=+(\"function\"==typeof n?n.apply(this,arguments):n),h=(\"function\"==typeof i?i.apply(this,arguments):i)-f,p=Math.min(Math.abs(h)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(h<0?-1:1),g=t.sum(u),m=g?(h-c*d)/g:0,v=t.range(c),y=[];return null!=r&&v.sort(r===Na?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),v.forEach((function(t){y[t]={data:s[t],value:l=u[t],startAngle:f,endAngle:f+=l*m+d,padAngle:p}})),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Na={};function ja(t){return t.x}function Ua(t){return t.y}function Va(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=L,r=Ga,n=Ya,i=Va,a=ja,o=Ua;function s(l,c){if(!(p=l.length))return l;var u=l.map((function(t,r){return e.call(s,t,r)})),f=u.map((function(t){return t.map((function(t,e){return[a.call(s,t,e),o.call(s,t,e)]}))})),h=r.call(s,f,c);u=t.permute(u,h),f=t.permute(f,h);var p,d,g,m,v=n.call(s,f,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],m=v[g],f[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],m+=f[d-1][g][1],f[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:qa.get(t)||Ga,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Ha.get(t)||Ya,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var qa=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Wa),o=e.map(Xa),s=t.range(i).sort((function(t,e){return a[t]-a[e]})),l=0,c=0,u=[],f=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],f.push(n));return f.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:Ga}),Ha=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,f=t[0],h=f.length,p=[];for(p[0]=l=c=0,r=1;r<h;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=f[r][0]-f[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<h;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ya});function Ga(e){return t.range(e.length)}function Ya(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Wa(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function Xa(t){return t.reduce(Za,0)}function Za(t,e){return t+e[1]}function Ja(t,e){return Ka(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ka(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Qa(e){return[t.min(e),t.max(e)]}function $a(t,e){return t.value-e.value}function to(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function eo(t,e){t._pack_next=e,e._pack_prev=t}function ro(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function no(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,f=1/0,h=-1/0;if(e.forEach(io),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(oo(r,n,i=e[2]),x(i),to(r,i),r._pack_prev=i,to(i,n),n=r._pack_next,a=3;a<l;a++){oo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(ro(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!ro(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?eo(r,n=o):eo(r=s,n),a--):(to(r,i),n=i,x(i))}var m=(c+u)/2,v=(f+h)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=m,i.y-=v,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(ao)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),f=Math.min(t.y-t.r,f),h=Math.max(t.y+t.r,h)}}function io(t){t._pack_next=t._pack_prev=t}function ao(t){delete t._pack_next,delete t._pack_prev}function oo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function so(t,e){return t.parent==e.parent?1:2}function lo(t){var e=t.children;return e.length?e[0]:t.t}function co(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function uo(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function fo(t,e,r){return t.a.parent===e.parent?t.a:r}function ho(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function po(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function go(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function mo(t){return t.rangeExtent?t.rangeExtent():go(t.range())}function vo(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function yo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function xo(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:bo}t.layout.histogram=function(){var e=!0,r=Number,n=Qa,i=Ja;function a(a,o){for(var s,l,c=[],u=a.map(r,this),f=n.call(this,u,o),h=i.call(this,f,u,o),p=(o=-1,u.length),d=h.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=h[o+1]-(s.x=h[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=f[0]&&l<=f[1]&&((s=c[t.bisect(h,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=de(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ka(e,t)}:de(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort($a),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Oa(s,(function(t){t.r=+u(t.value)})),Oa(s,no),n){var f=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Oa(s,(function(t){t.r+=f})),Oa(s,no),Oa(s,(function(t){t.r-=f}))}return function t(e,r,n,i){var a=e.children;if(e.x=r+=i*e.x,e.y=n+=i*e.y,e.r*=i,a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Pa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],f=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Oa(f,o),f.parent.m=-f.z,za(f,s),i)za(u,l);else{var h=u,p=u,d=u;za(u,(function(t){t.x<h.x&&(h=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)}));var g=r(h,p)/2-h.x,m=n[0]/(p.x+r(p,h)/2+g),v=n[1]/(d.depth||1);za(u,(function(t){t.x=(t.x+g)*m,t.y=t.depth*v}))}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=co(s),a=lo(a),s&&a;)l=lo(l),(o=co(o)).a=t,(i=s.z+f-a.z-c+r(s._,a._))>0&&(uo(fo(s,t,n),t,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!co(o)&&(o.t=s,o.m+=f-u),a&&!lo(l)&&(l.t=a,l.m+=c-h,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Pa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Oa(c,(function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce((function(t,e){return t+e.x}),0)/t.length}(n),e.y=function(e){return 1+t.max(e,(function(t){return t.y}))}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)}));var f=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),h=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=f.x-r(f,h)/2,d=h.x+r(h,f)/2;return Oa(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Pa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=ho,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function f(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),h=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=h?(c.pop(),h=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,h=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(f)}}function h(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(h)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?h:f)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){var r=t.call(g,e,e.depth);return null==r?ho(e):po(e,\"number\"==typeof r?[r,r,r,r]:r)}function r(e){return po(e,t)}var n;return o=null==(a=t)?ho:\"function\"==(n=typeof t)?e:\"number\"===n?(t=[t,t,t,t],r):r,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Pa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var bo={floor:L,ceil:L};function _o(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function wo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function To(t,e){return yo(t,xo(ko(t,e)[2])),yo(t,xo(ko(t,e)[2])),t}function ko(t,e){null==e&&(e=10);var r=go(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function Mo(e,r){return t.range.apply(t,ko(e,r))}function Ao(e,r,n){var i=ko(e,r);if(n){var a=Ce.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+Eo(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=Eo(e[2]);return t in So?Math.abs(r-Eo(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+Eo(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?_o:vo,s=i?wa:_a;return a=t(e,r,s,n),o=t(r,e,s,$i),l}function l(t){return a(t)}return l.invert=function(t){return o(t)},l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e},l.range=function(t){return arguments.length?(r=t,s()):r},l.rangeRound=function(t){return l.range(t).interpolate(da)},l.clamp=function(t){return arguments.length?(i=t,s()):i},l.interpolate=function(t){return arguments.length?(n=t,s()):n},l.ticks=function(t){return Mo(e,t)},l.tickFormat=function(t,r){return Ao(e,t,r)},l.nice=function(t){return To(e,t),s()},l.copy=function(){return t(e,r,n,i)},s()}([0,1],[0,1],$i,!1)};var So={s:1,g:1,p:1,r:1,e:1};function Eo(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}return l.invert=function(t){return s(r.invert(t))},l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a},l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n},l.nice=function(){var t=yo(a.map(o),i?Math:Lo);return r.domain(t),a=t.map(s),l},l.ticks=function(){var t=go(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),f=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var h=1;h<f;h++)e.push(s(c)*h);e.push(s(c))}else for(e.push(s(c));c++<u;)for(h=f-1;h>0;h--)e.push(s(c)*h);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e},l.tickFormat=function(e,r){if(!arguments.length)return Co;arguments.length<2?r=Co:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}},l.copy=function(){return e(r.copy(),n,i,a)},wo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var Co=t.format(\".0e\"),Lo={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Io(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Io(r),a=Io(1/r);function o(t){return e(i(t))}return o.invert=function(t){return a(e.invert(t))},o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n},o.ticks=function(t){return Mo(n,t)},o.tickFormat=function(t,e){return Ao(n,t,e)},o.nice=function(t){return o.domain(To(n,t))},o.exponent=function(t){return arguments.length?(i=Io(r=t),a=Io(1/r),e.domain(n.map(i)),o):r},o.copy=function(){return t(e.copy(),r,n)},wo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map((function(t){return e+n*t}))}return s.domain=function(t){if(!arguments.length)return r;r=[],i=new _;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)},s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a},s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s},s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s},s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=(f-u)/(r.length-e+2*i);return a=l(u+h*i,h),c&&a.reverse(),o=h*(1-e),n={t:\"rangeBands\",a:arguments},s},s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=Math.floor((f-u)/(r.length-e+2*i));return a=l(u+Math.round((f-u-(r.length-e)*h)/2),h),c&&a.reverse(),o=Math.round(h*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s},s.rangeBand=function(){return o},s.rangeExtent=function(){return go(n.a[0])},s.copy=function(){return e(r,n)},s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(Po)},t.scale.category20=function(){return t.scale.ordinal().range(zo)},t.scale.category20b=function(){return t.scale.ordinal().range(Oo)},t.scale.category20c=function(){return t.scale.ordinal().range(Do)};var Po=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(ae),zo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(ae),Oo=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(ae),Do=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(ae);function Ro(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}return o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(h),a()):r},o.range=function(t){return arguments.length?(n=t,a()):n},o.quantiles=function(){return i},o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]},o.copy=function(){return e(r,n)},a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}return o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]},o.range=function(t){return arguments.length?(n=t,s()):n},o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]},o.copy=function(){return t(e,r,n)},s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}return i.domain=function(t){return arguments.length?(r=t,i):r},i.range=function(t){return arguments.length?(n=t,i):n},i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]},i.copy=function(){return e(r,n)},i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}return r.invert=r,r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e},r.ticks=function(t){return Mo(e,t)},r.tickFormat=function(t,r){return Ao(e,t,r)},r.copy=function(){return t(e)},r}([0,1])},t.svg={},t.svg.arc=function(){var t=Bo,e=No,r=Ro,n=Fo,i=jo,a=Uo,o=Vo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Ct,f=a.apply(this,arguments)-Ct,h=Math.abs(f-u),p=u>f?0:1;if(c<s&&(d=c,c=s,s=d),h>=Et)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,m,v,y,x,b,_,w,T,k,M,A=0,S=0,E=[];if((v=(+o.apply(this,arguments)||0)/2)&&(m=n===Fo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=Dt(m/c*Math.sin(v))),s&&(A=Dt(m/s*Math.sin(v)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(f-S),_=c*Math.sin(f-S);var C=Math.abs(f-u-2*S)<=At?0:1;if(S&&qo(y,x,b,_)===p^C){var L=(u+f)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(f-A),T=s*Math.sin(f-A),k=s*Math.cos(u+A),M=s*Math.sin(u+A);var I=Math.abs(u-f+2*A)<=At?0:1;if(A&&qo(w,T,k,M)===1-p^I){var P=(u+f)/2;w=s*Math.cos(P),T=s*Math.sin(P),k=M=null}}else w=T=0;if(h>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,O=d;if(h<At){var D=null==k?[w,T]:null==b?[y,x]:li([y,x],[k,M],[b,_],[w,T]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);O=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=Ho(null==k?[w,T]:[k,M],[y,x],c,z,p),q=Ho([b,_],[w,T],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^qo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=k){var H=Ho([y,x],[k,M],s,-O,p),G=Ho([w,T],null==b?[y,x]:[b,_],s,-O,p);d===O?E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^qo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",O,\",\",O,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",T)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",T),null!=k&&E.push(\"A\",s,\",\",s,\" 0 \",I,\",\",1-p,\" \",k,\",\",M);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=de(e),s):t},s.outerRadius=function(t){return arguments.length?(e=de(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=de(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Fo?Fo:de(t),s):n},s.startAngle=function(t){return arguments.length?(i=de(t),s):i},s.endAngle=function(t){return arguments.length?(a=de(t),s):a},s.padAngle=function(t){return arguments.length?(o=de(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Ct;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Fo=\"auto\";function Bo(t){return t.innerRadius}function No(t){return t.outerRadius}function jo(t){return t.startAngle}function Uo(t){return t.endAngle}function Vo(t){return t&&t.padAngle}function qo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function Ho(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,f=t[1]+c,h=e[0]+l,p=e[1]+c,d=(u+h)/2,g=(f+p)/2,m=h-u,v=p-f,y=m*m+v*v,x=r-n,b=u*p-h*f,_=(v<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*v-m*_)/y,T=(-b*m-v*_)/y,k=(b*v+m*_)/y,M=(-b*m+v*_)/y,A=w-d,S=T-g,E=k-d,C=M-g;return A*A+S*S>E*E+C*C&&(w=k,T=M),[[w-l,T-c],[w*r/x,T*r/x]]}function Go(t){var e=ri,r=ni,n=Yr,i=Wo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,f=a.length,h=de(e),p=de(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<f;)n.call(this,s=a[u],u)?c.push([+h.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Yo.get(t)||Wo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return Go(L)};var Yo=t.map({linear:Wo,\"linear-closed\":Xo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Zo,\"step-after\":Jo,basis:$o,\"basis-open\":function(t){if(t.length<4)return Wo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(ts(ns,a)+\",\"+ts(ns,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),is(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[ts(ns,o),\",\",ts(ns,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),is(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return $o(t)},cardinal:function(t,e){return t.length<3?Wo(t):t[0]+Ko(t,Qo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Wo(t):t[1]+Ko(t.slice(1,-1),Qo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?Xo(t):t[0]+Ko((t.push(t[0]),t),Qo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Wo(t):t[0]+Ko(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=as(i,a);for(;++e<r;)n[e]=(o+(o=as(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=as(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Wo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function Xo(t){return t.join(\"L\")+\"Z\"}function Zo(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Jo(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Ko(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Wo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Qo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function $o(t){if(t.length<3)return Wo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",ts(ns,o),\",\",ts(ns,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),is(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function ts(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Yo.forEach((function(t,e){e.key=t,e.closed=/-closed$/.test(t)}));var es=[0,2/3,1/3,0],rs=[0,1/3,2/3,0],ns=[0,1/6,2/3,1/6];function is(t,e,r){t.push(\"C\",ts(es,e),\",\",ts(es,r),\",\",ts(rs,e),\",\",ts(rs,r),\",\",ts(ns,e),\",\",ts(ns,r))}function as(t,e){return(e[1]-t[1])/(e[0]-t[0])}function os(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Ct,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function ss(t){var e=ri,r=ri,n=0,i=ni,a=Yr,o=Wo,s=o.key,l=o,c=\"L\",u=.7;function f(s){var f,h,p,d=[],g=[],m=[],v=-1,y=s.length,x=de(e),b=de(n),_=e===r?function(){return h}:de(r),w=n===i?function(){return p}:de(i);function T(){d.push(\"M\",o(t(m),u),c,l(t(g.reverse()),u),\"Z\")}for(;++v<y;)a.call(this,f=s[v],v)?(g.push([h=+x.call(this,f,v),p=+b.call(this,f,v)]),m.push([+_.call(this,f,v),+w.call(this,f,v)])):g.length&&(T(),g=[],m=[]);return g.length&&T(),d.length?d.join(\"\"):null}return f.x=function(t){return arguments.length?(e=r=t,f):r},f.x0=function(t){return arguments.length?(e=t,f):e},f.x1=function(t){return arguments.length?(r=t,f):r},f.y=function(t){return arguments.length?(n=i=t,f):i},f.y0=function(t){return arguments.length?(n=t,f):n},f.y1=function(t){return arguments.length?(i=t,f):i},f.defined=function(t){return arguments.length?(a=t,f):a},f.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Yo.get(t)||Wo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",f):s},f.tension=function(t){return arguments.length?(u=t,f):u},f}function ls(t){return t.radius}function cs(t){return[t.x,t.y]}function us(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Ct;return[r*Math.cos(n),r*Math.sin(n)]}}function fs(){return 64}function hs(){return\"circle\"}function ps(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=Go(os);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Zo.reverse=Jo,Jo.reverse=Zo,t.svg.area=function(){return ss(L)},t.svg.area.radial=function(){var t=ss(os);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Vn,e=qn,r=ls,n=jo,i=Uo;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,((i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\")}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Ct,u=i.call(t,s,o)-Ct;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=de(t),a):r},a.source=function(e){return arguments.length?(t=de(e),a):t},a.target=function(t){return arguments.length?(e=de(t),a):e},a.startAngle=function(t){return arguments.length?(n=de(t),a):n},a.endAngle=function(t){return arguments.length?(i=de(t),a):i},a},t.svg.diagonal=function(){var t=Vn,e=qn,r=cs;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=de(e),n):t},n.target=function(t){return arguments.length?(e=de(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=cs,n=e.projection;return e.projection=function(t){return arguments.length?n(us(r=t)):r},e},t.svg.symbol=function(){var t=hs,e=fs;function r(r,n){return(ds.get(t.call(this,r,n))||ps)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=de(e),r):t},r.size=function(t){return arguments.length?(e=de(t),r):e},r};var ds=t.map({circle:ps,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*ms)),r=e*ms;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/gs),r=e*gs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/gs),r=e*gs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ds.keys();var gs=Math.sqrt(3),ms=Math.tan(30*Lt);Y.transition=function(t){for(var e,r,n=bs||++Ts,i=As(t),a=[],o=_s||{time:Date.now(),ease:ca,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(r=c[u])&&Ss(r,u,i,n,o),e.push(r)}return xs(a,i,n)},Y.interrupt=function(t){return this.each(null==t?vs:ys(As(t)))};var vs=ys(As());function ys(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function xs(t,e,r){return U(t,ws),t.namespace=e,t.id=r,t}var bs,_s,ws=[],Ts=0;function ks(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function Ms(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function As(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function Ss(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),f=u[n];function h(r){var i=u.active,h=u[i];for(var d in h&&(h.timer.c=null,h.timer.t=NaN,--u.count,delete u[i],h.event&&h.event.interrupt.call(t,t.__data__,h.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,we((function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1}),0,a),u.active=n,f.event&&f.event.start.call(t,t.__data__,e),c=[],f.tween.forEach((function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)})),l=f.ease,s=f.duration}function p(i){for(var a=i/s,o=l(a),h=c.length;h>0;)c[--h].call(t,o);if(a>=1)return f.event&&f.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}f||(a=i.time,o=we((function(t){var e=f.delay;if(o.t=e+a,e<=t)return h(t-e);o.c=h}),0,a),f=u[n]={tween:new _,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}ws.call=Y.call,ws.empty=Y.empty,ws.node=Y.node,ws.size=Y.size,t.transition=function(e,r){return e&&e.transition?bs?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=ws,ws.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=W(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),Ss(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return xs(o,a,i)},ws.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=X(t);for(var c=-1,u=this.length;++c<u;)for(var f=this[c],h=-1,p=f.length;++h<p;)if(n=f[h]){a=n[s][o],r=t.call(n,n.__data__,h,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&Ss(i,d,s,o,a),e.push(i)}return xs(l,s,o)},ws.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=lt(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return xs(n,this.namespace,this.id)},ws.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},ws.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ba:$i,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}function s(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})}function l(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}return ks(this,\"attr.\"+e,r,i.local?l:s)},ws.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},ws.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}function a(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=$i(i,e),function(e){this.style.setProperty(t,n(e),r)})})}return ks(this,\"style.\"+t,e,a)},ws.styleTween=function(t,e,r){function n(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}}return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,n)},ws.text=function(t){return ks(this,\"text\",t,Ms)},ws.remove=function(){var t=this.namespace;return this.each(\"end.transition\",(function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)}))},ws.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,(function(t){t[n][r].ease=e})))},ws.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},ws.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},ws.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=_s,o=bs;try{bs=n,ut(this,(function(t,r,a){_s=t[i][n],e.call(t,t.__data__,r,a)}))}finally{_s=a,bs=o}}else ut(this,(function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)}));return this},ws.transition=function(){for(var t,e,r,n=this.id,i=++Ts,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,f=(c=this[s]).length;u<f;u++)(e=c[u])&&Ss(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return xs(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=Es,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each((function(){var n,u=t.select(this),f=this.__chart__||r,h=this.__chart__=r.copy(),p=null==c?h.ticks?h.ticks.apply(h,l):h.domain():c,d=null==e?h.tickFormat?h.tickFormat.apply(h,l):L:e,g=u.selectAll(\".tick\").data(p,h),m=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),v=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=mo(h),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));m.append(\"line\"),m.append(\"text\");var T,k,M,A,S=m.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),I=m.select(\"text\"),P=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ls,T=\"x\",M=\"y\",k=\"x2\",A=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=Is,T=\"y\",M=\"x\",k=\"y2\",A=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(A,z*a),I.attr(M,z*x),E.attr(k,0).attr(A,z*a),P.attr(T,0).attr(M,z*x),h.rangeBand){var O=h,D=O.rangeBand()/2;f=h=function(t){return O(t)+D}}else f.rangeBand?f=h:v.call(n,h,f);m.call(n,f,h),y.call(n,h,h)}))}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in Cs?t+\"\":Es,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var Es=\"bottom\",Cs={top:1,right:1,bottom:1,left:1};function Ls(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"}))}function Is(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"}))}t.svg.brush=function(){var e,r,n=N(h,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,f=zs[0];function h(e){e.each((function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",m).on(\"touchstart.brush\",m),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(f,L);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",(function(t){return\"resize \"+t})).style(\"cursor\",(function(t){return Ps[t]})).append(\"rect\").attr(\"x\",(function(t){return/[ew]$/.test(t)?-3:null})).attr(\"y\",(function(t){return/^[ns]/.test(t)?-3:null})).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",h.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=mo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=mo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)}))}function p(t){t.selectAll(\".resize\").attr(\"transform\",(function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"}))}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function m(){var f,m,v=this,y=t.select(t.event.target),x=n.of(v,arguments),b=t.select(v),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,T=!/^(e|w)$/.test(_)&&a,k=y.classed(\"extent\"),M=bt(v),A=t.mouse(v),S=t.select(o(v)).on(\"keydown.brush\",L).on(\"keyup.brush\",I);if(t.event.changedTouches?S.on(\"touchmove.brush\",P).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",P).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),k)A[0]=s[0]-A[0],A[1]=l[0]-A[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);m=[s[1-E]-A[0],l[1-C]-A[1]],A[0]=s[E],A[1]=l[C]}else t.event.altKey&&(f=A.slice());function L(){32==t.event.keyCode&&(k||(f=null,A[0]-=s[1],A[1]-=l[1],k=2),F())}function I(){32==t.event.keyCode&&2==k&&(A[0]+=s[1],A[1]+=l[1],k=0,F())}function P(){var e=t.mouse(v),r=!1;m&&(e[0]+=m[0],e[1]+=m[1]),k||(t.event.altKey?(f||(f=[(s[0]+s[1])/2,(l[0]+l[1])/2]),A[0]=s[+(e[0]<f[0])],A[1]=l[+(e[1]<f[1])]):f=null),w&&z(e,i,0)&&(d(b),r=!0),T&&z(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:k?\"move\":\"resize\"}))}function z(t,n,i){var a,o,h=mo(n),p=h[0],d=h[1],g=A[i],m=i?l:s,v=m[1]-m[0];if(k&&(p-=g,d-=v+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],k?o=(a+=g)+v:(f&&(g=Math.max(p,Math.min(d,2*f[i]-a))),g<a?(o=a,a=g):o=g),m[0]!=a||m[1]!=o)return i?r=null:e=null,m[0]=a,m[1]=o,!0}function O(){P(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",h.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),M(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),P()}return h.event=function(i){i.each((function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,bs?t.select(this).transition().each(\"start.brush\",(function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})})).tween(\"brush:brush\",(function(){var t=ta(s,a.x),n=ta(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}})).each(\"end.brush\",(function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})})):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))}))},h.x=function(t){return arguments.length?(f=zs[!(i=t)<<1|!a],h):i},h.y=function(t){return arguments.length?(f=zs[!i<<1|!(a=t)],h):a},h.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),h):i&&a?[c,u]:i?c:a?u:null},h.extent=function(t){var n,o,c,u,f;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(f=n,n=o,o=f),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(f=c,c=u,u=f),c==l[0]&&u==l[1]||(l=[c,u])),h):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(f=n,n=o,o=f))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(f=c,c=u,u=f))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},h.clear=function(){return h.empty()||(s=[0,0],l=[0,0],e=r=null),h},h.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(h,n,\"on\")};var Ps={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},zs=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Os=Pe.format=sr.timeFormat,Ds=Os.utc,Rs=Ds(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Fs(t){return t.toISOString()}function Bs(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(js,i);return a==js.length?[r.year,ko(e.map((function(t){return t/31536e6})),n)[2]]:a?r[i/js[a-1]<js[a]/i?a-1:a]:[qs,ko(e,n)[2]]}return i.invert=function(t){return Ns(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(Ns)},i.nice=function(t,e){var r=i.domain(),n=go(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,Ns(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(yo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=Ns(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=Ns(+e+1);return e}}:t))},i.ticks=function(t,e){var r=go(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],Ns(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Bs(e.copy(),r,n)},wo(i,e)}function Ns(t){return new Date(t)}Os.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Fs:Rs,Fs.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Fs.toString=Rs.toString,Pe.second=Re((function(t){return new ze(1e3*Math.floor(t/1e3))}),(function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))}),(function(t){return t.getSeconds()})),Pe.seconds=Pe.second.range,Pe.seconds.utc=Pe.second.utc.range,Pe.minute=Re((function(t){return new ze(6e4*Math.floor(t/6e4))}),(function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))}),(function(t){return t.getMinutes()})),Pe.minutes=Pe.minute.range,Pe.minutes.utc=Pe.minute.utc.range,Pe.hour=Re((function(t){var e=t.getTimezoneOffset()/60;return new ze(36e5*(Math.floor(t/36e5-e)+e))}),(function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))}),(function(t){return t.getHours()})),Pe.hours=Pe.hour.range,Pe.hours.utc=Pe.hour.utc.range,Pe.month=Re((function(t){return(t=Pe.day(t)).setDate(1),t}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t){return t.getMonth()})),Pe.months=Pe.month.range,Pe.months.utc=Pe.month.utc.range;var js=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Us=[[Pe.second,1],[Pe.second,5],[Pe.second,15],[Pe.second,30],[Pe.minute,1],[Pe.minute,5],[Pe.minute,15],[Pe.minute,30],[Pe.hour,1],[Pe.hour,3],[Pe.hour,6],[Pe.hour,12],[Pe.day,1],[Pe.day,2],[Pe.week,1],[Pe.month,1],[Pe.month,3],[Pe.year,1]],Vs=Os.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),qs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(Ns)},floor:L,ceil:L};Us.year=Pe.year,Pe.scale=function(){return Bs(t.scale.linear(),Us,Vs)};var Hs=Us.map((function(t){return[t[0].utc,t[1]]})),Gs=Ds.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function Ys(t){return JSON.parse(t.responseText)}function Ws(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Hs.year=Pe.year.utc,Pe.scale.utc=function(){return Bs(t.scale.linear(),Hs,Gs)},t.text=ge((function(t){return t.responseText})),t.json=function(t,e){return me(t,\"application/json\",Ys,e)},t.html=function(t,e){return me(t,\"text/html\",Ws,e)},t.xml=ge((function(t){return t.responseXML})),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],170:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],171:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map((function(t,e){return[t[0],e]}));n.sort((function(t,e){return t[0]-e[0]}));for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var f=t[u],h=new Array(s+1),p=0,d=0;d<s;++d){var g=f[d];h[d]=g,p+=g*g}h[s]=p,l[u]=new a(h,u),c=Math.max(p,c)}i(l,o),r=l.length;var m=new Array(r+s+1),v=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1);for(u=0;u<=s;++u)x[u]=0;x[s]=y,m[0]=x.slice(),v[0]=-1;for(u=0;u<=s;++u){(h=x.slice())[u]=1,m[u+1]=h,v[u+1]=-1}for(u=0;u<r;++u){var b=l[u];m[u+s+1]=b.point,v[u+s+1]=b.index}var _=n(m,!1);_=e?_.filter((function(t){for(var e=0,r=0;r<=s;++r){var n=v[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0})):_.filter((function(t){for(var e=0;e<=s;++e){var r=v[t[e]];if(r<0)return!1;t[e]=r}return!0}));if(1&s)for(u=0;u<_.length;++u){h=(b=_[u])[0];b[0]=b[1],b[1]=h}return _}},{\"incremental-convex-hull\":459,uniq:597}],172:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],f=n.measureText(u[0]).width+n.measureText(u[1]).width,h=n.measureText(u).width;if(Math.abs(f-h)>s*l){var p=(h-f)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],173:[function(t,e,r){(function(t){(function(){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this)}).call(this,t(\"buffer\").Buffer)},{buffer:111}],174:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach((function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)})),t.closePath()}},{\"abs-svg-path\":65,\"normalize-svg-path\":497}],175:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],176:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],177:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,d,m=e&&e.length,v=m?e[0]*r:t.length,y=i(t,0,v,r,!0),x=[];if(!y||y.next===y.prev)return x;if(m&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(g(u));for(p.sort(f),o=0;o<p.length;o++)h(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<v;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);d=0!==(d=Math.max(l-n,c-s))?1/d:0}return o(y,x,r,n,s,d),x}function i(t,e,r,n,i){var a,o;if(i===E(t,e,r,n)>0)for(a=e;a<r;a+=n)o=M(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=M(a,t[a],t[a+1],o);return o&&x(o,o.next)&&(A(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!x(n,n.next)&&0!==y(n.prev,n,n.next))n=n.next;else{if(A(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,f,h){if(t){!h&&f&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=d(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,f);for(var p,g,m=t;t.prev!==t.next;)if(p=t.prev,g=t.next,f?l(t,n,i,f):s(t))e.push(p.i/r),e.push(t.i/r),e.push(g.i/r),A(t),t=g.next,m=g.next;else if((t=g)===m){h?1===h?o(t=c(a(t),e,r),e,r,n,i,f,2):2===h&&u(t,e,r,n,i,f):o(a(t),e,r,n,i,f,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(y(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(m(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&y(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(y(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,f=d(s,l,e,r,n),h=d(c,u,e,r,n),p=t.prevZ,g=t.nextZ;p&&p.z>=f&&g&&g.z<=h;){if(p!==t.prev&&p!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,g!==t.prev&&g!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}for(;p&&p.z>=f;){if(p!==t.prev&&p!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;g&&g.z<=h;){if(g!==t.prev&&g!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,o=n.next.next;!x(i,o)&&b(i,n,n.next,o)&&T(i,o)&&T(o,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(o.i/r),A(n),A(n.next),n=t=o),n=n.next}while(n!==t);return a(n)}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=k(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function f(t,e){return t.x-e.x}function h(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,f=r.y,h=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&m(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),T(n,t)&&(l<h||l===h&&(n.x>r.x||n.x===r.x&&p(r,n)))&&(r=n,h=l)),n=n.next}while(n!==c);return r}(t,e)){var r=k(e,t);a(e,e.next),a(r,r.next)}}function p(t,e){return y(t.prev,t,e.prev)<0&&y(e.next,t,t.next)<0}function d(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function g(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function m(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&b(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(T(t,e)&&T(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(y(t.prev,t,e.prev)||y(t,e.prev,e))||x(t,e)&&y(t.prev,t,t.next)>0&&y(e.prev,e,e.next)>0)}function y(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function x(t,e){return t.x===e.x&&t.y===e.y}function b(t,e,r,n){var i=w(y(t,e,r)),a=w(y(t,e,n)),o=w(y(r,n,t)),s=w(y(r,n,e));return i!==a&&o!==s||(!(0!==i||!_(t,r,e))||(!(0!==a||!_(t,n,e))||(!(0!==o||!_(r,t,n))||!(0!==s||!_(r,e,n)))))}function _(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function w(t){return t>0?1:t<0?-1:0}function T(t,e){return y(t.prev,t,t.next)<0?y(t,e,t.next)>=0&&y(t,t.prev,e)>=0:y(t,e,t.prev)<0||y(t,t.next,e)<0}function k(t,e){var r=new S(t.i,t.x,t.y),n=new S(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function M(t,e,r,n){var i=new S(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function A(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function S(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function E(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(E(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(E(t,c,u,r))}var f=0;for(s=0;s<n.length;s+=3){var h=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;f+=Math.abs((t[h]-t[d])*(t[p+1]-t[h+1])-(t[h]-t[p])*(t[d+1]-t[h+1]))}return 0===o&&0===f?0:Math.abs((f-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],178:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;var o=new Array(e);for(i=0;i<e;++i)o[i]=[];for(i=0;i<r;++i){a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],(function(t,e){return t-e}));return o};var n=t(\"uniq\")},{uniq:597}],179:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t,e){var r,i=[],a=[],o=[],s={},l=[];function c(t){var e,n,i=!1;for(a.push(t),o[t]=!0,e=0;e<l[t].length;e++)(n=l[t][e])===r?(u(r,a),i=!0):o[n]||(i=c(n));if(i)!function t(e){o[e]=!1,s.hasOwnProperty(e)&&Object.keys(s[e]).forEach((function(r){delete s[e][r],o[r]&&t(r)}))}(t);else for(e=0;e<l[t].length;e++){n=l[t][e];var f=s[n];f||(f={},s[n]=f),f[n]=!0}return a.pop(),i}function u(t,r){var n=[].concat(r).concat(t);e?e(c):i.push(n)}function f(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter((function(t){return t>=e}))}(e);for(var r,i=n(t).components.filter((function(t){return t.length>1})),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map((function(t,e){return-1===l.indexOf(e)?[]:t.filter((function(t){return-1!==l.indexOf(t)}))}))}}r=0;for(var h=t.length;r<h;){var p=f(r);if(r=p.leastVertex,l=p.adjList){for(var d=0;d<l.length;d++)for(var g=0;g<l[d].length;g++){var m=l[d][g];o[+m]=!1,s[m]={}}c(r),r+=1}else r=h}return e?void 0:i}},{\"strongly-connected-components\":569}],180:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":211}],181:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":182,\"./shim\":183}],182:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),f=Array.isArray,h=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,m,v,y,x,b,_,w,T=arguments[1],k=arguments[2];if(t=Object(l(t)),c(T)&&s(T),this&&this!==Array&&a(this))e=this;else{if(!T){if(i(t))return 1!==(v=t.length)?Array.apply(null,t):((m=new Array(1))[0]=t[0],m);if(f(t)){for(m=new Array(v=t.length),r=0;r<v;++r)m[r]=t[r];return m}}m=[]}if(!f(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(m=new e),b=x.next(),r=0;!b.done;)w=T?h.call(T,k,b.value,r):b.value,e?(p.value=w,d(m,r,p)):m[r]=w,b=x.next(),++r;v=r}else if(u(t)){for(v=t.length,e&&(m=new e),r=0,g=0;r<v;++r)w=t[r],r+1<v&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=T?h.call(T,k,w,g):w,e?(p.value=w,d(m,g,p)):m[g]=w,++g;v=g}if(void 0===v)for(v=o(t.length),e&&(m=new e(v)),r=0;r<v;++r)w=T?h.call(T,k,t[r],r):t[r],e?(p.value=w,d(m,r,p)):m[r]=w;return e&&(p.value=null,m.length=v),m}},{\"../../function/is-arguments\":184,\"../../function/is-function\":185,\"../../number/to-pos-integer\":191,\"../../object/is-value\":200,\"../../object/valid-callable\":209,\"../../object/valid-value\":211,\"../../string/is-string\":215,\"es6-symbol\":225}],184:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],185:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=RegExp.prototype.test.bind(/^[object [A-Za-z0-9]*Function]$/);e.exports=function(t){return\"function\"==typeof t&&i(n.call(t))}},{}],186:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],187:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":188,\"./shim\":189}],188:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],189:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],190:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":187}],191:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":190}],192:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,f=arguments[2],h=arguments[3];return r=Object(i(r)),n(c),u=s(r),h&&u.sort(\"function\"==typeof h?a.call(h,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,(function(t,n){return l.call(r,t)?o.call(c,f,r[t],t,r,n):e}))}}},{\"./valid-callable\":209,\"./valid-value\":211}],193:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":194,\"./shim\":195}],194:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],195:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)n(e=arguments[o]).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":201,\"../valid-value\":211}],196:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,(function(e){(o.ensure||e in t)&&(s[e]=t[e])})):i(s,t),s}},{\"../array/from\":181,\"./assign\":193,\"./valid-value\":211}],197:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach((function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}})),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":207,\"./set-prototype-of/shim\":208}],198:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":192}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":200}],200:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":186}],201:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":202,\"./shim\":203}],202:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],203:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":200}],204:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,(function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)})),r}},{\"./for-each\":198,\"./valid-callable\":209}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create,o=function(t,e){var r;for(r in t)e[r]=t[r]};e.exports=function(t){var e=a(null);return i.call(arguments,(function(t){n(t)&&o(Object(t),e)})),e}},{\"./is-value\":200}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],208:[function(t,e,r){\"use strict\";var n,i=t(\"../is-object\"),a=t(\"../valid-value\"),o=Object.prototype.isPrototypeOf,s=Object.defineProperty,l={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(a(t),null===e||i(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=function(t){var e,r;return t?(2===t.level?t.set?(r=t.set,e=function(t,e){return r.call(n(t,e),e),t}):e=function(t,e){return n(t,e).__proto__=e,t}:e=function t(e,r){var i;return n(e,r),(i=o.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&s(t.nullPolyfill,\"__proto__\",l),e},Object.defineProperty(e,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:t.level})):null}(function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}()),t(\"../create\")},{\"../create\":197,\"../is-object\":199,\"../valid-value\":211}],209:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],210:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":199}],211:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":200}],212:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":213,\"./shim\":214}],213:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],214:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],215:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],216:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],217:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o((function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t}))}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":220,d:155,\"es5-ext/object/set-prototype-of\":206,\"es5-ext/string/#/contains\":212,\"es6-symbol\":225}],218:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,f,h,p,d,g,m,v=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),f=function(){h=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,v,u.value,f),h)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(m=g.charCodeAt(0))>=55296&&m<=56319&&(g+=t[++p]),l.call(e,v,g,f),!h);++p);else c.call(t,(function(t){return l.call(e,v,t,f),h}))}},{\"./get\":219,\"es5-ext/function/is-arguments\":184,\"es5-ext/object/valid-callable\":209,\"es5-ext/string/is-string\":215}],219:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":217,\"./string\":222,\"./valid-iterable\":223,\"es5-ext/function/is-arguments\":184,\"es5-ext/string/is-string\":215,\"es6-symbol\":225}],220:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),f=Object.defineProperty,h=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");h(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,h(n.prototype,a({_next:l((function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()})),next:l((function(){return this._createResult(this._next())})),_createResult:l((function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}})),_resolve:l((function(t){return this.__list__[t]})),_unBind:l((function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)})),toString:l((function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"}))},c({_onAdd:l((function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach((function(e,r){e>=t&&(this.__redo__[r]=++e)}),this),this.__redo__.push(t)):f(this,\"__redo__\",l(\"c\",[t])))})),_onDelete:l((function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach((function(e,r){e>t&&(this.__redo__[r]=--e)}),this)))})),_onClear:l((function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0}))}))),f(n.prototype,u.iterator,l((function(){return this})))},{d:155,\"d/auto-bind\":154,\"es5-ext/array/#/clear\":180,\"es5-ext/object/assign\":193,\"es5-ext/object/valid-callable\":209,\"es5-ext/object/valid-value\":211,\"es6-symbol\":225}],221:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":184,\"es5-ext/object/is-value\":200,\"es5-ext/string/is-string\":215,\"es6-symbol\":225}],222:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a((function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()})),_resolve:a((function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r}))}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":220,d:155,\"es5-ext/object/set-prototype-of\":206,\"es6-symbol\":225}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":221}],224:[function(t,e,r){(function(n,i){(function(){\n",
       "/*!\n",
       " * @overview es6-promise - a tiny implementation of Promises/A+.\n",
       " * @copyright Copyright (c) 2014 Yehuda Katz, Tom Dale, Stefan Penner and contributors (Conversion to ES6 API by Jake Archibald)\n",
       " * @license   Licensed under MIT license\n",
       " *            See https://raw.githubusercontent.com/stefanpenner/es6-promise/master/LICENSE\n",
       " * @version   v4.2.8+1e68dce6\n",
       " */\n",
       "!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,(function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(m):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},f=u.MutationObserver||u.WebKitMutationObserver,h=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(m,1)}}var g=new Array(1e3);function m(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var v,y,x,b,_=void 0;function w(t,e){var r=this,n=new this.constructor(M);void 0===n[k]&&D(n);var i=r._state;if(i){var a=arguments[i-1];l((function(){return z(i,n,a,r._result)}))}else I(r,n,t,e);return n}function T(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(M);return S(e,t),e}h?_=function(){return n.nextTick(m)}:f?(y=0,x=new f(m),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((v=new MessageChannel).port1.onmessage=m,_=function(){return v.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var t=Function(\"return this\")().require(\"vertx\");return\"undefined\"!=typeof(o=t.runOnLoop||t.runOnContext)?function(){o(m)}:d()}catch(t){return d()}}():d();var k=Math.random().toString(36).substring(2);function M(){}function A(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===T?function(t,e){1===e._state?C(t,e._result):2===e._state?L(t,e._result):I(e,void 0,(function(e){return S(t,e)}),(function(e){return L(t,e)}))}(t,r):void 0===n?C(t,r):e(n)?function(t,e,r){l((function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,(function(r){n||(n=!0,e!==r?S(t,r):C(t,r))}),(function(e){n||(n=!0,L(t,e))}),t._label);!n&&i&&(n=!0,L(t,i))}),t)}(t,r,n):C(t,r)}function S(t,e){if(t===e)L(t,new TypeError(\"You cannot resolve a promise with itself\"));else if(i=typeof(n=e),null===n||\"object\"!==i&&\"function\"!==i)C(t,e);else{var r=void 0;try{r=e.then}catch(e){return void L(t,e)}A(t,e,r)}var n,i}function E(t){t._onerror&&t._onerror(t._result),P(t)}function C(t,e){void 0===t._state&&(t._result=e,t._state=1,0!==t._subscribers.length&&l(P,t))}function L(t,e){void 0===t._state&&(t._state=2,t._result=e,l(E,t))}function I(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+1]=r,i[a+2]=n,0===a&&t._state&&l(P,t)}function P(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?z(r,n,i,a):i(a);t._subscribers.length=0}}function z(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=!0;if(a){try{o=n(i)}catch(t){l=!1,s=t}if(r===o)return void L(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i;void 0!==r._state||(a&&l?S(r,o):!1===l?L(r,s):1===t?C(r,o):2===t&&L(r,o))}var O=0;function D(t){t[k]=O++,t._state=void 0,t._result=void 0,t._subscribers=[]}var R=function(){function t(t,e){this._instanceConstructor=t,this.promise=new t(M),this.promise[k]||D(this.promise),r(e)?(this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?C(this.promise,this._result):(this.length=this.length||0,this._enumerate(e),0===this._remaining&&C(this.promise,this._result))):L(this.promise,new Error(\"Array Methods must be provided an Array\"))}return t.prototype._enumerate=function(t){for(var e=0;void 0===this._state&&e<t.length;e++)this._eachEntry(t[e],e)},t.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===T){var i=void 0,a=void 0,o=!1;try{i=t.then}catch(t){o=!0,a=t}if(i===w&&void 0!==t._state)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===F){var s=new r(M);o?L(s,a):A(s,t,i),this._willSettleAt(s,e)}else this._willSettleAt(new r((function(e){return e(t)})),e)}else this._willSettleAt(n(t),e)},t.prototype._settledAt=function(t,e,r){var n=this.promise;void 0===n._state&&(this._remaining--,2===t?L(n,r):this._result[e]=r),0===this._remaining&&C(n,this._result)},t.prototype._willSettleAt=function(t,e){var r=this;I(t,void 0,(function(t){return r._settledAt(1,e,t)}),(function(t){return r._settledAt(2,e,t)}))},t}();var F=function(){function t(e){this[k]=O++,this._result=this._state=void 0,this._subscribers=[],M!==e&&(\"function\"!=typeof e&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof t?function(t,e){try{e((function(e){S(t,e)}),(function(e){L(t,e)}))}catch(e){L(t,e)}}(this,e):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}return t.prototype.catch=function(t){return this.then(null,t)},t.prototype.finally=function(t){var r=this.constructor;return e(t)?this.then((function(e){return r.resolve(t()).then((function(){return e}))}),(function(e){return r.resolve(t()).then((function(){throw e}))})):this.then(t,t)},t}();return F.prototype.then=w,F.all=function(t){return new R(this,t).promise},F.race=function(t){var e=this;return r(t)?new e((function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)})):new e((function(t,e){return e(new TypeError(\"You must pass an array to race.\"))}))},F.resolve=T,F.reject=function(t){var e=new this(M);return L(e,t),e},F._setScheduler=function(t){s=t},F._setAsap=function(t){l=t},F._asap=l,F.polyfill=function(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=F},F.Promise=F,F}))}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:526}],225:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?t(\"ext/global-this\").Symbol:t(\"./polyfill\")},{\"./is-implemented\":226,\"./polyfill\":231,\"ext/global-this\":238}],226:[function(t,e,r){\"use strict\";var n=t(\"ext/global-this\"),i={object:!0,symbol:!0};e.exports=function(){var t,e=n.Symbol;if(\"function\"!=typeof e)return!1;t=e(\"test symbol\");try{String(t)}catch(t){return!1}return!!i[typeof e.iterator]&&(!!i[typeof e.toPrimitive]&&!!i[typeof e.toStringTag])}},{\"ext/global-this\":238}],227:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],228:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=Object.create,a=Object.defineProperty,o=Object.prototype,s=i(null);e.exports=function(t){for(var e,r,i=0;s[t+(i||\"\")];)++i;return s[t+=i||\"\"]=!0,a(o,e=\"@@\"+t,n.gs(null,(function(t){r||(r=!0,a(this,e,n(t)),r=!1)}))),e}},{d:155}],229:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=t(\"ext/global-this\").Symbol;e.exports=function(t){return Object.defineProperties(t,{hasInstance:n(\"\",i&&i.hasInstance||t(\"hasInstance\")),isConcatSpreadable:n(\"\",i&&i.isConcatSpreadable||t(\"isConcatSpreadable\")),iterator:n(\"\",i&&i.iterator||t(\"iterator\")),match:n(\"\",i&&i.match||t(\"match\")),replace:n(\"\",i&&i.replace||t(\"replace\")),search:n(\"\",i&&i.search||t(\"search\")),species:n(\"\",i&&i.species||t(\"species\")),split:n(\"\",i&&i.split||t(\"split\")),toPrimitive:n(\"\",i&&i.toPrimitive||t(\"toPrimitive\")),toStringTag:n(\"\",i&&i.toStringTag||t(\"toStringTag\")),unscopables:n(\"\",i&&i.unscopables||t(\"unscopables\"))})}},{d:155,\"ext/global-this\":238}],230:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=t(\"../../../validate-symbol\"),a=Object.create(null);e.exports=function(t){return Object.defineProperties(t,{for:n((function(e){return a[e]?a[e]:a[e]=t(String(e))})),keyFor:n((function(t){var e;for(e in i(t),a)if(a[e]===t)return e}))})}},{\"../../../validate-symbol\":232,d:155}],231:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"d\"),s=t(\"./validate-symbol\"),l=t(\"ext/global-this\").Symbol,c=t(\"./lib/private/generate-name\"),u=t(\"./lib/private/setup/standard-symbols\"),f=t(\"./lib/private/setup/symbol-registry\"),h=Object.create,p=Object.defineProperties,d=Object.defineProperty;if(\"function\"==typeof l)try{String(l()),a=!0}catch(t){}else l=null;i=function(t){if(this instanceof i)throw new TypeError(\"Symbol is not a constructor\");return n(t)},e.exports=n=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return a?l(e):(r=h(i.prototype),e=void 0===e?\"\":String(e),p(r,{__description__:o(\"\",e),__name__:o(\"\",c(e))}))},u(n),f(n),p(i.prototype,{constructor:o(n),toString:o(\"\",(function(){return this.__name__}))}),p(n.prototype,{toString:o((function(){return\"Symbol (\"+s(this).__description__+\")\"})),valueOf:o((function(){return s(this)}))}),d(n.prototype,n.toPrimitive,o(\"\",(function(){var t=s(this);return\"symbol\"==typeof t?t:t.toString()}))),d(n.prototype,n.toStringTag,o(\"c\",\"Symbol\")),d(i.prototype,n.toStringTag,o(\"c\",n.prototype[n.toStringTag])),d(i.prototype,n.toPrimitive,o(\"c\",n.prototype[n.toPrimitive]))},{\"./lib/private/generate-name\":228,\"./lib/private/setup/standard-symbols\":229,\"./lib/private/setup/symbol-registry\":230,\"./validate-symbol\":232,d:155,\"ext/global-this\":238}],232:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":227}],233:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":234,\"./polyfill\":236}],234:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],235:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],236:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),f=t(\"es6-iterator/for-of\"),h=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,m=Object.prototype.hasOwnProperty,v=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,v(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(f(e,(function(e){s(e),t.set(e[0],e[1])})),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c((function(t){return!!m.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)})),get:c((function(t){if(m.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]})),has:c((function(t){return m.call(o(t),this.__weakMapData__)})),set:c((function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this})),toString:c((function(){return\"[object WeakMap]\"}))}),g(n.prototype,h,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":235,d:155,\"es5-ext/object/is-value\":200,\"es5-ext/object/set-prototype-of\":206,\"es5-ext/object/valid-object\":210,\"es5-ext/object/valid-value\":211,\"es5-ext/string/random-uniq\":216,\"es6-iterator/for-of\":218,\"es6-iterator/get\":219,\"es6-symbol\":225}],237:[function(t,e,r){var n=function(){if(\"object\"==typeof self&&self)return self;if(\"object\"==typeof window&&window)return window;throw new Error(\"Unable to resolve global `this`\")};e.exports=function(){if(this)return this;try{Object.defineProperty(Object.prototype,\"__global__\",{get:function(){return this},configurable:!0})}catch(t){return n()}try{return __global__||n()}finally{delete Object.prototype.__global__}}()},{}],238:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?globalThis:t(\"./implementation\")},{\"./implementation\":237,\"./is-implemented\":239}],239:[function(t,e,r){\"use strict\";e.exports=function(){return\"object\"==typeof globalThis&&(!!globalThis&&globalThis.Array===Array)}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],241:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":470}],242:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:return\"number\"==typeof t?new o(n=l(t),n,0):new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,f=this.bounds;if(o<0)for(var h=u-1,p=0;p<u;++p,--h)s[p]=l[h];else if(o>=r-1){h=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--h)s[p]=l[h]+d*c[h]}else{h=u*(o+1)-1;var g=e[o],m=e[o+1]-g||1,v=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--h)v[p]=l[h],x[p]=c[h]*m,y[p]=l[h+u],b[p]=c[h+u]*m,_=_&&v[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=v[p];else n(v,x,y,b,(t-g)/m,s)}var w=f[0],T=f[1];for(p=0;p<u;++p)s[p]=a(w[p],T[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,f=(e[r-1],0);f<c;++f,--u)o[f]=l[u];else{u=c*(a+1)-1;var h=e[a],p=e[a+1]-h||1,d=this._scratch[1],g=this._scratch[2],m=this._scratch[3],v=this._scratch[4],y=!0;for(f=0;f<c;++f,--u)d[f]=s[u],m[f]=l[u]*p,g[f]=s[u+c],v[f]=l[u+c]*p,y=y&&d[f]===g[f]&&m[f]===v[f]&&0===m[f];if(y)for(f=0;f<c;++f)o[f]=0;else{n.derivative(d,m,g,v,(t-h)/p,o);for(f=0;f<c;++f)o[f]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var f=0;f<r;++f)n.push(n[o++]),i.push(0);this._time.push(t);for(f=r;f>0;--f)n.push(a(l[f-1],c[f-1],arguments[f])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],f=s>1e-6?1/s:0;this._time.push(t);for(var h=r;h>0;--h){var p=a(c[h-1],u[h-1],arguments[h]);n.push(p),i.push((p-n[o++])*f)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,f=u>1e-6?1/u:0;this._time.push(t);for(var h=r;h>0;--h){var p=arguments[h];n.push(a(l[h-1],c[h-1],n[o++]+p)),i.push(p*f)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var f=r-1;f>=0;--f)n.push(a(l[f],c[f],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":243,\"cubic-hermite\":150}],243:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],244:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var f=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new f(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new f(t):(e=new f(t.length+r)).set(t,r)}return e}},{dtype:175}],245:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var f=r.getContext(\"2d\");f.fillStyle=\"#000\",f.fillRect(0,0,r.width,r.height),f.font=a,f.textAlign=\"center\",f.textBaseline=\"middle\",f.fillStyle=\"#fff\";var h=o[0]/2,p=o[1]/2;for(c=0;c<s.length;c++)f.fillText(s[c],h,p),(h+=o[0])>e[0]-o[0]/2&&(h=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":147}],246:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,f=u.getContext(\"2d\"),h={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,f.font=t;var d={top:0};f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillStyle=\"black\",f.fillText(\"H\",0,0);var g=a(f.getImageData(0,0,p,p));f.clearRect(0,0,p,p),f.textBaseline=\"bottom\",f.fillText(\"H\",0,p);var m=a(f.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-m+g,f.clearRect(0,0,p,p),f.textBaseline=\"alphabetic\",f.fillText(\"H\",0,p);var v=p-a(f.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=v,f.clearRect(0,0,p,p),f.textBaseline=\"middle\",f.fillText(\"H\",0,.5*p);var y=a(f.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"hanging\",f.fillText(\"H\",0,.5*p);var x=a(f.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"ideographic\",f.fillText(\"H\",0,p);var b=a(f.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,h.upper&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.upper,0,0),d.upper=a(f.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),h.lower&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.lower,0,0),d.lower=a(f.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),h.tittle&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.tittle,0,0),d.tittle=a(f.getImageData(0,0,p,p))),h.ascent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.ascent,0,0),d.ascent=a(f.getImageData(0,0,p,p))),h.descent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.descent,0,0),d.descent=o(f.getImageData(0,0,p,p))),h.overshoot){f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.overshoot,0,0);var _=o(f.getImageData(0,0,p,p));d.overshoot=_-v}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],247:[function(t,e,r){\"use strict\";e.exports=function(t){return new s(t||g,null)};function n(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function i(t){return new n(t._color,t.key,t.value,t.left,t.right,t._count)}function a(t,e){return new n(t,e.key,e.value,e.left,e.right,e._count)}function o(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function s(t,e){this._compare=t,this.root=e}var l=s.prototype;function c(t,e){var r;if(e.left&&(r=c(t,e.left)))return r;return(r=t(e.key,e.value))||(e.right?c(t,e.right):void 0)}function u(t,e,r,n){if(e(t,n.key)<=0){var i;if(n.left)if(i=u(t,e,r,n.left))return i;if(i=r(n.key,n.value))return i}if(n.right)return u(t,e,r,n.right)}function f(t,e,r,n,i){var a,o=r(t,i.key),s=r(e,i.key);if(o<=0){if(i.left&&(a=f(t,e,r,n,i.left)))return a;if(s>0&&(a=n(i.key,i.value)))return a}if(s>0&&i.right)return f(t,e,r,n,i.right)}function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(l,\"keys\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(e)})),t}}),Object.defineProperty(l,\"values\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(r)})),t}}),Object.defineProperty(l,\"length\",{get:function(){return this.root?this.root._count:0}}),l.insert=function(t,e){for(var r=this._compare,i=this.root,l=[],c=[];i;){var u=r(t,i.key);l.push(i),c.push(u),i=u<=0?i.left:i.right}l.push(new n(0,t,e,null,null,1));for(var f=l.length-2;f>=0;--f){i=l[f];c[f]<=0?l[f]=new n(i._color,i.key,i.value,l[f+1],i.right,i._count+1):l[f]=new n(i._color,i.key,i.value,i.left,l[f+1],i._count+1)}for(f=l.length-1;f>1;--f){var h=l[f-1];i=l[f];if(1===h._color||1===i._color)break;var p=l[f-2];if(p.left===h)if(h.left===i){if(!(d=p.right)||0!==d._color){if(p._color=0,p.left=h.right,h._color=1,h.right=p,l[f-2]=h,l[f-1]=i,o(p),o(h),f>=3)(g=l[f-3]).left===p?g.left=h:g.right=h;break}h._color=1,p.right=a(1,d),p._color=0,f-=1}else{if(!(d=p.right)||0!==d._color){if(h.right=i.left,p._color=0,p.left=i.right,i._color=1,i.left=h,i.right=p,l[f-2]=i,l[f-1]=h,o(p),o(h),o(i),f>=3)(g=l[f-3]).left===p?g.left=i:g.right=i;break}h._color=1,p.right=a(1,d),p._color=0,f-=1}else if(h.right===i){if(!(d=p.left)||0!==d._color){if(p._color=0,p.right=h.left,h._color=1,h.left=p,l[f-2]=h,l[f-1]=i,o(p),o(h),f>=3)(g=l[f-3]).right===p?g.right=h:g.left=h;break}h._color=1,p.left=a(1,d),p._color=0,f-=1}else{var d;if(!(d=p.left)||0!==d._color){var g;if(h.left=i.right,p._color=0,p.right=i.left,i._color=1,i.right=h,i.left=p,l[f-2]=i,l[f-1]=h,o(p),o(h),o(i),f>=3)(g=l[f-3]).right===p?g.right=i:g.left=i;break}h._color=1,p.left=a(1,d),p._color=0,f-=1}}return l[0]._color=1,new s(r,l[0])},l.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return c(t,this.root);case 2:return u(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return f(e,r,this._compare,t,this.root)}},Object.defineProperty(l,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(l,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),l.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},l.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},l.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},l.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},l.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},l.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},l.remove=function(t){var e=this.find(t);return e?e.remove():this},l.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var p=h.prototype;function d(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function g(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(p,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(p,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),p.clone=function(){return new h(this.tree,this._stack.slice())},p.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new n(r._color,r.key,r.value,r.left,r.right,r._count);for(var l=t.length-2;l>=0;--l){(r=t[l]).left===t[l+1]?e[l]=new n(r._color,r.key,r.value,e[l+1],r.right,r._count):e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count)}if((r=e[e.length-1]).left&&r.right){var c=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var u=e[c-1];e.push(new n(r._color,u.key,u.value,r.left,r.right,r._count)),e[c-1].key=r.key,e[c-1].value=r.value;for(l=e.length-2;l>=c;--l)r=e[l],e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count);e[c-1].left=e[c]}if(0===(r=e[e.length-1])._color){var f=e[e.length-2];f.left===r?f.left=null:f.right===r&&(f.right=null),e.pop();for(l=0;l<e.length;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(r.left||r.right){r.left?d(r,r.left):r.right&&d(r,r.right),r._color=1;for(l=0;l<e.length-1;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(1===e.length)return new s(this.tree._compare,null);for(l=0;l<e.length;++l)e[l]._count--;var h=e[e.length-2];return function(t){for(var e,r,n,s,l=t.length-1;l>=0;--l){if(e=t[l],0===l)return void(e._color=1);if((r=t[l-1]).left===e){if((n=r.right).right&&0===n.right._color){if(s=(n=r.right=i(n)).right=i(n.right),r.right=n.left,n.left=r,n.right=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).left===r?c.left=n:c.right=n;return void(t[l-1]=n)}if(n.left&&0===n.left._color){if(s=(n=r.right=i(n)).left=i(n.left),r.right=s.left,n.left=s.right,s.left=r,s.right=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).left===r?c.left=s:c.right=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.right=a(0,n));r.right=a(0,n);continue}n=i(n),r.right=n.left,n.left=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).left===r?c.left=n:c.right=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}else{if((n=r.left).left&&0===n.left._color){if(s=(n=r.left=i(n)).left=i(n.left),r.left=n.right,n.right=r,n.left=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).right===r?c.right=n:c.left=n;return void(t[l-1]=n)}if(n.right&&0===n.right._color){if(s=(n=r.left=i(n)).right=i(n.right),r.left=s.right,n.right=s.left,s.right=r,s.left=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).right===r?c.right=s:c.left=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.left=a(0,n));r.left=a(0,n);continue}var c;n=i(n),r.left=n.right,n.right=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).right===r?c.right=n:c.left=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}}}(e),h.left===r?h.left=null:h.right=null,new s(this.tree._compare,e[0])},Object.defineProperty(p,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(p,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(p,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),p.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),p.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),i=e[e.length-1];r[r.length-1]=new n(i._color,i.key,t,i.left,i.right,i._count);for(var a=e.length-2;a>=0;--a)(i=e[a]).left===e[a+1]?r[a]=new n(i._color,i.key,i.value,r[a+1],i.right,i._count):r[a]=new n(i._color,i.key,i.value,i.left,r[a+1],i._count);return new s(this.tree._compare,r[0])},p.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],248:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function a(t){if(t<0)return Number(\"0/0\");for(var e=i[0],r=i.length-1;r>0;--r)e+=i[r]/(t+r);var n=t+607/128+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(a(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var o=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(o,e+.5)*Math.exp(-o)*r},e.exports.log=a},{}],249:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],250:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var f=u.prototype;function h(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}f.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,(function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]})),u=!1,f=!1;if(\"bounds\"in t)for(var h=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)h[p][d]!==this.bounds[p][d]&&(f=!0),this.bounds[p][d]=h[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,f=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),f=!0,u=!0,this._firstInit=!1),f&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort((function(t,e){return t.x-e.x}));s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new h,new h,new h];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var f=a,h=s,p=o,d=l;c&1<<u&&(f=s,h=a,p=l,d=o),f[u]=r[0][u],h[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],m={model:l,view:l,projection:l,_ortho:!1};f.isOpaque=function(){return!0},f.isTransparent=function(){return!1},f.drawTransparent=function(t){};var v=[0,0,0],y=[0,0,0],x=[0,0,0];f.draw=function(t){t=t||m;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),f=u.cubeEdges,h=u.axis,b=n[12],_=n[13],w=n[14],T=n[15],k=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*T)/e.drawingBufferHeight,M=0;M<3;++M)this.lastCubeProps.cubeEdges[M]=f[M],this.lastCubeProps.axis[M]=h[M];var A=p;for(M=0;M<3;++M)d(p[M],M,this.bounds,f,h);e=this.gl;var S,E=g;for(M=0;M<3;++M)this.backgroundEnable[M]?E[M]=h[M]:E[M]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(M=0;M<3;++M){var C=[0,0,0];h[M]>0?C[M]=a[1][M]:C[M]=a[0][M];for(var L=0;L<2;++L){var I=(M+1+L)%3,P=(M+1+(1^L))%3;this.gridEnable[I]&&this._lines.drawGrid(I,P,this.bounds,C,this.gridColor[I],this.gridWidth[I]*this.pixelRatio)}for(L=0;L<2;++L){I=(M+1+L)%3,P=(M+1+(1^L))%3;this.zeroEnable[P]&&Math.min(a[0][P],a[1][P])<=0&&Math.max(a[0][P],a[1][P])>=0&&this._lines.drawZero(I,P,this.bounds,C,this.zeroLineColor[P],this.zeroLineWidth[P]*this.pixelRatio)}}for(M=0;M<3;++M){this.lineEnable[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].primalOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio),this.lineMirror[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].mirrorOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio);var z=c(v,A[M].primalMinor),O=c(y,A[M].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=k/r[5*L];z[L]*=D[L]*R,O[L]*=D[L]*R}this.lineTickEnable[M]&&this._lines.drawAxisTicks(M,A[M].primalOffset,z,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio),this.lineTickMirror[M]&&this._lines.drawAxisTicks(M,A[M].mirrorOffset,O,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0||a>0&&l<0||a<0&&l>0||a<0&&l<0?N(n):(o>0&&s>0||o>0&&s<0||o<0&&s>0||o<0&&s<0)&&N(i)}for(M=0;M<3;++M){var U=A[M].primalMinor,V=A[M].mirrorMinor,q=c(x,A[M].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[M]&&(q[L]+=k*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[M]=1,this.tickEnable[M]){-3600===this.tickAngle[M]?(this.tickAngle[M]=0,this.tickAlign[M]=\"auto\"):this.tickAlign[M]=-1,F=1,\"auto\"===(S=[this.tickAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(M,U,V);for(L=0;L<3;++L)q[L]+=k*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(M,this.tickSize[M],this.tickAngle[M],q,this.tickColor[M],H,B,S)}if(this.labelEnable[M]){F=0,B=[0,0,0],this.labels[M].length>4&&(N(M),F=1),\"auto\"===(S=[this.labelAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=k*U[L]*this.labelPad[L]/r[5*L];q[M]+=.5*(a[0][M]+a[1][M]),this._text.drawLabel(M,this.labelSize[M],this.labelAngle[M],q,this.labelColor[M],[0,0,0],B,S)}}this._text.unbind()},f.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":251,\"./lib/cube.js\":252,\"./lib/lines.js\":253,\"./lib/text.js\":255,\"./lib/ticks.js\":256}],251:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,f=[0,0,0],h=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),f[l]=p,h[l]=p;for(var d=-1;d<=1;d+=2){f[c]=d;for(var g=-1;g<=1;g+=2)f[u]=g,e.push(f[0],f[1],f[2],h[0],h[1],h[2]),s+=1}var m=c;c=u,u=m}var v=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:v,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:v,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,v,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":254,\"gl-buffer\":259,\"gl-vao\":358}],252:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],h(l[y],u,s),y+=1}}var w=-1;for(x=0;x<8;++x){for(var T=l[x][3],k=0;k<3;++k)c[x][k]=l[x][k]/T;p&&(c[x][2]*=-1),T<0&&(w<0||c[x][2]<c[w][2])&&(w=x)}if(w<0){w=0;for(var M=0;M<3;++M){for(var A=(M+2)%3,S=(M+1)%3,E=-1,C=-1,L=0;L<2;++L){var I=(z=L<<M)+(L<<A)+(1-L<<S),P=z+(1-L<<A)+(L<<S);o(c[z],c[I],c[P],f)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<M);else{for(L=0;L<2;++L){I=(z=L<<M)+(L<<A)+(1-L<<S),P=z+(1-L<<A)+(L<<S);var z,O=d([l[z],l[I],l[P],l[z+(1<<A)+(1<<S)]]);L?E=O:C=O}C>E&&(w|=1<<M)}}}var D=7^w,R=-1;for(x=0;x<8;++x)x!==w&&x!==D&&(R<0||c[R][1]>c[x][1])&&(R=x);var F=-1;for(x=0;x<3;++x){if((N=R^1<<x)!==w&&N!==D)F<0&&(F=N),(S=c[N])[0]<c[F][0]&&(F=N)}var B=-1;for(x=0;x<3;++x){var N;if((N=R^1<<x)!==w&&N!==D&&N!==F)B<0&&(B=N),(S=c[N])[0]>c[B][0]&&(B=N)}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^B)]=R&B;var U=7^B;U===w||U===D?(U=7^F,j[n.log2(B^U)]=U&B):j[n.log2(F^U)]=U&F;var V=m,q=w;for(M=0;M<3;++M)V[M]=q&1<<M?-1:1;return v};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),f=[0,0,0];function h(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,f=l[0]/l[3]-n,h=l[1]/l[3]-i;o+=Math.abs(c*h-u*f)}return o}var g=[1,1,1],m=[0,0,0],v={cubeEdges:g,axis:m}},{\"bit-twiddle\":97,\"gl-mat4/multiply\":295,\"robust-orientation\":548,\"split-polygon\":566}],253:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var f=0;f<3;++f){for(var h=o.length/3|0,d=0;d<r[f].length;++d){var g=+r[f][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var m=o.length/3|0;s[f]=h,l[f]=m-h;h=o.length/3|0;for(var v=0;v<r[f].length;++v){g=+r[f][v].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}m=o.length/3|0;c[f]=h,u[f]=m-h}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function f(t){return t[0]=t[1]=t[2]=0,t}function h(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=f(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=h(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=f(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=f(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=f(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=f(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=f(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=h(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=f(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=f(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=f(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=h(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=f(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":254,\"gl-buffer\":259,\"gl-vao\":358}],254:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":335,glslify:257}],255:[function(t,e,r){(function(r){(function(){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),f=i(t,[{buffer:u,size:3}]),h=o(t);h.attributes.position.location=0;var p=new c(t,h,u,f);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,f=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,f[0]=this.gl.drawingBufferWidth,f[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=f},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var f=(n||12)/12,h=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var m=p[d],v=2;v>=0;--v){var y=h[m[v]];o.push(f*y[0],-f*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],f=[0,0,0],h=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){f[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),h[d]=(o.length/3|0)-f[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=f,this.labelCount=h},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this)}).call(this,t(\"_process\"))},{\"./shaders\":254,_process:526,\"gl-buffer\":259,\"gl-vao\":358,\"vectorize-text\":600}],256:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var f=\"\"+c;f.length<i;)f=\"0\"+f;return u+\".\"+f}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],257:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],258:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,f){var h=e.model||c,p=e.view||c,v=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(f=f||a(h,p,v,x,y)).axis;o(u,p,h),o(u,v,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var T=n(s(u,u));s(u,u);for(var k=0;k<3;++k){var M=(k+1)%3,A=(k+2)%3,S=m;t:for(w=0;w<2;++w){var E=[];if(b[k]<0!=!!w){S[k]=x[w][k];for(var C=0;C<2;++C){S[M]=x[C^w][M];for(var L=0;L<2;++L)S[A]=x[L^C^w][A],E.push(S.slice())}var I=y?5:4;for(C=I;C===I;++C){if(0===E.length)continue t;E=i.positive(E,T[C])}for(C=0;C<E.length;++C){A=E[C];var P=d(m,u,A,r,l);for(L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,A[L]),_[L].hi=Math.max(_[L].hi,A[L]),L!==k&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(P[L])))}}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function f(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var h=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=h,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,f=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+f*f)}return t}var g=[new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0)],m=[0,0,0]},{\"./lib/cube.js\":252,\"extract-frustum-planes\":240,\"gl-mat4/multiply\":295,\"gl-mat4/transpose\":306,\"gl-vec4/transformMat4\":429,\"split-polygon\":566}],259:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var f;f=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?f:f.subarray(0,t.length),e),n.free(f)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:495,\"ndarray-ops\":490,\"typedarray-pool\":595}],260:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\");e.exports=function(t,e){var r=t.positions,i=t.vectors,a={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),a;for(var o=0,s=1/0,l=-1/0,c=1/0,u=-1/0,f=1/0,h=-1/0,p=null,d=null,g=[],m=1/0,v=!1,y=0;y<r.length;y++){var x=r[y];s=Math.min(x[0],s),l=Math.max(x[0],l),c=Math.min(x[1],c),u=Math.max(x[1],u),f=Math.min(x[2],f),h=Math.max(x[2],h);var b=i[y];if(n.length(b)>o&&(o=n.length(b)),y){var _=2*n.distance(p,x)/(n.length(d)+n.length(b));_?(m=Math.min(m,_),v=!1):v=!0}v||(p=x,d=b),g.push(b)}var w=[s,c,f],T=[l,u,h];e&&(e[0]=w,e[1]=T),0===o&&(o=1);var k=1/o;isFinite(m)||(m=1),a.vectorScale=m;var M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*k),a.coneScale=M;y=0;for(var A=0;y<r.length;y++)for(var S=(x=r[y])[0],E=x[1],C=x[2],L=g[y],I=n.length(L)*k,P=0;P<8;P++){a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vertexIntensity.push(I,I,I),a.vertexIntensity.push(I,I,I);var z=a.positions.length;a.cells.push([z-6,z-5,z-4],[z-3,z-2,z-1])}return a};var i=t(\"./lib/shaders\");e.exports.createMesh=t(\"./create_mesh\"),e.exports.createConeMesh=function(t,r){return e.exports.createMesh(t,r,{shaders:i,traceType:\"cone\"})}},{\"./create_mesh\":261,\"./lib/shaders\":262,\"gl-vec3\":377}],261:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"gl-mat4/multiply\"),l=t(\"gl-mat4/invert\"),c=t(\"ndarray\"),u=t(\"colormap\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e,r,n,i,a,o,s,l,c,u){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=c,this.triangleCount=0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.traceType=u,this.tubeScale=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=f,this._view=f,this._projection=f,this._resolution=[1,1]}var p=h.prototype;function d(t,e){var r=n(t,e.meshShader.vertex,e.meshShader.fragment,null,e.meshShader.attributes);return r.attributes.position.location=0,r.attributes.color.location=2,r.attributes.uv.location=3,r.attributes.vector.location=4,r}function g(t,e){var r=n(t,e.pickShader.vertex,e.pickShader.fragment,null,e.pickShader.attributes);return r.attributes.position.location=0,r.attributes.id.location=1,r.attributes.vector.location=4,r}p.isOpaque=function(){return this.opacity>=1},p.isTransparent=function(){return this.opacity<1},p.pickSlots=1,p.setPickBase=function(t){this.pickId=t},p.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=u({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return c(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],o=[],s=[],l=[],f=[];this.cells=r,this.positions=n,this.vectors=i;var h=t.meshColor||[1,1,1,1],p=t.vertexIntensity,d=1/0,g=-1/0;if(p)if(t.vertexIntensityBounds)d=+t.vertexIntensityBounds[0],g=+t.vertexIntensityBounds[1];else for(var m=0;m<p.length;++m){var v=p[m];d=Math.min(d,v),g=Math.max(g,v)}else for(m=0;m<n.length;++m){v=n[m][2];d=Math.min(d,v),g=Math.max(g,v)}this.intensity=p||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n),this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(m=0;m<n.length;++m)for(var y=n[m],x=0;x<3;++x)!isNaN(y[x])&&isFinite(y[x])&&(this.bounds[0][x]=Math.min(this.bounds[0][x],y[x]),this.bounds[1][x]=Math.max(this.bounds[1][x],y[x]));var b=0;t:for(m=0;m<r.length;++m){var _=r[m];switch(_.length){case 3:for(x=0;x<3;++x){y=n[T=_[x]];for(var w=0;w<3;++w)if(isNaN(y[w])||!isFinite(y[w]))continue t}for(x=0;x<3;++x){var T;y=n[T=_[2-x]];a.push(y[0],y[1],y[2],y[3]);var k=i[T];o.push(k[0],k[1],k[2],k[3]||0);var M,A=h;3===A.length?s.push(A[0],A[1],A[2],1):s.push(A[0],A[1],A[2],A[3]),M=p?[(p[T]-d)/(g-d),0]:[(y[2]-d)/(g-d),0],l.push(M[0],M[1]),f.push(m)}b+=1}}this.triangleCount=b,this.trianglePositions.update(a),this.triangleVectors.update(o),this.triangleColors.update(s),this.triangleUVs.update(l),this.triangleIds.update(new Uint32Array(f))}},p.drawTransparent=p.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||f,n=t.view||f,i=t.projection||f,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var c={model:r,view:n,projection:i,inverseModel:f.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,texture:0};c.inverseModel=l(c.inverseModel,c.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);s(u,c.view,c.model),s(u,c.projection,u),l(u,u);for(o=0;o<3;++o)c.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];c.lightPosition[o]=p/h}if(this.triangleCount>0){var g=this.triShader;g.bind(),g.uniforms=c,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},p.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||f,n=t.view||f,i=t.projection||f,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind())},p.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3),i={position:n,dataCoordinate:n,index:Math.floor(r[1]/48)};return\"cone\"===this.traceType?i.index=Math.floor(r[1]/48):\"streamtube\"===this.traceType&&(i.intensity=this.intensity[r[1]],i.velocity=this.vectors[r[1]].slice(0,3),i.divergence=this.vectors[r[1]][3],i.index=e),i},p.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleIds.dispose()},e.exports=function(t,e,r){var n=r.shaders;1===arguments.length&&(t=(e=t).gl);var s=d(t,n),l=g(t,n),u=o(t,c(new Uint8Array([255,255,255,255]),[1,1,4]));u.generateMipmap(),u.minFilter=t.LINEAR_MIPMAP_LINEAR,u.magFilter=t.LINEAR;var f=i(t),p=i(t),m=i(t),v=i(t),y=i(t),x=a(t,[{buffer:f,type:t.FLOAT,size:4},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:m,type:t.FLOAT,size:4},{buffer:v,type:t.FLOAT,size:2},{buffer:p,type:t.FLOAT,size:4}]),b=new h(t,u,s,l,f,p,y,m,v,x,r.traceType||\"cone\");return b.update(e),b}},{colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-shader\":335,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495}],262:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, coneScale, coneOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float vectorScale, coneScale, coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector.xyz), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:263}],263:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],264:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34e3:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],265:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":264}],266:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var f=0;f<3;++f)e.lineWidth(this.lineWidth[f]*this.pixelRatio),r.capSize=this.capSize[f]*u,this.lineCount[f]&&e.drawArrays(e.LINES,this.lineOffset[f],this.lineCount[f]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function f(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],h=0;h<3;++h)if(isNaN(u[h])||!isFinite(u[h]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+f(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+f(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":268,\"gl-buffer\":259,\"gl-vao\":358}],267:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],268:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":335,glslify:267}],269:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var f=1;if(\"color\"in(n=n||{})){if((f=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(f>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(f>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+f+\" draw buffers\")}}var h=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&f>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");h=t.FLOAT}else n.preferFloat&&f>0&&p&&(h=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var m=!1;\"stencil\"in n&&(m=!!n.stencil);return new d(t,e,r,h,f,g,m,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function f(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function h(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,m=[0|e,0|r];Object.defineProperties(m,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=m,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,m=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var v=0;v<o;++v)t.color[v]=h(r,i,a,m,r.RGBA,r.COLOR_ATTACHMENT0+v);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=h(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=h(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null);for(v=0;v<t.color.length;++v)t.color[v].dispose(),t.color[v]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),f(x)}u(r,e)}(this)}var g=d.prototype;function m(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),f(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return m(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return m(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,m(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":353}],270:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),f=t.split(\"\\n\"),h={},p=0;p<f.length;p++){var d=f[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));h[g]=d}}var m=o(e).split(\"\\n\");for(p=0;p<m.length;p++)if(h[p+3]||h[p+2]||h[p+1]){var v=m[p];if(c+=v+\"\\n\",h[p+1]){var y=h[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":66,\"gl-constants/lookup\":265,\"glsl-shader-name\":431,\"sprintf-js\":567}],271:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),f=s(r),h=s(r),p=new c(t,n,i,a,u,f,h);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,f=c.prototype,h=[0,0,1,0,0,1,1,0,1,1,0,1];f.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var f=e.uniforms;f.viewTransform=u,f.shape=this.shape;var h=e.attributes;this.positionBuffer.bind(),h.position.pointer(),this.weightBuffer.bind(),h.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),h.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),f.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],f=l[2]-l[0],h=l[3]-l[1];t[0]=2*c/f,t[4]=2*u/h,t[6]=2*(a[0]-l[0])/f-1,t[7]=2*(a[1]-l[1])/h-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),f.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},f.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]),l=!1!==t.zsmooth;this.xData=r,this.yData=o;var c,u,f,p,d=t.colorLevels||[0],g=t.colorValues||[0,0,0,1],m=d.length,v=this.bounds;l?(c=v[0]=r[0],u=v[1]=o[0],f=v[2]=r[r.length-1],p=v[3]=o[o.length-1]):(c=v[0]=r[0]+(r[1]-r[0])/2,u=v[1]=o[0]+(o[1]-o[0])/2,f=v[2]=r[r.length-1]+(r[r.length-1]-r[r.length-2])/2,p=v[3]=o[o.length-1]+(o[o.length-1]-o[o.length-2])/2);var y=1/(f-c),x=1/(p-u),b=e[0],_=e[1];this.shape=[b,_];var w=(l?(b-1)*(_-1):b*_)*(h.length>>>1);this.numVertices=w;for(var T=a.mallocUint8(4*w),k=a.mallocFloat32(2*w),M=a.mallocUint8(2*w),A=a.mallocUint32(w),S=0,E=l?b-1:b,C=l?_-1:_,L=0;L<C;++L){var I,P;l?(I=x*(o[L]-u),P=x*(o[L+1]-u)):(I=L<_-1?x*(o[L]-(o[L+1]-o[L])/2-u):x*(o[L]-(o[L]-o[L-1])/2-u),P=L<_-1?x*(o[L]+(o[L+1]-o[L])/2-u):x*(o[L]+(o[L]-o[L-1])/2-u));for(var z=0;z<E;++z){var O,D;l?(O=y*(r[z]-c),D=y*(r[z+1]-c)):(O=z<b-1?y*(r[z]-(r[z+1]-r[z])/2-c):y*(r[z]-(r[z]-r[z-1])/2-c),D=z<b-1?y*(r[z]+(r[z+1]-r[z])/2-c):y*(r[z]+(r[z]-r[z-1])/2-c));for(var R=0;R<h.length;R+=2){var F,B,N,j,U=h[R],V=h[R+1],q=s[l?(L+V)*b+(z+U):L*b+z],H=n.le(d,q);if(H<0)F=g[0],B=g[1],N=g[2],j=g[3];else if(H===m-1)F=g[4*m-4],B=g[4*m-3],N=g[4*m-2],j=g[4*m-1];else{var G=(q-d[H])/(d[H+1]-d[H]),Y=1-G,W=4*H,X=4*(H+1);F=Y*g[W]+G*g[X],B=Y*g[W+1]+G*g[X+1],N=Y*g[W+2]+G*g[X+2],j=Y*g[W+3]+G*g[X+3]}T[4*S]=255*F,T[4*S+1]=255*B,T[4*S+2]=255*N,T[4*S+3]=255*j,k[2*S]=.5*O+.5*D,k[2*S+1]=.5*I+.5*P,M[2*S]=U,M[2*S+1]=V,A[S]=L*b+z,S+=1}}}this.positionBuffer.update(k),this.weightBuffer.update(M),this.colorBuffer.update(T),this.idBuffer.update(A),a.free(k),a.free(T),a.free(M),a.free(A)},f.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":272,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335,\"iota-array\":463,\"typedarray-pool\":595}],272:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:273}],273:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],274:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\n// https://github.com/mikolalysenko/glsl-read-float/blob/master/index.glsl\\nvec4 packFloat(float v) {\\n  float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  float e = floor(log2(av));\\n  float m = av * pow(2.0, -e) - 1.0;\\n\\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n\\n  //Unpack exponent\\n  float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0;\\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, packFloat(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":335,glslify:276}],275:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=f(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),l=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),u=c(new Array(1024),[256,1,4]),p=0;p<1024;++p)u.data[p]=255;var d=a(e,u);d.wrap=e.REPEAT;var g=new v(e,r,o,s,l,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=new Uint8Array(4),s=new Float32Array(o.buffer);var l=t(\"binary-search-bounds\"),c=t(\"ndarray\"),u=t(\"./lib/shaders\"),f=u.createShader,h=u.createPickShader,p=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function d(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function g(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function m(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var y=v.prototype;y.isTransparent=function(){return this.hasAlpha},y.isOpaque=function(){return!this.hasAlpha},y.pickSlots=1,y.setPickBase=function(t){this.pickId=t},y.drawTransparent=y.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,clipBounds:g(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,pickId:this.pickId,clipBounds:g(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],s=0,u=0,f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],h=t.position||t.positions;if(h){var p=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,m=!1;t:for(e=1;e<h.length;++e){var v,y,x,b=h[e-1],_=h[e];for(a.push(s),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,m=!0}continue t}f[0][r]=Math.min(f[0][r],b[r],_[r]),f[1][r]=Math.max(f[1][r],b[r],_[r])}Array.isArray(p[0])?(v=p.length>e-1?p[e-1]:p.length>0?p[p.length-1]:[0,0,0,1],y=p.length>e?p[e]:p.length>0?p[p.length-1]:[0,0,0,1]):v=y=p,3===v.length&&(v=[v[0],v[1],v[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&v[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var T=s;if(s+=d(b,_),m){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3]);u+=2,m=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3],b[0],b[1],b[2],_[0],_[1],_[2],T,-x,v[0],v[1],v[2],v[3],_[0],_[1],_[2],b[0],b[1],b[2],s,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],s,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(s),o.push(h[h.length-1].slice()),this.bounds=f,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var k=t.dashes.slice();for(k.unshift(0),e=1;e<k.length;++e)k[e]=k[e-1]+k[e];var M=c(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)M.set(e,0,r,0);1&l.le(k,k[k.length-1]*e/255)?M.set(e,0,0,0):M.set(e,0,0,255)}this.texture.setPixels(M)}},y.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},y.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=function(t,e,r,n){return o[0]=n,o[1]=r,o[2]=e,o[3]=t,s[0]}(t.value[0],t.value[1],t.value[2],0),r=l.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new m(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),c=1-a,u=[0,0,0],f=0;f<3;++f)u[f]=c*n[f]+a*i[f];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new m(e,u,h,this.points[h])}},{\"./lib/shaders\":274,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495}],276:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],277:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15];return t[0]=s*(h*v-p*m)-f*(l*v-c*m)+g*(l*p-c*h),t[1]=-(n*(h*v-p*m)-f*(i*v-a*m)+g*(i*p-a*h)),t[2]=n*(l*v-c*m)-s*(i*v-a*m)+g*(i*c-a*l),t[3]=-(n*(l*p-c*h)-s*(i*p-a*h)+f*(i*c-a*l)),t[4]=-(o*(h*v-p*m)-u*(l*v-c*m)+d*(l*p-c*h)),t[5]=r*(h*v-p*m)-u*(i*v-a*m)+d*(i*p-a*h),t[6]=-(r*(l*v-c*m)-o*(i*v-a*m)+d*(i*c-a*l)),t[7]=r*(l*p-c*h)-o*(i*p-a*h)+u*(i*c-a*l),t[8]=o*(f*v-p*g)-u*(s*v-c*g)+d*(s*p-c*f),t[9]=-(r*(f*v-p*g)-u*(n*v-a*g)+d*(n*p-a*f)),t[10]=r*(s*v-c*g)-o*(n*v-a*g)+d*(n*c-a*s),t[11]=-(r*(s*p-c*f)-o*(n*p-a*f)+u*(n*c-a*s)),t[12]=-(o*(f*m-h*g)-u*(s*m-l*g)+d*(s*h-l*f)),t[13]=r*(f*m-h*g)-u*(n*m-i*g)+d*(n*h-i*f),t[14]=-(r*(s*m-l*g)-o*(n*m-i*g)+d*(n*l-i*s)),t[15]=r*(s*h-l*f)-o*(n*h-i*f)+u*(n*l-i*s),t}},{}],278:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],279:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],280:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],281:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],f=t[10],h=t[11],p=t[12],d=t[13],g=t[14],m=t[15];return(e*o-r*a)*(f*m-h*g)-(e*s-n*a)*(u*m-h*d)+(e*l-i*a)*(u*g-f*d)+(r*s-n*o)*(c*m-h*p)-(r*l-i*o)*(c*g-f*p)+(n*l-i*s)*(c*d-u*p)}},{}],282:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,f=n*s,h=i*o,p=i*s,d=i*l,g=a*o,m=a*s,v=a*l;return t[0]=1-f-d,t[1]=u+v,t[2]=h-m,t[3]=0,t[4]=u-v,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=h+m,t[9]=p-g,t[10]=1-c-f,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],283:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o=r[0],s=r[1],l=r[2],c=Math.sqrt(o*o+s*s+l*l);if(Math.abs(c)<1e-6)return null;return o*=c=1/c,s*=c,l*=c,n=Math.sin(e),i=Math.cos(e),a=1-i,t[0]=o*o*a+i,t[1]=s*o*a+l*n,t[2]=l*o*a-s*n,t[3]=0,t[4]=o*s*a-l*n,t[5]=s*s*a+i,t[6]=l*s*a+o*n,t[7]=0,t[8]=o*l*a+s*n,t[9]=s*l*a-o*n,t[10]=l*l*a+i,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],284:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,f=n*l,h=n*c,p=i*l,d=i*c,g=a*c,m=o*s,v=o*l,y=o*c;return t[0]=1-(p+g),t[1]=f+y,t[2]=h-v,t[3]=0,t[4]=f-y,t[5]=1-(u+g),t[6]=d+m,t[7]=0,t[8]=h+v,t[9]=d-m,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],285:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=e[1],t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=e[2],t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],286:[function(t,e,r){e.exports=function(t,e){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=e[0],t[13]=e[1],t[14]=e[2],t[15]=1,t}},{}],287:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=n,t[6]=r,t[7]=0,t[8]=0,t[9]=-r,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],288:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=0,t[2]=-r,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=r,t[9]=0,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],289:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=0,t[4]=-r,t[5]=n,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],290:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(r-e),l=1/(i-n),c=1/(a-o);return t[0]=2*a*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=2*a*l,t[6]=0,t[7]=0,t[8]=(r+e)*s,t[9]=(i+n)*l,t[10]=(o+a)*c,t[11]=-1,t[12]=0,t[13]=0,t[14]=o*a*2*c,t[15]=0,t}},{}],291:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],292:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),copy:t(\"./copy\"),identity:t(\"./identity\"),transpose:t(\"./transpose\"),invert:t(\"./invert\"),adjoint:t(\"./adjoint\"),determinant:t(\"./determinant\"),multiply:t(\"./multiply\"),translate:t(\"./translate\"),scale:t(\"./scale\"),rotate:t(\"./rotate\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),fromRotation:t(\"./fromRotation\"),fromRotationTranslation:t(\"./fromRotationTranslation\"),fromScaling:t(\"./fromScaling\"),fromTranslation:t(\"./fromTranslation\"),fromXRotation:t(\"./fromXRotation\"),fromYRotation:t(\"./fromYRotation\"),fromZRotation:t(\"./fromZRotation\"),fromQuat:t(\"./fromQuat\"),frustum:t(\"./frustum\"),perspective:t(\"./perspective\"),perspectiveFromFieldOfView:t(\"./perspectiveFromFieldOfView\"),ortho:t(\"./ortho\"),lookAt:t(\"./lookAt\"),str:t(\"./str\")}},{\"./adjoint\":277,\"./clone\":278,\"./copy\":279,\"./create\":280,\"./determinant\":281,\"./fromQuat\":282,\"./fromRotation\":283,\"./fromRotationTranslation\":284,\"./fromScaling\":285,\"./fromTranslation\":286,\"./fromXRotation\":287,\"./fromYRotation\":288,\"./fromZRotation\":289,\"./frustum\":290,\"./identity\":291,\"./invert\":293,\"./lookAt\":294,\"./multiply\":295,\"./ortho\":296,\"./perspective\":297,\"./perspectiveFromFieldOfView\":298,\"./rotate\":299,\"./rotateX\":300,\"./rotateY\":301,\"./rotateZ\":302,\"./scale\":303,\"./str\":304,\"./translate\":305,\"./transpose\":306}],293:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*g-f*d,M=u*m-h*d,A=u*v-p*d,S=f*m-h*g,E=f*v-p*g,C=h*v-p*m,L=y*C-x*E+b*S+_*A-w*M+T*k;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*T-m*w+v*_)*L,t[3]=(h*w-f*T-p*_)*L,t[4]=(l*A-o*C-c*M)*L,t[5]=(r*C-i*A+a*M)*L,t[6]=(m*b-d*T-v*x)*L,t[7]=(u*T-h*b+p*x)*L,t[8]=(o*E-s*A+c*k)*L,t[9]=(n*A-r*E-a*k)*L,t[10]=(d*w-g*b+v*y)*L,t[11]=(f*b-u*w-p*y)*L,t[12]=(s*M-o*S-l*k)*L,t[13]=(r*S-n*M+i*k)*L,t[14]=(g*x-d*_-m*y)*L,t[15]=(u*_-f*x+h*y)*L,t}},{}],294:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,g=e[0],m=e[1],v=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],T=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(m-w)<1e-6&&Math.abs(v-T)<1e-6)return n(t);f=g-_,h=m-w,p=v-T,d=1/Math.sqrt(f*f+h*h+p*p),a=x*(p*=d)-b*(h*=d),o=b*(f*=d)-y*p,s=y*h-x*f,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=h*s-p*o,c=p*a-f*s,u=f*o-h*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=f,t[3]=0,t[4]=o,t[5]=c,t[6]=h,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*m+s*v),t[13]=-(l*g+c*m+u*v),t[14]=-(f*g+h*m+p*v),t[15]=1,t}},{\"./identity\":291}],295:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],g=e[12],m=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*g,t[1]=x*i+b*l+_*h+w*m,t[2]=x*a+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*f+w*g,t[5]=x*i+b*l+_*h+w*m,t[6]=x*a+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*f+w*g,t[9]=x*i+b*l+_*h+w*m,t[10]=x*a+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*f+w*g,t[13]=x*i+b*l+_*h+w*m,t[14]=x*a+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}},{}],296:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],297:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],298:[function(t,e,r){e.exports=function(t,e,r,n){var i=Math.tan(e.upDegrees*Math.PI/180),a=Math.tan(e.downDegrees*Math.PI/180),o=Math.tan(e.leftDegrees*Math.PI/180),s=Math.tan(e.rightDegrees*Math.PI/180),l=2/(o+s),c=2/(i+a);return t[0]=l,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=c,t[6]=0,t[7]=0,t[8]=-(o-s)*l*.5,t[9]=(i-a)*c*.5,t[10]=n/(r-n),t[11]=-1,t[12]=0,t[13]=0,t[14]=n*r/(r-n),t[15]=0,t}},{}],299:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S,E=n[0],C=n[1],L=n[2],I=Math.sqrt(E*E+C*C+L*L);if(Math.abs(I)<1e-6)return null;E*=I=1/I,C*=I,L*=I,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],f=e[4],h=e[5],p=e[6],d=e[7],g=e[8],m=e[9],v=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,T=C*C*o+a,k=L*C*o+E*i,M=E*L*o+C*i,A=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+f*b+g*_,t[1]=l*x+h*b+m*_,t[2]=c*x+p*b+v*_,t[3]=u*x+d*b+y*_,t[4]=s*w+f*T+g*k,t[5]=l*w+h*T+m*k,t[6]=c*w+p*T+v*k,t[7]=u*w+d*T+y*k,t[8]=s*M+f*A+g*S,t[9]=l*M+h*A+m*S,t[10]=c*M+p*A+v*S,t[11]=u*M+d*A+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],300:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t}},{}],301:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-f*n,t[3]=l*i-h*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+f*i,t[11]=l*n+h*i,t}},{}],302:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t}},{}],303:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],304:[function(t,e,r){e.exports=function(t){return\"mat4(\"+t[0]+\", \"+t[1]+\", \"+t[2]+\", \"+t[3]+\", \"+t[4]+\", \"+t[5]+\", \"+t[6]+\", \"+t[7]+\", \"+t[8]+\", \"+t[9]+\", \"+t[10]+\", \"+t[11]+\", \"+t[12]+\", \"+t[13]+\", \"+t[14]+\", \"+t[15]+\")\"}},{}],305:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,g=r[0],m=r[1],v=r[2];e===t?(t[12]=e[0]*g+e[4]*m+e[8]*v+e[12],t[13]=e[1]*g+e[5]*m+e[9]*v+e[13],t[14]=e[2]*g+e[6]*m+e[10]*v+e[14],t[15]=e[3]*g+e[7]*m+e[11]*v+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*g+s*m+f*v+e[12],t[13]=i*g+l*m+h*v+e[13],t[14]=a*g+c*m+p*v+e[14],t[15]=o*g+u*m+d*v+e[15]);return t}},{}],306:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],307:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}function s(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}e.exports=function(t,e,r,a,l,c){if(1===t.length)return[0,t[0].slice()];for(var u=new Array(t.length),f=0;f<t.length;++f)u[f]=o(t[f],r,a,l,c);var h=0,p=1/0;for(f=0;f<u.length;++f){for(var d=0,g=0;g<2;++g)d+=Math.pow(u[f][g]-e[g],2);d<p&&(p=d,h=f)}var m=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(u,e),v=0;for(f=0;f<3;++f){if(m[f]<-.001||m[f]>1.0001)return null;v+=m[f]}if(Math.abs(v-1)>.001)return null;return[h,s(t,m),m]}},{barycentric:78,\"polytope-closest-point/lib/closest_point_2d.js\":525}],308:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:h,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:310}],309:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),f=t(\"colormap\"),h=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),m=d.meshShader,v=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function T(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,T,k,M,A,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=h,this.triangleUVs=f,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=m,this.edgeUVs=v,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=T,this.pointSizes=k,this.pointIds=b,this.pointVAO=M,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=A,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickVertex=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var k=T.prototype;function M(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function A(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}function S(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}function E(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function L(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function I(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}k.isOpaque=function(){return!this.hasAlpha},k.isTransparent=function(){return this.hasAlpha},k.pickSlots=1,k.setPickBase=function(t){this.pickId=t},k.highlight=function(t){if(t&&this.contourEnable){for(var e=h(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var f=c[0];2===c.length&&(f=c[u]);for(var d=n[f][0],g=n[f][1],m=i[f],v=1-m,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=m*y[b]+v*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},k.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=f({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*M(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],h=[],p=[],d=[],g=[],m=[],v=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,T=t.cellNormals,k=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,A=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!T&&(T=s.faceNormals(r,n,A)),T||w||(w=s.vertexNormals(r,n,k));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,I=t.vertexIntensity,P=t.cellUVs,z=t.cellIntensity,O=1/0,D=-1/0;if(!L&&!P)if(I)if(t.vertexIntensityBounds)O=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<I.length;++R){var F=I[R];O=Math.min(O,F),D=Math.max(D,F)}else if(z)if(t.cellIntensityBounds)O=+t.cellIntensityBounds[0],D=+t.cellIntensityBounds[1];else for(R=0;R<z.length;++R){F=z[R];O=Math.min(O,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];O=Math.min(O,F),D=Math.max(D,F)}this.intensity=I||(z||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n)),this.pickVertex=!(z||E);var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;v.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],g.push(Z[0],Z[1]),m.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),(X=S?S[W]:E?E[R]:C)?this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)):a.push(.5,.5,.5,1),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],c.push(Z[0],Z[1]),J=w?w[W]:T[R],l.push(J[0],J[1],J[2]),h.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(v),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(m)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(h))}},k.drawTransparent=k.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var f,h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/h}this.triangleCount>0&&((f=this.triShader).bind(),f.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((f=this.lineShader).bind(),f.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((f=this.pointShader).bind(),f.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((f=this.contourShader).bind(),f.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},k.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},k.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=t.coord[0],s=t.coord[1];if(!this.pickVertex){var l=this.positions[r[0]],c=this.positions[r[1]],u=this.positions[r[2]],f=[(l[0]+c[0]+u[0])/3,(l[1]+c[1]+u[1])/3,(l[2]+c[2]+u[2])/3];return{_cellCenter:!0,position:[o,s],index:e,cell:r,cellId:e,intensity:this.intensity[e],dataCoordinate:f}}var h=g(i,[o*this.pixelRatio,this._resolution[1]-s*this.pixelRatio],this._model,this._view,this._projection,this._resolution);if(!h)return null;var p=h[2],d=0;for(a=0;a<r.length;++a)d+=p[a]*this.intensity[r[a]];return{position:h[1],index:r[h[0]],cell:r,cellId:e,intensity:d,dataCoordinate:this.positions[r[h[0]]]}},k.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\");if(!r)throw new Error(\"derivatives not supported\");var n=A(t),s=S(t),l=E(t),c=C(t),f=L(t),h=I(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),m=i(t),v=i(t),y=i(t),x=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:m,type:t.FLOAT,size:2},{buffer:v,type:t.FLOAT,size:3}]),b=i(t),_=i(t),w=i(t),k=i(t),M=a(t,[{buffer:b,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),P=i(t),z=i(t),O=i(t),D=i(t),R=i(t),F=a(t,[{buffer:P,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:O,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=a(t,[{buffer:B,type:t.FLOAT,size:3}]),j=new T(t,p,n,s,l,c,f,h,d,y,g,m,v,x,b,k,_,w,M,P,R,z,O,D,F,B,N);return j.update(e),j}},{\"./lib/closest-point\":307,\"./lib/shaders\":308,colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-shader\":335,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495,normals:498,\"simplicial-complex-contour\":556,\"typedarray-pool\":595}],310:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],311:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"gl-buffer\":259,\"gl-shader\":335}],312:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,f,h,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],f=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,h=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var m=a[g],v=a[g+2]-m,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*v/x,c[g]=2*(m-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){f[0]=f[1]=0,f[g]=1,r.uniforms.dataAxis=f,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=h[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,f=this.ticks,h=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,m=s.pixelRatio,v=s.screenBox,y=v[2]-v[0],x=v[3]-v[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var T=p[w],k=p[w+2]-T,M=.5*(d[w+2]+d[w]),A=d[w+2]-d[w];e[w]=2*k/A,t[w]=2*(T-M)/A}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,I=6*f[0].length,P=Math.min(a.ge(f[0],(d[0]-p[0])/(p[2]-p[0]),l),f[0].length),z=Math.min(a.gt(f[0],(d[2]-p[0])/(p[2]-p[0]),l),f[0].length),O=0+6*P,D=6*Math.max(0,z-P),R=Math.min(a.ge(f[1],(d[1]-p[1])/(p[3]-p[1]),l),f[1].length),F=Math.min(a.gt(f[1],(d[3]-p[1])/(p[3]-p[1]),l),f[1].length),B=I+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*m/y,o[1]=C[1]*m/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*m/y,o[1]=E[0]*m/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,O,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*m/y,o[1]=C[3]*m/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*m/y,o[1]=E[2]*m/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,O,D))}}(),d.update=(h=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],f=0;f<l.length;++f){var d=(l[f].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=h[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":314,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335}],313:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"gl-buffer\":259,\"gl-shader\":335}],314:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:316}],315:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,f,h,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],f=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,h=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,m=e.tickColor,v=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],T=this.labelCount[t],k=o.lt(n,l[t]),M=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(h[2+t]-h[t])-1;var A=2/h[2+(1^t)]-h[1^t];u[1^t]=A*s[1^t]-1,d[t]&&(u[1^t]-=A*p*g[t],k<M&&i[M]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=m[t],r.uniforms.angle=v[t],a.drawArrays(a.TRIANGLES,i[k],i[M]-i[k]))),y[t]&&T&&(u[1^t]-=A*p*x[t],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,T)),u[1^t]=A*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=A*p*g[t+2],k<M&&i[M]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=m[t+2],r.uniforms.angle=v[t+2],a.drawArrays(a.TRIANGLES,i[k],i[M]-i[k]))),y[t+2]&&T&&(u[1^t]+=A*p*x[t+2],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,T))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(h=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],f=a[o],g=a[o+2]-f,m=i[o],v=i[o+2]-m;p[o]=2*l/u*g/v,h[o]=2*(s-c)/u*g/v}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=h,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],f=[-1/0],h=l[o];for(e=0;e<h.length;++e){var p=h[e],d=p.x,g=p.text,m=p.font||\"sans-serif\";i=p.fontSize||12;for(var v=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(m,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*v);u.push(Math.floor(s.length/3)),f.push(d)}this.tickOffset[o]=u,this.tickX[o]=f}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335,\"text-cache\":575}],316:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],317:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function f(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var f=this.zeroLineEnable,h=this.zeroLineColor,p=this.zeroLineWidth;if(f[0]||f[1]){o.bind();for(var d=0;d<2;++d)if(f[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],h[d]):o.drawLine(e[0],g,e[2],g,p[d],h[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var m=this.borderLineEnable,v=this.borderLineWidth,y=this.borderLineColor;for(m[1]&&o.drawLine(r[0],r[1]-.5*v[1]*i,r[0],r[3]+.5*v[3]*i,v[1],y[1]),m[0]&&o.drawLine(r[0]-.5*v[0]*i,r[1],r[2]+.5*v[2]*i,r[1],v[0],y[0]),m[3]&&o.drawLine(r[2],r[1]-.5*v[1]*i,r[2],r[3]+.5*v[3]*i,v[3],y[3]),m[2]&&o.drawLine(r[0]-.5*v[0]*i,r[3],r[2]+.5*v[2]*i,r[3],v[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl,this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var f=c[u].pick(a,o,l);if(f)return f}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t)||!!t.titleEnable,this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(f),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":311,\"./lib/grid\":312,\"./lib/line\":313,\"./lib/text\":315,\"gl-select-static\":334}],318:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],f=0,h=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===h&&t.clientHeight===p;return h=t.clientWidth,p=t.clientHeight,a?!l:(f=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return f},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",(function(t){return t.preventDefault(),!1})),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,h=!!a.control,p=!!a.alt,g=!!a.shift,m=!!(1&e),v=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,T=d.flipY?1:-1,k=Math.PI*d.rotateSpeed,M=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&m&&!h&&!p&&!g||m&&!h&&!p&&g)&&c.rotate(M,w*k*b,-T*k*_,0),(l&&m&&!h&&!p&&!g||v||m&&h&&!p&&!g)&&c.pan(M,-d.translateSpeed*b*f,d.translateSpeed*_*f,0),u&&m&&!h&&!p&&!g||y||m&&!h&&p&&!g)){var A=-d.zoomSpeed*_/window.innerHeight*(M-c.lastT())*100;c.pan(M,0,0,f*(Math.exp(A)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",(function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods)}),!!l&&{passive:!0}),t.addEventListener(\"touchmove\",(function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()}),!!l&&{passive:!1}),t.addEventListener(\"touchend\",(function(t){e(0,d._lastX,d._lastY,d._lastMods)}),!!l&&{passive:!0}),d.wheelListener=o(t,(function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,f*(Math.exp(o)-1))}}}),!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":54,\"has-passive-events\":441,\"mouse-change\":483,\"mouse-event-offset\":484,\"mouse-wheel\":486,\"right-now\":542}],319:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":335,glslify:320}],320:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],321:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),f=t(\"gl-mat4/perspective\"),h=t(\"gl-mat4/ortho\"),p=t(\"./lib/shader\"),d=t(\"is-mobile\")({tablet:!0,featureDetect:!0});function g(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function v(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e){if(e=document.createElement(\"canvas\"),t.container)t.container.appendChild(e);else document.body.appendChild(e)}var r=t.gl;r||(t.glOptions&&(d=!!t.glOptions.preserveDrawingBuffer),r=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:d}));if(!r)throw new Error(\"webgl not supported\");var y=t.bounds||[[-10,-10,-10],[10,10,10]],x=new g,b=l(r,r.drawingBufferWidth,r.drawingBufferHeight,{preferFloat:!d}),_=p(r),w=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,T={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:w},k=t.axes||{},M=i(r,k);M.enable=!k.disable;var A=t.spikes||{},S=o(r,A),E=[],C=[],L=[],I=[],P=!0,z=!0,O=new Array(16),D=new Array(16),R={view:null,projection:O,model:D,_ortho:!1},F=(z=!0,[r.drawingBufferWidth,r.drawingBufferHeight]),B=t.cameraObject||n(e,T),N={gl:r,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:x,camera:B,axes:M,axesPixels:null,spikes:S,bounds:y,objects:E,shape:F,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:v(t.autoResize),autoBounds:v(t.autoBounds),autoScale:!!t.autoScale,autoCenter:v(t.autoCenter),clipToBounds:v(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:R,oncontextloss:null,mouseListener:null,_stopped:!1,getAspectratio:function(){return{x:this.aspect[0],y:this.aspect[1],z:this.aspect[2]}},setAspectratio:function(t){this.aspect[0]=t.x,this.aspect[1]=t.y,this.aspect[2]=t.z,z=!0},setBounds:function(t,e){this.bounds[0][t]=e.min,this.bounds[1][t]=e.max},setClearColor:function(t){this.clearColor=t},clearRGBA:function(){this.gl.clearColor(this.clearColor[0],this.clearColor[1],this.clearColor[2],this.clearColor[3]),this.gl.clear(this.gl.COLOR_BUFFER_BIT|this.gl.DEPTH_BUFFER_BIT)}},j=[r.drawingBufferWidth/N.pixelRatio|0,r.drawingBufferHeight/N.pixelRatio|0];function U(){if(!N._stopped&&N.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*N.pixelRatio),a=0|Math.ceil(n*N.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",P=!0}}}N.autoResize&&U();function V(){for(var t=E.length,e=I.length,n=0;n<e;++n)L[n]=0;t:for(n=0;n<t;++n){var i=E[n],a=i.pickSlots;if(a){for(var o=0;o<e;++o)if(L[o]+a<255){C[n]=o,i.setPickBase(L[o]+1),L[o]+=a;continue t}var l=s(r,F);C[n]=e,I.push(l),L.push(a),i.setPickBase(1),e+=1}else C[n]=-1}for(;e>0&&0===L[e-1];)L.pop(),I.pop().dispose()}function q(){if(N.contextLost)return!0;r.isContextLost()&&(N.contextLost=!0,N.mouseListener.enabled=!1,N.selection.object=null,N.oncontextloss&&N.oncontextloss())}window.addEventListener(\"resize\",U),N.update=function(t){N._stopped||(t=t||{},P=!0,z=!0)},N.add=function(t){N._stopped||(t.axes=M,E.push(t),C.push(-1),P=!0,z=!0,V())},N.remove=function(t){if(!N._stopped){var e=E.indexOf(t);e<0||(E.splice(e,1),C.pop(),P=!0,z=!0,V())}},N.dispose=function(){if(!N._stopped&&(N._stopped=!0,window.removeEventListener(\"resize\",U),e.removeEventListener(\"webglcontextlost\",q),N.mouseListener.enabled=!1,!N.contextLost)){M.dispose(),S.dispose();for(var t=0;t<E.length;++t)E[t].dispose();b.dispose();for(t=0;t<I.length;++t)I[t].dispose();_.dispose(),r=null,M=null,S=null,E=[]}},N._mouseRotating=!1,N._prevButtons=0,N.enableMouseListeners=function(){N.mouseListener=u(e,(function(t,e,r){if(!N._stopped){var n=I.length,i=E.length,a=x.object;x.distance=1/0,x.mouse[0]=e,x.mouse[1]=r,x.object=null,x.screen=null,x.dataCoordinate=x.dataPosition=null;var o=!1;if(t&&N._prevButtons)N._mouseRotating=!0;else{N._mouseRotating&&(z=!0),N._mouseRotating=!1;for(var s=0;s<n;++s){var l=I[s].query(e,j[1]-r-1,N.pickRadius);if(l){if(l.distance>x.distance)continue;for(var c=0;c<i;++c){var u=E[c];if(C[c]===s){var f=u.pick(l);f&&(x.buttons=t,x.screen=l.coord,x.distance=l.distance,x.object=u,x.index=f.distance,x.dataPosition=f.position,x.dataCoordinate=f.dataCoordinate,x.data=f,o=!0)}}}}}a&&a!==x.object&&(a.highlight&&a.highlight(null),P=!0),x.object&&(x.object.highlight&&x.object.highlight(x.data),P=!0),(o=o||x.object!==a)&&N.onselect&&N.onselect(x),1&t&&!(1&N._prevButtons)&&N.onclick&&N.onclick(x),N._prevButtons=t}}))},e.addEventListener(\"webglcontextlost\",q);var H=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],G=[H[0].slice(),H[1].slice()];function Y(){if(!q()){U();var t=N.camera.tick();R.view=N.camera.matrix,P=P||t,z=z||t,M.pixelRatio=N.pixelRatio,S.pixelRatio=N.pixelRatio;var e=E.length,n=H[0],i=H[1];n[0]=n[1]=n[2]=1/0,i[0]=i[1]=i[2]=-1/0;for(var o=0;o<e;++o){(L=E[o]).pixelRatio=N.pixelRatio,L.axes=N.axes,P=P||!!L.dirty,z=z||!!L.dirty;var s=L.bounds;if(s)for(var l=s[0],u=s[1],p=0;p<3;++p)n[p]=Math.min(n[p],l[p]),i[p]=Math.max(i[p],u[p])}var d=N.bounds;if(N.autoBounds)for(p=0;p<3;++p){if(i[p]<n[p])n[p]=-1,i[p]=1;else{n[p]===i[p]&&(n[p]-=1,i[p]+=1);var g=.05*(i[p]-n[p]);n[p]=n[p]-g,i[p]=i[p]+g}d[0][p]=n[p],d[1][p]=i[p]}var v=!1;for(p=0;p<3;++p)v=v||G[0][p]!==d[0][p]||G[1][p]!==d[1][p],G[0][p]=d[0][p],G[1][p]=d[1][p];if(z=z||v,P=P||v){if(v){var y=[0,0,0];for(o=0;o<3;++o)y[o]=m((d[1][o]-d[0][o])/10);M.autoTicks?M.update({bounds:d,tickSpacing:y}):M.update({bounds:d})}var T=r.drawingBufferWidth,k=r.drawingBufferHeight;F[0]=T,F[1]=k,j[0]=0|Math.max(T/N.pixelRatio,1),j[1]=0|Math.max(k/N.pixelRatio,1),function(t,e){var r=t.bounds,n=t.cameraParams,i=n.projection,a=n.model,o=t.gl.drawingBufferWidth,s=t.gl.drawingBufferHeight,l=t.zNear,c=t.zFar,u=t.fovy,p=o/s;e?(h(i,-p,p,-1,1,l,c),n._ortho=!0):(f(i,u,p,l,c),n._ortho=!1);for(var d=0;d<16;++d)a[d]=0;a[15]=1;var g=0;for(d=0;d<3;++d)g=Math.max(g,r[1][d]-r[0][d]);for(d=0;d<3;++d)t.autoScale?a[5*d]=t.aspect[d]/(r[1][d]-r[0][d]):a[5*d]=1/g,t.autoCenter&&(a[12+d]=.5*-a[5*d]*(r[0][d]+r[1][d]))}(N,w);for(o=0;o<e;++o){(L=E[o]).axesBounds=d,N.clipToBounds&&(L.clipBounds=d)}x.object&&(N.snapToData?S.position=x.dataCoordinate:S.position=x.dataPosition,S.bounds=d),z&&(z=!1,function(){if(!q()){r.colorMask(!0,!0,!0,!0),r.depthMask(!0),r.disable(r.BLEND),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL);for(var t=E.length,e=I.length,n=0;n<e;++n){var i=I[n];i.shape=j,i.begin();for(var a=0;a<t;++a)if(C[a]===n){var o=E[a];o.drawPick&&(o.pixelRatio=1,o.drawPick(R))}i.end()}}}()),N.axesPixels=a(N.axes,R,T,k),N.onrender&&N.onrender(),r.bindFramebuffer(r.FRAMEBUFFER,null),r.viewport(0,0,T,k),N.clearRGBA(),r.depthMask(!0),r.colorMask(!0,!0,!0,!0),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL),r.disable(r.BLEND),r.disable(r.CULL_FACE);var A=!1;M.enable&&(A=A||M.isTransparent(),M.draw(R)),S.axes=M,x.object&&S.draw(R),r.disable(r.CULL_FACE);for(o=0;o<e;++o){(L=E[o]).axes=M,L.pixelRatio=N.pixelRatio,L.isOpaque&&L.isOpaque()&&L.draw(R),L.isTransparent&&L.isTransparent()&&(A=!0)}if(A){b.shape=F,b.bind(),r.clear(r.DEPTH_BUFFER_BIT),r.colorMask(!1,!1,!1,!1),r.depthMask(!0),r.depthFunc(r.LESS),M.enable&&M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){(L=E[o]).isOpaque&&L.isOpaque()&&L.draw(R)}r.enable(r.BLEND),r.blendEquation(r.FUNC_ADD),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.colorMask(!0,!0,!0,!0),r.depthMask(!1),r.clearColor(0,0,0,0),r.clear(r.COLOR_BUFFER_BIT),M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){var L;(L=E[o]).isTransparent&&L.isTransparent()&&L.drawTransparent(R)}r.bindFramebuffer(r.FRAMEBUFFER,null),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.disable(r.DEPTH_TEST),_.bind(),b.color[0].bind(0),_.uniforms.accumBuffer=0,c(r),r.disable(r.BLEND)}P=!1;for(o=0;o<e;++o)E[o].dirty=!1}}}return N.enableMouseListeners(),function t(){if(N._stopped||N.contextLost)return;Y(),requestAnimationFrame(t)}(),N.redraw=function(){N._stopped||(P=!0,Y())},N},createCamera:n}},{\"./camera.js\":318,\"./lib/shader\":319,\"a-big-triangle\":64,\"gl-axes3d\":250,\"gl-axes3d/properties\":258,\"gl-fbo\":269,\"gl-mat4/ortho\":296,\"gl-mat4/perspective\":297,\"gl-select-static\":334,\"gl-spikes3d\":345,\"is-mobile\":467,\"mouse-change\":483}],322:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:323}],323:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],324:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),f=new s(t,a,l,c,u);return f.update(e),t.addObject(f),f};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var f=n.getParameter(n.BLEND),h=n.getParameter(n.DITHER);return f&&!this.blend&&n.disable(n.BLEND),h&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),f&&!this.blend&&n.enable(n.BLEND),h&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":322,\"gl-buffer\":259,\"gl-shader\":335,\"typedarray-pool\":595}],325:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],f=e[2],h=e[3],p=r[0],d=r[1],g=r[2],m=r[3];(a=c*p+u*d+f*g+h*m)<0&&(a=-a,p=-p,d=-d,g=-g,m=-m);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*f+l*g,t[3]=s*h+l*m,t}},{}],326:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],327:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var f=[[1/0,1/0],[-1/0,-1/0]],h=u.positions.length;for(l=0;l<h;++l){var p=u.positions[l];for(c=0;c<2;++c)f[0][c]=Math.min(f[0][c],p[c]),f[1][c]=Math.max(f[1][c],p[c])}return a[t]=[s,u,f]};var i={}},{\"vectorize-text\":600}],328:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],f={vertex:a,fragment:l,attributes:u},h={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},m={vertex:s,fragment:c,attributes:u};function v(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return v(t,f)},r.createOrtho=function(t){return v(t,h)},r.createProject=function(t){return v(t,p)},r.createPickPerspective=function(t){return v(t,d)},r.createPickOrtho=function(t){return v(t,g)},r.createPickProject=function(t){return v(t,m)}},{\"gl-shader\":335,glslify:329}],329:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],330:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return h(n,n),h(n,n),h(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t||t>1?1:t}function m(t,e,r,n,i,a,o,s,l,c,u,f){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=f,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),f=i(e),h=i(e),p=i(e),d=i(e),g=a(e,[{buffer:f,size:3,type:e.FLOAT},{buffer:h,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),v=new m(e,r,n,o,f,h,p,d,g,s,c,u);return v.update(t),v};var v=m.prototype;v.pickSlots=1,v.setPickBase=function(t){this.pickId=t},v.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},v.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],T=f.slice(),k=[0,0,0],M=[[0,0,0],[0,0,0]];function A(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||f,u=r.view||f,h=r.projection||f,d=e.axesBounds,g=function(t){for(var e=M,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=h,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var m=0;m<3;++m)if(a[m]){l.scale=e.projectScale[m],l.opacity=e.projectOpacity[m];for(var v=T,C=0;C<16;++C)v[C]=0;for(C=0;C<4;++C)v[5*C]=1;v[5*m]=0,i[m]<0?v[12+m]=d[0][m]:v[12+m]=d[1][m],s(v,c,v),l.model=v;var L=(m+1)%3,I=(m+2)%3,P=A(x),z=A(b);P[L]=1,z[I]=1;var O=p(0,0,0,S(_,P)),D=p(0,0,0,S(w,z));if(Math.abs(O[1])>Math.abs(D[1])){var R=O;O=D,D=R,R=P,P=z,z=R;var F=L;L=I,I=F}O[0]<0&&(P[L]=-1),D[1]>0&&(z[I]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*I+C],2);P[L]/=Math.sqrt(B),z[I]/=Math.sqrt(N),l.axes[0]=P,l.axes[1]=z,l.fragClipBounds[0]=E(k,g[0],m,-1e8),l.fragClipBounds[1]=E(k,g[1],m,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function I(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||f,l.view=n.view||f,l.projection=n.projection||f,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function P(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}v.draw=function(t){I(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},v.drawTransparent=function(t){I(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},v.drawPick=function(t){I(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},v.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},v.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},v.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],f=[-1/0,-1/0,-1/0],h=t.glyph,p=t.color,d=t.size,m=t.angle,v=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],T=0;T<3;++T)if(isNaN(w[T])||!isFinite(w[T]))continue t;var k=(N=P(h,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;x+=3*k.cells.length,b+=2*M.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),I=o.mallocUint32(S);if(S>0){var z=0,O=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(v)&&Array.isArray(v[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],T=0;T<3;++T){if(isNaN(w[T])||!isFinite(w[T]))continue t;f[T]=Math.max(f[T],w[T]),u[T]=Math.min(u[T],w[T])}k=(N=P(h,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(T=0;T<3;++T)D[T]=U[T];D[3]=1}else if(4===U.length){for(T=0;T<4;++T)D[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(v)){var U;if(3===(U=B?n<v.length?v[n]:[0,0,0,0]:v).length){for(T=0;T<3;++T)R[T]=U[T];R[T]=1}else if(4===U.length){for(T=0;T<4;++T)R[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(m)?q=n<m.length?+m[n]:0:m&&(q=+m);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],T=0;T<3;++T)f[T]=Math.max(f[T],w[T]),u[T]=Math.min(u[T],w[T]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-A[0][0]:Y<0?1+A[1][0]:1,W*=W>0?1-A[0][1]:W<0?1+A[1][1]:1],Z=k.cells||[],J=k.positions||[];for(T=0;T<Z.length;++T)for(var K=Z[T],Q=0;Q<3;++Q){for(var $=0;$<3;++$)E[3*z+$]=w[$];for($=0;$<4;++$)C[4*z+$]=D[$];I[z]=y;var tt=J[K[Q]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=M.edges,J=M.positions,T=0;T<Z.length;++T)for(K=Z[T],Q=0;Q<2;++Q){for($=0;$<3;++$)E[3*O+$]=w[$];for($=0;$<4;++$)C[4*O+$]=R[$];I[O]=y;tt=J[K[Q]];L[2*O]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*O+1]=V*(G*tt[0]+H*tt[1]+X[1]),O+=1}}}this.bounds=[u,f],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(I),o.free(E),o.free(C),o.free(L),o.free(I)},v.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":326,\"./lib/glyphs\":327,\"./lib/shaders\":328,\"gl-buffer\":259,\"gl-mat4/multiply\":295,\"gl-vao\":358,\"is-string-blank\":470,\"typedarray-pool\":595}],331:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:332}],332:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],333:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,f=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],h=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(f=Math.max(f,c[0]),h=Math.max(h,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<f||d<h)){o.bind();var g=s[2]-s[0],m=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,h,i),o.drawBox(0,h,f,d,i),o.drawBox(0,d,g,m,i),o.drawBox(p,h,g,d,i)),this.innerFill&&o.drawBox(f,h,p,d,n),r>0){var v=r*u;o.drawBox(f-v,h-v,p+v,h+v,a),o.drawBox(f-v,d-v,p+v,d+v,a),o.drawBox(f-v,h-v,f+v,d+v,a),o.drawBox(p-v,h-v,p+v,d+v,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":331,\"gl-buffer\":259,\"gl-shader\":335}],334:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=e[0],a=e[1],o=n(t,r,a,{}),s=i.mallocUint8(r*a*4);return new l(t,o,s)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2;function s(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function l(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var c=l.prototype;Object.defineProperty(c,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),c.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},c.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},c.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),l=0|Math.min(Math.max(e-r,0),n[1]),c=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||c<=l)return null;var u=[o-i,c-l],f=a(this.buffer,[u[0],u[1],4],[4,4*n[0],1],4*(i+n[0]*l)),h=function(t,e,r){for(var n=1e8,i=-1,a=-1,o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++){var u=t.get(l,c,0),f=t.get(l,c,1),h=t.get(l,c,2),p=t.get(l,c,3);if(u<255||f<255||h<255||p<255){var d=e-l,g=r-c,m=d*d+g*g;m<n&&(n=m,i=l,a=c)}}return[i,a,n]}(f.hi(u[0],u[1],1),r,r),p=h[0],d=h[1];return p<0||Math.pow(this.radius,2)<h[2]?null:new s(p+i|0,d+l|0,f.get(p,d,0),[f.get(p,d,1),f.get(p,d,2),f.get(p,d,3)],Math.sqrt(h[2]))},c.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":97,\"gl-fbo\":269,ndarray:495,\"typedarray-pool\":595}],335:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function f(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var h=this,p=h.gl,d=h._vref;h._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),h.vertShader=h._vref.shader;var g=this._fref;if(h._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),h.fragShader=h._fref.shader,!r||!c){var m=p.createProgram();if(p.attachShader(m,h.fragShader),p.attachShader(m,h.vertShader),p.linkProgram(m),!p.getProgramParameter(m,p.LINK_STATUS)){var v=p.getProgramInfoLog(m);throw new l(v,\"Error linking program:\"+v)}r=r||s.uniforms(p,m),c=c||s.attributes(p,m),p.deleteProgram(m)}(c=c.slice()).sort(f);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var T=0|w.type.charAt(w.type.length-1),k=new Array(T),M=0;M<T;++M)k[M]=_.length,b.push(w.name+\"[\"+M+\"]\"),\"number\"==typeof w.location?_.push(w.location+M):Array.isArray(w.location)&&w.location.length===T&&\"number\"==typeof w.location[M]?_.push(0|w.location[M]):_.push(-1);x.push({name:w.name,type:w.type,locations:k})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var A=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(A)>=0;)A+=1;_[y]=A}var S=new Array(r.length);function E(){h.program=o.program(p,h._vref,h._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(h.program,r[t].name)}E(),h._relink=E,h.types={uniforms:a(r),attributes:a(c)},h.attributes=i(p,h,x,_),Object.defineProperty(h,\"uniforms\",n(p,h,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":336,\"./lib/create-attributes\":337,\"./lib/create-uniforms\":338,\"./lib/reflect\":339,\"./lib/runtime-reflect\":340,\"./lib/shader-cache\":341}],336:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],337:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],f=u.name,h=u.type,p=u.locations;switch(h){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,f);break;default:if(h.indexOf(\"vec\")>=0){if((d=h.charCodeAt(h.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);o(t,e,p[0],i,d,a,f)}else{if(!(h.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+f+\": \"+h);var d;if((d=h.charCodeAt(h.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);s(t,e,p,i,d,a,f)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var f=Function.apply(null,l),h=new i(t,e,r,n,a,f);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),f(t,n[r],e),e},get:function(){return h},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var f=new Array(i),h=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))h.call(t,o,e[a]);else{for(var s=0;s<i;++s)f[s]=e[i*a+s];h.call(t,o,f)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":336}],338:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a;if((a=r.charCodeAt(r.length-1)-48)<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}if((a=r.charCodeAt(r.length-1)-48)<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}return n.push(\"return obj}\"),new Function(\"gl\",\"locations\",n.join(\"\\n\"))(t,s)}function u(n,l,u){if(\"object\"==typeof u){var h=f(u);Object.defineProperty(n,l,{get:a(h),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r;if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function f(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var h=n(r,!0);return{get:a(f(h)),set:c(h),enumerable:!0,configurable:!0}}},{\"./GLError\":336,\"./reflect\":339}],339:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name.split(\".\"),a=r,o=0;o<i.length;++o){var s=i[o].split(\"[\");if(s.length>1){s[0]in a||(a[s[0]]=[]),a=a[s[0]];for(var l=1;l<s.length;++l){var c=parseInt(s[l]);l<s.length-1||o<i.length-1?(c in a||(l<s.length-1?a[c]=[]:a[c]={}),a=a[c]):a[c]=e?n:t[n].type}}else o<i.length-1?(s[0]in a||(a[s[0]]={}),a=a[s[0]]):a[s[0]]=e?n:t[n].type}return r}},{}],340:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],341:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":336,\"gl-format-compiler-error\":270,\"weakmap-shim\":605}],342:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map((function(t){return t.slice()})),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],343:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],344:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":335,glslify:343}],345:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var f=new s(t,l,c,u);return f.update(e),f};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],f=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var h=c,p=u,d=0;d<3;++d)i&&i[d]<0?(h[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(h[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);f[0]=e.drawingBufferWidth,f[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,h,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=f;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":344,\"gl-buffer\":259,\"gl-vao\":358}],346:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, tubeScale;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:347}],347:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],348:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"],o=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++)o=Math.max(o,n.length(l[c]));var u=t.map((function(t){return function(t,e,r,a){for(var o=t.points,s=t.velocities,l=t.divergences,c=[],u=[],f=[],h=[],p=[],d=[],g=0,m=0,v=i.create(),y=i.create(),x=0;x<o.length;x++){var b=o[x],_=s[x],w=l[x];0===e&&(w=.05*r),m=n.length(_)/a,v=i.create(),n.copy(v,_),v[3]=w;for(var T=0;T<8;T++)p[T]=[b[0],b[1],b[2],T];if(h.length>0)for(T=0;T<8;T++){var k=(T+1)%8;c.push(h[T],p[T],p[k],p[k],h[k],h[T]),f.push(y,v,v,v,y,y),d.push(g,m,m,m,g,g);var M=c.length;u.push([M-6,M-5,M-4],[M-3,M-2,M-1])}var A=h;h=p,p=A;var S=y;y=v,v=S;var E=g;g=m,m=E}return{positions:c,cells:u,vectors:f,vertexIntensity:d}}(t,r,a,o)})),f=[],h=[],p=[],d=[];for(s=0;s<u.length;s++){var g=u[s],m=f.length;f=f.concat(g.positions),p=p.concat(g.vectors),d=d.concat(g.vertexIntensity);for(c=0;c<g.cells.length;c++){var v=g.cells[c],y=[];h.push(y);for(var x=0;x<v.length;x++)y.push(v[x]+m)}}return{positions:f,cells:h,vectors:p,vertexIntensity:d,colormap:e}},s=function(t,e){var r,n=t.length;for(r=0;r<n;r++){var i=t[r];if(i===e)return r;if(i>e)return r-1}return r},l=function(t,e,r){return t<e?e:t>r?r:t},c=function(t){var e=1/0;t.sort((function(t,e){return t-e}));for(var r=t.length,n=1;n<r;n++){var i=Math.abs(t[n]-t[n-1]);i<e&&(e=i)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,u=t.tubeSize||1,f=t.absoluteTubeSize,h=t.gridFill||\"+x+y+z\",p={};-1!==h.indexOf(\"-x\")&&(p.reversedX=!0),-1!==h.indexOf(\"-y\")&&(p.reversedY=!0),-1!==h.indexOf(\"-z\")&&(p.reversedZ=!0),p.filled=a.indexOf(h.replace(/-/g,\"\").replace(/\\+/g,\"\"));var d=t.getVelocity||function(e){return function(t,e,r){var i=e.vectors,a=e.meshgrid,o=t[0],c=t[1],u=t[2],f=a[0].length,h=a[1].length,p=a[2].length,d=s(a[0],o),g=s(a[1],c),m=s(a[2],u),v=d+1,y=g+1,x=m+1;if(d=l(d,0,f-1),v=l(v,0,f-1),g=l(g,0,h-1),y=l(y,0,h-1),m=l(m,0,p-1),x=l(x,0,p-1),d<0||g<0||m<0||v>f-1||y>h-1||x>p-1)return n.create();var b,_,w,T,k,M,A=a[0][d],S=a[0][v],E=a[1][g],C=a[1][y],L=a[2][m],I=(o-A)/(S-A),P=(c-E)/(C-E),z=(u-L)/(a[2][x]-L);switch(isFinite(I)||(I=.5),isFinite(P)||(P=.5),isFinite(z)||(z=.5),r.reversedX&&(d=f-1-d,v=f-1-v),r.reversedY&&(g=h-1-g,y=h-1-y),r.reversedZ&&(m=p-1-m,x=p-1-x),r.filled){case 5:k=m,M=x,w=g*p,T=y*p,b=d*p*h,_=v*p*h;break;case 4:k=m,M=x,b=d*p,_=v*p,w=g*p*f,T=y*p*f;break;case 3:w=g,T=y,k=m*h,M=x*h,b=d*h*p,_=v*h*p;break;case 2:w=g,T=y,b=d*h,_=v*h,k=m*h*f,M=x*h*f;break;case 1:b=d,_=v,k=m*f,M=x*f,w=g*f*p,T=y*f*p;break;default:b=d,_=v,w=g*f,T=y*f,k=m*f*h,M=x*f*h}var O=i[b+w+k],D=i[b+w+M],R=i[b+T+k],F=i[b+T+M],B=i[_+w+k],N=i[_+w+M],j=i[_+T+k],U=i[_+T+M],V=n.create(),q=n.create(),H=n.create(),G=n.create();n.lerp(V,O,B,I),n.lerp(q,D,N,I),n.lerp(H,R,j,I),n.lerp(G,F,U,I);var Y=n.create(),W=n.create();n.lerp(Y,V,H,P),n.lerp(W,q,G,P);var X=n.create();return n.lerp(X,Y,W,z),X}(e,t,p)},g=t.getDivergence||function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=d(r);n.subtract(a,a,e),n.scale(a,a,1/i),n.add(r,t,[0,i,0]);var o=d(r);n.subtract(o,o,e),n.scale(o,o,1/i),n.add(r,t,[0,0,i]);var s=d(r);return n.subtract(s,s,e),n.scale(s,s,1/i),n.add(r,a,o),n.add(r,r,s),r},m=[],v=e[0][0],y=e[0][1],x=e[0][2],b=e[1][0],_=e[1][1],w=e[1][2],T=function(t){var e=t[0],r=t[1],n=t[2];return!(e<v||e>b||r<y||r>_||n<x||n>w)},k=10*n.distance(e[0],e[1])/i,M=k*k,A=1,S=0,E=r.length;E>1&&(A=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=t.length,l=0;l<s;l++){var u=t[l],f=u[0],h=u[1],p=u[2];i[f]||(e.push(f),i[f]=!0),a[h]||(r.push(h),a[h]=!0),o[p]||(n.push(p),o[p]=!0)}var d=c(e),g=c(r),m=c(n),v=Math.min(d,g,m);return isFinite(v)?v:1}(r));for(var C=0;C<E;C++){var L=n.create();n.copy(L,r[C]);var I=[L],P=[],z=d(L),O=L;P.push(z);var D=[],R=g(L,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F),m.push({points:I,velocities:P,divergences:D});for(var B=0;B<100*i&&I.length<i&&T(L);){B++;var N=n.clone(z),j=n.squaredLength(N);if(0===j)break;if(j>M&&n.scale(N,N,k/Math.sqrt(j)),n.add(N,N,L),z=d(N),n.squaredDistance(O,N)-M>-1e-4*M){I.push(N),O=N,P.push(z);R=g(N,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F)}L=N}}var U=o(m,t.colormap,S,A);return f?U.tubeScale=f:(0===S&&(S=1),U.tubeScale=.5*u*A/S),U};var u=t(\"./lib/shaders\"),f=t(\"gl-cone3d\").createMesh;e.exports.createTubeMesh=function(t,e){return f(t,e,{shaders:u,traceType:\"streamtube\"})}},{\"./lib/shaders\":346,\"gl-cone3d\":260,\"gl-vec3\":377,\"gl-vec4\":413}],349:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if (\\n    kill > 0.0 ||\\n    vColor.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], worldCoordinate)\\n  ) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":335,glslify:350}],350:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],351:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:40,offset:0},{buffer:c,size:3,stride:40,offset:16},{buffer:c,size:3,stride:40,offset:28}]),f=i(e),h=a(e,[{buffer:f,size:4,stride:20,offset:0},{buffer:f,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,256,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var m=new A(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,f,h,p,d,[0,0,0]),v={levels:[[],[],[]]};for(var w in t)v[w]=t[w];return v.colormap=v.colormap||\"jet\",m.update(v),m};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),f=t(\"ndarray\"),h=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),m=t(\"ndarray-gradient\"),v=t(\"./lib/shaders\"),y=v.createShader,x=v.createContourShader,b=v.createPickShader,_=v.createPickContourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],k=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=k[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();function A(t,e,r,n,i,a,o,l,c,u,h,p,d,g,m){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=m,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=h,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var S=A.prototype;S.genColormap=function(t,e){var r=!1,n=u([l({colormap:t,nshades:256,format:\"rgba\"}).map((function(t,n){var i=e?function(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}(n/255,e):t[3];return i<1&&(r=!0),[t[0],t[1],t[2],255*i]}))]);return c.divseq(n,255),this.hasAlphaScale=r,n},S.isTransparent=function(){return this.opacity<1||this.hasAlphaScale},S.isOpaque=function(){return!this.isTransparent()},S.pickSlots=1,S.setPickBase=function(t){this.pickId=t};var E=[0,0,0],C={showSurface:!1,showContour:!1,projections:[w.slice(),w.slice(),w.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function L(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||E,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=C.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=C.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return C.showSurface=o,C.showContour=s,C}var I={model:w,view:w,projection:w,inverseModel:w.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},P=w.slice(),z=[1,0,0,0,1,0,0,0,1];function O(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=I;n.model=t.model||w,n.view=t.view||w,n.projection=t.projection||w,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=z,n.vertexColor=this.vertexColor;var s=P;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=L(n,this);if(u.showSurface){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour){var f=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,f.bind(),f.uniforms=n;var h=this._contourVAO;for(h.bind(),i=0;i<3;++i)for(f.uniforms.permutation=k[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(f.uniforms.contourColor=this.highlightColor[i],f.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(f.uniforms.contourColor=this.contourColor[i],f.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(f.uniforms.height=this.contourLevels[i][o],h.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(f.uniforms.model=u.projections[i],f.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){f.uniforms.permutation=k[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(f.uniforms.contourColor=this.highlightColor[o],f.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(f.uniforms.contourColor=this.contourColor[o],f.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(f.uniforms.height=this.contourLevels[o][g],h.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(h.unbind(),(h=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(f.uniforms.model=n.model,f.uniforms.clipBounds=n.clipBounds,f.uniforms.permutation=k[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),f.uniforms.contourColor=this.dynamicColor[i],f.uniforms.contourTint=this.dynamicTint[i],f.uniforms.height=this.dynamicLevel[i],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(f.uniforms.model=u.projections[o],f.uniforms.clipBounds=u.clipBounds[o],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));h.unbind()}}S.draw=function(t){return O.call(this,t,!1)},S.drawTransparent=function(t){return O.call(this,t,!0)};var D={model:w,view:w,projection:w,inverseModel:w,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function R(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function F(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function B(t){if(Array.isArray(t)){if(Array.isArray(t))return[F(t[0]),F(t[1]),F(t[2])];var e=F(t);return[e.slice(),e.slice(),e.slice()]}}S.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=D;r.model=t.model||w,r.view=t.view||w,r.projection=t.projection||w,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=z;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=L(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=k[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=k[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},S.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var f=u?a:1-a,h=0;h<2;++h)for(var p=i+u,d=s+h,m=f*(h?l:1-l),v=0;v<3;++v)c[v]+=this._field[v].get(p,d)*m;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],v=0;v<3;++v)r.dataCoordinate[v]=this._field[v].get(r.index[0],r.index[1]);return r},S.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},S.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=R(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=R(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=R(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=B(t.contourColor)),\"contourProject\"in t&&(this.contourProject=R(t.contourProject,(function(t){return R(t,Boolean)}))),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=B(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=R(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=R(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0),\"colormap\"in t&&this._colorMap.setPixels(this.genColormap(t.colormap,this.opacityscale));var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=f(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var l=t.coords;if(!Array.isArray(l)||3!==l.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var c=l[o];for(v=0;v<2;++v)if(c.shape[v]!==a[v])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],c)}}else if(t.ticks){var u=t.ticks;if(!Array.isArray(u)||2!==u.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var p=u[o];if((Array.isArray(p)||p.length)&&(p=f(p)),p.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var d=f(p.data,a);d.stride[o]=p.stride[0],d.stride[1^o]=0,this.padField(this._field[o],d)}}else{for(o=0;o<2;++o){var g=[0,0];g[o]=1,this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2],g,0)}this._field[0].set(0,0,0);for(var v=0;v<a[0];++v)this._field[0].set(v+1,0,v);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),v=0;v<a[1];++v)this._field[1].set(0,v+1,v);this._field[1].set(0,a[1]+1,a[1]-1)}var y=this._field,x=f(s.mallocFloat(3*y[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)m(x.pick(o),y[o],\"mirror\");var b=f(s.mallocFloat(3*y[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(v=0;v<a[1]+2;++v){var _=x.get(0,o,v,0),w=x.get(0,o,v,1),k=x.get(1,o,v,0),M=x.get(1,o,v,1),A=x.get(2,o,v,0),S=x.get(2,o,v,1),E=k*S-M*A,C=A*w-S*_,L=_*M-w*k,I=Math.sqrt(E*E+C*C+L*L);I<1e-8?(I=Math.max(Math.abs(E),Math.abs(C),Math.abs(L)))<1e-8?(L=1,C=E=0,I=1):I=1/I:I=1/Math.sqrt(I),b.set(o,v,0,E*I),b.set(o,v,1,C*I),b.set(o,v,2,L*I)}s.free(x.data);var P=[1/0,1/0,1/0],z=[-1/0,-1/0,-1/0],O=1/0,D=-1/0,F=(a[0]-1)*(a[1]-1)*6,N=s.mallocFloat(n.nextPow2(10*F)),j=0,U=0;for(o=0;o<a[0]-1;++o)t:for(v=0;v<a[1]-1;++v){for(var V=0;V<2;++V)for(var q=0;q<2;++q)for(var H=0;H<3;++H){var G=this._field[H].get(1+o+V,1+v+q);if(isNaN(G)||!isFinite(G))continue t}for(H=0;H<6;++H){var Y=o+T[H][0],W=v+T[H][1],X=this._field[0].get(Y+1,W+1),Z=this._field[1].get(Y+1,W+1);G=this._field[2].get(Y+1,W+1),E=b.get(Y+1,W+1,0),C=b.get(Y+1,W+1,1),L=b.get(Y+1,W+1,2),t.intensity&&(J=t.intensity.get(Y,W));var J=t.intensity?t.intensity.get(Y,W):G+this.objectOffset[2];N[j++]=Y,N[j++]=W,N[j++]=X,N[j++]=Z,N[j++]=G,N[j++]=0,N[j++]=J,N[j++]=E,N[j++]=C,N[j++]=L,P[0]=Math.min(P[0],X+this.objectOffset[0]),P[1]=Math.min(P[1],Z+this.objectOffset[1]),P[2]=Math.min(P[2],G+this.objectOffset[2]),O=Math.min(O,J),z[0]=Math.max(z[0],X+this.objectOffset[0]),z[1]=Math.max(z[1],Z+this.objectOffset[1]),z[2]=Math.max(z[2],G+this.objectOffset[2]),D=Math.max(D,J),U+=1}}for(t.intensityBounds&&(O=+t.intensityBounds[0],D=+t.intensityBounds[1]),o=6;o<j;o+=10)N[o]=(N[o]-O)/(D-O);this._vertexCount=U,this._coordinateBuffer.update(N.subarray(0,j)),s.freeFloat(N),s.free(b.data),this.bounds=[P,z],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===O&&this.intensityBounds[1]===D||(r=!0),this.intensityBounds=[O,D]}if(\"levels\"in t){var K=t.levels;for(K=Array.isArray(K[0])?K.slice():[[],[],K],o=0;o<3;++o)K[o]=K[o].slice(),K[o].sort((function(t,e){return t-e}));for(o=0;o<3;++o)for(v=0;v<K[o].length;++v)K[o][v]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(K[o].length!==this.contourLevels[o].length){r=!0;break}for(v=0;v<K[o].length;++v)if(K[o][v]!==this.contourLevels[o][v]){r=!0;break t}}this.contourLevels=K}if(r){y=this._field,a=this.shape;for(var Q=[],$=0;$<3;++$){var tt=this.contourLevels[$],et=[],rt=[],nt=[0,0,0];for(o=0;o<tt.length;++o){var it=h(this._field[$],tt[o]);et.push(Q.length/5|0),U=0;t:for(v=0;v<it.cells.length;++v){var at=it.cells[v];for(H=0;H<2;++H){var ot=it.positions[at[H]],st=ot[0],lt=0|Math.floor(st),ct=st-lt,ut=ot[1],ft=0|Math.floor(ut),ht=ut-ft,pt=!1;e:for(var dt=0;dt<3;++dt){nt[dt]=0;var gt=($+dt+1)%3;for(V=0;V<2;++V){var mt=V?ct:1-ct;for(Y=0|Math.min(Math.max(lt+V,0),a[0]),q=0;q<2;++q){var vt=q?ht:1-ht;if(W=0|Math.min(Math.max(ft+q,0),a[1]),G=dt<2?this._field[gt].get(Y,W):(this.intensity.get(Y,W)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(G)||isNaN(G)){pt=!0;break e}var yt=mt*vt;nt[dt]+=yt*G}}}if(pt){if(H>0){for(var xt=0;xt<5;++xt)Q.pop();U-=1}continue t}Q.push(nt[0],nt[1],ot[0],ot[1],nt[2]),U+=1}}rt.push(U)}this._contourOffsets[$]=et,this._contourCounts[$]=rt}var bt=s.mallocFloat(Q.length);for(o=0;o<Q.length;++o)bt[o]=Q[o];this._contourBuffer.update(bt),s.freeFloat(bt)}},S.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},S.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],f=this._field[l],p=this._field[c],d=h(u,r[o]),g=d.cells,m=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var v=g[e],y=0;y<2;++y){var x=m[v[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),T=b-_,k=1-T,M=+x[1],A=0|M,S=0|Math.min(A+1,i[1]),E=M-A,C=1-E,L=k*C,I=k*E,P=T*C,z=T*E,O=L*f.get(_,A)+I*f.get(_,S)+P*f.get(w,A)+z*f.get(w,S),D=L*p.get(_,A)+I*p.get(_,S)+P*p.get(w,A)+z*p.get(w,S);if(isNaN(O)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=O,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":349,\"binary-search-bounds\":96,\"bit-twiddle\":97,colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495,\"ndarray-gradient\":488,\"ndarray-ops\":490,\"ndarray-pack\":491,\"surface-nets\":570,\"typedarray-pool\":595}],352:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),f=t(\"parse-rect\"),h=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),m=t(\"object-assign\"),v=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var T=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(h(t)?t:{})};T.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(T.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(T.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},T.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map((function(t){return parseFloat(t)})):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=f(t.viewport),T.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=T.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach((function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(T.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:T.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=T.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:v(c,{origin:\"top\",fontSize:T.baseFontSize,fontStyle:u.join(\" \")})},T.fonts[i]=e.font[r]}})),(a||o)&&this.font.forEach((function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)})),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),h=0;h<s.length;h++)s[h]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach((function(t,n){T.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=T.atlasContext.measureText(o).width/T.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);m(t.kerning,g(t.family,{pairs:s}))}}}))}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,k=u.mallocFloat(2*this.count),M=0,A=0;M<this.counts.length;M++){var S=this.counts[M];if(w)for(var E=0;E<S;E++)k[A++]=t.position[2*M],k[A++]=t.position[2*M+1];else for(var C=0;C<S;C++)k[A++]=t.position[M][0],k[A++]=t.position[M][1]}this.position.call?this.position({type:\"float\",data:k}):this.position=this.regl.buffer({type:\"float\",data:k}),u.freeFloat(k)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),I=u.mallocFloat(2*this.count);this.textWidth=[];for(var P=0,z=0;P<this.counts.length;P++){for(var O=this.counts[P],D=this.font[P]||this.font[0],R=this.fontAtlas[P]||this.fontAtlas[0],F=0;F<O;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],I[2*z]=D.width[B],F){var j=I[2*z-2],U=I[2*z],V=I[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}I[2*z+1]=V}else I[2*z+1]=.5*I[2*z];z++}this.textWidth.push(I.length?.5*I[2*z-2]+I[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:I,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(I),r.length&&this.font.forEach((function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(T.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:T.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})}))}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map((function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0}))),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map((function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],T.normalViewport||(i*=-1),i}))),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},T.prototype.destroy=function(){},T.prototype.kerning=!0,T.prototype.position={constant:new Float32Array(2)},T.prototype.translate=null,T.prototype.scale=null,T.prototype.font=null,T.prototype.text=\"\",T.prototype.positionOffset=[0,0],T.prototype.opacity=1,T.prototype.color=new Uint8Array([0,0,0,255]),T.prototype.alignOffset=[0,0],T.normalViewport=!1,T.maxAtlasSize=1024,T.atlasCanvas=document.createElement(\"canvas\"),T.atlasContext=T.atlasCanvas.getContext(\"2d\",{alpha:!1}),T.baseFontSize=64,T.fonts={},e.exports=T},{\"bit-twiddle\":97,\"color-normalize\":125,\"css-font\":144,\"detect-kerning\":172,\"es6-weak-map\":233,\"flatten-vertex-data\":244,\"font-atlas\":245,\"font-measure\":246,\"gl-util/context\":354,\"is-plain-obj\":469,\"object-assign\":499,\"parse-rect\":504,\"parse-unit\":506,\"pick-by-alias\":511,regl:540,\"to-px\":578,\"typedarray-pool\":595}],353:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||c(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=u(e)?e:e.raw;if(r)return y(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return x(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}function u(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var f=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function p(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var d=p.prototype;function g(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function m(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new p(t,o,e,r,n,i)}function y(t,e,r,n,i,a){var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new p(t,o,r,n,i,a)}function x(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=g(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var u,h,d=0;if(2===o.length)d=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])d=t.ALPHA;else if(2===o[2])d=t.LUMINANCE_ALPHA;else if(3===o[2])d=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");d=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var v=e.size;if(l)u=0===e.offset&&e.data.length===v?e.data:e.data.subarray(e.offset,e.offset+v);else{var y=[o[2],o[2]*o[0],1];h=a.malloc(v,r);var x=n(h,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):f(x,e),u=h.subarray(0,v)}var b=m(t);return t.texImage2D(t.TEXTURE_2D,0,d,o[0],o[1],0,d,c,u),l||a.free(h),new p(t,b,o[0],o[1],d,c)}Object.defineProperties(d,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),d.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},d.dispose=function(){this.gl.deleteTexture(this.handle)},d.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},d.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=u(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,u){var h=u.dtype,p=u.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var d=0,m=0,v=g(p,u.stride.slice());\"float32\"===h?d=t.FLOAT:\"float64\"===h?(d=t.FLOAT,v=!1,h=\"float32\"):\"uint8\"===h?d=t.UNSIGNED_BYTE:(d=t.UNSIGNED_BYTE,v=!1,h=\"uint8\");if(2===p.length)m=t.LUMINANCE,p=[p[0],p[1],1],u=n(u.data,p,[u.stride[0],u.stride[1],1],u.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])m=t.ALPHA;else if(2===p[2])m=t.LUMINANCE_ALPHA;else if(3===p[2])m=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");m=t.RGBA}p[2]}m!==t.LUMINANCE&&m!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(m=s);if(m!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=u.size,x=c.indexOf(o)<0;x&&c.push(o);if(d===l&&v)0===u.offset&&u.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data.subarray(u.offset,u.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data.subarray(u.offset,u.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);d===t.FLOAT&&l===t.UNSIGNED_BYTE?f(_,u):i.assign(_,u),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:495,\"ndarray-ops\":490,\"typedarray-pool\":595}],354:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":511}],355:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,f=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,f)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else{t.bindBuffer(t.ARRAY_BUFFER,null);for(i=0;i<n;++i)t.disableVertexAttribArray(i)}}},{}],356:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":355}],357:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":355}],358:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":356,\"./lib/vao-native.js\":357}],359:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],360:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":370,\"./fromValues\":376,\"./normalize\":387}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],363:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],364:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],365:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],366:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":367}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],368:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":369}],369:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],370:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],371:[function(t,e,r){e.exports=1e-6},{}],372:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":371}],373:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],374:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],375:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":364}],376:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],377:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":359,\"./angle\":360,\"./ceil\":361,\"./clone\":362,\"./copy\":363,\"./create\":364,\"./cross\":365,\"./dist\":366,\"./distance\":367,\"./div\":368,\"./divide\":369,\"./dot\":370,\"./epsilon\":371,\"./equals\":372,\"./exactEquals\":373,\"./floor\":374,\"./forEach\":375,\"./fromValues\":376,\"./inverse\":378,\"./len\":379,\"./length\":380,\"./lerp\":381,\"./max\":382,\"./min\":383,\"./mul\":384,\"./multiply\":385,\"./negate\":386,\"./normalize\":387,\"./random\":388,\"./rotateX\":389,\"./rotateY\":390,\"./rotateZ\":391,\"./round\":392,\"./scale\":393,\"./scaleAndAdd\":394,\"./set\":395,\"./sqrDist\":396,\"./sqrLen\":397,\"./squaredDistance\":398,\"./squaredLength\":399,\"./sub\":400,\"./subtract\":401,\"./transformMat3\":402,\"./transformMat4\":403,\"./transformQuat\":404}],378:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],379:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":380}],380:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],382:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],383:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],384:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":385}],385:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],386:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],387:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],388:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],389:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],390:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],391:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],392:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],393:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],395:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],396:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":398}],397:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":399}],398:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],399:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],400:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":401}],401:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],402:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],403:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],404:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t}},{}],405:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],406:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],407:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],408:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],409:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],410:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],411:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],412:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],413:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":405,\"./clone\":406,\"./copy\":407,\"./create\":408,\"./distance\":409,\"./divide\":410,\"./dot\":411,\"./fromValues\":412,\"./inverse\":414,\"./length\":415,\"./lerp\":416,\"./max\":417,\"./min\":418,\"./multiply\":419,\"./negate\":420,\"./normalize\":421,\"./random\":422,\"./scale\":423,\"./scaleAndAdd\":424,\"./set\":425,\"./squaredDistance\":426,\"./squaredLength\":427,\"./subtract\":428,\"./transformMat4\":429,\"./transformQuat\":430}],414:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],415:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],416:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],417:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],418:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],419:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],420:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],421:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],422:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":421,\"./scale\":423}],423:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],424:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],425:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],426:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],427:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],428:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],429:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],430:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t[3]=e[3],t}},{}],431:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":77,\"glsl-tokenizer\":438}],432:[function(t,e,r){e.exports=function(t){var e,r,c,u=0,f=0,h=999,p=[],d=[],g=1,m=0,v=0,y=!1,x=!1,b=\"\",_=a,w=n;\"300 es\"===(t=t||{}).version&&(_=s,w=o);var T={},k={};for(u=0;u<_.length;u++)T[_[u]]=!0;for(u=0;u<w.length;u++)k[w[u]]=!0;return function(t){return d=[],null!==t?function(t){u=0,t.toString&&(t=t.toString());var r;b+=t.replace(/\\r\\n/g,\"\\n\"),c=b.length;for(;e=b[u],u<c;){switch(r=u,h){case 0:u=C();break;case 1:case 2:u=E();break;case 3:u=L();break;case 4:u=z();break;case 11:u=P();break;case 5:u=O();break;case 9999:u=D();break;case 9:u=S();break;case 999:u=A()}if(r!==u)switch(b[r]){case\"\\n\":m=0,++g;break;default:++m}}return f+=u,b=b.slice(u),d}(t):function(t){p.length&&M(p.join(\"\"));return h=10,M(\"(eof)\"),d}()};function M(t){t.length&&d.push({type:l[h],data:t,position:v,line:g,column:m})}function A(){return p=p.length?[]:p,\"/\"===r&&\"*\"===e?(v=f+u-1,h=0,r=e,u+1):\"/\"===r&&\"/\"===e?(v=f+u-1,h=1,r=e,u+1):\"#\"===e?(h=2,v=f+u,u):/\\s/.test(e)?(h=9,v=f+u,u):(y=/\\d/.test(e),x=/[^\\w_]/.test(e),v=f+u,h=y?4:x?3:9999,u)}function S(){return/[^\\s]/g.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function E(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(p.push(e),r=e,u+1):(M(p.join(\"\")),h=999,u)}function C(){return\"/\"===e&&\"*\"===r?(p.push(e),M(p.join(\"\")),h=999,u+1):(p.push(e),r=e,u+1)}function L(){if(\".\"===r&&/\\d/.test(e))return h=5,u;if(\"/\"===r&&\"*\"===e)return h=0,u;if(\"/\"===r&&\"/\"===e)return h=1,u;if(\".\"===e&&p.length){for(;I(p););return h=5,u}if(\";\"===e||\")\"===e||\"(\"===e){if(p.length)for(;I(p););return M(e),h=999,u+1}var t=2===p.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;I(p););return h=999,u}return p.push(e),r=e,u+1}function I(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return M(r),v+=r.length,(p=p.slice(r.length)).length}}function P(){return/[^a-fA-F0-9]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function z(){return\".\"===e||/[eE]/.test(e)?(p.push(e),h=5,r=e,u+1):\"x\"===e&&1===p.length&&\"0\"===p[0]?(h=11,p.push(e),r=e,u+1):/[^\\d]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function O(){return\"f\"===e&&(p.push(e),r=e,u+=1),/[eE]/.test(e)?(p.push(e),r=e,u+1):(\"-\"!==e&&\"+\"!==e||!/[eE]/.test(r))&&/[^\\d]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function D(){if(/[^\\d\\w_]/.test(e)){var t=p.join(\"\");return h=k[t]?8:T[t]?7:6,M(p.join(\"\")),h=999,u}return p.push(e),r=e,u+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":434,\"./lib/builtins-300es\":433,\"./lib/literals\":436,\"./lib/literals-300es\":435,\"./lib/operators\":437}],433:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter((function(t){return!/^(gl\\_|texture)/.test(t)})),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":434}],434:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],435:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":436}],436:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"uint\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],437:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],438:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":432}],439:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],440:[function(t,e,r){(function(r){(function(){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":464}],441:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":464}],442:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],443:[function(t,e,r){\"use strict\";var n=t(\"./types\");e.exports=function(t,e){var r;for(r in n)if(n[r].detect(t,e))return r}},{\"./types\":446}],444:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"fs\"),i=t(\"path\"),a=t(\"./types\"),o=t(\"./detector\");function s(t,e){var r=o(t,e);if(r in a){var n=a[r].calculate(t,e);if(!1!==n)return n.type=r,n}throw new TypeError(\"unsupported file type: \"+r+\" (file: \"+e+\")\")}e.exports=function(t,e){if(r.isBuffer(t))return s(t);if(\"string\"!=typeof t)throw new TypeError(\"invalid invocation\");var a=i.resolve(t);if(\"function\"!=typeof e)return s(function(t){var e=n.openSync(t,\"r\"),i=n.fstatSync(e).size,a=Math.min(i,524288),o=r.alloc(a);return n.readSync(e,o,0,a,0),n.closeSync(e),o}(a),a);!function(t,e){n.open(t,\"r\",(function(i,a){if(i)return e(i);n.fstat(a,(function(i,o){if(i)return e(i);var s=o.size;if(s<=0)return e(new Error(\"File size is not greater than 0 \\u2014\\u2014 \"+t));var l=Math.min(s,524288),c=r.alloc(l);n.read(a,c,0,l,0,(function(t){if(t)return e(t);n.close(a,(function(t){e(t,c)}))}))}))}))}(a,(function(t,r){if(t)return e(t);var n;try{n=s(r,a)}catch(e){t=e}e(t,n)}))},e.exports.types=Object.keys(a)}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"./detector\":443,\"./types\":446,buffer:111,fs:109,path:507}],445:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){return r=r||0,t[\"readUInt\"+e+(n?\"BE\":\"LE\")].call(t,r)}},{}],446:[function(t,e,r){\"use strict\";var n={bmp:t(\"./types/bmp\"),cur:t(\"./types/cur\"),dds:t(\"./types/dds\"),gif:t(\"./types/gif\"),icns:t(\"./types/icns\"),ico:t(\"./types/ico\"),jpg:t(\"./types/jpg\"),png:t(\"./types/png\"),psd:t(\"./types/psd\"),svg:t(\"./types/svg\"),tiff:t(\"./types/tiff\"),webp:t(\"./types/webp\")};e.exports=n},{\"./types/bmp\":447,\"./types/cur\":448,\"./types/dds\":449,\"./types/gif\":450,\"./types/icns\":451,\"./types/ico\":452,\"./types/jpg\":453,\"./types/png\":454,\"./types/psd\":455,\"./types/svg\":456,\"./types/tiff\":457,\"./types/webp\":458}],447:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return\"BM\"===t.toString(\"ascii\",0,2)},calculate:function(t){return{width:t.readUInt32LE(18),height:Math.abs(t.readInt32LE(22))}}}},{}],448:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return 0===t.readUInt16LE(0)&&2===t.readUInt16LE(2)},calculate:t(\"./ico\").calculate}},{\"./ico\":452}],449:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return 542327876===t.readUInt32LE(0)},calculate:function(t){return{height:t.readUInt32LE(12),width:t.readUInt32LE(16)}}}},{}],450:[function(t,e,r){\"use strict\";var n=/^GIF8[79]a/;e.exports={detect:function(t){var e=t.toString(\"ascii\",0,6);return n.test(e)},calculate:function(t){return{width:t.readUInt16LE(6),height:t.readUInt16LE(8)}}}},{}],451:[function(t,e,r){\"use strict\";var n={ICON:32,\"ICN#\":32,\"icm#\":16,icm4:16,icm8:16,\"ics#\":16,ics4:16,ics8:16,is32:16,s8mk:16,icp4:16,icl4:32,icl8:32,il32:32,l8mk:32,icp5:32,ic11:32,ich4:48,ich8:48,ih32:48,h8mk:48,icp6:64,ic12:32,it32:128,t8mk:128,ic07:128,ic08:256,ic13:256,ic09:512,ic14:512,ic10:1024};function i(t,e){var r=e+4;return[t.toString(\"ascii\",e,r),t.readUInt32BE(r)]}function a(t){var e=n[t];return{width:e,height:e,type:t}}e.exports={detect:function(t){return\"icns\"===t.toString(\"ascii\",0,4)},calculate:function(t){var e,r,n,o=t.length,s=8,l=t.readUInt32BE(4);if(r=a((e=i(t,s))[0]),(s+=e[1])===l)return r;for(n={width:r.width,height:r.height,images:[r]};s<l&&s<o;)r=a((e=i(t,s))[0]),s+=e[1],n.images.push(r);return n}}},{}],452:[function(t,e,r){\"use strict\";function n(t,e){var r=t.readUInt8(e);return 0===r?256:r}function i(t,e){var r=6+16*e;return{width:n(t,r),height:n(t,r+1)}}e.exports={detect:function(t){return 0===t.readUInt16LE(0)&&1===t.readUInt16LE(2)},calculate:function(t){var e,r=t.readUInt16LE(4),n=i(t,0);if(1===r)return n;for(n.images=[{width:n.width,height:n.height}],e=1;e<r;e+=1)n.images.push(i(t,e));return n}}},{}],453:[function(t,e,r){\"use strict\";var n=t(\"../readUInt\");function i(t){return\"45786966\"===t.toString(\"hex\",2,6)}function a(t,e){return{height:t.readUInt16BE(e),width:t.readUInt16BE(e+2)}}function o(t,e){var r=t.slice(2,e),i=r.toString(\"hex\",6,8),a=\"4d4d\"===i;if(a||\"4949\"===i)return function(t,e){for(var r,i,a=n(t,16,14,e),o=0;o<a;o++){if(i=(r=16+12*o)+12,r>t.length)return;var s=t.slice(r,i);if(274===n(s,16,0,e)){if(3!==n(s,16,2,e))return;if(1!==n(s,32,4,e))return;return n(s,16,8,e)}}}(r,a)}function s(t,e){if(e>t.length)throw new TypeError(\"Corrupt JPG, exceeded buffer limits\");if(255!==t[e])throw new TypeError(\"Invalid JPG, marker table corrupted\")}e.exports={detect:function(t){return\"ffd8\"===t.toString(\"hex\",0,2)},calculate:function(t){var e,r,n;for(t=t.slice(4);t.length;){if(r=t.readUInt16BE(0),i(t)&&(e=o(t,r)),s(t,r),192===(n=t[r+1])||193===n||194===n){var l=a(t,r+5);return e?{width:l.width,height:l.height,orientation:e}:l}t=t.slice(r+2)}throw new TypeError(\"Invalid JPG, no size found\")}}},{\"../readUInt\":445}],454:[function(t,e,r){\"use strict\";e.exports={detect:function(t){if(\"PNG\\r\\n\\x1a\\n\"===t.toString(\"ascii\",1,8)){var e=t.toString(\"ascii\",12,16);if(\"CgBI\"===e&&(e=t.toString(\"ascii\",28,32)),\"IHDR\"!==e)throw new TypeError(\"invalid png\");return!0}},calculate:function(t){return\"CgBI\"===t.toString(\"ascii\",12,16)?{width:t.readUInt32BE(32),height:t.readUInt32BE(36)}:{width:t.readUInt32BE(16),height:t.readUInt32BE(20)}}}},{}],455:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return\"8BPS\"===t.toString(\"ascii\",0,4)},calculate:function(t){return{width:t.readUInt32BE(18),height:t.readUInt32BE(14)}}}},{}],456:[function(t,e,r){\"use strict\";var n=/<svg\\s([^>\"']|\"[^\"]*\"|'[^']*')*>/;var i={root:n,width:/\\swidth=(['\"])([^%]+?)\\1/,height:/\\sheight=(['\"])([^%]+?)\\1/,viewbox:/\\sviewBox=(['\"])(.+?)\\1/},a={cm:96/2.54,mm:96/2.54/10,m:96/2.54*100,pt:96/72,pc:96/72/12,em:16,ex:8};function o(t){var e=/([0-9.]+)([a-z]*)/.exec(t);if(e)return Math.round(parseFloat(e[1])*(a[e[2]]||1))}function s(t){var e=t.split(\" \");return{width:o(e[2]),height:o(e[3])}}e.exports={detect:function(t){return n.test(t)},calculate:function(t){var e=t.toString(\"utf8\").match(i.root);if(e){var r=function(t){var e=t.match(i.width),r=t.match(i.height),n=t.match(i.viewbox);return{width:e&&o(e[2]),height:r&&o(r[2]),viewbox:n&&s(n[2])}}(e[0]);if(r.width&&r.height)return function(t){return{width:t.width,height:t.height}}(r);if(r.viewbox)return function(t){var e=t.viewbox.width/t.viewbox.height;return t.width?{width:t.width,height:Math.floor(t.width/e)}:t.height?{width:Math.floor(t.height*e),height:t.height}:{width:t.viewbox.width,height:t.viewbox.height}}(r)}throw new TypeError(\"invalid svg\")}}},{}],457:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"fs\"),i=t(\"../readUInt\");function a(t,e){var r=i(t,16,8,e);return(i(t,16,10,e)<<16)+r}function o(t){if(t.length>24)return t.slice(12)}e.exports={detect:function(t){var e=t.toString(\"hex\",0,4);return\"49492a00\"===e||\"4d4d002a\"===e},calculate:function(t,e){if(!e)throw new TypeError(\"Tiff doesn't support buffer\");var s=\"BE\"===function(t){var e=t.toString(\"ascii\",0,2);return\"II\"===e?\"LE\":\"MM\"===e?\"BE\":void 0}(t),l=function(t,e){for(var r,n,s,l={};t&&t.length&&(r=i(t,16,0,e),n=i(t,16,2,e),s=i(t,32,4,e),0!==r);)1!==s||3!==n&&4!==n||(l[r]=a(t,e)),t=o(t);return l}(function(t,e,a){var o=i(t,32,4,a),s=1024,l=n.statSync(e).size;o+s>l&&(s=l-o-10);var c=r.alloc(s),u=n.openSync(e,\"r\");return n.readSync(u,c,0,s,o),c.slice(2)}(t,e,s),s),c=l[256],u=l[257];if(!c||!u)throw new TypeError(\"Invalid Tiff, missing tags\");return{width:c,height:u}}}}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"../readUInt\":445,buffer:111,fs:109}],458:[function(t,e,r){\"use strict\";e.exports={detect:function(t){var e=\"RIFF\"===t.toString(\"ascii\",0,4),r=\"WEBP\"===t.toString(\"ascii\",8,12),n=\"VP8\"===t.toString(\"ascii\",12,15);return e&&r&&n},calculate:function(t){var e=t.toString(\"ascii\",12,16);if(t=t.slice(20,30),\"VP8X\"===e){var r=t[0];return!(!(0==(192&r))||!(0==(1&r)))&&function(t){return{width:1+t.readUIntLE(4,3),height:1+t.readUIntLE(7,3)}}(t)}if(\"VP8 \"===e&&47!==t[0])return function(t){return{width:16383&t.readInt16LE(6),height:16383&t.readInt16LE(8)}}(t);var n=t.toString(\"hex\",3,6);return\"VP8L\"===e&&\"9d012a\"!==n&&function(t){return{width:1+((63&t[2])<<8|t[1]),height:1+((15&t[4])<<10|t[3]<<2|(192&t[2])>>6)}}(t)}}},{}],459:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);var f=new a(l,new Array(i+1),!1),h=f.adjacent,p=new Array(i+2);for(u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var m=d[0];d[0]=d[1],d[1]=m;var v=new a(d,new Array(i+1),!0);h[u]=v,p[u]=v}p[i+1]=f;for(u=0;u<=i;++u){d=h[u].vertices;var y=h[u].adjacent;for(g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=f;else for(var b=0;b<=i;++b)h[b].vertices.indexOf(x)<0&&(y[g]=h[b])}}var _=new c(i,o,p),w=!!e;for(u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter((function(t){return!t.boundary})),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,f=0;f<=r;++f){var h=u[f];i[f]=h<0?e:a[h]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var f=c[u];if(!(f.lastVisited>=r)){var h=a[u];a[u]=t;var p=this.orient();if(a[u]=h,p<0){s=f;continue t}f.boundary?f.lastVisited=-r:f.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,f=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var h=[];f.length>0;){var p=(e=f.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var m=0;m<=n;++m)if(m!==g){var v=d[m];if(v.boundary&&!(v.lastVisited>=r)){var y=v.vertices;if(v.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,v.boundary=!1,c.push(v),f.push(v),v.lastVisited=r;continue}v.lastVisited=-r}var _=v.adjacent,w=p.slice(),T=d.slice(),k=new a(w,T,!0);u.push(k);var M=_.indexOf(e);if(!(M<0)){_[M]=k,T[g]=v,w[m]=-1,T[m]=e,d[m]=k,k.flip();for(b=0;b<=n;++b){var A=w[b];if(!(A<0||A===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}h.push(new o(S,k,b))}}}}}}h.sort(s);for(m=0;m+1<h.length;m+=2){var I=h[m],P=h[m+1],z=I.index,O=P.index;z<0||O<0||(I.cell.adjacent[I.index]=P.cell,P.cell.adjacent[P.index]=I.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var f=o[0];o[0]=o[1],o[1]=f}e.push(o)}}return e}},{\"robust-orientation\":548,\"simplicial-complex\":558}],460:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new v(null);return new v(m(t))};var a=i.prototype;function o(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function s(t,e){var r=m(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function l(t,e){var r=t.intervals([]);r.push(e),s(t,r)}function c(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?0:(r.splice(n,1),s(t,r),1)}function u(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function f(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function h(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function p(t,e){return t-e}function d(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function g(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function m(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(p);var n=e[e.length>>1],a=[],o=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?a.push(l):n<l[0]?o.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(d),u.sort(g),new i(n,m(a),m(o),c,u)}function v(t){this.root=t}a.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},a.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?l(this,t):this.left.insert(t):this.left=m([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?l(this,t):this.right.insert(t):this.right=m([t]);else{var r=n.ge(this.leftPoints,t,d),i=n.ge(this.rightPoints,t,g);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},a.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?c(this,t):2===(s=this.left.remove(t))?(this.left=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?c(this,t):2===(s=this.right.remove(t))?(this.right=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(1===this.count)return this.leftPoints[0]===t?2:0;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,i=this.left;i.right;)r=i,i=i.right;if(r===this)i.right=this.right;else{var a=this.left,s=this.right;r.count-=i.count,r.right=i.left,i.left=a,i.right=s}o(this,i),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?o(this,this.left):o(this,this.right);return 1}for(a=n.ge(this.leftPoints,t,d);a<this.leftPoints.length&&this.leftPoints[a][0]===t[0];++a)if(this.leftPoints[a]===t){this.count-=1,this.leftPoints.splice(a,1);for(s=n.ge(this.rightPoints,t,g);s<this.rightPoints.length&&this.rightPoints[s][1]===t[1];++s)if(this.rightPoints[s]===t)return this.rightPoints.splice(s,1),1}return 0},a.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return u(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return f(this.rightPoints,t,e)}return h(this.leftPoints,e)},a.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?u(this.leftPoints,e,r):t>this.mid?f(this.rightPoints,t,r):h(this.leftPoints,r)};var y=v.prototype;y.insert=function(t){this.root?this.root.insert(t):this.root=new i(t[0],null,null,[t],[t])},y.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),0!==e}return!1},y.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},y.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(y,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(y,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":461}],461:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],462:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],463:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],464:[function(t,e,r){e.exports=!0},{}],465:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}\n",
       "/*!\n",
       " * Determine if an object is a Buffer\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],466:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],467:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a,e.exports.default=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;if(e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"!=typeof e)return!1;var r=t.tablet?i.test(e):n.test(e);return!r&&t.tablet&&t.featureDetect&&navigator&&navigator.maxTouchPoints>1&&-1!==e.indexOf(\"Macintosh\")&&-1!==e.indexOf(\"Safari\")&&(r=!0),r}},{}],468:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],469:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],470:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],471:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],472:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],473:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():(t=t||self).mapboxgl=n()}(this,(function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,(function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[2]*this.x+t[3]*this.y;return this.x=t[0]*this.x+t[1]*this.y,this.y=e,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=r*this.x+e*this.y;return this.x=e*this.x-r*this.y,this.y=n,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=e.x+r*(this.x-e.x)-n*(this.y-e.y),this.y=i,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var s=o(.25,.1,.25,1);function l(t,e,r){return Math.min(r,Math.max(e,t))}function c(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function u(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function h(){return f++}function p(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function d(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function g(t,e){t.forEach((function(t){e[t]&&(e[t]=e[t].bind(e))}))}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function v(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function y(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function x(t){return Array.isArray(t)?t.map(x):\"object\"==typeof t&&t?v(t,x):t}var b={};function _(t){b[t]||(\"undefined\"!=typeof console&&console.warn(t),b[t]=!0)}function w(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)e+=((o=t[i]).x-(a=t[r]).x)*(a.y+o.y);return e}function k(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}function M(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,(function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"})),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}var A=null;function S(t){if(null==A){var e=t.navigator?t.navigator.userAgent:null;A=!!t.safari||!(!e||!(/\\b(iPad|iPhone|iPod)\\b/.test(e)||e.match(\"Safari\")&&!e.match(\"Chrome\")))}return A}function E(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var C,L,I,P,z=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),O=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,D=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,R={now:z,frame:function(t){var e=O(t);return{cancel:function(){return D(e)}}},getImageData:function(t,e){void 0===e&&(e=0);var r=self.document.createElement(\"canvas\"),n=r.getContext(\"2d\");if(!n)throw new Error(\"failed to create canvas 2d context\");return r.width=t.width,r.height=t.height,n.drawImage(t,0,0,t.width,t.height),n.getImageData(-e,-e,t.width+2*e,t.height+2*e)},resolveURL:function(t){return C||(C=self.document.createElement(\"a\")),C.href=t,C.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio},get prefersReducedMotion(){return!!self.matchMedia&&(null==L&&(L=self.matchMedia(\"(prefers-reduced-motion: reduce)\")),L.matches)}},F={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},B={supported:!1,testSupport:function(t){!N&&P&&(j?U(t):I=t)}},N=!1,j=!1;function U(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,P),t.isContextLost())return;B.supported=!0}catch(t){}t.deleteTexture(e),N=!0}self.document&&((P=self.document.createElement(\"img\")).onload=function(){I&&U(I),I=null,j=!0},P.onerror=function(){N=!0,I=null},P.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var V=\"01\",q=function(t,e){this._transformRequestFn=t,this._customAccessToken=e,this._createSkuToken()};function H(t){return 0===t.indexOf(\"mapbox:\")}q.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",V,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},q.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},q.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},q.prototype.normalizeStyleURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/styles/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeGlyphsURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/fonts/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSourceURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSpriteURL=function(t,e,r,n){var i=X(t);return H(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,this._makeAPIURL(i,this._customAccessToken||n)):(i.path+=\"\"+e+r,Z(i))},q.prototype.normalizeTileURL=function(t,e){if(this._isSkuTokenExpired()&&this._createSkuToken(),t&&!H(t))return t;var r=X(t);r.path=r.path.replace(/(\\.(png|jpg)\\d*)(?=$)/,(R.devicePixelRatio>=2||512===e?\"@2x\":\"\")+(B.supported?\".webp\":\"$1\")),r.path=r.path.replace(/^.+\\/v4\\//,\"/\"),r.path=\"/v4\"+r.path;var n=this._customAccessToken||function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e].match(/^access_token=(.*)$/);if(n)return n[1]}return null}(r.params)||F.ACCESS_TOKEN;return F.REQUIRE_ACCESS_TOKEN&&n&&this._skuToken&&r.params.push(\"sku=\"+this._skuToken),this._makeAPIURL(r,n)},q.prototype.canonicalizeTileURL=function(t,e){var r=X(t);if(!r.path.match(/(^\\/v4\\/)/)||!r.path.match(/\\.[\\w]+$/))return t;var n=\"mapbox://tiles/\";n+=r.path.replace(\"/v4/\",\"\");var i=r.params;return e&&(i=i.filter((function(t){return!t.match(/^access_token=/)}))),i.length&&(n+=\"?\"+i.join(\"&\")),n},q.prototype.canonicalizeTileset=function(t,e){for(var r=!!e&&H(e),n=[],i=0,a=t.tiles||[];i<a.length;i+=1){var o=a[i];Y(o)?n.push(this.canonicalizeTileURL(o,r)):n.push(o)}return n},q.prototype._makeAPIURL=function(t,e){var r=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\",n=X(F.API_URL);if(t.protocol=n.protocol,t.authority=n.authority,\"/\"!==n.path&&(t.path=\"\"+n.path+t.path),!F.REQUIRE_ACCESS_TOKEN)return Z(t);if(!(e=e||F.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+r);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+r);return t.params=t.params.filter((function(t){return-1===t.indexOf(\"access_token\")})),t.params.push(\"access_token=\"+e),Z(t)};var G=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function Y(t){return G.test(t)}var W=/^(\\w+):\\/\\/([^/?]*)(\\/[^?]+)?\\??(.+)?/;function X(t){var e=t.match(W);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function Z(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function J(t){if(!t)return null;var e=t.split(\".\");if(!e||3!==e.length)return null;try{return JSON.parse(decodeURIComponent(self.atob(e[1]).split(\"\").map((function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)})).join(\"\")))}catch(t){return null}}var K=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};K.prototype.getStorageKey=function(t){var e,r=J(F.ACCESS_TOKEN);return e=r&&r.u?self.btoa(encodeURIComponent(r.u).replace(/%([0-9A-F]{2})/g,(function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):F.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+e:\"mapbox.eventData:\"+e},K.prototype.fetchEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){_(\"Unable to read from LocalStorage\")}},K.prototype.saveEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){_(\"Unable to write to LocalStorage\")}},K.prototype.processRequests=function(t){},K.prototype.postEvent=function(t,e,r,n){var i=this;if(F.EVENTS_URL){var a=X(F.EVENTS_URL);a.params.push(\"access_token=\"+(n||F.ACCESS_TOKEN||\"\"));var o={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.10.1\",skuId:V,userId:this.anonId},s=e?u(o,e):o,l={url:Z(a),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([s])};this.pendingRequest=xt(l,(function(t){i.pendingRequest=null,r(t),i.saveEventData(),i.processRequests(n)}))}},K.prototype.queueRequest=function(t,e){this.queue.push(t),this.processRequests(e)};var Q,$,tt=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.postMapLoadEvent=function(t,e,r,n){this.skuToken=r,(F.EVENTS_URL&&n||F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)})))&&this.queueRequest({id:e,timestamp:Date.now()},n)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){var r=this.queue.shift(),n=r.id,i=r.timestamp;n&&this.success[n]||(this.anonId||this.fetchEventData(),d(this.anonId)||(this.anonId=p()),this.postEvent(i,{skuToken:this.skuToken},(function(t){t||n&&(e.success[n]=!0)}),t))}},e}(K),et=new(function(t){function e(e){t.call(this,\"appUserTurnstile\"),this._customAccessToken=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.postTurnstileEvent=function(t,e){F.EVENTS_URL&&F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)}))&&this.queueRequest(Date.now(),e)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var r=J(F.ACCESS_TOKEN),n=r?r.u:F.ACCESS_TOKEN,i=n!==this.eventData.tokenU;d(this.anonId)||(this.anonId=p(),i=!0);var a=this.queue.shift();if(this.eventData.lastSuccess){var o=new Date(this.eventData.lastSuccess),s=new Date(a),l=(a-this.eventData.lastSuccess)/864e5;i=i||l>=1||l<-1||o.getDate()!==s.getDate()}else i=!0;if(!i)return this.processRequests();this.postEvent(a,{\"enabled.telemetry\":!1},(function(t){t||(e.eventData.lastSuccess=a,e.eventData.tokenU=n)}),t)}},e}(K)),rt=et.postTurnstileEvent.bind(et),nt=new tt,it=nt.postMapLoadEvent.bind(nt),at=500,ot=50;function st(){self.caches&&!Q&&(Q=self.caches.open(\"mapbox-tiles\"))}function lt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var ct,ut=1/0;function ft(){return null==ct&&(ct=self.OffscreenCanvas&&new self.OffscreenCanvas(1,1).getContext(\"2d\")&&\"function\"==typeof self.createImageBitmap),ct}var ht={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(ht);var pt,dt,gt=function(t){function e(e,r,n){401===r&&Y(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error),mt=k()?function(){return self.worker&&self.worker.referrer}:function(){return(\"blob:\"===self.location.protocol?self.parent:self).location.href},vt=function(t,e){if(!(/^file:/.test(r=t.url)||/^file:/.test(mt())&&!/^\\w+:/.test(r))){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return function(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:mt(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&Y(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&_(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then((function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new gt(r.statusText,r.status,t.url))})).catch((function(t){20!==t.code&&e(new Error(t.message))}))}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then((function(t){o||(n&&s&&function(t,e,r){if(st(),Q){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach((function(t,e){return n.headers.set(e,t)}));var i=M(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<42e4||function(t,e){if(void 0===$)try{new Response(new ReadableStream),$=!0}catch(t){$=!1}$?e(t.body):t.blob().then(e)}(e,(function(e){var r=new self.Response(e,n);st(),Q&&Q.then((function(e){return e.put(lt(t.url),r)})).catch((function(t){return _(t.message)}))})))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))})).catch((function(t){o||e(new Error(t.message))}))};return s?function(t,e){if(st(),!Q)return e(null);var r=lt(t.url);Q.then((function(t){t.match(r).then((function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")||0),r=M(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})).catch(e)})).catch(e)}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}(t,e);if(k()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e,void 0,!0)}var r;return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&(r.responseType=\"text\",r.setRequestHeader(\"Accept\",\"application/json\")),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new gt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},yt=function(t,e){return vt(u(t,{type:\"arrayBuffer\"}),e)},xt=function(t,e){return vt(u(t,{method:\"POST\"}),e)};pt=[],dt=0;var bt=function(t,e){if(B.supported&&(t.headers||(t.headers={}),t.headers.accept=\"image/webp,*/*\"),dt>=F.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return pt.push(r),r}dt++;var n=!1,i=function(){if(!n)for(n=!0,dt--;pt.length&&dt<F.MAX_PARALLEL_IMAGE_REQUESTS;){var t=pt.shift();t.cancelled||(t.cancel=bt(t.requestParameters,t.callback).cancel)}},a=yt(t,(function(t,r,n,a){i(),t?e(t):r&&(ft()?function(t,e){var r=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});self.createImageBitmap(r).then((function(t){e(null,t)})).catch((function(t){e(new Error(\"Could not load image because of \"+t.message+\". Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))}))}(r,e):function(t,e,r,n){var i=new self.Image,a=self.URL;i.onload=function(){e(null,i),a.revokeObjectURL(i.src)},i.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var o=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});i.cacheControl=r,i.expires=n,i.src=t.byteLength?a.createObjectURL(o):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}(r,e,n,a))}));return{cancel:function(){a.cancel(),i()}}};function _t(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function wt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Tt=function(t,e){void 0===e&&(e={}),u(this,e),this.type=t},kt=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",u({error:e},r))}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Tt),Mt=function(){};Mt.prototype.on=function(t,e){return this._listeners=this._listeners||{},_t(t,e,this._listeners),this},Mt.prototype.off=function(t,e){return wt(t,e,this._listeners),wt(t,e,this._oneTimeListeners),this},Mt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},_t(t,e,this._oneTimeListeners),this},Mt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Tt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];wt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(u(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof kt&&console.error(t.error);return this},Mt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},Mt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var At={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},promoteId:{type:\"promoteId\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1},promoteId:{type:\"promoteId\"}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{\"fill-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{\"circle-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"resolvedImage\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[\"text-field\"],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"text-field\",{\"!\":\"text-variable-anchor\"}],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-writing-mode\":{type:\"array\",value:\"enum\",values:{horizontal:{},vertical:{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{},within:{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:24,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},in:{group:\"Lookup\"},\"index-of\":{group:\"Lookup\"},slice:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},image:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},distance:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},within:{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,overridable:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}},promoteId:{\"*\":{type:\"string\"}}},St=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Et(t){var e=t.value;return e?[new St(t.key,e,\"constants have been deprecated as of v8\")]:[]}function Ct(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Lt(t){return t instanceof Number||t instanceof String||t instanceof Boolean?t.valueOf():t}function It(t){if(Array.isArray(t))return t.map(It);if(t instanceof Object&&!(t instanceof Number||t instanceof String||t instanceof Boolean)){var e={};for(var r in t)e[r]=It(t[r]);return e}return Lt(t)}var Pt=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Error),zt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r];this.bindings[i[0]]=i[1]}};zt.prototype.concat=function(t){return new zt(this,t)},zt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},zt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var Ot={kind:\"null\"},Dt={kind:\"number\"},Rt={kind:\"string\"},Ft={kind:\"boolean\"},Bt={kind:\"color\"},Nt={kind:\"object\"},jt={kind:\"value\"},Ut={kind:\"collator\"},Vt={kind:\"formatted\"},qt={kind:\"resolvedImage\"};function Ht(t,e){return{kind:\"array\",itemType:t,N:e}}function Gt(t){if(\"array\"===t.kind){var e=Gt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var Yt=[Ot,Dt,Rt,Ft,Bt,Vt,Nt,Ht(jt),qt];function Wt(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!Wt(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=Yt;r<n.length;r+=1)if(!Wt(n[r],e))return null}return\"Expected \"+Gt(t)+\" but found \"+Gt(e)+\" instead.\"}function Xt(t,e){return e.some((function(e){return e.kind===t.kind}))}function Zt(t,e){return e.some((function(e){return\"null\"===e?null===t:\"array\"===e?Array.isArray(t):\"object\"===e?t&&!Array.isArray(t)&&\"object\"==typeof t:e===typeof t}))}var Jt=e((function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return n(\"%\"===t[t.length-1]?parseFloat(t)/100*255:parseInt(t))}function a(t){return(e=\"%\"===t[t.length-1]?parseFloat(t)/100:parseFloat(t))<0?0:e>1?1:e;var e}function o(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,s=t.replace(/ /g,\"\").toLowerCase();if(s in r)return r[s].slice();if(\"#\"===s[0])return 4===s.length?(e=parseInt(s.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===s.length&&(e=parseInt(s.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=s.indexOf(\"(\"),c=s.indexOf(\")\");if(-1!==l&&c+1===s.length){var u=s.substr(0,l),f=s.substr(l+1,c-(l+1)).split(\",\"),h=1;switch(u){case\"rgba\":if(4!==f.length)return null;h=a(f.pop());case\"rgb\":return 3!==f.length?null:[i(f[0]),i(f[1]),i(f[2]),h];case\"hsla\":if(4!==f.length)return null;h=a(f.pop());case\"hsl\":if(3!==f.length)return null;var p=(parseFloat(f[0])%360+360)%360/360,d=a(f[1]),g=a(f[2]),m=g<=.5?g*(d+1):g+d-g*d,v=2*g-m;return[n(255*o(v,m,p+1/3)),n(255*o(v,m,p)),n(255*o(v,m,p-1/3)),h];default:return null}}return null}}catch(t){}})).parseCSSColor,Kt=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};Kt.parse=function(t){if(t){if(t instanceof Kt)return t;if(\"string\"==typeof t){var e=Jt(t);if(e)return new Kt(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},Kt.prototype.toString=function(){var t=this.toArray(),e=t[1],r=t[2],n=t[3];return\"rgba(\"+Math.round(t[0])+\",\"+Math.round(e)+\",\"+Math.round(r)+\",\"+n+\")\"},Kt.prototype.toArray=function(){var t=this.a;return 0===t?[0,0,0,0]:[255*this.r/t,255*this.g/t,255*this.b/t,t]},Kt.black=new Kt(0,0,0,1),Kt.white=new Kt(1,1,1,1),Kt.transparent=new Kt(0,0,0,0),Kt.red=new Kt(1,0,0,1);var Qt=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};Qt.prototype.compare=function(t,e){return this.collator.compare(t,e)},Qt.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var $t=function(t,e,r,n,i){this.text=t,this.image=e,this.scale=r,this.fontStack=n,this.textColor=i},te=function(t){this.sections=t};te.fromString=function(t){return new te([new $t(t,null,null,null,null)])},te.prototype.isEmpty=function(){return 0===this.sections.length||!this.sections.some((function(t){return 0!==t.text.length||t.image&&0!==t.image.name.length}))},te.factory=function(t){return t instanceof te?t:te.fromString(t)},te.prototype.toString=function(){return 0===this.sections.length?\"\":this.sections.map((function(t){return t.text})).join(\"\")},te.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];if(n.image)t.push([\"image\",n.image.name]);else{t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),n.textColor&&(i[\"text-color\"]=[\"rgba\"].concat(n.textColor.toArray())),t.push(i)}}return t};var ee=function(t){this.name=t.name,this.available=t.available};function re(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function ne(t){if(null===t)return!0;if(\"string\"==typeof t)return!0;if(\"boolean\"==typeof t)return!0;if(\"number\"==typeof t)return!0;if(t instanceof Kt)return!0;if(t instanceof Qt)return!0;if(t instanceof te)return!0;if(t instanceof ee)return!0;if(Array.isArray(t)){for(var e=0,r=t;e<r.length;e+=1)if(!ne(r[e]))return!1;return!0}if(\"object\"==typeof t){for(var n in t)if(!ne(t[n]))return!1;return!0}return!1}function ie(t){if(null===t)return Ot;if(\"string\"==typeof t)return Rt;if(\"boolean\"==typeof t)return Ft;if(\"number\"==typeof t)return Dt;if(t instanceof Kt)return Bt;if(t instanceof Qt)return Ut;if(t instanceof te)return Vt;if(t instanceof ee)return qt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=ie(i[n]);if(e){if(e===a)continue;e=jt;break}e=a}return Ht(e||jt,r)}return Nt}function ae(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof Kt||t instanceof te||t instanceof ee?t.toString():JSON.stringify(t)}ee.prototype.toString=function(){return this.name},ee.fromString=function(t){return t?new ee({name:t,available:!1}):null},ee.prototype.serialize=function(){return[\"image\",this.name]};var oe=function(t,e){this.type=t,this.value=e};oe.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!ne(t[1]))return e.error(\"invalid value\");var r=t[1],n=ie(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new oe(n,r)},oe.prototype.evaluate=function(){return this.value},oe.prototype.eachChild=function(){},oe.prototype.outputDefined=function(){return!0},oe.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof Kt?[\"rgba\"].concat(this.value.toArray()):this.value instanceof te?this.value.serialize():this.value};var se=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};se.prototype.toJSON=function(){return this.message};var le={string:Rt,number:Dt,boolean:Ft,object:Nt},ce=function(t,e){this.type=t,this.args=e};ce.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in le)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=le[s],n++}else a=jt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=Ht(a,o)}else r=le[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,jt);if(!c)return null;l.push(c)}return new ce(r,l)},ce.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!Wt(this.type,ie(r)))return r;if(e===this.args.length-1)throw new se(\"Expected value to be of type \"+Gt(this.type)+\", but found \"+Gt(ie(r))+\" instead.\")}return null},ce.prototype.eachChild=function(t){this.args.forEach(t)},ce.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ce.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map((function(t){return t.serialize()})))};var ue=function(t){this.type=Vt,this.sections=t};ue.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[1];if(!Array.isArray(r)&&\"object\"==typeof r)return e.error(\"First argument must be an image or text section.\");for(var n=[],i=!1,a=1;a<=t.length-1;++a){var o=t[a];if(i&&\"object\"==typeof o&&!Array.isArray(o)){i=!1;var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Dt)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,Ht(Rt))))return null;var c=null;if(o[\"text-color\"]&&!(c=e.parse(o[\"text-color\"],1,Bt)))return null;var u=n[n.length-1];u.scale=s,u.font=l,u.textColor=c}else{var f=e.parse(t[a],1,jt);if(!f)return null;var h=f.type.kind;if(\"string\"!==h&&\"value\"!==h&&\"null\"!==h&&\"resolvedImage\"!==h)return e.error(\"Formatted text type must be 'string', 'value', 'image' or 'null'.\");i=!0,n.push({content:f,scale:null,font:null,textColor:null})}}return new ue(n)},ue.prototype.evaluate=function(t){return new te(this.sections.map((function(e){var r=e.content.evaluate(t);return ie(r)===qt?new $t(\"\",r,null,null,null):new $t(ae(r),null,e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null,e.textColor?e.textColor.evaluate(t):null)})))},ue.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.content),n.scale&&t(n.scale),n.font&&t(n.font),n.textColor&&t(n.textColor)}},ue.prototype.outputDefined=function(){return!1},ue.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.content.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),n.textColor&&(i[\"text-color\"]=n.textColor.serialize()),t.push(i)}return t};var fe=function(t){this.type=qt,this.input=t};fe.parse=function(t,e){if(2!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Rt);return r?new fe(r):e.error(\"No image name provided.\")},fe.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=ee.fromString(e);return r&&t.availableImages&&(r.available=t.availableImages.indexOf(e)>-1),r},fe.prototype.eachChild=function(t){t(this.input)},fe.prototype.outputDefined=function(){return!1},fe.prototype.serialize=function(){return[\"image\",this.input.serialize()]};var he={\"to-boolean\":Ft,\"to-color\":Bt,\"to-number\":Dt,\"to-string\":Rt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=he[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,jt);if(!o)return null;i.push(o)}return new pe(n,i)},pe.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof Kt)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":re(e[0],e[1],e[2],e[3])))return new Kt(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new se(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new se(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?te.fromString(ae(this.args[0].evaluate(t))):\"resolvedImage\"===this.type.kind?ee.fromString(ae(this.args[0].evaluate(t))):ae(this.args[0].evaluate(t))},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},pe.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new ue([{content:this.args[0],scale:null,font:null,textColor:null}]).serialize();if(\"resolvedImage\"===this.type.kind)return new fe(this.args[0]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild((function(e){t.push(e.serialize())})),t};var de=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ge=function(){this.globals=null,this.feature=null,this.featureState=null,this.formattedSection=null,this._parseColorCache={},this.availableImages=null,this.canonical=null};ge.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ge.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?de[this.feature.type]:this.feature.type:null},ge.prototype.geometry=function(){return this.feature&&\"geometry\"in this.feature?this.feature.geometry:null},ge.prototype.canonicalID=function(){return this.canonical},ge.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ge.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=Kt.parse(t)),e};var me=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};me.prototype.evaluate=function(t){return this._evaluate(t,this.args)},me.prototype.eachChild=function(t){this.args.forEach(t)},me.prototype.outputDefined=function(){return!1},me.prototype.serialize=function(){return[this.name].concat(this.args.map((function(t){return t.serialize()})))},me.parse=function(t,e){var r,n=t[0],i=me.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter((function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1})),l=null,c=0,u=s;c<u.length;c+=1){var f=u[c],h=f[0],p=f[1];l=new Be(e.registry,e.path,null,e.scope);for(var d=[],g=!1,m=1;m<t.length;m++){var v=t[m],y=Array.isArray(h)?h[m-1]:h.type,x=l.parse(v,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(h)&&h.length!==d.length)l.error(\"Expected \"+h.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(h)?h[b]:h.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new me(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var T=(s.length?s:o).map((function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Gt).join(\", \")+\")\":\"(\"+Gt(e.type)+\"...)\"})).join(\" | \"),k=[],M=1;M<t.length;M++){var A=e.parse(t[M],1+k.length);if(!A)return null;k.push(Gt(A.type))}e.error(\"Expected arguments of type \"+T+\", but found (\"+k.join(\", \")+\") instead.\")}return null},me.register=function(t,e){for(var r in me.definitions=e,e)t[r]=me};var ve=function(t,e,r){this.type=Ut,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function ye(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.min(t[1],e[1]),t[2]=Math.max(t[2],e[0]),t[3]=Math.max(t[3],e[1])}function xe(t,e){return!(t[0]<=e[0]||t[2]>=e[2]||t[1]<=e[1]||t[3]>=e[3])}function be(t,e){var r=(180+t[0])/360,n=(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t[1]*Math.PI/360)))/360,i=Math.pow(2,e.z);return[Math.round(r*i*8192),Math.round(n*i*8192)]}function _e(t,e,r){return e[1]>t[1]!=r[1]>t[1]&&t[0]<(r[0]-e[0])*(t[1]-e[1])/(r[1]-e[1])+e[0]}function we(t,e){for(var r,n,i,a,o,s,l,c=!1,u=0,f=e.length;u<f;u++)for(var h=e[u],p=0,d=h.length;p<d-1;p++){if((a=(r=t)[0]-(n=h[p])[0])*(l=r[1]-(i=h[p+1])[1])-(s=r[0]-i[0])*(o=r[1]-n[1])==0&&a*s<=0&&o*l<=0)return!1;_e(t,h[p],h[p+1])&&(c=!c)}return c}function Te(t,e){for(var r=0;r<e.length;r++)if(we(t,e[r]))return!0;return!1}function ke(t,e,r,n){var i=n[0]-r[0],a=n[1]-r[1],o=(t[0]-r[0])*a-i*(t[1]-r[1]),s=(e[0]-r[0])*a-i*(e[1]-r[1]);return o>0&&s<0||o<0&&s>0}function Me(t,e,r){for(var n=0,i=r;n<i.length;n+=1)for(var a=i[n],o=0;o<a.length-1;++o)if(0!=(f=[(u=a[o+1])[0]-(c=a[o])[0],u[1]-c[1]])[0]*(h=[(l=e)[0]-(s=t)[0],l[1]-s[1]])[1]-f[1]*h[0]&&ke(s,l,c,u)&&ke(c,u,s,l))return!0;var s,l,c,u,f,h;return!1}function Ae(t,e){for(var r=0;r<t.length;++r)if(!we(t[r],e))return!1;for(var n=0;n<t.length-1;++n)if(Me(t[n],t[n+1],e))return!1;return!0}function Se(t,e){for(var r=0;r<e.length;r++)if(Ae(t,e[r]))return!0;return!1}function Ee(t,e,r){for(var n=[],i=0;i<t.length;i++){for(var a=[],o=0;o<t[i].length;o++){var s=be(t[i][o],r);ye(e,s),a.push(s)}n.push(a)}return n}function Ce(t,e,r){for(var n=[],i=0;i<t.length;i++){var a=Ee(t[i],e,r);n.push(a)}return n}function Le(t,e,r,n){if(t[0]<r[0]||t[0]>r[2]){var i=.5*n,a=t[0]-r[0]>i?-n:r[0]-t[0]>i?n:0;0===a&&(a=t[0]-r[2]>i?-n:r[2]-t[0]>i?n:0),t[0]+=a}ye(e,t)}function Ie(t,e,r,n){for(var i=8192*Math.pow(2,n.z),a=[8192*n.x,8192*n.y],o=[],s=0,l=t;s<l.length;s+=1)for(var c=0,u=l[s];c<u.length;c+=1){var f=u[c],h=[f.x+a[0],f.y+a[1]];Le(h,e,r,i),o.push(h)}return o}function Pe(t,e,r,n){for(var i,a=8192*Math.pow(2,n.z),o=[8192*n.x,8192*n.y],s=[],l=0,c=t;l<c.length;l+=1){for(var u=[],f=0,h=c[l];f<h.length;f+=1){var p=h[f],d=[p.x+o[0],p.y+o[1]];ye(e,d),u.push(d)}s.push(u)}if(e[2]-e[0]<=a/2){(i=e)[0]=i[1]=1/0,i[2]=i[3]=-1/0;for(var g=0,m=s;g<m.length;g+=1)for(var v=0,y=m[g];v<y.length;v+=1)Le(y[v],e,r,a)}return s}ve.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Ft);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Ft);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Rt))?null:new ve(n,i,a)},ve.prototype.evaluate=function(t){return new Qt(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},ve.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},ve.prototype.outputDefined=function(){return!1},ve.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var ze=function(t,e){this.type=Ft,this.geojson=t,this.geometries=e};function Oe(t){if(t instanceof me){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}if(t instanceof ze)return!1;var e=!0;return t.eachChild((function(t){e&&!Oe(t)&&(e=!1)})),e}function De(t){if(t instanceof me&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild((function(t){e&&!De(t)&&(e=!1)})),e}function Re(t,e){if(t instanceof me&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild((function(t){r&&!Re(t,e)&&(r=!1)})),r}ze.parse=function(t,e){if(2!==t.length)return e.error(\"'within' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(ne(t[1])){var r=t[1];if(\"FeatureCollection\"===r.type)for(var n=0;n<r.features.length;++n){var i=r.features[n].geometry.type;if(\"Polygon\"===i||\"MultiPolygon\"===i)return new ze(r,r.features[n].geometry)}else if(\"Feature\"===r.type){var a=r.geometry.type;if(\"Polygon\"===a||\"MultiPolygon\"===a)return new ze(r,r.geometry)}else if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type)return new ze(r,r)}return e.error(\"'within' expression requires valid geojson object that contains polygon geometry type.\")},ze.prototype.evaluate=function(t){if(null!=t.geometry()&&null!=t.canonicalID()){if(\"Point\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Ee(e.coordinates,n,i),o=Ie(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!we(l[s],a))return!1}if(\"MultiPolygon\"===e.type){var c=Ce(e.coordinates,n,i),u=Ie(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var f=0,h=u;f<h.length;f+=1)if(!Te(h[f],c))return!1}return!0}(t,this.geometries);if(\"LineString\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Ee(e.coordinates,n,i),o=Pe(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!Ae(l[s],a))return!1}if(\"MultiPolygon\"===e.type){var c=Ce(e.coordinates,n,i),u=Pe(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var f=0,h=u;f<h.length;f+=1)if(!Se(h[f],c))return!1}return!0}(t,this.geometries)}return!1},ze.prototype.eachChild=function(){},ze.prototype.outputDefined=function(){return!0},ze.prototype.serialize=function(){return[\"within\",this.geojson]};var Fe=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Fe.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Fe(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Fe.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Fe.prototype.eachChild=function(){},Fe.prototype.outputDefined=function(){return!1},Fe.prototype.serialize=function(){return[\"var\",this.name]};var Be=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new zt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map((function(t){return\"[\"+t+\"]\"})).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Ne(t,e){for(var r,n=t.length-1,i=0,a=n,o=0;i<=a;)if((r=t[o=Math.floor((i+a)/2)])<=e){if(o===n||e<t[o+1])return o;i=o+1}else{if(!(r>e))throw new se(\"Input is not a number.\");a=o-1}return 0}Be.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Be.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new ce(e,[t]):\"coerce\"===r?new pe(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind&&\"resolvedImage\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof oe)&&\"resolvedImage\"!==a.type.kind&&function t(e){if(e instanceof Fe)return t(e.boundExpression);if(e instanceof me&&\"error\"===e.name)return!1;if(e instanceof ve)return!1;if(e instanceof ze)return!1;var r=e instanceof pe||e instanceof ce,n=!0;return e.eachChild((function(e){n=r?n&&t(e):n&&e instanceof oe})),!!n&&Oe(e)&&Re(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"])}(a)){var l=new ge;try{a=new oe(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return this.error(void 0===t?\"'undefined' value invalid. Use null instead.\":\"object\"==typeof t?'Bare objects invalid. Use [\"literal\", {...}] instead.':\"Expected an array, but found \"+typeof t+\" instead.\")},Be.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Be(this.registry,n,e||null,i,this.errors)},Be.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map((function(t){return\"[\"+t+\"]\"})).join(\"\");this.errors.push(new Pt(n,t))},Be.prototype.checkSubtype=function(t,e){var r=Wt(t,e);return r&&this.error(r),r};var je=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[1];this.labels.push(a[0]),this.outputs.push(o)}};function Ue(t,e,r){return t*(1-r)+e*r}je.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Dt);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new je(i,r,n)},je.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Ne(e,n)].evaluate(t)},je.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},je.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},je.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ve=Object.freeze({__proto__:null,number:Ue,color:function(t,e,r){return new Kt(Ue(t.r,e.r,r),Ue(t.g,e.g,r),Ue(t.b,e.b,r),Ue(t.a,e.a,r))},array:function(t,e,r){return t.map((function(t,n){return Ue(t,e[n],r)}))}}),qe=6/29*3*(6/29),He=Math.PI/180,Ge=180/Math.PI;function Ye(t){return t>.008856451679035631?Math.pow(t,1/3):t/qe+4/29}function We(t){return t>6/29?t*t*t:qe*(t-4/29)}function Xe(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ze(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function Je(t){var e=Ze(t.r),r=Ze(t.g),n=Ze(t.b),i=Ye((.4124564*e+.3575761*r+.1804375*n)/.95047),a=Ye((.2126729*e+.7151522*r+.072175*n)/1);return{l:116*a-16,a:500*(i-a),b:200*(a-Ye((.0193339*e+.119192*r+.9503041*n)/1.08883)),alpha:t.a}}function Ke(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=1*We(e),r=.95047*We(r),n=1.08883*We(n),new Kt(Xe(3.2404542*r-1.5371385*e-.4985314*n),Xe(-.969266*r+1.8760108*e+.041556*n),Xe(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}function Qe(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}var $e={forward:Je,reverse:Ke,interpolate:function(t,e,r){return{l:Ue(t.l,e.l,r),a:Ue(t.a,e.a,r),b:Ue(t.b,e.b,r),alpha:Ue(t.alpha,e.alpha,r)}}},tr={forward:function(t){var e=Je(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Ge;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*He,r=t.c;return Ke({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:Qe(t.h,e.h,r),c:Ue(t.c,e.c,r),l:Ue(t.l,e.l,r),alpha:Ue(t.alpha,e.alpha,r)}}},er=Object.freeze({__proto__:null,lab:$e,hcl:tr}),rr=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[1];this.labels.push(s[0]),this.outputs.push(l)}};function nr(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}rr.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=nr(e,t.base,n,i);else if(\"linear\"===t.name)a=nr(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(nr(e,1,n,i))}return a},rr.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some((function(t){return\"number\"!=typeof t||t<0||t>1})))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Dt)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Bt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var f=a[u],h=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof f)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=f)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(h,d,c);if(!g)return null;c=c||g.type,l.push([f,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new rr(c,r,n,i,l):e.error(\"Type \"+Gt(c)+\" is not interpolatable.\")},rr.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Ne(e,n),o=rr.interpolationFactor(this.interpolation,n,e[a],e[a+1]),s=r[a].evaluate(t),l=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ve[this.type.kind.toLowerCase()](s,l,o):\"interpolate-hcl\"===this.operator?tr.reverse(tr.interpolate(tr.forward(s),tr.forward(l),o)):$e.reverse($e.interpolate($e.forward(s),$e.forward(l),o))},rr.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},rr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},rr.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var ir=function(t,e){this.type=t,this.args=e};ir.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=e.parse(o[a],1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!s)return null;r=r||s.type,i.push(s)}var l=n&&i.some((function(t){return Wt(n,t.type)}));return new ir(l?jt:r,i)},ir.prototype.evaluate=function(t){for(var e,r=null,n=0,i=0,a=this.args;i<a.length&&(n++,(r=a[i].evaluate(t))&&r instanceof ee&&!r.available&&(e||(e=r.name),r=null,n===this.args.length&&(r=e)),null===r);i+=1);return r},ir.prototype.eachChild=function(t){this.args.forEach(t)},ir.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ir.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var ar=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};ar.prototype.evaluate=function(t){return this.result.evaluate(t)},ar.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},ar.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new ar(r,o):null},ar.prototype.outputDefined=function(){return this.result.outputDefined()},ar.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e];t.push(n[0],n[1].serialize())}return t.push(this.result.serialize()),t};var or=function(t,e,r){this.type=t,this.index=e,this.input=r};or.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Dt),n=e.parse(t[2],2,Ht(e.expectedType||jt));return r&&n?new or(n.type.itemType,r,n):null},or.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new se(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new se(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new se(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},or.prototype.eachChild=function(t){t(this.index),t(this.input)},or.prototype.outputDefined=function(){return!1},or.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var sr=function(t,e){this.type=Ft,this.needle=t,this.haystack=e};sr.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,jt);return r&&n?Xt(r.type,[Ft,Rt,Dt,Ot,jt])?new sr(r,n):e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(r.type)+\" instead\"):null},sr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!r)return!1;if(!Zt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new se(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(ie(e))+\" instead.\");if(!Zt(r,[\"string\",\"array\"]))throw new se(\"Expected second argument to be of type array or string, but found \"+Gt(ie(r))+\" instead.\");return r.indexOf(e)>=0},sr.prototype.eachChild=function(t){t(this.needle),t(this.haystack)},sr.prototype.outputDefined=function(){return!0},sr.prototype.serialize=function(){return[\"in\",this.needle.serialize(),this.haystack.serialize()]};var lr=function(t,e,r){this.type=Dt,this.needle=t,this.haystack=e,this.fromIndex=r};lr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,jt);if(!r||!n)return null;if(!Xt(r.type,[Ft,Rt,Dt,Ot,jt]))return e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Dt);return i?new lr(r,n,i):null}return new lr(r,n)},lr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!Zt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new se(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(ie(e))+\" instead.\");if(!Zt(r,[\"string\",\"array\"]))throw new se(\"Expected second argument to be of type array or string, but found \"+Gt(ie(r))+\" instead.\");if(this.fromIndex){var n=this.fromIndex.evaluate(t);return r.indexOf(e,n)}return r.indexOf(e)},lr.prototype.eachChild=function(t){t(this.needle),t(this.haystack),this.fromIndex&&t(this.fromIndex)},lr.prototype.outputDefined=function(){return!1},lr.prototype.serialize=function(){if(null!=this.fromIndex&&void 0!==this.fromIndex){var t=this.fromIndex.serialize();return[\"index-of\",this.needle.serialize(),this.haystack.serialize(),t]}return[\"index-of\",this.needle.serialize(),this.haystack.serialize()]};var cr=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};cr.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,f=s;u<f.length;u+=1){var h=f[u];if(\"number\"!=typeof h&&\"string\"!=typeof h)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof h&&Math.abs(h)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof h&&Math.floor(h)!==h)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,ie(h)))return null}else r=ie(h);if(void 0!==i[String(h)])return c.error(\"Branch labels must be unique.\");i[String(h)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,jt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new cr(r,n,d,i,a,g):null},cr.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(ie(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},cr.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},cr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))&&this.otherwise.outputDefined()},cr.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(f=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[f][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],f=u[0],h=u[1];e.push(1===h.length?s(h[0]):h.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var ur=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};ur.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Ft);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new ur(r,n,s):null},ur.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[1];if(n[0].evaluate(t))return i.evaluate(t)}return this.otherwise.evaluate(t)},ur.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[1];t(n[0]),t(i)}t(this.otherwise)},ur.prototype.outputDefined=function(){return this.branches.every((function(t){return t[1].outputDefined()}))&&this.otherwise.outputDefined()},ur.prototype.serialize=function(){var t=[\"case\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var fr=function(t,e,r,n){this.type=t,this.input=e,this.beginIndex=r,this.endIndex=n};function hr(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function pr(t,e,r,n){return 0===n.compare(e,r)}function dr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Ft,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,jt);if(!a)return null;if(!hr(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Gt(a.type)+\"'.\");var o=e.parse(t[2],2,jt);if(!o)return null;if(!hr(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Gt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Gt(a.type)+\"' and '\"+Gt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new ce(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new ce(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Ut)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=ie(a),l=ie(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new se('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=ie(a),u=ie(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.outputDefined=function(){return!0},i.prototype.serialize=function(){var e=[t];return this.eachChild((function(t){e.push(t.serialize())})),e},i}()}fr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,Dt);if(!r||!n)return null;if(!Xt(r.type,[Ht(jt),Rt,jt]))return e.error(\"Expected first argument to be of type array or string, but found \"+Gt(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Dt);return i?new fr(r.type,r,n,i):null}return new fr(r.type,r,n)},fr.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=this.beginIndex.evaluate(t);if(!Zt(e,[\"string\",\"array\"]))throw new se(\"Expected first argument to be of type array or string, but found \"+Gt(ie(e))+\" instead.\");if(this.endIndex){var n=this.endIndex.evaluate(t);return e.slice(r,n)}return e.slice(r)},fr.prototype.eachChild=function(t){t(this.input),t(this.beginIndex),this.endIndex&&t(this.endIndex)},fr.prototype.outputDefined=function(){return!1},fr.prototype.serialize=function(){if(null!=this.endIndex&&void 0!==this.endIndex){var t=this.endIndex.serialize();return[\"slice\",this.input.serialize(),this.beginIndex.serialize(),t]}return[\"slice\",this.input.serialize(),this.beginIndex.serialize()]};var gr=dr(\"==\",(function(t,e,r){return e===r}),pr),mr=dr(\"!=\",(function(t,e,r){return e!==r}),(function(t,e,r,n){return!pr(0,e,r,n)})),vr=dr(\"<\",(function(t,e,r){return e<r}),(function(t,e,r,n){return n.compare(e,r)<0})),yr=dr(\">\",(function(t,e,r){return e>r}),(function(t,e,r,n){return n.compare(e,r)>0})),xr=dr(\"<=\",(function(t,e,r){return e<=r}),(function(t,e,r,n){return n.compare(e,r)<=0})),br=dr(\">=\",(function(t,e,r){return e>=r}),(function(t,e,r,n){return n.compare(e,r)>=0})),_r=function(t,e,r,n,i){this.type=Rt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};_r.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Dt);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Rt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Rt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Dt)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Dt))?null:new _r(r,i,a,o,s)},_r.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},_r.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},_r.prototype.outputDefined=function(){return!1},_r.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var wr=function(t){this.type=Dt,this.input=t};wr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Gt(r.type)+\" instead.\"):new wr(r):null},wr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new se(\"Expected value to be of type string or array, but found \"+Gt(ie(e))+\" instead.\")},wr.prototype.eachChild=function(t){t(this.input)},wr.prototype.outputDefined=function(){return!1},wr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var Tr={\"==\":gr,\"!=\":mr,\">\":yr,\"<\":vr,\">=\":br,\"<=\":xr,array:ce,at:or,boolean:ce,case:ur,coalesce:ir,collator:ve,format:ue,image:fe,in:sr,\"index-of\":lr,interpolate:rr,\"interpolate-hcl\":rr,\"interpolate-lab\":rr,length:wr,let:ar,literal:oe,match:cr,number:ce,\"number-format\":_r,object:ce,slice:fr,step:je,string:ce,\"to-boolean\":pe,\"to-color\":pe,\"to-number\":pe,\"to-string\":pe,var:Fe,within:ze};function kr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=re(r,n,i,o);if(s)throw new se(s);return new Kt(r/255*o,n/255*o,i/255*o,o)}function Mr(t,e){return t in e}function Ar(t,e){var r=e[t];return void 0===r?null:r}function Sr(t){return{type:t}}function Er(t){return{result:\"success\",value:t}}function Cr(t){return{result:\"error\",value:t}}function Lr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function Ir(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function Pr(t){return!!t.expression&&t.expression.interpolated}function zr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function Or(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Dr(t){return t}function Rr(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Fr(t,e,r,n,i){return Rr(typeof r===i?n[r]:void 0,t.default,e.default)}function Br(t,e,r){if(\"number\"!==zr(r))return Rr(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Ne(t.stops.map((function(t){return t[0]})),r);return t.stops[i][1]}function Nr(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==zr(r))return Rr(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Ne(t.stops.map((function(t){return t[0]})),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ve[e.type]||Dr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=er[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function jr(t,e,r){return\"color\"===e.type?r=Kt.parse(r):\"formatted\"===e.type?r=te.fromString(r.toString()):\"resolvedImage\"===e.type?r=ee.fromString(r.toString()):zr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Rr(r,t.default,e.default)}me.register(Tr,{error:[{kind:\"error\"},[Rt],function(t,e){throw new se(e[0].evaluate(t))}],typeof:[Rt,[jt],function(t,e){return Gt(ie(e[0].evaluate(t)))}],\"to-rgba\":[Ht(Dt,4),[Bt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Bt,[Dt,Dt,Dt],kr],rgba:[Bt,[Dt,Dt,Dt,Dt],kr],has:{type:Ft,overloads:[[[Rt],function(t,e){return Mr(e[0].evaluate(t),t.properties())}],[[Rt,Nt],function(t,e){var r=e[1];return Mr(e[0].evaluate(t),r.evaluate(t))}]]},get:{type:jt,overloads:[[[Rt],function(t,e){return Ar(e[0].evaluate(t),t.properties())}],[[Rt,Nt],function(t,e){var r=e[1];return Ar(e[0].evaluate(t),r.evaluate(t))}]]},\"feature-state\":[jt,[Rt],function(t,e){return Ar(e[0].evaluate(t),t.featureState||{})}],properties:[Nt,[],function(t){return t.properties()}],\"geometry-type\":[Rt,[],function(t){return t.geometryType()}],id:[jt,[],function(t){return t.id()}],zoom:[Dt,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Dt,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Dt,[],function(t){return t.globals.lineProgress||0}],accumulated:[jt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Dt,Sr(Dt),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Dt,Sr(Dt),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Dt,overloads:[[[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)-r.evaluate(t)}],[[Dt],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)/r.evaluate(t)}],\"%\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)%r.evaluate(t)}],ln2:[Dt,[],function(){return Math.LN2}],pi:[Dt,[],function(){return Math.PI}],e:[Dt,[],function(){return Math.E}],\"^\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return Math.pow(e[0].evaluate(t),r.evaluate(t))}],sqrt:[Dt,[Dt],function(t,e){return Math.sqrt(e[0].evaluate(t))}],log10:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))/Math.LN10}],ln:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))}],log2:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))/Math.LN2}],sin:[Dt,[Dt],function(t,e){return Math.sin(e[0].evaluate(t))}],cos:[Dt,[Dt],function(t,e){return Math.cos(e[0].evaluate(t))}],tan:[Dt,[Dt],function(t,e){return Math.tan(e[0].evaluate(t))}],asin:[Dt,[Dt],function(t,e){return Math.asin(e[0].evaluate(t))}],acos:[Dt,[Dt],function(t,e){return Math.acos(e[0].evaluate(t))}],atan:[Dt,[Dt],function(t,e){return Math.atan(e[0].evaluate(t))}],min:[Dt,Sr(Dt),function(t,e){return Math.min.apply(Math,e.map((function(e){return e.evaluate(t)})))}],max:[Dt,Sr(Dt),function(t,e){return Math.max.apply(Math,e.map((function(e){return e.evaluate(t)})))}],abs:[Dt,[Dt],function(t,e){return Math.abs(e[0].evaluate(t))}],round:[Dt,[Dt],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Dt,[Dt],function(t,e){return Math.floor(e[0].evaluate(t))}],ceil:[Dt,[Dt],function(t,e){return Math.ceil(e[0].evaluate(t))}],\"filter-==\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Ft,[jt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Ft,[Rt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Ft,[jt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Ft,[],function(t){return null!==t.id()&&void 0!==t.id()}],\"filter-type-in\":[Ft,[Ht(Rt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Ft,[Ht(jt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Ft,[Rt,Ht(jt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Ft,[Rt,Ht(jt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Ft,overloads:[[[Ft,Ft],function(t,e){var r=e[1];return e[0].evaluate(t)&&r.evaluate(t)}],[Sr(Ft),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Ft,overloads:[[[Ft,Ft],function(t,e){var r=e[1];return e[0].evaluate(t)||r.evaluate(t)}],[Sr(Ft),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Ft,[Ft],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Ft,[Rt],function(t,e){var r=t.globals&&t.globals.isSupportedScript;return!r||r(e[0].evaluate(t))}],upcase:[Rt,[Rt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Rt,[Rt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Rt,Sr(jt),function(t,e){return e.map((function(e){return ae(e.evaluate(t))})).join(\"\")}],\"resolved-locale\":[Rt,[Ut],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Ur=function(t,e){this.expression=t,this._warningHistory={},this._evaluator=new ge,this._defaultValue=e?function(t){return\"color\"===t.type&&Or(t.default)?new Kt(0,0,0,0):\"color\"===t.type?Kt.parse(t.default)||null:void 0===t.default?null:t.default}(e):null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Vr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in Tr}function qr(t,e){var r=new Be(Tr,[],e?function(t){var e={color:Bt,string:Rt,number:Dt,enum:Rt,boolean:Ft,formatted:Vt,resolvedImage:qt};return\"array\"===t.type?Ht(e[t.value]||jt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?Er(new Ur(n,e)):Cr(r.errors)}Ur.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a,this.expression.evaluate(this._evaluator)},Ur.prototype.evaluate=function(t,e,r,n,i,a){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a||null;try{var o=this.expression.evaluate(this._evaluator);if(null==o||\"number\"==typeof o&&o!=o)return this._defaultValue;if(this._enumValues&&!(o in this._enumValues))throw new se(\"Expected value to be one of \"+Object.keys(this._enumValues).map((function(t){return JSON.stringify(t)})).join(\", \")+\", but found \"+JSON.stringify(o)+\" instead.\");return o}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var Hr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!De(e.expression)};Hr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},Hr.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)};var Gr=function(t,e,r,n){this.kind=t,this.zoomStops=r,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!De(e.expression),this.interpolationType=n};function Yr(t,e){if(\"error\"===(t=qr(t,e)).result)return t;var r=t.value.expression,n=Oe(r);if(!n&&!Lr(e))return Cr([new Pt(\"\",\"data expressions not supported\")]);var i=Re(r,[\"zoom\"]);if(!i&&!Ir(e))return Cr([new Pt(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof ar)r=t(e.result);else if(e instanceof ir)for(var n=0,i=e.args;n<i.length&&!(r=t(i[n]));n+=1);else(e instanceof je||e instanceof rr)&&e.input instanceof me&&\"zoom\"===e.input.name&&(r=e);return r instanceof Pt||e.eachChild((function(e){var n=t(e);n instanceof Pt?r=n:!r&&n?r=new Pt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Pt(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))})),r}(r);return a||i?a instanceof Pt?Cr([a]):a instanceof rr&&!Pr(e)?Cr([new Pt(\"\",'\"interpolate\" expressions cannot be used with this property')]):Er(a?new Gr(n?\"camera\":\"composite\",t.value,a.labels,a instanceof rr?a.interpolation:void 0):new Hr(n?\"constant\":\"source\",t.value)):Cr([new Pt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Gr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},Gr.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)},Gr.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?rr.interpolationFactor(this.interpolationType,t,e,r):0};var Wr=function(t,e){this._parameters=t,this._specification=e,Ct(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||!(s||void 0!==e.property),c=e.type||(Pr(r)?\"exponential\":\"interval\");if(o&&((e=Ct({},e)).stops&&(e.stops=e.stops.map((function(t){return[t[0],Kt.parse(t[1])]}))),e.default=Kt.parse(e.default?e.default:r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!er[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===c)n=Nr;else if(\"interval\"===c)n=Br;else if(\"categorical\"===c){n=Fr,i=Object.create(null);for(var u=0,f=e.stops;u<f.length;u+=1){var h=f[u];i[h[0]]=h[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==c)throw new Error('Unknown function type \"'+c+'\"');n=jr}if(s){for(var p={},d=[],g=0;g<e.stops.length;g++){var m=e.stops[g],v=m[0].zoom;void 0===p[v]&&(p[v]={zoom:v,type:e.type,property:e.property,default:e.default,stops:[]},d.push(v)),p[v].stops.push([m[0].value,m[1]])}for(var y=[],x=0,b=d;x<b.length;x+=1){var _=b[x];y.push([p[_].zoom,t(p[_],r)])}var w={name:\"linear\"};return{kind:\"composite\",interpolationType:w,interpolationFactor:rr.interpolationFactor.bind(void 0,w),zoomStops:y.map((function(t){return t[0]})),evaluate:function(t,n){var i=t.zoom;return Nr({stops:y,base:e.base},r,i).evaluate(i,n)}}}if(l){var T=\"exponential\"===c?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:rr.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map((function(t){return t[0]})),evaluate:function(t){return n(e,r,t.zoom,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Rr(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Xr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=zr(r);if(\"object\"!==l)return[new St(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],f=n[u]||n[\"*\"],h=void 0;if(i[u])h=i[u];else if(n[u])h=bn;else if(i[\"*\"])h=i[\"*\"];else{if(!n[\"*\"]){s.push(new St(e,r[c],'unknown property \"'+c+'\"'));continue}h=bn}s=s.concat(h({key:(e?e+\".\":e)+c,value:r[c],valueSpec:f,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new St(e,r,'missing required property \"'+p+'\"'));return s}function Zr(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||bn;if(\"array\"!==zr(e))return[new St(a,e,\"array expected, \"+zr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new St(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new St(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===zr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Jr(t){var e=t.key,r=t.value,n=t.valueSpec,i=zr(r);return\"number\"===i&&r!=r&&(i=\"NaN\"),\"number\"!==i?[new St(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new St(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new St(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function Kr(t){var e,r,n,i=t.valueSpec,a=Lt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===zr(t.value.stops)&&\"array\"===zr(t.value.stops[0])&&\"object\"===zr(t.value.stops[0][0]),u=Xr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new St(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Zr({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:f})),\"array\"===zr(r)&&0===r.length&&e.push(new St(t.key,r,\"array must have at least one stop\")),e},default:function(t){return bn({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new St(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new St(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!Pr(t.valueSpec)&&u.push(new St(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!Lr(t.valueSpec)?u.push(new St(t.key,t.value,\"property functions not supported\")):s&&!Ir(t.valueSpec)&&u.push(new St(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new St(t.key,t.value,'\"property\" property is required')),u;function f(t){var e=[],a=t.value,s=t.key;if(\"array\"!==zr(a))return[new St(s,a,\"array expected, \"+zr(a)+\" found\")];if(2!==a.length)return[new St(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==zr(a[0]))return[new St(s,a,\"object expected, \"+zr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new St(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new St(s,a,\"object stop key must have value\")];if(n&&n>Lt(a[0].zoom))return[new St(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Lt(a[0].zoom)!==n&&(n=Lt(a[0].zoom),r=void 0,o={}),e=e.concat(Xr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Jr,value:h}}))}else e=e.concat(h({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Vr(It(a[1]))?e.concat([new St(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(bn({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function h(t,n){var s=zr(t.value),l=Lt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new St(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new St(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return Lr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new St(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new St(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new St(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new St(t.key,c,\"integer expected, found \"+l)]}}function Qr(t){var e=(\"property\"===t.expressionContext?Yr:qr)(It(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map((function(e){return new St(\"\"+t.key+e.key,t.value,e.message)}));var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&!r.outputDefined())return[new St(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!De(r))return[new St(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!De(r))return[new St(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!Re(r,[\"zoom\",\"feature-state\"]))return[new St(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!Oe(r))return[new St(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function $r(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Lt(r))&&i.push(new St(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Lt(r))&&i.push(new St(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function tn(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":return t.length>=3&&(\"string\"!=typeof t[1]||Array.isArray(t[2]));case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!tn(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Wr.deserialize=function(t){return new Wr(t._parameters,t._specification)},Wr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var en={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function rn(t){if(null==t)return{filter:function(){return!0},needGeometry:!1};tn(t)||(t=an(t));var e=qr(t,en);if(\"error\"===e.result)throw new Error(e.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return{filter:function(t,r,n){return e.value.evaluate(t,r,{},n)},needGeometry:function t(e){if(!Array.isArray(e))return!1;if(\"within\"===e[0])return!0;for(var r=1;r<e.length;r++)if(t(e[r]))return!0;return!1}(t)}}function nn(t,e){return t<e?-1:t>e?1:0}function an(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?on(t[1],t[2],\"==\"):\"!=\"===r?cn(on(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?on(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(an))):\"all\"===r?[\"all\"].concat(t.slice(1).map(an)):\"none\"===r?[\"all\"].concat(t.slice(1).map(an).map(cn)):\"in\"===r?sn(t[1],t.slice(2)):\"!in\"===r?cn(sn(t[1],t.slice(2))):\"has\"===r?ln(t[1]):\"!has\"===r?cn(ln(t[1])):\"within\"!==r||t}function on(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function sn(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some((function(t){return typeof t!=typeof e[0]}))?[\"filter-in-large\",t,[\"literal\",e.sort(nn)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function ln(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function cn(t){return[\"!\",t]}function un(t){return tn(It(t.value))?Qr(Ct({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==zr(r))return[new St(n,r,\"array expected, \"+zr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new St(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat($r({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Lt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Lt(r[1])&&o.push(new St(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new St(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=zr(r[1]))&&o.push(new St(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=zr(r[s]),\"$type\"===Lt(r[1])?o=o.concat($r({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new St(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=zr(r[1]),2!==r.length?o.push(new St(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new St(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));break;case\"within\":i=zr(r[1]),2!==r.length?o.push(new St(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"object\"!==i&&o.push(new St(n+\"[1]\",r[1],\"object expected, \"+i+\" found\"))}return o}(t)}function fn(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return bn({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new St(r,a,'unknown property \"'+o+'\"')];if(\"string\"===zr(a)&&Lr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new St(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var f=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&f.push(new St(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&Or(It(a))&&\"identity\"===Lt(a.type)&&f.push(new St(r,a,'\"text-font\" does not support identity functions'))),f.concat(bn({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function hn(t){return fn(t,\"paint\")}function pn(t){return fn(t,\"layout\")}function dn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new St(n,r,'either \"type\" or \"ref\" is required'));var o,s=Lt(r.type),l=Lt(r.ref);if(r.id)for(var c=Lt(r.id),u=0;u<t.arrayIndex;u++){var f=i.layers[u];Lt(f.id)===c&&e.push(new St(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+f.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach((function(t){t in r&&e.push(new St(n,r[t],'\"'+t+'\" is prohibited for ref layers'))})),i.layers.forEach((function(t){Lt(t.id)===l&&(o=t)})),o?o.ref?e.push(new St(n,r.ref,\"ref cannot reference another ref layer\")):s=Lt(o.type):e.push(new St(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var h=i.sources&&i.sources[r.source],p=h&&Lt(h.type);h?\"vector\"===p&&\"raster\"===s?e.push(new St(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new St(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new St(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&h.lineMetrics||e.push(new St(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new St(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new St(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new St(n,r,'missing required property \"source\"'));return e=e.concat(Xr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return bn({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:un,layout:function(t){return Xr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return pn(Ct({layerType:s},t))}}})},paint:function(t){return Xr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return hn(Ct({layerType:s},t))}}})}}}))}function gn(t){var e=t.value,r=t.key,n=zr(e);return\"string\"!==n?[new St(r,e,\"string expected, \"+n+\" found\")]:[]}var mn={promoteId:function(t){var e=t.key,r=t.value;if(\"string\"===zr(r))return gn({key:e,value:r});var n=[];for(var i in r)n.push.apply(n,gn({key:e+\".\"+i,value:r[i]}));return n}};function vn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new St(r,e,'\"type\" is required')];var a,o=Lt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":return Xr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n,objectElementValidators:mn});case\"geojson\":if(a=Xr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n,objectElementValidators:mn}),e.cluster)for(var s in e.clusterProperties){var l=e.clusterProperties[s],c=l[0],u=\"string\"==typeof c?[c,[\"accumulated\"],[\"get\",s]]:c;a.push.apply(a,Qr({key:r+\".\"+s+\".map\",value:l[1],expressionContext:\"cluster-map\"})),a.push.apply(a,Qr({key:r+\".\"+s+\".reduce\",value:u,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Xr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Xr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new St(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return $r({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function yn(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=zr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new St(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=a.concat(l&&n[l[1]]&&n[l[1]].transition?bn({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r}):n[s]?bn({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r}):[new St(s,e[s],'unknown property \"'+s+'\"')])}return a}var xn={\"*\":function(){return[]},array:Zr,boolean:function(t){var e=t.value,r=t.key,n=zr(e);return\"boolean\"!==n?[new St(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Jr,color:function(t){var e=t.key,r=t.value,n=zr(r);return\"string\"!==n?[new St(e,r,\"color expected, \"+n+\" found\")]:null===Jt(r)?[new St(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Et,enum:$r,filter:un,function:Kr,layer:dn,object:Xr,source:vn,light:yn,string:gn,formatted:function(t){return 0===gn(t).length?[]:Qr(t)},resolvedImage:function(t){return 0===gn(t).length?[]:Qr(t)}};function bn(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&Or(Lt(e))?Kr(t):r.expression&&Vr(It(e))?Qr(t):r.type&&xn[r.type]?xn[r.type](t):Xr(Ct({},t,{valueSpec:r.type?n[r.type]:r}))}function _n(t){var e=t.value,r=t.key,n=gn(t);return n.length||(-1===e.indexOf(\"{fontstack}\")&&n.push(new St(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new St(r,e,'\"glyphs\" url must include a \"{range}\" token'))),n}function wn(t,e){void 0===e&&(e=At);var r=[];return r=r.concat(bn({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:_n,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Et({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),Tn(r)}function Tn(t){return[].concat(t).sort((function(t,e){return t.line-e.line}))}function kn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return Tn(t.apply(this,e))}}wn.source=kn(vn),wn.light=kn(yn),wn.layer=kn(dn),wn.filter=kn(un),wn.paintProperty=kn(hn),wn.layoutProperty=kn(pn);var Mn=wn,An=Mn.light,Sn=Mn.paintProperty,En=Mn.layoutProperty;function Cn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1)t.fire(new kt(new Error(i[n].message))),r=!0;return r}var Ln=In;function In(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],this.d=(e=i[1])+2*(r=i[2]);for(var a=0;a<this.d*this.d;a++){var o=i[3+a],s=i[3+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[3+n.length+1];this.keys=i.subarray(i[3+n.length],l),this.bboxes=i.subarray(l),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var c=0;c<this.d*this.d;c++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var u=r/e*t;this.min=-u,this.max=t+u}In.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},In.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},In.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},In.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},In.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,f=0;f<l.length;f++){var h=l[f];if(void 0===o[h]){var p=4*h;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[h]=!0,a.push(c[h])):o[h]=!1}}},In.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),f=this._convertToCellCoord(n),h=l;h<=u;h++)for(var p=c;p<=f;p++){var d=this.d*p+h;if((!s||s(this._convertFromCellCoord(h),this._convertFromCellCoord(p),this._convertFromCellCoord(h+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},In.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},In.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},In.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=3+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[3+o]=a,i.set(s,a),a+=s.length}return i[3+t.length]=a,i.set(this.keys,a),i[3+t.length+1]=a+=this.keys.length,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var Pn=self.ImageData,zn=self.ImageBitmap,On={};function Dn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),On[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Rn in Dn(\"Object\",Object),Ln.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},Ln.deserialize=function(t){return new Ln(t.buffer)},Dn(\"Grid\",Ln),Dn(\"Color\",Kt),Dn(\"Error\",Error),Dn(\"ResolvedImage\",ee),Dn(\"StylePropertyFunction\",Wr),Dn(\"StyleExpression\",Ur,{omit:[\"_evaluator\"]}),Dn(\"ZoomDependentExpression\",Gr),Dn(\"ZoomConstantExpression\",Hr),Dn(\"CompoundExpression\",me,{omit:[\"_evaluate\"]}),Tr)Tr[Rn]._classRegistryKey||Dn(\"Expression_\"+Rn,Tr[Rn]);function Fn(t){return t&&\"undefined\"!=typeof ArrayBuffer&&(t instanceof ArrayBuffer||t.constructor&&\"ArrayBuffer\"===t.constructor.name)}function Bn(t){return zn&&t instanceof zn}function Nn(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(Fn(t)||Bn(t))return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof Pn)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1)n.push(Nn(a[i],e));return n}if(\"object\"==typeof t){var o=t.constructor,s=o._classRegistryKey;if(!s)throw new Error(\"can't serialize object of unregistered class\");var l=o.serialize?o.serialize(t,e):{};if(!o.serialize){for(var c in t)if(t.hasOwnProperty(c)&&!(On[s].omit.indexOf(c)>=0)){var u=t[c];l[c]=On[s].shallow.indexOf(c)>=0?u:Nn(u,e)}t instanceof Error&&(l.message=t.message)}if(l.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==s&&(l.$name=s),l}throw new Error(\"can't serialize object of type \"+typeof t)}function jn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||Fn(t)||Bn(t)||ArrayBuffer.isView(t)||t instanceof Pn)return t;if(Array.isArray(t))return t.map(jn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=On[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=On[e].shallow.indexOf(o)>=0?s:jn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Un=function(){this.first=!0};Un.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var Vn={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function qn(t){for(var e=0,r=t;e<r.length;e+=1)if(Hn(r[e].charCodeAt(0)))return!0;return!1}function Hn(t){return!(746!==t&&747!==t&&(t<4352||!(Vn[\"Bopomofo Extended\"](t)||Vn.Bopomofo(t)||Vn[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||Vn[\"CJK Compatibility Ideographs\"](t)||Vn[\"CJK Compatibility\"](t)||Vn[\"CJK Radicals Supplement\"](t)||Vn[\"CJK Strokes\"](t)||!(!Vn[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||Vn[\"CJK Unified Ideographs Extension A\"](t)||Vn[\"CJK Unified Ideographs\"](t)||Vn[\"Enclosed CJK Letters and Months\"](t)||Vn[\"Hangul Compatibility Jamo\"](t)||Vn[\"Hangul Jamo Extended-A\"](t)||Vn[\"Hangul Jamo Extended-B\"](t)||Vn[\"Hangul Jamo\"](t)||Vn[\"Hangul Syllables\"](t)||Vn.Hiragana(t)||Vn[\"Ideographic Description Characters\"](t)||Vn.Kanbun(t)||Vn[\"Kangxi Radicals\"](t)||Vn[\"Katakana Phonetic Extensions\"](t)||Vn.Katakana(t)&&12540!==t||!(!Vn[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!Vn[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||Vn[\"Unified Canadian Aboriginal Syllabics\"](t)||Vn[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||Vn[\"Vertical Forms\"](t)||Vn[\"Yijing Hexagram Symbols\"](t)||Vn[\"Yi Syllables\"](t)||Vn[\"Yi Radicals\"](t))))}function Gn(t){return!(Hn(t)||function(t){return!!(Vn[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||Vn[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||Vn[\"Letterlike Symbols\"](t)||Vn[\"Number Forms\"](t)||Vn[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||Vn[\"Control Pictures\"](t)&&9251!==t||Vn[\"Optical Character Recognition\"](t)||Vn[\"Enclosed Alphanumerics\"](t)||Vn[\"Geometric Shapes\"](t)||Vn[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||Vn[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||Vn[\"CJK Symbols and Punctuation\"](t)||Vn.Katakana(t)||Vn[\"Private Use Area\"](t)||Vn[\"CJK Compatibility Forms\"](t)||Vn[\"Small Form Variants\"](t)||Vn[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function Yn(t){return t>=1424&&t<=2303||Vn[\"Arabic Presentation Forms-A\"](t)||Vn[\"Arabic Presentation Forms-B\"](t)}function Wn(t,e){return!(!e&&Yn(t)||t>=2304&&t<=3583||t>=3840&&t<=4255||Vn.Khmer(t))}function Xn(t){for(var e=0,r=t;e<r.length;e+=1)if(Yn(r[e].charCodeAt(0)))return!0;return!1}var Zn=null,Jn=\"unavailable\",Kn=null,Qn=function(t){t&&\"string\"==typeof t&&t.indexOf(\"NetworkError\")>-1&&(Jn=\"error\"),Zn&&Zn(t)};function $n(){ti.fire(new Tt(\"pluginStateChange\",{pluginStatus:Jn,pluginURL:Kn}))}var ti=new Mt,ei=function(){return Jn},ri=function(){if(\"deferred\"!==Jn||!Kn)throw new Error(\"rtl-text-plugin cannot be downloaded unless a pluginURL is specified\");Jn=\"loading\",$n(),Kn&&yt({url:Kn},(function(t){t?Qn(t):(Jn=\"loaded\",$n())}))},ni={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return\"loaded\"===Jn||null!=ni.applyArabicShaping},isLoading:function(){return\"loading\"===Jn},setState:function(t){Jn=t.pluginStatus,Kn=t.pluginURL},isParsed:function(){return null!=ni.applyArabicShaping&&null!=ni.processBidirectionalText&&null!=ni.processStyledBidirectionalText},getPluginURL:function(){return Kn}},ii=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Un,this.transition={})};ii.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!Wn(n[r].charCodeAt(0),e))return!1;return!0}(t,ni.isLoaded())},ii.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},ii.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var ai=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(Or(t))return new Wr(t,e);if(Vr(t)){var r=Yr(t,e);if(\"error\"===r.result)throw new Error(r.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=Kt.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};ai.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},ai.prototype.possiblyEvaluate=function(t,e,r){return this.property.possiblyEvaluate(this,t,e,r)};var oi=function(t){this.property=t,this.value=new ai(t,void 0)};oi.prototype.transitioned=function(t,e){return new li(this.property,this.value,e,u({},t.transition,this.transition),t.now)},oi.prototype.untransitioned=function(){return new li(this.property,this.value,null,{},0)};var si=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};si.prototype.getValue=function(t){return x(this._values[t].value.value)},si.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new oi(this._values[t].property)),this._values[t].value=new ai(this._values[t].property,null===e?void 0:x(e))},si.prototype.getTransition=function(t){return x(this._values[t].transition)},si.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new oi(this._values[t].property)),this._values[t].transition=x(e)||void 0},si.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},si.prototype.transitioned=function(t,e){for(var r=new ci(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},si.prototype.untransitioned=function(){for(var t=new ci(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var li=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};li.prototype.possiblyEvaluate=function(t,e,r){var n=t.now||0,i=this.value.possiblyEvaluate(t,e,r),a=this.prior;if(a){if(n>this.end)return this.prior=null,i;if(this.value.isDataDriven())return this.prior=null,i;if(n<this.begin)return a.possiblyEvaluate(t,e,r);var o=(n-this.begin)/(this.end-this.begin);return this.property.interpolate(a.possiblyEvaluate(t,e,r),i,function(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}(o))}return i};var ci=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};ci.prototype.possiblyEvaluate=function(t,e,r){for(var n=new hi(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n},ci.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1)if(this._values[e[t]].prior)return!0;return!1};var ui=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};ui.prototype.getValue=function(t){return x(this._values[t].value)},ui.prototype.setValue=function(t,e){this._values[t]=new ai(this._values[t].property,null===e?void 0:x(e))},ui.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},ui.prototype.possiblyEvaluate=function(t,e,r){for(var n=new hi(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n};var fi=function(t,e,r){this.property=t,this.value=e,this.parameters=r};fi.prototype.isConstant=function(){return\"constant\"===this.value.kind},fi.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},fi.prototype.evaluate=function(t,e,r,n){return this.property.evaluate(this.value,this.parameters,t,e,r,n)};var hi=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};hi.prototype.get=function(t){return this._values[t]};var pi=function(t){this.specification=t};pi.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},pi.prototype.interpolate=function(t,e,r){var n=Ve[this.specification.type];return n?n(t,e,r):t};var di=function(t,e){this.specification=t,this.overrides=e};di.prototype.possiblyEvaluate=function(t,e,r,n){return new fi(this,\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?{kind:\"constant\",value:t.expression.evaluate(e,null,{},r,n)}:t.expression,e)},di.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new fi(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ve[this.specification.type];return n?new fi(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},di.prototype.evaluate=function(t,e,r,n,i,a){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n,i,a)};var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0===t.value)return new fi(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n),a=\"resolvedImage\"===t.property.specification.type&&\"string\"!=typeof i?i.name:i,o=this._calculate(a,a,a,e);return new fi(this,{kind:\"constant\",value:o},e)}if(\"camera\"===t.expression.kind){var s=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new fi(this,{kind:\"constant\",value:s},e)}return new fi(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n,i,a){if(\"source\"===t.kind){var o=t.evaluate(e,r,n,i,a);return this._calculate(o,o,o,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(di),mi=function(t){this.specification=t};mi.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n);return this._calculate(i,i,i,e)}return this._calculate(t.expression.evaluate(new ii(Math.floor(e.zoom-1),e)),t.expression.evaluate(new ii(Math.floor(e.zoom),e)),t.expression.evaluate(new ii(Math.floor(e.zoom+1),e)),e)}},mi.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},mi.prototype.interpolate=function(t){return t};var vi=function(t){this.specification=t};vi.prototype.possiblyEvaluate=function(t,e,r,n){return!!t.expression.evaluate(e,null,{},r,n)},vi.prototype.interpolate=function(){return!1};var yi=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},this.overridableProperties=[],t){var r=t[e];r.specification.overridable&&this.overridableProperties.push(e);var n=this.defaultPropertyValues[e]=new ai(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new oi(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};Dn(\"DataDrivenProperty\",di),Dn(\"DataConstantProperty\",pi),Dn(\"CrossFadedDataDrivenProperty\",gi),Dn(\"CrossFadedProperty\",mi),Dn(\"ColorRampProperty\",vi);var xi=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter={filter:function(){return!0},needGeometry:!1},\"custom\"!==e.type&&(this.metadata=(e=e).metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new ui(r.layout)),r.paint)){for(var n in this._transitionablePaint=new si(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned(),this.paint=new hi(r.paint)}}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){void 0===r&&(r={}),null!=e&&this._validate(En,\"layers.\"+this.id+\".layout.\"+t,t,e,r)||(\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e)},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e&&this._validate(Sn,\"layers.\"+this.id+\".paint.\"+t,t,e,r))return!1;if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var n=this._transitionablePaint._values[t],i=\"cross-faded-data-driven\"===n.property.specification[\"property-type\"],a=n.value.isDataDriven(),o=n.value;this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t);var s=this._transitionablePaint._values[t].value;return s.isDataDriven()||a||i||this._handleOverridablePaintPropertyUpdate(t,o,s)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype._handleOverridablePaintPropertyUpdate=function(t,e,r){return!1},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t,e){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t,void 0,e)),this.paint=this._transitioningPaint.possiblyEvaluate(t,void 0,e)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),y(t,(function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)}))},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&Cn(this,t.call(Mn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:At,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof fi&&Lr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(Mt),bi={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},_i=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},wi=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function Ti(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map((function(t){var i=bi[t.type].BYTES_PER_ELEMENT,a=r=ki(r,Math.max(e,i)),o=t.components||1;return n=Math.max(n,i),r+=i*o,{name:t.name,type:t.type,components:o,offset:a}})),size:ki(r,Math.max(n,e)),alignment:e}}function ki(t,e){return Math.ceil(t/e)*e}wi.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},wi.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},wi.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},wi.prototype.clear=function(){this.length=0},wi.prototype.resize=function(t){this.reserve(t),this.length=t},wi.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},wi.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(wi);Mi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout2i4\",Mi);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(wi);Ai.prototype.bytesPerElement=8,Dn(\"StructArrayLayout4i8\",Ai);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(wi);Si.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2i4i12\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(wi);Ei.prototype.bytesPerElement=8,Dn(\"StructArrayLayout2i4ub8\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c){var u=this.length;return this.resize(u+1),this.emplace(u,t,e,r,n,i,a,o,s,l,c)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u){var f=9*t,h=18*t;return this.uint16[f+0]=e,this.uint16[f+1]=r,this.uint16[f+2]=n,this.uint16[f+3]=i,this.uint16[f+4]=a,this.uint16[f+5]=o,this.uint16[f+6]=s,this.uint16[f+7]=l,this.uint8[h+16]=c,this.uint8[h+17]=u,t},e}(wi);Ci.prototype.bytesPerElement=18,Dn(\"StructArrayLayout8ui2ub18\",Ci);var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u,f)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h){var p=12*t;return this.int16[p+0]=e,this.int16[p+1]=r,this.int16[p+2]=n,this.int16[p+3]=i,this.uint16[p+4]=a,this.uint16[p+5]=o,this.uint16[p+6]=s,this.uint16[p+7]=l,this.int16[p+8]=c,this.int16[p+9]=u,this.int16[p+10]=f,this.int16[p+11]=h,t},e}(wi);Li.prototype.bytesPerElement=24,Dn(\"StructArrayLayout4i4ui4i24\",Li);var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(wi);Ii.prototype.bytesPerElement=12,Dn(\"StructArrayLayout3f12\",Ii);var Pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.uint32[1*t+0]=e,t},e}(wi);Pi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout1ul4\",Pi);var zi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l){var c=this.length;return this.resize(c+1),this.emplace(c,t,e,r,n,i,a,o,s,l)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c){var u=10*t,f=5*t;return this.int16[u+0]=e,this.int16[u+1]=r,this.int16[u+2]=n,this.int16[u+3]=i,this.int16[u+4]=a,this.int16[u+5]=o,this.uint32[f+3]=s,this.uint16[u+8]=l,this.uint16[u+9]=c,t},e}(wi);zi.prototype.bytesPerElement=20,Dn(\"StructArrayLayout6i1ul2ui20\",zi);var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(wi);Oi.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2i2i2i12\",Oi);var Di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n,i)},e.prototype.emplace=function(t,e,r,n,i,a){var o=4*t,s=8*t;return this.float32[o+0]=e,this.float32[o+1]=r,this.float32[o+2]=n,this.int16[s+6]=i,this.int16[s+7]=a,t},e}(wi);Di.prototype.bytesPerElement=16,Dn(\"StructArrayLayout2f1f2i16\",Di);var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(wi);Ri.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2ub2f12\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(wi);Fi.prototype.bytesPerElement=6,Dn(\"StructArrayLayout3ui6\",Fi);var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m){var v=this.length;return this.resize(v+1),this.emplace(v,t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v){var y=24*t,x=12*t,b=48*t;return this.int16[y+0]=e,this.int16[y+1]=r,this.uint16[y+2]=n,this.uint16[y+3]=i,this.uint32[x+2]=a,this.uint32[x+3]=o,this.uint32[x+4]=s,this.uint16[y+10]=l,this.uint16[y+11]=c,this.uint16[y+12]=u,this.float32[x+7]=f,this.float32[x+8]=h,this.uint8[b+36]=p,this.uint8[b+37]=d,this.uint8[b+38]=g,this.uint32[x+10]=m,this.int16[y+22]=v,t},e}(wi);Bi.prototype.bytesPerElement=48,Dn(\"StructArrayLayout2i2ui3ul3ui2f3ub1ul1i48\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S){var E=this.length;return this.resize(E+1),this.emplace(E,t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S,E){var C=34*t,L=17*t;return this.int16[C+0]=e,this.int16[C+1]=r,this.int16[C+2]=n,this.int16[C+3]=i,this.int16[C+4]=a,this.int16[C+5]=o,this.int16[C+6]=s,this.int16[C+7]=l,this.uint16[C+8]=c,this.uint16[C+9]=u,this.uint16[C+10]=f,this.uint16[C+11]=h,this.uint16[C+12]=p,this.uint16[C+13]=d,this.uint16[C+14]=g,this.uint16[C+15]=m,this.uint16[C+16]=v,this.uint16[C+17]=y,this.uint16[C+18]=x,this.uint16[C+19]=b,this.uint16[C+20]=_,this.uint16[C+21]=w,this.uint16[C+22]=T,this.uint32[L+12]=k,this.float32[L+13]=M,this.float32[L+14]=A,this.float32[L+15]=S,this.float32[L+16]=E,t},e}(wi);Ni.prototype.bytesPerElement=68,Dn(\"StructArrayLayout8i15ui1ul4f68\",Ni);var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.float32[1*t+0]=e,t},e}(wi);ji.prototype.bytesPerElement=4,Dn(\"StructArrayLayout1f4\",ji);var Ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(wi);Ui.prototype.bytesPerElement=6,Dn(\"StructArrayLayout3i6\",Ui);var Vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=4*t;return this.uint32[2*t+0]=e,this.uint16[i+2]=r,this.uint16[i+3]=n,t},e}(wi);Vi.prototype.bytesPerElement=8,Dn(\"StructArrayLayout1ul2ui8\",Vi);var qi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(wi);qi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout2ui4\",qi);var Hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.uint16[1*t+0]=e,t},e}(wi);Hi.prototype.bytesPerElement=2,Dn(\"StructArrayLayout1ui2\",Hi);var Gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(wi);Gi.prototype.bytesPerElement=8,Dn(\"StructArrayLayout2f8\",Gi);var Yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(wi);Yi.prototype.bytesPerElement=16,Dn(\"StructArrayLayout4f16\",Yi);var Wi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(_i);Wi.prototype.size=20;var Xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Wi(this,t)},e}(zi);Dn(\"CollisionBoxArray\",Xi);var Zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},placedOrientation:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0},associatedIconIndex:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.placedOrientation.get=function(){return this._structArray.uint8[this._pos1+37]},r.placedOrientation.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+38]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+38]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},r.associatedIconIndex.get=function(){return this._structArray.int16[this._pos2+22]},Object.defineProperties(e.prototype,r),e}(_i);Zi.prototype.size=48;var Ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Zi(this,t)},e}(Bi);Dn(\"PlacedSymbolArray\",Ji);var Ki=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},placedIconSymbolIndex:{configurable:!0},verticalPlacedIconSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},verticalTextBoxStartIndex:{configurable:!0},verticalTextBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},verticalIconBoxStartIndex:{configurable:!0},verticalIconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},numVerticalIconVertices:{configurable:!0},useRuntimeCollisionCircles:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},textOffset0:{configurable:!0},textOffset1:{configurable:!0},collisionCircleDiameter:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.placedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+6]},r.verticalPlacedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+7]},r.key.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.verticalTextBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.verticalTextBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+12]},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+13]},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+14]},r.verticalIconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+15]},r.verticalIconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+16]},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+17]},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+18]},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+19]},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+20]},r.numVerticalIconVertices.get=function(){return this._structArray.uint16[this._pos2+21]},r.useRuntimeCollisionCircles.get=function(){return this._structArray.uint16[this._pos2+22]},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+12]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+12]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+13]},r.textOffset0.get=function(){return this._structArray.float32[this._pos4+14]},r.textOffset1.get=function(){return this._structArray.float32[this._pos4+15]},r.collisionCircleDiameter.get=function(){return this._structArray.float32[this._pos4+16]},Object.defineProperties(e.prototype,r),e}(_i);Ki.prototype.size=68;var Qi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Ki(this,t)},e}(Ni);Dn(\"SymbolInstanceArray\",Qi);var $i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e}(ji);Dn(\"GlyphOffsetArray\",$i);var ta=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e}(Ui);Dn(\"SymbolLineVertexArray\",ta);var ea=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},Object.defineProperties(e.prototype,r),e}(_i);ea.prototype.size=8;var ra=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new ea(this,t)},e}(Vi);Dn(\"FeatureIndexArray\",ra);var na=Ti([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,ia=function(t){void 0===t&&(t=[]),this.segments=t};function aa(t,e){return 256*(t=l(Math.floor(t),0,255))+l(Math.floor(e),0,255)}ia.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>ia.MAX_VERTEX_ARRAY_LENGTH&&_(\"Max vertices per segment is \"+ia.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>ia.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},ia.prototype.get=function(){return this.segments},ia.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},ia.simpleSegment=function(t,e,r,n){return new ia([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},ia.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,Dn(\"SegmentVector\",ia);var oa=Ti([{name:\"a_pattern_from\",components:4,type:\"Uint16\"},{name:\"a_pattern_to\",components:4,type:\"Uint16\"},{name:\"a_pixel_ratio_from\",components:1,type:\"Uint8\"},{name:\"a_pixel_ratio_to\",components:1,type:\"Uint8\"}]),sa=e((function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(n=t.length-(r=3&t.length),i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}})),la=e((function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}})),ca=sa,ua=la;ca.murmur3=sa,ca.murmur2=ua;var fa=function(){this.ids=[],this.positions=[],this.indexed=!1};fa.prototype.add=function(t,e,r,n){this.ids.push(pa(t)),this.positions.push(e,r,n)},fa.prototype.getPositions=function(t){for(var e=pa(t),r=0,n=this.ids.length-1;r<n;){var i=r+n>>1;this.ids[i]>=e?n=i:r=i+1}for(var a=[];this.ids[r]===e;)a.push({index:this.positions[3*r],start:this.positions[3*r+1],end:this.positions[3*r+2]}),r++;return a},fa.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){for(;n<i;){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;da(e,o,s),da(r,3*o,3*s),da(r,3*o+1,3*s+1),da(r,3*o+2,3*s+2)}s-n<i-s?(t(e,r,n,s),n=s+1):(t(e,r,s+1,i),i=s)}}(r,n,0,r.length-1),e&&e.push(r.buffer,n.buffer),{ids:r,positions:n}},fa.deserialize=function(t){var e=new fa;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e};var ha=Math.pow(2,53)-1;function pa(t){var e=+t;return!isNaN(e)&&e<=ha?e:ca(String(t))}function da(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Dn(\"FeaturePositionMap\",fa);var ga=function(t,e){this.gl=t.gl,this.location=e},ma=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(ga),va=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(ga),ya=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(ga),xa=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(ga),ba=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(ga),_a=function(t){function e(e,r){t.call(this,e,r),this.current=Kt.transparent}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(ga),wa=new Float32Array(16),Ta=function(t){function e(e,r){t.call(this,e,r),this.current=wa}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(ga);function ka(t){return[aa(255*t.r,255*t.g),aa(255*t.b,255*t.a)]}var Ma=function(t,e,r){this.value=t,this.uniformNames=e.map((function(t){return\"u_\"+t})),this.type=r};Ma.prototype.setUniform=function(t,e,r){t.set(r.constantOr(this.value))},Ma.prototype.getBinding=function(t,e,r){return\"color\"===this.type?new _a(t,e):new va(t,e)};var Aa=function(t,e){this.uniformNames=e.map((function(t){return\"u_\"+t})),this.patternFrom=null,this.patternTo=null,this.pixelRatioFrom=1,this.pixelRatioTo=1};Aa.prototype.setConstantPatternPositions=function(t,e){this.pixelRatioFrom=e.pixelRatio,this.pixelRatioTo=t.pixelRatio,this.patternFrom=e.tlbr,this.patternTo=t.tlbr},Aa.prototype.setUniform=function(t,e,r,n){var i=\"u_pattern_to\"===n?this.patternTo:\"u_pattern_from\"===n?this.patternFrom:\"u_pixel_ratio_to\"===n?this.pixelRatioTo:\"u_pixel_ratio_from\"===n?this.pixelRatioFrom:null;i&&t.set(i)},Aa.prototype.getBinding=function(t,e,r){return\"u_pattern\"===r.substr(0,9)?new ba(t,e):new va(t,e)};var Sa=function(t,e,r,n){this.expression=t,this.type=r,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}})),this.paintVertexArray=new n};Sa.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.paintVertexArray.length,o=this.expression.evaluate(new ii(0),e,{},n,[],i);this.paintVertexArray.resize(t),this._setPaintValue(a,t,o)},Sa.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:0},r,n);this._setPaintValue(t,e,i)},Sa.prototype._setPaintValue=function(t,e,r){if(\"color\"===this.type)for(var n=ka(r),i=t;i<e;i++)this.paintVertexArray.emplace(i,n[0],n[1]);else{for(var a=t;a<e;a++)this.paintVertexArray.emplace(a,r);this.maxValue=Math.max(this.maxValue,Math.abs(r))}},Sa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Sa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()};var Ea=function(t,e,r,n,i,a){this.expression=t,this.uniformNames=e.map((function(t){return\"u_\"+t+\"_t\"})),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}})),this.paintVertexArray=new a};Ea.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.expression.evaluate(new ii(this.zoom),e,{},n,[],i),o=this.expression.evaluate(new ii(this.zoom+1),e,{},n,[],i),s=this.paintVertexArray.length;this.paintVertexArray.resize(t),this._setPaintValue(s,t,a,o)},Ea.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:this.zoom},r,n),a=this.expression.evaluate({zoom:this.zoom+1},r,n);this._setPaintValue(t,e,i,a)},Ea.prototype._setPaintValue=function(t,e,r,n){if(\"color\"===this.type)for(var i=ka(r),a=ka(n),o=t;o<e;o++)this.paintVertexArray.emplace(o,i[0],i[1],a[0],a[1]);else{for(var s=t;s<e;s++)this.paintVertexArray.emplace(s,r,n);this.maxValue=Math.max(this.maxValue,Math.abs(r),Math.abs(n))}},Ea.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Ea.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Ea.prototype.setUniform=function(t,e){var r=this.useIntegerZoom?Math.floor(e.zoom):e.zoom,n=l(this.expression.interpolationFactor(r,this.zoom,this.zoom+1),0,1);t.set(n)},Ea.prototype.getBinding=function(t,e,r){return new va(t,e)};var Ca=function(t,e,r,n,i,a){this.expression=t,this.type=e,this.useIntegerZoom=r,this.zoom=n,this.layerId=a,this.zoomInPaintVertexArray=new i,this.zoomOutPaintVertexArray=new i};Ca.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray.length;this.zoomInPaintVertexArray.resize(t),this.zoomOutPaintVertexArray.resize(t),this._setPaintValues(n,t,e.patterns&&e.patterns[this.layerId],r)},Ca.prototype.updatePaintArray=function(t,e,r,n,i){this._setPaintValues(t,e,r.patterns&&r.patterns[this.layerId],i)},Ca.prototype._setPaintValues=function(t,e,r,n){if(n&&r){var i=n[r.min],a=n[r.mid],o=n[r.max];if(i&&a&&o)for(var s=t;s<e;s++)this.zoomInPaintVertexArray.emplace(s,a.tl[0],a.tl[1],a.br[0],a.br[1],i.tl[0],i.tl[1],i.br[0],i.br[1],a.pixelRatio,i.pixelRatio),this.zoomOutPaintVertexArray.emplace(s,a.tl[0],a.tl[1],a.br[0],a.br[1],o.tl[0],o.tl[1],o.br[0],o.br[1],a.pixelRatio,o.pixelRatio)}},Ca.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,oa.members,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,oa.members,this.expression.isStateDependent))},Ca.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()};var La=function(t,e,r,n){this.binders={},this.layoutAttributes=n,this._buffers=[];var i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof fi&&Lr(o.property.specification)){var s=Pa(a,t.type),l=o.value,c=o.property.specification.type,u=o.property.useIntegerZoom,f=o.property.specification[\"property-type\"],h=\"cross-faded\"===f||\"cross-faded-data-driven\"===f;if(\"constant\"===l.kind)this.binders[a]=h?new Aa(l.value,s):new Ma(l.value,s,c),i.push(\"/u_\"+a);else if(\"source\"===l.kind||h){var p=za(a,c,\"source\");this.binders[a]=h?new Ca(l,c,u,e,p,t.id):new Sa(l,s,c,p),i.push(\"/a_\"+a)}else{var d=za(a,c,\"composite\");this.binders[a]=new Ea(l,s,c,u,e,d),i.push(\"/z_\"+a)}}}this.cacheKey=i.sort().join(\"\")};La.prototype.getMaxValue=function(t){var e=this.binders[t];return e instanceof Sa||e instanceof Ea?e.maxValue:0},La.prototype.populatePaintArrays=function(t,e,r,n,i){for(var a in this.binders){var o=this.binders[a];(o instanceof Sa||o instanceof Ea||o instanceof Ca)&&o.populatePaintArray(t,e,r,n,i)}},La.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders){var n=this.binders[r];n instanceof Aa&&n.setConstantPatternPositions(t,e)}},La.prototype.updatePaintArrays=function(t,e,r,n,i){var a=!1;for(var o in t)for(var s=0,l=e.getPositions(o);s<l.length;s+=1){var c=l[s],u=r.feature(c.index);for(var f in this.binders){var h=this.binders[f];if((h instanceof Sa||h instanceof Ea||h instanceof Ca)&&!0===h.expression.isStateDependent){var p=n.paint.get(f);h.expression=p.value,h.updatePaintArray(c.start,c.end,u,t[o],i),a=!0}}}return a},La.prototype.defines=function(){var t=[];for(var e in this.binders){var r=this.binders[e];(r instanceof Ma||r instanceof Aa)&&t.push.apply(t,r.uniformNames.map((function(t){return\"#define HAS_UNIFORM_\"+t})))}return t},La.prototype.getPaintVertexBuffers=function(){return this._buffers},La.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders){var i=this.binders[n];if(i instanceof Ma||i instanceof Aa||i instanceof Ea)for(var a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s],s);r.push({name:s,property:n,binding:l})}}}return r},La.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property;this.binders[l].setUniform(o.binding,n,r.get(l),s)}},La.prototype.updatePaintBuffers=function(t){for(var e in this._buffers=[],this.binders){var r=this.binders[e];if(t&&r instanceof Ca){var n=2===t.fromScale?r.zoomInPaintVertexBuffer:r.zoomOutPaintVertexBuffer;n&&this._buffers.push(n)}else(r instanceof Sa||r instanceof Ea)&&r.paintVertexBuffer&&this._buffers.push(r.paintVertexBuffer)}},La.prototype.upload=function(t){for(var e in this.binders){var r=this.binders[e];(r instanceof Sa||r instanceof Ea||r instanceof Ca)&&r.upload(t)}this.updatePaintBuffers()},La.prototype.destroy=function(){for(var t in this.binders){var e=this.binders[t];(e instanceof Sa||e instanceof Ea||e instanceof Ca)&&e.destroy()}};var Ia=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=new La(o,r,n,t)}this.needsUpload=!1,this._featureMap=new fa,this._bufferOffset=0};function Pa(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function za(t,e,r){var n={color:{source:Gi,composite:Yi},number:{source:ji,composite:Gi}},i=function(t){return{\"line-pattern\":{source:Ci,composite:Ci},\"fill-pattern\":{source:Ci,composite:Ci},\"fill-extrusion-pattern\":{source:Ci,composite:Ci}}[t]}(t);return i&&i[r]||n[e][r]}Ia.prototype.populatePaintArrays=function(t,e,r,n,i,a){for(var o in this.programConfigurations)this.programConfigurations[o].populatePaintArrays(t,e,n,i,a);void 0!==e.id&&this._featureMap.add(e.id,r,this._bufferOffset,t),this._bufferOffset=t,this.needsUpload=!0},Ia.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,this._featureMap,e,o,n)||this.needsUpload}},Ia.prototype.get=function(t){return this.programConfigurations[t]},Ia.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},Ia.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},Dn(\"ConstantBinder\",Ma),Dn(\"CrossFadedConstantBinder\",Aa),Dn(\"SourceExpressionBinder\",Sa),Dn(\"CrossFadedCompositeBinder\",Ca),Dn(\"CompositeExpressionBinder\",Ea),Dn(\"ProgramConfiguration\",La,{omit:[\"_buffers\"]}),Dn(\"ProgramConfigurationSet\",Ia);var Oa={min:-1*Math.pow(2,14),max:Math.pow(2,14)-1};function Da(t){for(var e=8192/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<Oa.min||o.x>Oa.max||o.y<Oa.min||o.y>Oa.max)&&(_(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\"),o.x=l(o.x,Oa.min,Oa.max),o.y=l(o.y,Oa.min,Oa.max))}return r}function Ra(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var Fa=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Mi,this.indexArray=new Fi,this.segments=new ia,this.programConfigurations=new Ia(na,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function Ba(t,e){for(var r=0;r<t.length;r++)if(Wa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Wa(t,e[n]))return!0;return!!Va(t,e)}function Na(t,e,r){return!!Wa(t,e)||!!Ha(e,t,r)}function ja(t,e){if(1===t.length)return Ya(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Wa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ya(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(Va(t,e[o]))return!0;return!1}function Ua(t,e,r){if(t.length>1){if(Va(t,e))return!0;for(var n=0;n<e.length;n++)if(Ha(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(Ha(t[i],e,r))return!0;return!1}function Va(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(qa(n,i,e[a],e[a+1]))return!0;return!1}function qa(t,e,r,n){return w(t,r,n)!==w(e,r,n)&&w(t,e,r)!==w(t,e,n)}function Ha(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(Ga(t,e[i-1],e[i])<n)return!0;return!1}function Ga(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return t.distSqr(i<0?e:i>1?r:r.sub(e)._mult(i)._add(e))}function Ya(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)(n=r[s]).y>e.y!=(i=r[l]).y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Wa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Xa(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=w(t,e,r[0]);return a!==w(t,e,r[1])||a!==w(t,e,r[2])||a!==w(t,e,r[3])}function Za(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).getMaxValue(t)}function Ja(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ka(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++)s.push(t[l].sub(o));return s}Fa.prototype.populate=function(t,e,r){var n=this.layers[0],i=[],a=null;\"circle\"===n.type&&(a=n.layout.get(\"circle-sort-key\"));for(var o=0,s=t;o<s.length;o+=1){var l=s[o],c=l.feature,u=l.id,f=l.index,h=l.sourceLayerIndex,p=this.layers[0]._featureFilter.needGeometry,d={type:c.type,id:u,properties:c.properties,geometry:p?Da(c):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),d,r)){p||(d.geometry=Da(c));var g=a?a.evaluate(d,{},r):void 0;i.push({id:u,properties:c.properties,type:c.type,sourceLayerIndex:h,index:f,geometry:d.geometry,patterns:{},sortKey:g})}}a&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var m=0,v=i;m<v.length;m+=1){var y=v[m],x=y.geometry,b=y.index,_=y.sourceLayerIndex,w=t[b].feature;this.addFeature(y,x,b,r),e.featureIndex.insert(w,x,b,_,this.index)}},Fa.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Fa.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Fa.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Fa.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,na),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Fa.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Fa.prototype.addFeature=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1)for(var o=0,s=a[i];o<s.length;o+=1){var l=s[o],c=l.x,u=l.y;if(!(c<0||c>=8192||u<0||u>=8192)){var f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray,t.sortKey),h=f.vertexLength;Ra(this.layoutVertexArray,c,u,-1,-1),Ra(this.layoutVertexArray,c,u,1,-1),Ra(this.layoutVertexArray,c,u,1,1),Ra(this.layoutVertexArray,c,u,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),f.vertexLength+=4,f.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{},n)},Dn(\"CircleBucket\",Fa,{omit:[\"layers\"]});var Qa=new yi({\"circle-sort-key\":new di(At.layout_circle[\"circle-sort-key\"])}),$a={paint:new yi({\"circle-radius\":new di(At.paint_circle[\"circle-radius\"]),\"circle-color\":new di(At.paint_circle[\"circle-color\"]),\"circle-blur\":new di(At.paint_circle[\"circle-blur\"]),\"circle-opacity\":new di(At.paint_circle[\"circle-opacity\"]),\"circle-translate\":new pi(At.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new pi(At.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new pi(At.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new pi(At.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new di(At.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new di(At.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new di(At.paint_circle[\"circle-stroke-opacity\"])}),layout:Qa},to=\"undefined\"!=typeof Float32Array?Float32Array:Array;function eo(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}function ro(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],g=e[12],m=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*g,t[1]=x*i+b*l+_*h+w*m,t[2]=x*a+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,t[4]=(x=r[4])*n+(b=r[5])*s+(_=r[6])*f+(w=r[7])*g,t[5]=x*i+b*l+_*h+w*m,t[6]=x*a+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,t[8]=(x=r[8])*n+(b=r[9])*s+(_=r[10])*f+(w=r[11])*g,t[9]=x*i+b*l+_*h+w*m,t[10]=x*a+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,t[12]=(x=r[12])*n+(b=r[13])*s+(_=r[14])*f+(w=r[15])*g,t[13]=x*i+b*l+_*h+w*m,t[14]=x*a+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}Math.hypot||(Math.hypot=function(){for(var t=arguments,e=0,r=arguments.length;r--;)e+=t[r]*t[r];return Math.sqrt(e)});var no,io=ro;function ao(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}no=new to(3),to!=Float32Array&&(no[0]=0,no[1]=0,no[2]=0),function(){var t=new to(4);to!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();var oo=(function(){var t=new to(2);to!=Float32Array&&(t[0]=0,t[1]=0)}(),function(t){function e(e){t.call(this,e,$a)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new Fa(t)},e.prototype.queryRadius=function(t){var e=t;return Za(\"circle-radius\",this,e)+Za(\"circle-stroke-width\",this,e)+Ja(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ka(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),f=u?l:function(t,e){return t.map((function(t){return so(t,e)}))}(l,s),h=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,m=d[p];g<m.length;g+=1){var v=m[g],y=u?v:so(v,s),x=h,b=ao([],[v.x,v.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),Na(f,y,x))return!0}return!1},e}(xi));function so(t,e){var r=ao([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var lo=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Fa);function co(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function uo(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=co({},{width:n,height:i},r);fo(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function fo(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,f=0;f<i.width*a;f++)s[u+f]=o[c+f];return e}Dn(\"HeatmapBucket\",lo,{omit:[\"layers\"]});var ho=function(t,e){co(this,t,1,e)};ho.prototype.resize=function(t){uo(this,t,1)},ho.prototype.clone=function(){return new ho({width:this.width,height:this.height},new Uint8Array(this.data))},ho.copy=function(t,e,r,n,i){fo(t,e,r,n,i,1)};var po=function(t,e){co(this,t,4,e)};po.prototype.resize=function(t){uo(this,t,4)},po.prototype.replace=function(t,e){e?this.data.set(t):this.data=t instanceof Uint8ClampedArray?new Uint8Array(t.buffer):t},po.prototype.clone=function(){return new po({width:this.width,height:this.height},new Uint8Array(this.data))},po.copy=function(t,e,r,n,i){fo(t,e,r,n,i,4)},Dn(\"AlphaImage\",ho),Dn(\"RGBAImage\",po);var go={paint:new yi({\"heatmap-radius\":new di(At.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new di(At.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new pi(At.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new vi(At.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new pi(At.paint_heatmap[\"heatmap-opacity\"])})};function mo(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new po({width:256,height:1},r)}var vo=function(t){function e(e){t.call(this,e,go),this._updateColorRamp()}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new lo(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){this.colorRamp=mo(this._transitionablePaint._values[\"heatmap-color\"].value.expression,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(xi),yo={paint:new yi({\"hillshade-illumination-direction\":new pi(At.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new pi(At.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new pi(At.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new pi(At.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new pi(At.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new pi(At.paint_hillshade[\"hillshade-accent-color\"])})},xo=function(t){function e(e){t.call(this,e,yo)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(xi),bo=Ti([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,_o=To,wo=To;function To(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,f=u?e[0]*r:t.length,h=ko(t,0,f,r,!0),p=[];if(!h||h.next===h.prev)return p;if(u&&(h=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=ko(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(Do(o));for(s.sort(Io),i=0;i<s.length;i++)Po(s[i],r),r=Mo(r,r.next);return r}(t,e,h,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<f;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return Ao(h,p,r,n,i,c),p}function ko(t,e,r,n,i){var a,o;if(i===Xo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=Go(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=Go(a,t[a],t[a+1],o);return o&&No(o,o.next)&&(Yo(o),o=o.next),o}function Mo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!No(n,n.next)&&0!==Bo(n.prev,n,n.next))n=n.next;else{if(Yo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function Ao(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=Oo(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?Eo(t,n,i,a):So(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),Yo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?Ao(t=Co(Mo(t),e,r),e,r,n,i,a,2):2===o&&Lo(t,e,r,n,i,a):Ao(Mo(t),e,r,n,i,a,1);break}}}function So(t){var e=t.prev,r=t,n=t.next;if(Bo(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(Ro(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&Bo(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function Eo(t,e,r,n){var i=t.prev,a=t,o=t.next;if(Bo(i,a,o)>=0)return!1;for(var s=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,l=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,c=Oo(i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,e,r,n),u=Oo(s,l,e,r,n),f=t.prevZ,h=t.nextZ;f&&f.z>=c&&h&&h.z<=u;){if(f!==t.prev&&f!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,f.x,f.y)&&Bo(f.prev,f,f.next)>=0)return!1;if(f=f.prevZ,h!==t.prev&&h!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,h.x,h.y)&&Bo(h.prev,h,h.next)>=0)return!1;h=h.nextZ}for(;f&&f.z>=c;){if(f!==t.prev&&f!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,f.x,f.y)&&Bo(f.prev,f,f.next)>=0)return!1;f=f.prevZ}for(;h&&h.z<=u;){if(h!==t.prev&&h!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,h.x,h.y)&&Bo(h.prev,h,h.next)>=0)return!1;h=h.nextZ}return!0}function Co(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!No(i,a)&&jo(i,n,n.next,a)&&qo(i,a)&&qo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),Yo(n),Yo(n.next),n=t=a),n=n.next}while(n!==t);return Mo(n)}function Lo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&Fo(o,s)){var l=Ho(o,s);return o=Mo(o,o.next),l=Mo(l,l.next),Ao(o,e,r,n,i,a),void Ao(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function Io(t,e){return t.x-e.x}function Po(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,f=r.y,h=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&Ro(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),qo(n,t)&&(l<h||l===h&&(n.x>r.x||n.x===r.x&&zo(r,n)))&&(r=n,h=l)),n=n.next}while(n!==c);return r}(t,e)){var r=Ho(e,t);Mo(e,e.next),Mo(r,r.next)}}function zo(t,e){return Bo(t.prev,t,e.prev)<0&&Bo(e.next,t,t.next)<0}function Oo(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function Do(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function Ro(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function Fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&jo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(qo(t,e)&&qo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(Bo(t.prev,t,e.prev)||Bo(t,e.prev,e))||No(t,e)&&Bo(t.prev,t,t.next)>0&&Bo(e.prev,e,e.next)>0)}function Bo(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function No(t,e){return t.x===e.x&&t.y===e.y}function jo(t,e,r,n){var i=Vo(Bo(t,e,r)),a=Vo(Bo(t,e,n)),o=Vo(Bo(r,n,t)),s=Vo(Bo(r,n,e));return i!==a&&o!==s||!(0!==i||!Uo(t,r,e))||!(0!==a||!Uo(t,n,e))||!(0!==o||!Uo(r,t,n))||!(0!==s||!Uo(r,e,n))}function Uo(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function Vo(t){return t>0?1:t<0?-1:0}function qo(t,e){return Bo(t.prev,t,t.next)<0?Bo(t,e,t.next)>=0&&Bo(t,t.prev,e)>=0:Bo(t,e,t.prev)<0||Bo(t,t.next,e)<0}function Ho(t,e){var r=new Wo(t.i,t.x,t.y),n=new Wo(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function Go(t,e,r,n){var i=new Wo(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function Yo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function Wo(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function Xo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function Zo(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var f=e[r],h=n,p=i;for(Jo(e,n,r),a(e[i],f)>0&&Jo(e,n,i);h<p;){for(Jo(e,h,p),h++,p--;a(e[h],f)<0;)h++;for(;a(e[p],f)>0;)p--}0===a(e[n],f)?Jo(e,n,p):Jo(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ko)}function Jo(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ko(t,e){return t<e?-1:t>e?1:0}function Qo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(Zo(a[l],e,1,a[l].length-1,$o),a[l]=a[l].slice(0,e));return a}function $o(t,e){return e.area-t.area}function ts(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function es(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{},i.availableImages),f=c.evaluate({zoom:n},r,{},i.availableImages),h=c.evaluate({zoom:n+1},r,{},i.availableImages);f=f&&f.name?f.name:f,h=h&&h.name?h.name:h,a[u=u&&u.name?u.name:u]=!0,a[f]=!0,a[h]=!0,r.patterns[l.id]={min:u,mid:f,max:h}}}return r}To.deviation=function(t,e,r,n){var i=e&&e.length,a=Math.abs(Xo(t,0,i?e[0]*r:t.length,r));if(i)for(var o=0,s=e.length;o<s;o++)a-=Math.abs(Xo(t,e[o]*r,o<s-1?e[o+1]*r:t.length,r));var l=0;for(o=0;o<n.length;o+=3){var c=n[o]*r,u=n[o+1]*r,f=n[o+2]*r;l+=Math.abs((t[c]-t[f])*(t[u+1]-t[c+1])-(t[c]-t[u])*(t[f+1]-t[c+1]))}return 0===a&&0===l?0:Math.abs((l-a)/a)},To.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&r.holes.push(n+=t[i-1].length)}return r},_o.default=wo;var rs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Mi,this.indexArray=new Fi,this.indexArray2=new qi,this.programConfigurations=new Ia(bo,t.layers,t.zoom),this.segments=new ia,this.segments2=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};rs.prototype.populate=function(t,e,r){this.hasPattern=ts(\"fill\",this.layers,e);for(var n=this.layers[0].layout.get(\"fill-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,f=s.sourceLayerIndex,h=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:h?Da(l):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),p,r)){h||(p.geometry=Da(l));var d=n?n.evaluate(p,{},r,e.availableImages):void 0;i.push({id:c,properties:l.properties,type:l.type,sourceLayerIndex:f,index:u,geometry:p.geometry,patterns:{},sortKey:d})}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,m=i;g<m.length;g+=1){var v=m[g],y=v.geometry,x=v.index,b=v.sourceLayerIndex;if(this.hasPattern){var _=es(\"fill\",this.layers,v,this.zoom,e);this.patternFeatures.push(_)}else this.addFeature(v,y,x,r,{});e.featureIndex.insert(t[x].feature,y,x,b,this.index)}},rs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},rs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},rs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},rs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},rs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,bo),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},rs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},rs.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=Qo(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var f=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray),h=f.vertexLength,p=[],d=[],g=0,m=s;g<m.length;g+=1){var v=m[g];if(0!==v.length){v!==s[0]&&d.push(p.length/2);var y=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),x=y.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(x+v.length-1,x),p.push(v[0].x),p.push(v[0].y);for(var b=1;b<v.length;b++)this.layoutVertexArray.emplaceBack(v[b].x,v[b].y),this.indexArray2.emplaceBack(x+b-1,x+b),p.push(v[b].x),p.push(v[b].y);y.vertexLength+=v.length,y.primitiveLength+=v.length}}for(var _=_o(p,d),w=0;w<_.length;w+=3)this.indexArray.emplaceBack(h+_[w],h+_[w+1],h+_[w+2]);f.vertexLength+=l,f.primitiveLength+=_.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Dn(\"FillBucket\",rs,{omit:[\"layers\",\"patternFeatures\"]});var ns=new yi({\"fill-sort-key\":new di(At.layout_fill[\"fill-sort-key\"])}),is={paint:new yi({\"fill-antialias\":new pi(At.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new di(At.paint_fill[\"fill-opacity\"]),\"fill-color\":new di(At.paint_fill[\"fill-color\"]),\"fill-outline-color\":new di(At.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new pi(At.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new pi(At.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new gi(At.paint_fill[\"fill-pattern\"])}),layout:ns},as=function(t){function e(e){t.call(this,e,is)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r);var n=this.paint._values[\"fill-outline-color\"];\"constant\"===n.value.kind&&void 0===n.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new rs(t)},e.prototype.queryRadius=function(){return Ja(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ja(Ka(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(xi),os=Ti([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,ss=ls;function ls(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(cs,this,e)}function cs(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function us(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)n+=((r=t[o]).x-(e=t[i]).x)*(e.y+r.y);return n}ls.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ls.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},ls.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},ls.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=ls.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e];t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp((180-360*(r.y+s)/a)*Math.PI/180))-90]}}switch(this.type){case 1:var f=[];for(n=0;n<l.length;n++)f[n]=l[n][0];u(l=f);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=us(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var h={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(h.id=this.id),h};var fs=hs;function hs(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(ps,this,e),this.length=this._features.length}function ps(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function ds(t,e,r){if(3===t){var n=new fs(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}hs.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new ss(this._pbf,e,this.extent,this._keys,this._values)};var gs={VectorTile:function(t,e){this.layers=t.readFields(ds,{},e)},VectorTileFeature:ss,VectorTileLayer:fs},ms=gs.VectorTileFeature.types,vs=Math.pow(2,13);function ys(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*vs)+o,i*vs*2,a*vs*2,Math.round(s))}var xs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Si,this.indexArray=new Fi,this.programConfigurations=new Ia(os,t.layers,t.zoom),this.segments=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function bs(t,e){return t.x===e.x&&(t.x<0||t.x>8192)||t.y===e.y&&(t.y<0||t.y>8192)}xs.prototype.populate=function(t,e,r){this.features=[],this.hasPattern=ts(\"fill-extrusion\",this.layers,e);for(var n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.feature,s=a.id,l=a.index,c=a.sourceLayerIndex,u=this.layers[0]._featureFilter.needGeometry,f={type:o.type,id:s,properties:o.properties,geometry:u?Da(o):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),f,r)){var h={id:s,sourceLayerIndex:c,index:l,geometry:u?f.geometry:Da(o),properties:o.properties,type:o.type,patterns:{}};void 0!==o.id&&(h.id=o.id),this.hasPattern?this.features.push(es(\"fill-extrusion\",this.layers,h,this.zoom,e)):this.addFeature(h,h.geometry,l,r,{}),e.featureIndex.insert(o,h.geometry,l,c,this.index,!0)}}},xs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.features;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},xs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},xs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},xs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},xs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,os),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},xs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},xs.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=Qo(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,p=s;h<p.length;h+=1){var d=p[h];if(0!==d.length&&!((P=d).every((function(t){return t.x<0}))||P.every((function(t){return t.x>8192}))||P.every((function(t){return t.y<0}))||P.every((function(t){return t.y>8192}))))for(var g=0,m=0;m<d.length;m++){var v=d[m];if(m>=1){var y=d[m-1];if(!bs(v,y)){f.vertexLength+4>ia.MAX_VERTEX_ARRAY_LENGTH&&(f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var x=v.sub(y)._perp()._unit(),b=y.dist(v);g+b>32768&&(g=0),ys(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,0,g),ys(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,1,g),ys(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,0,g+=b),ys(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,1,g);var _=f.vertexLength;this.indexArray.emplaceBack(_,_+2,_+1),this.indexArray.emplaceBack(_+1,_+2,_+3),f.vertexLength+=4,f.primitiveLength+=2}}}}if(f.vertexLength+l>ia.MAX_VERTEX_ARRAY_LENGTH&&(f=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray)),\"Polygon\"===ms[t.type]){for(var w=[],T=[],k=f.vertexLength,M=0,A=s;M<A.length;M+=1){var S=A[M];if(0!==S.length){S!==s[0]&&T.push(w.length/2);for(var E=0;E<S.length;E++){var C=S[E];ys(this.layoutVertexArray,C.x,C.y,0,0,1,1,0),w.push(C.x),w.push(C.y)}}}for(var L=_o(w,T),I=0;I<L.length;I+=3)this.indexArray.emplaceBack(k+L[I],k+L[I+2],k+L[I+1]);f.primitiveLength+=L.length/3,f.vertexLength+=l}}var P;this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Dn(\"FillExtrusionBucket\",xs,{omit:[\"layers\",\"features\"]});var _s={paint:new yi({\"fill-extrusion-opacity\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new gi(At[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},ws=function(t){function e(e){t.call(this,e,_s)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new xs(t)},e.prototype.queryRadius=function(){return Ja(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ka(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),f=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),h=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];ao(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,f=n[8]*r,h=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,m=t;g<m.length;g+=1){for(var v=[],y=[],x=0,b=m[g];x<b.length;x+=1){var _=b[x],w=_.x,T=_.y,k=n[0]*w+n[4]*T+n[12],M=n[1]*w+n[5]*T+n[13],A=n[2]*w+n[6]*T+n[14],S=n[3]*w+n[7]*T+n[15],E=A+c,C=S+u,L=k+f,I=M+h,P=A+p,z=S+d,O=new i((k+s)/C,(M+l)/C);O.z=E/C,v.push(O);var D=new i(L/z,I/z);D.z=P/z,y.push(D)}a.push(v),o.push(y)}return[a,o]}(n,f,u,l);return function(t,e,r){var n=1/0;ja(r,e)&&(n=ks(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=[l,a[s+1],o[s+1],o[s],l];Ba(r,c)&&(n=Math.min(n,ks(r,c)))}return n!==1/0&&n}(p[0],p[1],h)},e}(xi);function Ts(t,e){return t.x*e.x+t.y*e.y}function ks(t,e){if(1===t.length){for(var r,n=0,i=e[n++];!r||i.equals(r);)if(!(r=e[n++]))return 1/0;for(;n<e.length;n++){var a=e[n],o=t[0],s=r.sub(i),l=a.sub(i),c=o.sub(i),u=Ts(s,s),f=Ts(s,l),h=Ts(l,l),p=Ts(c,s),d=Ts(c,l),g=u*h-f*f,m=(h*p-f*d)/g,v=(u*d-f*p)/g,y=i.z*(1-m-v)+r.z*m+a.z*v;if(isFinite(y))return y}return 1/0}for(var x=1/0,b=0,_=e;b<_.length;b+=1)x=Math.min(x,_[b].z);return x}var Ms=Ti([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,As=gs.VectorTileFeature.types,Ss=Math.cos(Math.PI/180*37.5),Es=Math.pow(2,14)/.5,Cs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Ei,this.indexArray=new Fi,this.programConfigurations=new Ia(Ms,t.layers,t.zoom),this.segments=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};Cs.prototype.populate=function(t,e,r){this.hasPattern=ts(\"line\",this.layers,e);for(var n=this.layers[0].layout.get(\"line-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,f=s.sourceLayerIndex,h=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:h?Da(l):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),p,r)){h||(p.geometry=Da(l));var d=n?n.evaluate(p,{},r):void 0;i.push({id:c,properties:l.properties,type:l.type,sourceLayerIndex:f,index:u,geometry:p.geometry,patterns:{},sortKey:d})}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,m=i;g<m.length;g+=1){var v=m[g],y=v.geometry,x=v.index,b=v.sourceLayerIndex;if(this.hasPattern){var _=es(\"line\",this.layers,v,this.zoom,e);this.patternFeatures.push(_)}else this.addFeature(v,y,x,r,{});e.featureIndex.insert(t[x].feature,y,x,b,this.index)}},Cs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Cs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},Cs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Cs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Cs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ms),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Cs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Cs.prototype.addFeature=function(t,e,r,n,i){for(var a=this.layers[0].layout,o=a.get(\"line-join\").evaluate(t,{}),s=a.get(\"line-cap\"),l=a.get(\"line-miter-limit\"),c=a.get(\"line-round-limit\"),u=0,f=e;u<f.length;u+=1)this.addLine(f[u],t,o,s,l,c);this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Cs.prototype.addLine=function(t,e,r,n,i,a){if(this.distance=0,this.scaledDistance=0,this.totalDistance=0,e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")){this.clipStart=+e.properties.mapbox_clip_start,this.clipEnd=+e.properties.mapbox_clip_end;for(var o=0;o<t.length-1;o++)this.totalDistance+=t[o].dist(t[o+1]);this.updateScaledDistance()}for(var s=\"Polygon\"===As[e.type],l=t.length;l>=2&&t[l-1].equals(t[l-2]);)l--;for(var c=0;c<l-1&&t[c].equals(t[c+1]);)c++;if(!(l<(s?3:2))){\"bevel\"===r&&(i=1.05);var u,f=this.overscaling<=16?122880/(512*this.overscaling):0,h=this.segments.prepareSegment(10*l,this.layoutVertexArray,this.indexArray),p=void 0,d=void 0,g=void 0,m=void 0;this.e1=this.e2=-1,s&&(m=t[c].sub(u=t[l-2])._unit()._perp());for(var v=c;v<l;v++)if(!(d=v===l-1?s?t[c+1]:void 0:t[v+1])||!t[v].equals(d)){m&&(g=m),u&&(p=u),u=t[v],m=d?d.sub(u)._unit()._perp():g;var y=(g=g||m).add(m);0===y.x&&0===y.y||y._unit();var x=g.x*m.x+g.y*m.y,b=y.x*m.x+y.y*m.y,_=0!==b?1/b:1/0,w=2*Math.sqrt(2-2*b),T=b<Ss&&p&&d,k=g.x*m.y-g.y*m.x>0;if(T&&v>c){var M=u.dist(p);if(M>2*f){var A=u.sub(u.sub(p)._mult(f/M)._round());this.updateDistance(p,A),this.addCurrentVertex(A,g,0,0,h),p=A}}var S=p&&d,E=S?r:s?\"butt\":n;if(S&&\"round\"===E&&(_<a?E=\"miter\":_<=2&&(E=\"fakeround\")),\"miter\"===E&&_>i&&(E=\"bevel\"),\"bevel\"===E&&(_>2&&(E=\"flipbevel\"),_<i&&(E=\"miter\")),p&&this.updateDistance(p,u),\"miter\"===E)y._mult(_),this.addCurrentVertex(u,y,0,0,h);else if(\"flipbevel\"===E){if(_>100)y=m.mult(-1);else{var C=_*g.add(m).mag()/g.sub(m).mag();y._perp()._mult(C*(k?-1:1))}this.addCurrentVertex(u,y,0,0,h),this.addCurrentVertex(u,y.mult(-1),0,0,h)}else if(\"bevel\"===E||\"fakeround\"===E){var L=-Math.sqrt(_*_-1),I=k?L:0,P=k?0:L;if(p&&this.addCurrentVertex(u,g,I,P,h),\"fakeround\"===E)for(var z=Math.round(180*w/Math.PI/20),O=1;O<z;O++){var D=O/z;if(.5!==D){var R=D-.5;D+=D*R*(D-1)*((1.0904+x*(x*(3.55645-1.43519*x)-3.2452))*R*R+(.848013+x*(.215638*x-1.06021)))}var F=m.sub(g)._mult(D)._add(g)._unit()._mult(k?-1:1);this.addHalfVertex(u,F.x,F.y,!1,k,0,h)}d&&this.addCurrentVertex(u,m,-I,-P,h)}else if(\"butt\"===E)this.addCurrentVertex(u,y,0,0,h);else if(\"square\"===E){var B=p?1:-1;this.addCurrentVertex(u,y,B,B,h)}else\"round\"===E&&(p&&(this.addCurrentVertex(u,g,0,0,h),this.addCurrentVertex(u,g,1,1,h,!0)),d&&(this.addCurrentVertex(u,m,-1,-1,h,!0),this.addCurrentVertex(u,m,0,0,h)));if(T&&v<l-1){var N=u.dist(d);if(N>2*f){var j=u.add(d.sub(u)._mult(f/N)._round());this.updateDistance(u,j),this.addCurrentVertex(j,m,0,0,h),u=j}}}}},Cs.prototype.addCurrentVertex=function(t,e,r,n,i,a){void 0===a&&(a=!1);var o=e.y*n-e.x,s=-e.y-e.x*n;this.addHalfVertex(t,e.x+e.y*r,e.y-e.x*r,a,!1,r,i),this.addHalfVertex(t,o,s,a,!0,-n,i),this.distance>Es/2&&0===this.totalDistance&&(this.distance=0,this.addCurrentVertex(t,e,r,n,i,a))},Cs.prototype.addHalfVertex=function(t,e,r,n,i,a,o){var s=.5*this.scaledDistance;this.layoutVertexArray.emplaceBack((t.x<<1)+(n?1:0),(t.y<<1)+(i?1:0),Math.round(63*e)+128,Math.round(63*r)+128,1+(0===a?0:a<0?-1:1)|(63&s)<<2,s>>6);var l=o.vertexLength++;this.e1>=0&&this.e2>=0&&(this.indexArray.emplaceBack(this.e1,this.e2,l),o.primitiveLength++),i?this.e2=l:this.e1=l},Cs.prototype.updateScaledDistance=function(){this.scaledDistance=this.totalDistance>0?(this.clipStart+(this.clipEnd-this.clipStart)*this.distance/this.totalDistance)*(Es-1):this.distance},Cs.prototype.updateDistance=function(t,e){this.distance+=t.dist(e),this.updateScaledDistance()},Dn(\"LineBucket\",Cs,{omit:[\"layers\",\"patternFeatures\"]});var Ls=new yi({\"line-cap\":new pi(At.layout_line[\"line-cap\"]),\"line-join\":new di(At.layout_line[\"line-join\"]),\"line-miter-limit\":new pi(At.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new pi(At.layout_line[\"line-round-limit\"]),\"line-sort-key\":new di(At.layout_line[\"line-sort-key\"])}),Is={paint:new yi({\"line-opacity\":new di(At.paint_line[\"line-opacity\"]),\"line-color\":new di(At.paint_line[\"line-color\"]),\"line-translate\":new pi(At.paint_line[\"line-translate\"]),\"line-translate-anchor\":new pi(At.paint_line[\"line-translate-anchor\"]),\"line-width\":new di(At.paint_line[\"line-width\"]),\"line-gap-width\":new di(At.paint_line[\"line-gap-width\"]),\"line-offset\":new di(At.paint_line[\"line-offset\"]),\"line-blur\":new di(At.paint_line[\"line-blur\"]),\"line-dasharray\":new mi(At.paint_line[\"line-dasharray\"]),\"line-pattern\":new gi(At.paint_line[\"line-pattern\"]),\"line-gradient\":new vi(At.paint_line[\"line-gradient\"])}),layout:Ls},Ps=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new ii(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=u({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(di))(Is.paint.properties[\"line-width\"].specification);Ps.useIntegerZoom=!0;var zs=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){this.gradient=mo(this._transitionablePaint._values[\"line-gradient\"].value.expression,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r),this.paint._values[\"line-floorwidth\"]=Ps.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new Cs(t)},e.prototype.queryRadius=function(t){var e=t,r=Os(Za(\"line-width\",this,e),Za(\"line-gap-width\",this,e)),n=Za(\"line-offset\",this,e);return r/2+Math.abs(n)+Ja(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ka(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*Os(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l],u=o[l+1],f=0===l?n:c.sub(o[l-1])._unit()._perp(),h=l===o.length-1?n:u.sub(c)._unit()._perp(),p=f._add(h)._unit();p._mult(1/(p.x*h.x+p.y*h.y)),s.push(p._mult(e)._add(c))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Wa(t,i[a]))return!0;if(Ua(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(xi);function Os(t,e){return e>0?e+2*t:t}var Ds=Ti([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"},{name:\"a_pixeloffset\",components:4,type:\"Int16\"}],4),Rs=Ti([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),Fs=(Ti([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),Ti([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),Bs=(Ti([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"}]),Ti([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),Ns=Ti([{name:\"a_pos\",components:2,type:\"Float32\"},{name:\"a_radius\",components:1,type:\"Float32\"},{name:\"a_flags\",components:2,type:\"Int16\"}],4);function js(t,e,r){return t.sections.forEach((function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),ni.applyArabicShaping&&(t=ni.applyArabicShaping(t)),t}(t.text,e,r)})),t}Ti([{name:\"triangle\",components:3,type:\"Uint16\"}]),Ti([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"placedOrientation\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Int16\",name:\"associatedIconIndex\"}]),Ti([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Int16\",name:\"placedIconSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedIconSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"verticalTextBoxStartIndex\"},{type:\"Uint16\",name:\"verticalTextBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"verticalIconBoxStartIndex\"},{type:\"Uint16\",name:\"verticalIconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint16\",name:\"numVerticalIconVertices\"},{type:\"Uint16\",name:\"useRuntimeCollisionCircles\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",components:2,name:\"textOffset\"},{type:\"Float32\",name:\"collisionCircleDiameter\"}]),Ti([{type:\"Float32\",name:\"offsetX\"}]),Ti([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var Us={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},Vs=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},qs=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Hs=Gs;function Gs(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}Gs.Varint=0,Gs.Fixed64=1,Gs.Bytes=2,Gs.Fixed32=5;var Ys=\"undefined\"==typeof TextDecoder?null:new TextDecoder(\"utf8\");function Ws(t){return t.type===Gs.Bytes?t.readVarint()+t.pos:t.pos+1}function Xs(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function Zs(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function Js(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function Ks(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function Qs(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function $s(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function tl(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function el(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function rl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function nl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function il(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function al(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function ol(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function sl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}function ll(t,e,r){1===t&&r.readMessage(cl,e)}function cl(t,e,r){if(3===t){var n=r.readMessage(ul,{}),i=n.width,a=n.height,o=n.left,s=n.top,l=n.advance;e.push({id:n.id,bitmap:new ho({width:i+6,height:a+6},n.bitmap),metrics:{width:i,height:a,left:o,top:s,advance:l}})}}function ul(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}function fl(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort((function(t,e){return e.h-t.h}));for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var f=u[c],h=o.length-1;h>=0;h--){var p=o[h];if(!(f.w>p.w||f.h>p.h)){if(f.x=p.x,f.y=p.y,l=Math.max(l,f.y+f.h),s=Math.max(s,f.x+f.w),f.w===p.w&&f.h===p.h){var d=o.pop();h<o.length&&(o[h]=d)}else f.h===p.h?(p.x+=f.w,p.w-=f.w):f.w===p.w?(p.y+=f.h,p.h-=f.h):(o.push({x:p.x+f.w,y:p.y,w:p.w-f.w,h:f.h}),p.y+=f.h,p.h-=f.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}Gs.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=al(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=sl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=al(this.buf,this.pos)+4294967296*al(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=al(this.buf,this.pos)+4294967296*sl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Vs(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Vs(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return Xs(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return Xs(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=this.pos;return this.pos=t,t-e>=12&&Ys?function(t,e,r){return Ys.decode(t.subarray(e,r))}(this.buf,e,t):function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(o=t[i+2],128==(192&(a=t[i+1]))&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(o=t[i+2],s=t[i+3],128==(192&(a=t[i+1]))&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,e,t)},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==Gs.Bytes)return t.push(this.readVarint(e));var r=Ws(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSVarint());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==Gs.Bytes)return t.push(this.readBoolean());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFloat());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==Gs.Bytes)return t.push(this.readDouble());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFixed32());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSFixed32());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFixed64());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSFixed64());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===Gs.Varint)for(;this.buf[this.pos++]>127;);else if(e===Gs.Bytes)this.pos=this.readVarint()+this.pos;else if(e===Gs.Fixed32)this.pos+=4;else{if(e!==Gs.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),ol(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),ol(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),ol(this.buf,-1&t,this.pos),ol(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),ol(this.buf,-1&t,this.pos),ol(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,r.buf[r.pos]=127&(t>>>=7)}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&Zs(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),qs(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),qs(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&Zs(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,Gs.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,Js,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,Ks,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,tl,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,Qs,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,$s,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,el,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,rl,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,nl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,il,e)},writeBytesField:function(t,e){this.writeTag(t,Gs.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,Gs.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,Gs.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,Gs.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var hl=function(t,e){var r=e.pixelRatio,n=e.version,i=e.stretchX,a=e.stretchY,o=e.content;this.paddedRect=t,this.pixelRatio=r,this.stretchX=i,this.stretchY=a,this.content=o,this.version=n},pl={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};pl.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},pl.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},pl.tlbr.get=function(){return this.tl.concat(this.br)},pl.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(hl.prototype,pl);var dl=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=fl(i),o=new po({width:a.w||1,height:a.h||1});for(var s in t){var l=t[s],c=r[s].paddedRect;po.copy(l.data,o,{x:0,y:0},{x:c.x+1,y:c.y+1},l.data)}for(var u in e){var f=e[u],h=n[u].paddedRect,p=h.x+1,d=h.y+1,g=f.data.width,m=f.data.height;po.copy(f.data,o,{x:0,y:0},{x:p,y:d},f.data),po.copy(f.data,o,{x:0,y:m-1},{x:p,y:d-1},{width:g,height:1}),po.copy(f.data,o,{x:0,y:0},{x:p,y:d+m},{width:g,height:1}),po.copy(f.data,o,{x:g-1,y:0},{x:p-1,y:d},{width:1,height:m}),po.copy(f.data,o,{x:0,y:0},{x:p+g,y:d},{width:1,height:m})}this.image=o,this.iconPositions=r,this.patternPositions=n};dl.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new hl(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},dl.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},dl.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl;r.update(e.data,void 0,{x:n[0],y:n[1]})}},Dn(\"ImagePosition\",hl),Dn(\"ImageAtlas\",dl);var gl={horizontal:1,vertical:2,horizontalOnly:3},ml=function(){this.scale=1,this.fontStack=\"\",this.imageName=null};ml.forText=function(t,e){var r=new ml;return r.scale=t||1,r.fontStack=e,r},ml.forImage=function(t){var e=new ml;return e.imageName=t,e};var vl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[],this.imageSectionID=null};function yl(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g){var m,v=vl.fromFeature(t,i);f===gl.vertical&&v.verticalizePunctuation();var y=ni.processBidirectionalText,x=ni.processStyledBidirectionalText;if(y&&1===v.sections.length){m=[];for(var b=0,_=y(v.toString(),Ml(v,c,a,e,n,p,d));b<_.length;b+=1){var w=_[b],T=new vl;T.text=w,T.sections=v.sections;for(var k=0;k<w.length;k++)T.sectionIndex.push(0);m.push(T)}}else if(x){m=[];for(var M=0,A=x(v.text,v.sectionIndex,Ml(v,c,a,e,n,p,d));M<A.length;M+=1){var S=A[M],E=new vl;E.text=S[0],E.sectionIndex=S[1],E.sections=v.sections,m.push(E)}}else m=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(v,Ml(v,c,a,e,n,p,d));var C=[],L={positionedLines:C,text:v.toString(),top:u[1],bottom:u[1],left:u[0],right:u[0],writingMode:f,iconsInText:!1,verticalizable:!1};return function(t,e,r,n,i,a,o,s,l,c,u,f){for(var h=0,p=-17,d=0,g=0,m=\"right\"===s?1:\"left\"===s?0:.5,v=0,y=0,x=i;y<x.length;y+=1){var b=x[y];b.trim();var _=b.getMaxScale(),w=24*(_-1),T={positionedGlyphs:[],lineOffset:0};t.positionedLines[v]=T;var k=T.positionedGlyphs,M=0;if(b.length()){for(var A=0;A<b.length();A++){var S=b.getSection(A),E=b.getSectionIndex(A),C=b.getCharCode(A),L=0,I=null,P=null,z=null,O=24,D=!(l===gl.horizontal||!u&&!Hn(C)||u&&(xl[C]||(H=C,Vn.Arabic(H)||Vn[\"Arabic Supplement\"](H)||Vn[\"Arabic Extended-A\"](H)||Vn[\"Arabic Presentation Forms-A\"](H)||Vn[\"Arabic Presentation Forms-B\"](H))));if(S.imageName){var R=n[S.imageName];if(!R)continue;z=S.imageName,t.iconsInText=t.iconsInText||!0,P=R.paddedRect;var F=R.displaySize;S.scale=24*S.scale/f,L=w+(24-F[1]*S.scale),O=(I={width:F[0],height:F[1],left:1,top:-3,advance:D?F[1]:F[0]}).advance;var B=D?F[0]*S.scale-24*_:F[1]*S.scale-24*_;B>0&&B>M&&(M=B)}else{var N=r[S.fontStack],j=N&&N[C];if(j&&j.rect)P=j.rect,I=j.metrics;else{var U=e[S.fontStack],V=U&&U[C];if(!V)continue;I=V.metrics}L=24*(_-S.scale)}D?(t.verticalizable=!0,k.push({glyph:C,imageName:z,x:h,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:I,rect:P}),h+=O*S.scale+c):(k.push({glyph:C,imageName:z,x:h,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:I,rect:P}),h+=I.advance*S.scale+c)}0!==k.length&&(d=Math.max(h-c,d),Sl(k,0,k.length-1,m,M)),h=0;var q=a*_+M;T.lineOffset=Math.max(M,w),p+=q,g=Math.max(q,g),++v}else p+=a,++v}var H,G=p- -17,Y=Al(o),W=Y.horizontalAlign,X=Y.verticalAlign;(function(t,e,r,n,i,a,o,s,l){var c,u=(e-r)*i;c=a!==o?-s*n- -17:(-n*l+.5)*o;for(var f=0,h=t;f<h.length;f+=1)for(var p=0,d=h[f].positionedGlyphs;p<d.length;p+=1){var g=d[p];g.x+=u,g.y+=c}})(t.positionedLines,m,W,X,d,g,a,G,i.length),t.top+=-X*G,t.bottom=t.top+G,t.left+=-W*d,t.right=t.left+d}(L,e,r,n,m,o,s,l,f,c,h,g),!function(t){for(var e=0,r=t;e<r.length;e+=1)if(0!==r[e].positionedGlyphs.length)return!1;return!0}(C)&&L}vl.fromFeature=function(t,e){for(var r=new vl,n=0;n<t.sections.length;n++){var i=t.sections[n];i.image?r.addImageSection(i):r.addTextSection(i,e)}return r},vl.prototype.length=function(){return this.text.length},vl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},vl.prototype.getSectionIndex=function(t){return this.sectionIndex[t]},vl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},vl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;e+=n&&Gn(n)&&!Us[t[r+1]]||i&&Gn(i)&&!Us[t[r-1]]||!Us[t[r]]?t[r]:Us[t[r]]}return e}(this.text)},vl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&xl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&xl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},vl.prototype.substring=function(t,e){var r=new vl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},vl.prototype.toString=function(){return this.text},vl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce((function(e,r){return Math.max(e,t.sections[r].scale)}),0)},vl.prototype.addTextSection=function(t,e){this.text+=t.text,this.sections.push(ml.forText(t.scale,t.fontStack||e));for(var r=this.sections.length-1,n=0;n<t.text.length;++n)this.sectionIndex.push(r)},vl.prototype.addImageSection=function(t){var e=t.image?t.image.name:\"\";if(0!==e.length){var r=this.getNextImageSectionCharCode();r?(this.text+=String.fromCharCode(r),this.sections.push(ml.forImage(e)),this.sectionIndex.push(this.sections.length-1)):_(\"Reached maximum number of images 6401\")}else _(\"Can't add FormattedSection with an empty image.\")},vl.prototype.getNextImageSectionCharCode=function(){return this.imageSectionID?this.imageSectionID>=63743?null:++this.imageSectionID:(this.imageSectionID=57344,this.imageSectionID)};var xl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},bl={};function _l(t,e,r,n,i,a){if(e.imageName){var o=n[e.imageName];return o?o.displaySize[0]*e.scale*24/a+i:0}var s=r[e.fontStack],l=s&&s[t];return l?l.metrics.advance*e.scale+i:0}function wl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function Tl(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function kl(t,e,r,n,i,a){for(var o=null,s=wl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],f=wl(e-u.x,r,i,a)+u.badness;f<=s&&(o=u,s=f)}return{index:t,x:e,priorBreak:o,badness:s}}function Ml(t,e,r,n,i,a,o){if(\"point\"!==a)return[];if(!t)return[];for(var s,l=[],c=function(t,e,r,n,i,a){for(var o=0,s=0;s<t.length();s++){var l=t.getSection(s);o+=_l(t.getCharCode(s),l,n,i,e,a)}return o/Math.max(1,Math.ceil(o/r))}(t,e,r,n,i,o),u=t.text.indexOf(\"\\u200b\")>=0,f=0,h=0;h<t.length();h++){var p=t.getSection(h),d=t.getCharCode(h);if(xl[d]||(f+=_l(d,p,n,i,e,o)),h<t.length()-1){var g=!((s=d)<11904||!(Vn[\"Bopomofo Extended\"](s)||Vn.Bopomofo(s)||Vn[\"CJK Compatibility Forms\"](s)||Vn[\"CJK Compatibility Ideographs\"](s)||Vn[\"CJK Compatibility\"](s)||Vn[\"CJK Radicals Supplement\"](s)||Vn[\"CJK Strokes\"](s)||Vn[\"CJK Symbols and Punctuation\"](s)||Vn[\"CJK Unified Ideographs Extension A\"](s)||Vn[\"CJK Unified Ideographs\"](s)||Vn[\"Enclosed CJK Letters and Months\"](s)||Vn[\"Halfwidth and Fullwidth Forms\"](s)||Vn.Hiragana(s)||Vn[\"Ideographic Description Characters\"](s)||Vn[\"Kangxi Radicals\"](s)||Vn[\"Katakana Phonetic Extensions\"](s)||Vn.Katakana(s)||Vn[\"Vertical Forms\"](s)||Vn[\"Yi Radicals\"](s)||Vn[\"Yi Syllables\"](s)));(bl[d]||g||p.imageName)&&l.push(kl(h+1,f,c,l,Tl(d,t.getCharCode(h+1),g&&u),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(kl(t.length(),f,c,l,0,!0))}function Al(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function Sl(t,e,r,n,i){if(n||i)for(var a=t[r],o=(t[r].x+a.metrics.advance*a.scale)*n,s=e;s<=r;s++)t[s].x-=o,t[s].y+=i}function El(t,e,r,n,i,a){var o,s=t.image;if(s.content){var l=s.content,c=s.pixelRatio||1;o=[l[0]/c,l[1]/c,s.displaySize[0]-l[2]/c,s.displaySize[1]-l[3]/c]}var u,f,h,p,d=e.left*a,g=e.right*a;\"width\"===r||\"both\"===r?(p=i[0]+d-n[3],f=i[0]+g+n[1]):f=(p=i[0]+(d+g-s.displaySize[0])/2)+s.displaySize[0];var m=e.top*a,v=e.bottom*a;return\"height\"===r||\"both\"===r?(u=i[1]+m-n[0],h=i[1]+v+n[2]):h=(u=i[1]+(m+v-s.displaySize[1])/2)+s.displaySize[1],{image:s,top:u,right:f,bottom:h,left:p,collisionPadding:o}}bl[10]=!0,bl[32]=!0,bl[38]=!0,bl[40]=!0,bl[41]=!0,bl[43]=!0,bl[45]=!0,bl[47]=!0,bl[173]=!0,bl[183]=!0,bl[8203]=!0,bl[8208]=!0,bl[8211]=!0,bl[8231]=!0;var Cl=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);function Ll(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new ii(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new ii(s)),maxSize:r.evaluate(new ii(l)),interpolationType:i}}function Il(t,e,r){var n=e.uSize,i=r.lowerSize;return\"source\"===t.kind?i/128:\"composite\"===t.kind?Ue(i/128,r.upperSize/128,e.uSizeT):n}function Pl(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=i?l(rr.interpolationFactor(i,e,t.minZoom,t.maxZoom),0,1):0;\"camera\"===t.kind?n=Ue(t.minSize,t.maxSize,a):r=a}return{uSizeT:r,uSize:n}}Dn(\"Anchor\",Cl);var zl=Object.freeze({__proto__:null,getSizeData:Ll,evaluateSizeForFeature:Il,evaluateSizeForZoom:Pl,SIZE_PACK_FACTOR:128});function Ol(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o],f=t[o+1];if(!f)return!1;var h=t[o-1].angleTo(u)-u.angleTo(f);for(h=Math.abs((h+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:h}),c+=h;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=u.dist(f)}return!0}function Dl(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function Rl(t,e,r){return t?.6*e*r:0}function Fl(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function Bl(t,e,r,n,i,a){for(var o=Rl(r,i,a),s=Fl(r,n)*a,l=0,c=Dl(t)/2,u=0;u<t.length-1;u++){var f=t[u],h=t[u+1],p=f.dist(h);if(l+p>c){var d=(c-l)/p,g=Ue(f.x,h.x,d),m=Ue(f.y,h.y,d),v=new Cl(g,m,h.angleTo(f),u);return v._round(),!o||Ol(t,v,s,o,e)?v:void 0}l+=p}}function Nl(t,e,r,n,i,a,o,s,l){var c=Rl(n,a,o),u=Fl(n,i),f=u*o,h=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-f<e/4&&(e=f+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,f=Dl(e),h=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var m=e[g],v=e[g+1],y=m.dist(v),x=v.angleTo(m);p+n<h+y;){var b=((p+=n)-h)/y,_=Ue(m.x,v.x,b),w=Ue(m.y,v.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=f){var T=new Cl(_,w,x,g);T._round(),i&&!Ol(e,T,o,i,a)||d.push(T)}}h+=y}return l||d.length||s||(d=t(e,h/2,n,i,a,o,s,!0,c)),d}(t,h?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,f,h,!1,l)}function jl(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var f=l[u],h=l[u+1];f.x<e&&h.x<e||(f.x<e?f=new i(e,f.y+(e-f.x)/(h.x-f.x)*(h.y-f.y))._round():h.x<e&&(h=new i(e,f.y+(e-f.x)/(h.x-f.x)*(h.y-f.y))._round()),f.y<r&&h.y<r||(f.y<r?f=new i(f.x+(r-f.y)/(h.y-f.y)*(h.x-f.x),r)._round():h.y<r&&(h=new i(f.x+(r-f.y)/(h.y-f.y)*(h.x-f.x),r)._round()),f.x>=n&&h.x>=n||(f.x>=n?f=new i(n,f.y+(n-f.x)/(h.x-f.x)*(h.y-f.y))._round():h.x>=n&&(h=new i(n,f.y+(n-f.x)/(h.x-f.x)*(h.y-f.y))._round()),f.y>=a&&h.y>=a||(f.y>=a?f=new i(f.x+(a-f.y)/(h.y-f.y)*(h.x-f.x),a)._round():h.y>=a&&(h=new i(f.x+(a-f.y)/(h.y-f.y)*(h.x-f.x),a)._round()),c&&f.equals(c[c.length-1])||o.push(c=[f]),c.push(h)))))}return o}function Ul(t,e,r,n){var a=[],o=t.image,s=o.pixelRatio,l=o.paddedRect.w-2,c=o.paddedRect.h-2,u=t.right-t.left,f=t.bottom-t.top,h=o.stretchX||[[0,l]],p=o.stretchY||[[0,c]],d=function(t,e){return t+e[1]-e[0]},g=h.reduce(d,0),m=p.reduce(d,0),v=l-g,y=c-m,x=0,b=g,_=0,w=m,T=0,k=v,M=0,A=y;if(o.content&&n){var S=o.content;x=Vl(h,0,S[0]),_=Vl(p,0,S[1]),b=Vl(h,S[0],S[2]),w=Vl(p,S[1],S[3]),T=S[0]-x,M=S[1]-_,k=S[2]-S[0]-b,A=S[3]-S[1]-w}var E=function(n,a,l,c){var h=Hl(n.stretch-x,b,u,t.left),p=Gl(n.fixed-T,k,n.stretch,g),d=Hl(a.stretch-_,w,f,t.top),v=Gl(a.fixed-M,A,a.stretch,m),y=Hl(l.stretch-x,b,u,t.left),S=Gl(l.fixed-T,k,l.stretch,g),E=Hl(c.stretch-_,w,f,t.top),C=Gl(c.fixed-M,A,c.stretch,m),L=new i(h,d),I=new i(y,d),P=new i(y,E),z=new i(h,E),O=new i(p/s,v/s),D=new i(S/s,C/s),R=e*Math.PI/180;if(R){var F=Math.sin(R),B=Math.cos(R),N=[B,-F,F,B];L._matMult(N),I._matMult(N),z._matMult(N),P._matMult(N)}var j=n.stretch+n.fixed,U=a.stretch+a.fixed;return{tl:L,tr:I,bl:z,br:P,tex:{x:o.paddedRect.x+1+j,y:o.paddedRect.y+1+U,w:l.stretch+l.fixed-j,h:c.stretch+c.fixed-U},writingMode:void 0,glyphOffset:[0,0],sectionIndex:0,pixelOffsetTL:O,pixelOffsetBR:D,minFontScaleX:k/s/u,minFontScaleY:A/s/f,isSDF:r}};if(n&&(o.stretchX||o.stretchY))for(var C=ql(h,v,g),L=ql(p,y,m),I=0;I<C.length-1;I++)for(var P=C[I],z=C[I+1],O=0;O<L.length-1;O++)a.push(E(P,L[O],z,L[O+1]));else a.push(E({fixed:0,stretch:-1},{fixed:0,stretch:-1},{fixed:0,stretch:l+1},{fixed:0,stretch:c+1}));return a}function Vl(t,e,r){for(var n=0,i=0,a=t;i<a.length;i+=1){var o=a[i];n+=Math.max(e,Math.min(r,o[1]))-Math.max(e,Math.min(r,o[0]))}return n}function ql(t,e,r){for(var n=[{fixed:-1,stretch:0}],i=0,a=t;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=n[n.length-1];n.push({fixed:s-c.stretch,stretch:c.stretch}),n.push({fixed:s-c.stretch,stretch:c.stretch+(l-s)})}return n.push({fixed:e+1,stretch:r}),n}function Hl(t,e,r,n){return t/e*r+n}function Gl(t,e,r,n){return t-e*r/n}var Yl=function(t,e,r,n,a,o,s,l,c,u){if(this.boxStartIndex=t.length,c){var f=o.top,h=o.bottom,p=o.collisionPadding;p&&(f-=p[1],h+=p[3]);var d=h-f;d>0&&(d=Math.max(10,d),this.circleDiameter=d)}else{var g=o.top*s-l,m=o.bottom*s+l,v=o.left*s-l,y=o.right*s+l,x=o.collisionPadding;if(x&&(v-=x[0]*s,g-=x[1]*s,y+=x[2]*s,m+=x[3]*s),u){var b=new i(v,g),_=new i(y,g),w=new i(v,m),T=new i(y,m),k=u*Math.PI/180;b._rotate(k),_._rotate(k),w._rotate(k),T._rotate(k),v=Math.min(b.x,_.x,w.x,T.x),y=Math.max(b.x,_.x,w.x,T.x),g=Math.min(b.y,_.y,w.y,T.y),m=Math.max(b.y,_.y,w.y,T.y)}t.emplaceBack(e.x,e.y,v,g,y,m,r,n,a)}this.boxEndIndex=t.length},Wl=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=Xl),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function Xl(t,e){return t<e?-1:t>e?1:0}function Zl(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var f=Math.min(o-n,s-a),h=f/2,p=new Wl([],Jl);if(0===f)return new i(n,a);for(var d=n;d<o;d+=f)for(var g=a;g<s;g+=f)p.push(new Kl(d+h,g+h,h,t));for(var m=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new Kl(r/e,n/e,0,t)}(t),v=p.length;p.length;){var y=p.pop();(y.d>m.d||!m.d)&&(m=y,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*y.d)/1e4,v)),y.max-m.d<=e||(p.push(new Kl(y.p.x-(h=y.h/2),y.p.y-h,h,t)),p.push(new Kl(y.p.x+h,y.p.y-h,h,t)),p.push(new Kl(y.p.x-h,y.p.y+h,h,t)),p.push(new Kl(y.p.x+h,y.p.y+h,h,t)),v+=4)}return r&&(console.log(\"num probes: \"+v),console.log(\"best distance: \"+m.d)),m.p}function Jl(t,e){return e.max-t.max}function Kl(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,Ga(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}Wl.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},Wl.prototype.pop=function(){if(0!==this.length){var t=this.data[0],e=this.data.pop();return this.length--,this.length>0&&(this.data[0]=e,this._down(0)),t}},Wl.prototype.peek=function(){return this.data[0]},Wl.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},Wl.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var Ql=Number.POSITIVE_INFINITY;function $l(t,e){return e[1]!==Ql?function(t,e,r){var n=0,i=0;switch(e=Math.abs(e),r=Math.abs(r),t){case\"top-right\":case\"top-left\":case\"top\":i=r-7;break;case\"bottom-right\":case\"bottom-left\":case\"bottom\":i=7-r}switch(t){case\"top-right\":case\"bottom-right\":case\"right\":n=-e;break;case\"top-left\":case\"bottom-left\":case\"left\":n=e}return[n,i]}(t,e[0],e[1]):function(t,e){var r=0,n=0;e<0&&(e=0);var i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-7;break;case\"bottom-right\":case\"bottom-left\":n=7-i;break;case\"bottom\":n=7-e;break;case\"top\":n=e-7}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}(t,e[0])}function tc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function ec(t,e,r,n,a,o,s,l,c,u,f,h,p,d,g){var m=function(t,e,r,n,a,o,s,l){for(var c=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,u=[],f=0,h=e.positionedLines;f<h.length;f+=1)for(var p=h[f],d=0,g=p.positionedGlyphs;d<g.length;d+=1){var m=g[d];if(m.rect){var v=m.rect||{},y=4,x=!0,b=1,_=0,w=(a||l)&&m.vertical,T=m.metrics.advance*m.scale/2;if(l&&e.verticalizable&&(_=p.lineOffset/2-(m.imageName?-(24-m.metrics.width*m.scale)/2:24*(m.scale-1))),m.imageName){var k=s[m.imageName];x=k.sdf,y=1/(b=k.pixelRatio)}var M=a?[m.x+T,m.y]:[0,0],A=a?[0,0]:[m.x+T+r[0],m.y+r[1]-_],S=[0,0];w&&(S=A,A=[0,0]);var E=(m.metrics.left-y)*m.scale-T+A[0],C=(-m.metrics.top-y)*m.scale+A[1],L=E+v.w*m.scale/b,I=C+v.h*m.scale/b,P=new i(E,C),z=new i(L,C),O=new i(E,I),D=new i(L,I);if(w){var R=new i(-T,T- -17),F=-Math.PI/2,B=12-T,N=new i(22-B,-(m.imageName?B:0)),j=new(Function.prototype.bind.apply(i,[null].concat(S)));P._rotateAround(F,R)._add(N)._add(j),z._rotateAround(F,R)._add(N)._add(j),O._rotateAround(F,R)._add(N)._add(j),D._rotateAround(F,R)._add(N)._add(j)}if(c){var U=Math.sin(c),V=Math.cos(c),q=[V,-U,U,V];P._matMult(q),z._matMult(q),O._matMult(q),D._matMult(q)}var H=new i(0,0),G=new i(0,0);u.push({tl:P,tr:z,bl:O,br:D,tex:v,writingMode:e.writingMode,glyphOffset:M,sectionIndex:m.sectionIndex,isSDF:x,pixelOffsetTL:H,pixelOffsetBR:G,minFontScaleX:0,minFontScaleY:0})}}return u}(0,r,l,a,o,s,n,t.allowVerticalPlacement),v=t.textSizeData,y=null;\"source\"===v.kind?(y=[128*a.layout.get(\"text-size\").evaluate(s,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'):\"composite\"===v.kind&&((y=[128*d.compositeTextSizes[0].evaluate(s,{},g),128*d.compositeTextSizes[1].evaluate(s,{},g)])[0]>32640||y[1]>32640)&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'),t.addSymbols(t.text,m,y,l,o,s,u,e,c.lineStartIndex,c.lineLength,p,g);for(var x=0,b=f;x<b.length;x+=1)h[b[x]]=t.text.placedSymbolArray.length-1;return 4*m.length}function rc(t){for(var e in t)return t[e];return null}function nc(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}var ic=gs.VectorTileFeature.types,ac=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function oc(t,e,r,n,i,a,o,s,l,c,u,f,h){var p=s?Math.min(32640,Math.round(s[0])):0,d=s?Math.min(32640,Math.round(s[1])):0;t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,(p<<1)+(l?1:0),d,16*c,16*u,256*f,256*h)}function sc(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}function lc(t){for(var e=0,r=t.sections;e<r.length;e+=1)if(Xn(r[e].text))return!0;return!1}var cc=function(t){this.layoutVertexArray=new Li,this.indexArray=new Fi,this.programConfigurations=t,this.segments=new ia,this.dynamicLayoutVertexArray=new Ii,this.opacityVertexArray=new Pi,this.placedSymbolArray=new Ji};cc.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length&&0===this.indexArray.length&&0===this.dynamicLayoutVertexArray.length&&0===this.opacityVertexArray.length},cc.prototype.upload=function(t,e,r,n){this.isEmpty()||(r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ds.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,Rs.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,ac,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t))},cc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},Dn(\"SymbolBuffers\",cc);var uc=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new ia,this.collisionVertexArray=new Ri};uc.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,Fs.members,!0)},uc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},Dn(\"CollisionBuffers\",uc);var fc=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1,this.hasRTLText=!1,this.sortKeyRanges=[],this.collisionCircleArray=[],this.placementInvProjMatrix=eo([]),this.placementViewportMatrix=eo([]);var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=Ll(this.zoom,e[\"text-size\"]),this.iconSizeData=Ll(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1),this.sortFeaturesByY=(\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey)&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),\"point\"===r.get(\"symbol-placement\")&&(this.writingModes=r.get(\"text-writing-mode\").map((function(t){return gl[t]}))),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id})),this.sourceID=t.sourceID};fc.prototype.createArrays=function(){this.text=new cc(new Ia(Ds.members,this.layers,this.zoom,(function(t){return/^text/.test(t)}))),this.icon=new cc(new Ia(Ds.members,this.layers,this.zoom,(function(t){return/^icon/.test(t)}))),this.glyphOffsetArray=new $i,this.lineVertexArray=new ta,this.symbolInstances=new Qi},fc.prototype.calculateGlyphDependencies=function(t,e,r,n,i){for(var a=0;a<t.length;a++)if(e[t.charCodeAt(a)]=!0,(r||n)&&i){var o=Us[t.charAt(a)];o&&(e[o.charCodeAt(0)]=!0)}},fc.prototype.populate=function(t,e,r){var n=this.layers[0],i=n.layout,a=i.get(\"text-font\"),o=i.get(\"text-field\"),s=i.get(\"icon-image\"),l=(\"constant\"!==o.value.kind||o.value.value instanceof te&&!o.value.value.isEmpty()||o.value.value.toString().length>0)&&(\"constant\"!==a.value.kind||a.value.value.length>0),c=\"constant\"!==s.value.kind||!!s.value.value||Object.keys(s.parameters).length>0,u=i.get(\"symbol-sort-key\");if(this.features=[],l||c){for(var f=e.iconDependencies,h=e.glyphDependencies,p=e.availableImages,d=new ii(this.zoom),g=0,m=t;g<m.length;g+=1){var v=m[g],y=v.feature,x=v.id,b=v.index,_=v.sourceLayerIndex,w=n._featureFilter.needGeometry,T={type:y.type,id:x,properties:y.properties,geometry:w?Da(y):[]};if(n._featureFilter.filter(d,T,r)){w||(T.geometry=Da(y));var k=void 0;if(l){var M=n.getValueAndResolveTokens(\"text-field\",T,r,p),A=te.factory(M);lc(A)&&(this.hasRTLText=!0),(!this.hasRTLText||\"unavailable\"===ei()||this.hasRTLText&&ni.isParsed())&&(k=js(A,n,T))}var S=void 0;if(c){var E=n.getValueAndResolveTokens(\"icon-image\",T,r,p);S=E instanceof ee?E:ee.fromString(E)}if(k||S){var C=this.sortFeaturesByKey?u.evaluate(T,{},r):void 0,L={id:x,text:k,icon:S,index:b,sourceLayerIndex:_,geometry:Da(y),properties:y.properties,type:ic[y.type],sortKey:C};if(this.features.push(L),S&&(f[S.name]=!0),k){var I=a.evaluate(T,{},r).join(\",\"),P=\"map\"===i.get(\"text-rotation-alignment\")&&\"point\"!==i.get(\"symbol-placement\");this.allowVerticalPlacement=this.writingModes&&this.writingModes.indexOf(gl.vertical)>=0;for(var z=0,O=k.sections;z<O.length;z+=1){var D=O[z];if(D.image)f[D.image.name]=!0;else{var R=qn(k.toString()),F=D.fontStack||I,B=h[F]=h[F]||{};this.calculateGlyphDependencies(D.text,B,P,this.allowVerticalPlacement,R)}}}}}}\"line\"===i.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.text?u.text.toString():null;if(h){var p=l(h,f),d=l(h,f,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,f),m=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(h,n[m].geometry,!0)]=m,n[g].geometry=null}else p in r?o(p,d,f):d in e?s(p,d,f):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter((function(t){return t.geometry}))}(this.features)),this.sortFeaturesByKey&&this.features.sort((function(t,e){return t.sortKey-e.sortKey}))}},fc.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},fc.prototype.isEmpty=function(){return 0===this.symbolInstances.length&&!this.hasRTLText},fc.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},fc.prototype.upload=function(t){!this.uploaded&&this.hasDebugData()&&(this.textCollisionBox.upload(t),this.iconCollisionBox.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},fc.prototype.destroyDebugData=function(){this.textCollisionBox.destroy(),this.iconCollisionBox.destroy()},fc.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.hasDebugData()&&this.destroyDebugData()},fc.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},fc.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c,u,f){for(var h=t.indexArray,p=t.layoutVertexArray,d=t.segments.prepareSegment(4*e.length,p,h,a.sortKey),g=this.glyphOffsetArray.length,m=d.vertexLength,v=this.allowVerticalPlacement&&o===gl.vertical?Math.PI/2:0,y=a.text&&a.text.sections,x=0;x<e.length;x++){var b=e[x],_=b.tl,w=b.tr,T=b.bl,k=b.br,M=b.tex,A=b.pixelOffsetTL,S=b.pixelOffsetBR,E=b.minFontScaleX,C=b.minFontScaleY,L=b.glyphOffset,I=b.isSDF,P=b.sectionIndex,z=d.vertexLength,O=L[1];oc(p,s.x,s.y,_.x,O+_.y,M.x,M.y,r,I,A.x,A.y,E,C),oc(p,s.x,s.y,w.x,O+w.y,M.x+M.w,M.y,r,I,S.x,A.y,E,C),oc(p,s.x,s.y,T.x,O+T.y,M.x,M.y+M.h,r,I,A.x,S.y,E,C),oc(p,s.x,s.y,k.x,O+k.y,M.x+M.w,M.y+M.h,r,I,S.x,S.y,E,C),sc(t.dynamicLayoutVertexArray,s,v),h.emplaceBack(z,z+1,z+2),h.emplaceBack(z+1,z+2,z+3),d.vertexLength+=4,d.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(L[0]),x!==e.length-1&&P===e[x+1].sectionIndex||t.programConfigurations.populatePaintArrays(p.length,a,a.index,{},f,y&&y[P])}t.placedSymbolArray.emplaceBack(s.x,s.y,g,this.glyphOffsetArray.length-g,m,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,0,!1,0,u)},fc.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},fc.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s){var l=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),c=l.vertexLength,u=a.layoutVertexArray,f=a.collisionVertexArray,h=s.anchorX,p=s.anchorY;this._addCollisionDebugVertex(u,f,o,h,p,new i(t,e)),this._addCollisionDebugVertex(u,f,o,h,p,new i(r,e)),this._addCollisionDebugVertex(u,f,o,h,p,new i(r,n)),this._addCollisionDebugVertex(u,f,o,h,p,new i(t,n)),l.vertexLength+=4;var d=a.indexArray;d.emplaceBack(c,c+1),d.emplaceBack(c+1,c+2),d.emplaceBack(c+2,c+3),d.emplaceBack(c+3,c),l.primitiveLength+=4},fc.prototype.addDebugCollisionBoxes=function(t,e,r,n){for(var i=t;i<e;i++){var a=this.collisionBoxArray.get(i);this.addCollisionDebugVertices(a.x1,a.y1,a.x2,a.y2,n?this.textCollisionBox:this.iconCollisionBox,a.anchorPoint,r)}},fc.prototype.generateCollisionDebugBuffers=function(){this.hasDebugData()&&this.destroyDebugData(),this.textCollisionBox=new uc(Oi,Bs.members,qi),this.iconCollisionBox=new uc(Oi,Bs.members,qi);for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.verticalTextBoxStartIndex,e.verticalTextBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e,!1),this.addDebugCollisionBoxes(e.verticalIconBoxStartIndex,e.verticalIconBoxEndIndex,e,!1)}},fc.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i,a,o,s,l){for(var c={},u=e;u<r;u++){var f=t.get(u);c.textBox={x1:f.x1,y1:f.y1,x2:f.x2,y2:f.y2,anchorPointX:f.anchorPointX,anchorPointY:f.anchorPointY},c.textFeatureIndex=f.featureIndex;break}for(var h=n;h<i;h++){var p=t.get(h);c.verticalTextBox={x1:p.x1,y1:p.y1,x2:p.x2,y2:p.y2,anchorPointX:p.anchorPointX,anchorPointY:p.anchorPointY},c.verticalTextFeatureIndex=p.featureIndex;break}for(var d=a;d<o;d++){var g=t.get(d);c.iconBox={x1:g.x1,y1:g.y1,x2:g.x2,y2:g.y2,anchorPointX:g.anchorPointX,anchorPointY:g.anchorPointY},c.iconFeatureIndex=g.featureIndex;break}for(var m=s;m<l;m++){var v=t.get(m);c.verticalIconBox={x1:v.x1,y1:v.y1,x2:v.x2,y2:v.y2,anchorPointX:v.anchorPointX,anchorPointY:v.anchorPointY},c.verticalIconFeatureIndex=v.featureIndex;break}return c},fc.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.verticalTextBoxStartIndex,r.verticalTextBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex,r.verticalIconBoxStartIndex,r.verticalIconBoxEndIndex))}},fc.prototype.hasTextData=function(){return this.text.segments.get().length>0},fc.prototype.hasIconData=function(){return this.icon.segments.get().length>0},fc.prototype.hasDebugData=function(){return this.textCollisionBox&&this.iconCollisionBox},fc.prototype.hasTextCollisionBoxData=function(){return this.hasDebugData()&&this.textCollisionBox.segments.get().length>0},fc.prototype.hasIconCollisionBoxData=function(){return this.hasDebugData()&&this.iconCollisionBox.segments.get().length>0},fc.prototype.addIndicesForPlacedSymbol=function(t,e){for(var r=t.placedSymbolArray.get(e),n=r.vertexStartIndex+4*r.numGlyphs,i=r.vertexStartIndex;i<n;i+=4)t.indexArray.emplaceBack(i,i+1,i+2),t.indexArray.emplaceBack(i+1,i+2,i+3)},fc.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort((function(t,e){return n[t]-n[e]||i[e]-i[t]})),a},fc.prototype.addToSortKeyRanges=function(t,e){var r=this.sortKeyRanges[this.sortKeyRanges.length-1];r&&r.sortKey===e?r.symbolInstanceEnd=t+1:this.sortKeyRanges.push({sortKey:e,symbolInstanceStart:t,symbolInstanceEnd:t+1})},fc.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=this.symbolInstances.get(n[r]);this.featureSortOrder.push(i.featureIndex),[i.rightJustifiedTextSymbolIndex,i.centerJustifiedTextSymbolIndex,i.leftJustifiedTextSymbolIndex].forEach((function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedSymbol(e.text,t)})),i.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.text,i.verticalPlacedTextSymbolIndex),i.placedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,i.placedIconSymbolIndex),i.verticalPlacedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,i.verticalPlacedIconSymbolIndex)}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},Dn(\"SymbolBucket\",fc,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),fc.MAX_GLYPHS=65535,fc.addDynamicAttributes=sc;var hc=new yi({\"symbol-placement\":new pi(At.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new pi(At.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new pi(At.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new di(At.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new pi(At.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new pi(At.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new pi(At.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new pi(At.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new pi(At.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new di(At.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new pi(At.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new pi(At.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new di(At.layout_symbol[\"icon-image\"]),\"icon-rotate\":new di(At.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new pi(At.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new pi(At.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new di(At.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new di(At.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new pi(At.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new pi(At.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new pi(At.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new di(At.layout_symbol[\"text-field\"]),\"text-font\":new di(At.layout_symbol[\"text-font\"]),\"text-size\":new di(At.layout_symbol[\"text-size\"]),\"text-max-width\":new di(At.layout_symbol[\"text-max-width\"]),\"text-line-height\":new pi(At.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new di(At.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new di(At.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new di(At.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new pi(At.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new di(At.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new pi(At.layout_symbol[\"text-max-angle\"]),\"text-writing-mode\":new pi(At.layout_symbol[\"text-writing-mode\"]),\"text-rotate\":new di(At.layout_symbol[\"text-rotate\"]),\"text-padding\":new pi(At.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new pi(At.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new di(At.layout_symbol[\"text-transform\"]),\"text-offset\":new di(At.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new pi(At.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new pi(At.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new pi(At.layout_symbol[\"text-optional\"])}),pc={paint:new yi({\"icon-opacity\":new di(At.paint_symbol[\"icon-opacity\"]),\"icon-color\":new di(At.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new di(At.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new di(At.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new di(At.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new pi(At.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new pi(At.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new di(At.paint_symbol[\"text-opacity\"]),\"text-color\":new di(At.paint_symbol[\"text-color\"],{runtimeType:Bt,getOverride:function(t){return t.textColor},hasOverride:function(t){return!!t.textColor}}),\"text-halo-color\":new di(At.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new di(At.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new di(At.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new pi(At.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new pi(At.paint_symbol[\"text-translate-anchor\"])}),layout:hc},dc=function(t){this.type=t.property.overrides?t.property.overrides.runtimeType:Ot,this.defaultValue=t};dc.prototype.evaluate=function(t){if(t.formattedSection){var e=this.defaultValue.property.overrides;if(e&&e.hasOverride(t.formattedSection))return e.getOverride(t.formattedSection)}return t.feature&&t.featureState?this.defaultValue.evaluate(t.feature,t.featureState):this.defaultValue.property.specification.default},dc.prototype.eachChild=function(t){this.defaultValue.isConstant()||t(this.defaultValue.value._styleExpression.expression)},dc.prototype.outputDefined=function(){return!1},dc.prototype.serialize=function(){return null},Dn(\"FormatSectionOverride\",dc,{omit:[\"defaultValue\"]});var gc=function(t){function e(e){t.call(this,e,pc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.recalculate=function(e,r){if(t.prototype.recalculate.call(this,e,r),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(this.layout._values[\"icon-rotation-alignment\"]=\"point\"!==this.layout.get(\"symbol-placement\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(this.layout._values[\"text-rotation-alignment\"]=\"point\"!==this.layout.get(\"symbol-placement\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\")),\"point\"===this.layout.get(\"symbol-placement\")){var n=this.layout.get(\"text-writing-mode\");if(n){for(var i=[],a=0,o=n;a<o.length;a+=1){var s=o[a];i.indexOf(s)<0&&i.push(s)}this.layout._values[\"text-writing-mode\"]=i}else this.layout._values[\"text-writing-mode\"]=[\"horizontal\"]}this._setPaintOverrides()},e.prototype.getValueAndResolveTokens=function(t,e,r,n){var i=this.layout.get(t).evaluate(e,{},r,n),a=this._unevaluatedLayout._values[t];return a.isDataDriven()||Vr(a.value)||!i?i:function(t,e){return e.replace(/{([^{}]+)}/g,(function(e,r){return r in t?String(t[r]):\"\"}))}(e.properties,i)},e.prototype.createBucket=function(t){return new fc(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype._setPaintOverrides=function(){for(var t=0,r=pc.paint.overridableProperties;t<r.length;t+=1){var n=r[t];if(e.hasPaintOverride(this.layout,n)){var i,a=this.paint.get(n),o=new dc(a),s=new Ur(o,a.property.specification);i=\"constant\"===a.value.kind||\"source\"===a.value.kind?new Hr(\"source\",s):new Gr(\"composite\",s,a.value.zoomStops,a.value._interpolationType),this.paint._values[n]=new fi(a.property,i,a.parameters)}}},e.prototype._handleOverridablePaintPropertyUpdate=function(t,r,n){return!(!this.layout||r.isDataDriven()||n.isDataDriven())&&e.hasPaintOverride(this.layout,t)},e.hasPaintOverride=function(t,e){var r=t.get(\"text-field\"),n=pc.paint.properties[e],i=!1,a=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n.overrides&&n.overrides.hasOverride(r[e]))return void(i=!0)};if(\"constant\"===r.value.kind&&r.value.value instanceof te)a(r.value.value.sections);else if(\"source\"===r.value.kind){var o=function(t){i||(t instanceof oe&&ie(t.value)===Vt?a(t.value.sections):t instanceof ue?a(t.sections):t.eachChild(o))},s=r.value;s._styleExpression&&o(s._styleExpression.expression)}return i},e}(xi),mc={paint:new yi({\"background-color\":new pi(At.paint_background[\"background-color\"]),\"background-pattern\":new mi(At.paint_background[\"background-pattern\"]),\"background-opacity\":new pi(At.paint_background[\"background-opacity\"])})},vc=function(t){function e(e){t.call(this,e,mc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(xi),yc={paint:new yi({\"raster-opacity\":new pi(At.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new pi(At.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new pi(At.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new pi(At.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new pi(At.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new pi(At.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new pi(At.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new pi(At.paint_raster[\"raster-fade-duration\"])})},xc=function(t){function e(e){t.call(this,e,yc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(xi),bc=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(xi),_c={circle:oo,heatmap:vo,hillshade:xo,fill:as,\"fill-extrusion\":ws,line:zs,symbol:gc,background:vc,raster:xc},wc=self.HTMLImageElement,Tc=self.HTMLCanvasElement,kc=self.HTMLVideoElement,Mc=self.ImageData,Ac=self.ImageBitmap,Sc=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Sc.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof wc||t instanceof Tc||t instanceof kc||t instanceof Mc||Ac&&t instanceof Ac?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof wc||t instanceof Tc||t instanceof kc||t instanceof Mc||Ac&&t instanceof Ac?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Sc.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Sc.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Sc.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ec=function(t){var e=this;this._callback=t,this._triggered=!1,\"undefined\"!=typeof MessageChannel&&(this._channel=new MessageChannel,this._channel.port2.onmessage=function(){e._triggered=!1,e._callback()})};Ec.prototype.trigger=function(){var t=this;this._triggered||(this._triggered=!0,this._channel?this._channel.port1.postMessage(!0):setTimeout((function(){t._triggered=!1,t._callback()}),0))},Ec.prototype.remove=function(){delete this._channel,this._callback=function(){}};var Cc=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.tasks={},this.taskQueue=[],this.cancelCallbacks={},g([\"receive\",\"process\"],this),this.invoker=new Ec(this.process),this.target.addEventListener(\"message\",this.receive,!1),this.globalScope=k()?t:self};function Lc(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}Cc.prototype.send=function(t,e,r,n,i){var a=this;void 0===i&&(i=!1);var o=Math.round(1e18*Math.random()).toString(36).substring(0,10);r&&(this.callbacks[o]=r);var s=S(this.globalScope)?void 0:[];return this.target.postMessage({id:o,type:t,hasCallback:!!r,targetMapId:n,mustQueue:i,sourceMapId:this.mapId,data:Nn(e,s)},s),{cancel:function(){r&&delete a.callbacks[o],a.target.postMessage({id:o,type:\"<cancel>\",targetMapId:n,sourceMapId:a.mapId})}}},Cc.prototype.receive=function(t){var e=t.data,r=e.id;if(r&&(!e.targetMapId||this.mapId===e.targetMapId))if(\"<cancel>\"===e.type){delete this.tasks[r];var n=this.cancelCallbacks[r];delete this.cancelCallbacks[r],n&&n()}else k()||e.mustQueue?(this.tasks[r]=e,this.taskQueue.push(r),this.invoker.trigger()):this.processTask(r,e)},Cc.prototype.process=function(){if(this.taskQueue.length){var t=this.taskQueue.shift(),e=this.tasks[t];delete this.tasks[t],this.taskQueue.length&&this.invoker.trigger(),e&&this.processTask(t,e)}},Cc.prototype.processTask=function(t,e){var r=this;if(\"<response>\"===e.type){var n=this.callbacks[t];delete this.callbacks[t],n&&(e.error?n(jn(e.error)):n(null,jn(e.data)))}else{var i=!1,a=S(this.globalScope)?void 0:[],o=e.hasCallback?function(e,n){i=!0,delete r.cancelCallbacks[t],r.target.postMessage({id:t,type:\"<response>\",sourceMapId:r.mapId,error:e?Nn(e):null,data:Nn(n,a)},a)}:function(t){i=!0},s=null,l=jn(e.data);if(this.parent[e.type])s=this.parent[e.type](e.sourceMapId,l,o);else if(this.parent.getWorkerSource){var c=e.type.split(\".\");s=this.parent.getWorkerSource(e.sourceMapId,c[0],l.source)[c[1]](l,o)}else o(new Error(\"Could not find function \"+e.type));!i&&s&&s.cancel&&(this.cancelCallbacks[t]=s.cancel)}},Cc.prototype.remove=function(){this.invoker.remove(),this.target.removeEventListener(\"message\",this.receive,!1)};var Ic=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};Ic.prototype.setNorthEast=function(t){return this._ne=t instanceof Pc?new Pc(t.lng,t.lat):Pc.convert(t),this},Ic.prototype.setSouthWest=function(t){return this._sw=t instanceof Pc?new Pc(t.lng,t.lat):Pc.convert(t),this},Ic.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Pc)e=t,r=t;else{if(!(t instanceof Ic))return Array.isArray(t)?4===t.length||t.every(Array.isArray)?this.extend(Ic.convert(t)):this.extend(Pc.convert(t)):this;if(r=t._ne,!(e=t._sw)||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Pc(e.lng,e.lat),this._ne=new Pc(r.lng,r.lat)),this},Ic.prototype.getCenter=function(){return new Pc((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},Ic.prototype.getSouthWest=function(){return this._sw},Ic.prototype.getNorthEast=function(){return this._ne},Ic.prototype.getNorthWest=function(){return new Pc(this.getWest(),this.getNorth())},Ic.prototype.getSouthEast=function(){return new Pc(this.getEast(),this.getSouth())},Ic.prototype.getWest=function(){return this._sw.lng},Ic.prototype.getSouth=function(){return this._sw.lat},Ic.prototype.getEast=function(){return this._ne.lng},Ic.prototype.getNorth=function(){return this._ne.lat},Ic.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},Ic.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},Ic.prototype.isEmpty=function(){return!(this._sw&&this._ne)},Ic.prototype.contains=function(t){var e=Pc.convert(t),r=e.lng,n=e.lat,i=this._sw.lng<=r&&r<=this._ne.lng;return this._sw.lng>this._ne.lng&&(i=this._sw.lng>=r&&r>=this._ne.lng),this._sw.lat<=n&&n<=this._ne.lat&&i},Ic.convert=function(t){return!t||t instanceof Ic?t:new Ic(t)};var Pc=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};Pc.prototype.wrap=function(){return new Pc(c(this.lng,-180,180),this.lat)},Pc.prototype.toArray=function(){return[this.lng,this.lat]},Pc.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Pc.prototype.distanceTo=function(t){var e=Math.PI/180,r=this.lat*e,n=t.lat*e,i=Math.sin(r)*Math.sin(n)+Math.cos(r)*Math.cos(n)*Math.cos((t.lng-this.lng)*e);return 6371008.8*Math.acos(Math.min(i,1))},Pc.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new Ic(new Pc(this.lng-r,this.lat-e),new Pc(this.lng+r,this.lat+e))},Pc.convert=function(t){if(t instanceof Pc)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Pc(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Pc(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var zc=2*Math.PI*6371008.8;function Oc(t){return zc*Math.cos(t*Math.PI/180)}function Dc(t){return(180+t)/360}function Rc(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function Fc(t,e){return t/Oc(e)}function Bc(t){return 360/Math.PI*Math.atan(Math.exp((180-360*t)*Math.PI/180))-90}var Nc=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Nc.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Pc.convert(t);return new Nc(Dc(r.lng),Rc(r.lat),Fc(e,r.lat))},Nc.prototype.toLngLat=function(){return new Pc(360*this.x-180,Bc(this.y))},Nc.prototype.toAltitude=function(){return this.z*Oc(Bc(this.y))},Nc.prototype.meterInMercatorCoordinateUnits=function(){return 1/zc*(t=Bc(this.y),1/Math.cos(t*Math.PI/180));var t};var jc=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=qc(0,t,t,e,r)};jc.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},jc.prototype.url=function(t,e){var r,n,i,a,o,s=(n=this.y,i=this.z,a=Lc(256*(r=this.x),256*(n=Math.pow(2,i)-n-1),i),o=Lc(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},jc.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i(8192*(t.x*e-this.x),8192*(t.y*e-this.y))},jc.prototype.toString=function(){return this.z+\"/\"+this.x+\"/\"+this.y};var Uc=function(t,e){this.wrap=t,this.canonical=e,this.key=qc(t,e.z,e.z,e.x,e.y)},Vc=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new jc(r,+n,+i),this.key=qc(e,t,r,n,i)};function qc(t,e,r,n,i){(t*=2)<0&&(t=-1*t-1);var a=1<<r;return(a*a*t+a*i+n).toString(36)+r.toString(36)+e.toString(36)}Vc.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},Vc.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new Vc(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new Vc(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},Vc.prototype.calculateScaledKey=function(t,e){var r=this.canonical.z-t;return t>this.canonical.z?qc(this.wrap*+e,t,this.canonical.z,this.canonical.x,this.canonical.y):qc(this.wrap*+e,t,t,this.canonical.x>>r,this.canonical.y>>r)},Vc.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},Vc.prototype.children=function(t){if(this.overscaledZ>=t)return[new Vc(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new Vc(e,this.wrap,e,r,n),new Vc(e,this.wrap,e,r+1,n),new Vc(e,this.wrap,e,r,n+1),new Vc(e,this.wrap,e,r+1,n+1)]},Vc.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},Vc.prototype.wrapped=function(){return new Vc(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},Vc.prototype.unwrapTo=function(t){return new Vc(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},Vc.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},Vc.prototype.toUnwrapped=function(){return new Uc(this.wrap,this.canonical)},Vc.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},Vc.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Nc(t.x-this.wrap,t.y))},Dn(\"CanonicalTileID\",jc),Dn(\"OverscaledTileID\",Vc,{omit:[\"posMatrix\"]});var Hc=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return _('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');this.stride=e.height;var n=this.dim=e.height-2;this.data=new Uint32Array(e.data.buffer),this.encoding=r||\"mapbox\";for(var i=0;i<n;i++)this.data[this._idx(-1,i)]=this.data[this._idx(0,i)],this.data[this._idx(n,i)]=this.data[this._idx(n-1,i)],this.data[this._idx(i,-1)]=this.data[this._idx(i,0)],this.data[this._idx(i,n)]=this.data[this._idx(i,n-1)];this.data[this._idx(-1,-1)]=this.data[this._idx(0,0)],this.data[this._idx(n,-1)]=this.data[this._idx(n-1,0)],this.data[this._idx(-1,n)]=this.data[this._idx(0,n-1)],this.data[this._idx(n,n)]=this.data[this._idx(n-1,n-1)]};Hc.prototype.get=function(t,e){var r=new Uint8Array(this.data.buffer),n=4*this._idx(t,e);return(\"terrarium\"===this.encoding?this._unpackTerrarium:this._unpackMapbox)(r[n],r[n+1],r[n+2])},Hc.prototype.getUnpackVector=function(){return\"terrarium\"===this.encoding?[256,1,1/256,32768]:[6553.6,25.6,.1,1e4]},Hc.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Hc.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Hc.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Hc.prototype.getPixels=function(){return new po({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Hc.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.data[this._idx(u,c)]=t.data[this._idx(u+s,c+l)]},Dn(\"DEMData\",Hc);var Gc=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Gc.prototype.encode=function(t){return this._stringToNumber[t]},Gc.prototype.decode=function(t){return this._numberToString[t]};var Yc=function(t,e,r,n,i){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,this.id=i},Wc={geometry:{configurable:!0}};Wc.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Wc.geometry.set=function(t){this._geometry=t},Yc.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Yc.prototype,Wc);var Xc=function(){this.state={},this.stateChanges={},this.deletedStates={}};Xc.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},u(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},Xc.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},Xc.prototype.getState=function(t,e){var r=String(e),n=u({},(this.state[t]||{})[r],(this.stateChanges[t]||{})[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var i=this.deletedStates[t][e];if(null===i)return{};for(var a in i)delete n[a]}return n},Xc.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},Xc.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),u(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var f=0,h=Object.keys(this.deletedStates[o][c]);f<h.length;f+=1)delete this.state[o][c][h[f]];s[c]=this.state[o][c]}r[o]=r[o]||{},u(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var p in t)t[p].setFeatureState(r,e)};var Zc=function(t,e){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=new Ln(8192,16,0),this.grid3D=new Ln(8192,16,0),this.featureIndexArray=new ra,this.promoteId=e};function Jc(t,e,r,n,i){return v(t,(function(t,a){var o=e instanceof hi?e.get(a):null;return o&&o.evaluate?o.evaluate(r,n,i):o}))}function Kc(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function Qc(t,e){return e-t}Zc.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],f=0;f<c.length;f++){var h=c[f];u[0]=Math.min(u[0],h.x),u[1]=Math.min(u[1],h.y),u[2]=Math.max(u[2],h.x),u[3]=Math.max(u[3],h.y)}u[0]<8192&&u[1]<8192&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Zc.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new gs.VectorTile(new Hs(this.rawTileData)).layers,this.sourceLayerCoder=new Gc(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Zc.prototype.query=function(t,e,r,n){var a=this;this.loadVTLayers();for(var o=t.params||{},s=8192/t.tileSize/t.scale,l=rn(o.filter),c=t.queryGeometry,u=t.queryPadding*s,f=Kc(c),h=this.grid.query(f.minX-u,f.minY-u,f.maxX+u,f.maxY+u),p=Kc(t.cameraQueryGeometry),d=0,g=this.grid3D.query(p.minX-u,p.minY-u,p.maxX+u,p.maxY+u,(function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,f=c;u<f.length;u+=1)if(Wa(t,f[u]))return!0;for(var h=0;h<t.length-1;h++)if(Xa(t[h],t[h+1],c))return!0;return!1}(t.cameraQueryGeometry,e-u,r-u,n+u,a+u)}));d<g.length;d+=1)h.push(g[d]);h.sort(Qc);for(var m,v={},y=function(i){var u=h[i];if(u!==m){m=u;var f=a.featureIndexArray.get(u),p=null;a.loadMatchingFeature(v,f.bucketIndex,f.sourceLayerIndex,f.featureIndex,l,o.layers,o.availableImages,e,r,n,(function(e,r,n){return p||(p=Da(e)),r.queryIntersectsFeature(c,e,n,p,a.z,t.transform,s,t.pixelPosMatrix)}))}},x=0;x<h.length;x++)y(x);return v},Zc.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s,l,c,u){var f=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,f)){var h=this.sourceLayerCoder.decode(r),p=this.vtLayers[h].feature(n);if(i.filter(new ii(this.tileID.overscaledZ),p))for(var d=this.getId(p,h),g=0;g<f.length;g++){var m=f[g];if(!(a&&a.indexOf(m)<0)){var v=s[m];if(v){var y={};void 0!==d&&c&&(y=c.getState(v.sourceLayer||\"_geojsonTileLayer\",d));var x=l[m];x.paint=Jc(x.paint,v.paint,p,y,o),x.layout=Jc(x.layout,v.layout,p,y,o);var b=!u||u(p,v,y);if(b){var _=new Yc(p,this.z,this.x,this.y,d);_.layer=x;var w=t[m];void 0===w&&(w=t[m]=[]),w.push({featureIndex:n,feature:_,intersectionZ:b})}}}}}},Zc.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a,o,s){var l={};this.loadVTLayers();for(var c=rn(i),u=0,f=t;u<f.length;u+=1)this.loadMatchingFeature(l,r,n,f[u],c,a,o,s,e);return l},Zc.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},Zc.prototype.getId=function(t,e){var r=t.id;return this.promoteId&&\"boolean\"==typeof(r=t.properties[\"string\"==typeof this.promoteId?this.promoteId:this.promoteId[e]])&&(r=Number(r)),r},Dn(\"FeatureIndex\",Zc,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var $c=function(t,e){this.tileID=t,this.uid=h(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.hasRTLText=!1,this.dependencies={},this.expiredRequestCount=0,this.state=\"loading\"};$c.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<R.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},$c.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},$c.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map((function(t){return e.getLayer(t)})).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map((function(t){return n.filter((function(e){return e.id===t}))[0]})));for(var o=0,s=n;o<s.length;o+=1)r[s[o].id]=t}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof fc){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}if(this.hasRTLText=!1,this.hasSymbolBuckets)for(var a in this.buckets){var o=this.buckets[a];if(o instanceof fc&&o.hasRTLText){this.hasRTLText=!0,ni.isLoading()||ni.isLoaded()||\"deferred\"!==ei()||ri();break}}for(var s in this.queryPadding=0,this.buckets){var l=this.buckets[s];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(s).queryRadius(l))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Xi},$c.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},$c.prototype.getBucket=function(t){return this.buckets[t.id]},$c.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Sc(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Sc(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},$c.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},$c.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l,c){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:n,cameraQueryGeometry:i,scale:a,tileSize:this.tileSize,pixelPosMatrix:c,transform:s,params:o,queryPadding:this.queryPadding*l},t,e,r):{}},$c.prototype.querySourceFeatures=function(t,e){var r=this.latestFeatureIndex;if(r&&r.rawTileData){var n=r.loadVTLayers(),i=e?e.sourceLayer:\"\",a=n._geojsonTileLayer||n[i];if(a)for(var o=rn(e&&e.filter),s=this.tileID.canonical,l=s.z,c=s.x,u=s.y,f={z:l,x:c,y:u},h=0;h<a.length;h++){var p=a.feature(h);if(o.filter(new ii(this.tileID.overscaledZ),p)){var d=r.getId(p,i),g=new Yc(p,l,c,u,d);g.tile=f,t.push(g)}}}},$c.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},$c.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},$c.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=M(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},$c.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},$c.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets)if(e.style.hasLayer(n)){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];if(o&&s&&0!==Object.keys(s).length){i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{});var l=e&&e.style&&e.style.getLayer(n);l&&(this.queryPadding=Math.max(this.queryPadding,l.queryRadius(i)))}}}},$c.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},$c.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<R.now()},$c.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},$c.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=R.now()+t},$c.prototype.setDependencies=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1)r[i[n]]=!0;this.dependencies[t]=r},$c.prototype.hasDependency=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=this.dependencies[n[r]];if(i)for(var a=0,o=e;a<o.length;a+=1)if(i[o[a]])return!0}return!1};var tu=self.performance,eu=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},tu.mark(this._marks.start)};eu.prototype.finish=function(){tu.mark(this._marks.end);var t=tu.getEntriesByName(this._marks.measure);return 0===t.length&&(tu.measure(this._marks.measure,this._marks.start,this._marks.end),t=tu.getEntriesByName(this._marks.measure),tu.clearMarks(this._marks.start),tu.clearMarks(this._marks.end),tu.clearMeasures(this._marks.measure)),t},t.Actor=Cc,t.AlphaImage=ho,t.CanonicalTileID=jc,t.CollisionBoxArray=Xi,t.Color=Kt,t.DEMData=Hc,t.DataConstantProperty=pi,t.DictionaryCoder=Gc,t.EXTENT=8192,t.ErrorEvent=kt,t.EvaluationParameters=ii,t.Event=Tt,t.Evented=Mt,t.FeatureIndex=Zc,t.FillBucket=rs,t.FillExtrusionBucket=xs,t.ImageAtlas=dl,t.ImagePosition=hl,t.LineBucket=Cs,t.LngLat=Pc,t.LngLatBounds=Ic,t.MercatorCoordinate=Nc,t.ONE_EM=24,t.OverscaledTileID=Vc,t.Point=i,t.Point$1=i,t.Properties=yi,t.Protobuf=Hs,t.RGBAImage=po,t.RequestManager=q,t.RequestPerformance=eu,t.ResourceType=ht,t.SegmentVector=ia,t.SourceFeatureState=Xc,t.StructArrayLayout1ui2=Hi,t.StructArrayLayout2f1f2i16=Di,t.StructArrayLayout2i4=Mi,t.StructArrayLayout3ui6=Fi,t.StructArrayLayout4i8=Ai,t.SymbolBucket=fc,t.Texture=Sc,t.Tile=$c,t.Transitionable=si,t.Uniform1f=va,t.Uniform1i=ma,t.Uniform2f=ya,t.Uniform3f=xa,t.Uniform4f=ba,t.UniformColor=_a,t.UniformMatrix4f=Ta,t.UnwrappedTileID=Uc,t.ValidationError=St,t.WritingMode=gl,t.ZoomHistory=Un,t.add=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t},t.addDynamicAttributes=sc,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach((function(t,o){e(t,(function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)}))}))},t.bezier=o,t.bindAll=g,t.browser=R,t.cacheEntryPossiblyAdded=function(t){++ut>ot&&(t.getActor().send(\"enforceCacheSizeLimit\",at),ut=0)},t.clamp=l,t.clearTileCache=function(t){var e=self.caches.delete(\"mapbox-tiles\");t&&e.catch(t).then((function(){return t()}))},t.clipLine=jl,t.clone=function(t){var e=new to(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=x,t.clone$2=function(t){var e=new to(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e},t.collisionCircleLayout=Ns,t.config=F,t.create=function(){var t=new to(16);return to!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=function(){var t=new to(9);return to!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t},t.create$2=function(){var t=new to(4);return to!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=qr,t.createLayout=Ti,t.createStyleLayer=function(t){return\"custom\"===t.type?new bc(t):new _c[t.type](t)},t.cross=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t},t.deepEqual=function t(e,r){if(Array.isArray(e)){if(!Array.isArray(r)||e.length!==r.length)return!1;for(var n=0;n<e.length;n++)if(!t(e[n],r[n]))return!1;return!0}if(\"object\"==typeof e&&null!==e&&null!==r){if(\"object\"!=typeof r)return!1;if(Object.keys(e).length!==Object.keys(r).length)return!1;for(var i in e)if(!t(e[i],r[i]))return!1;return!0}return e===r},t.dot=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]},t.dot$1=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]},t.ease=s,t.emitValidationErrors=Cn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){st(),Q&&Q.then((function(e){e.keys().then((function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])}))}))},t.evaluateSizeForFeature=Il,t.evaluateSizeForZoom=Pl,t.evaluateVariableOffset=$l,t.evented=ti,t.extend=u,t.featureFilter=rn,t.filterObject=y,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=Al,t.getAnchorJustification=tc,t.getArrayBuffer=yt,t.getImage=bt,t.getJSON=function(t,e){return vt(u(t,{type:\"json\"}),e)},t.getRTLTextPluginStatus=ei,t.getReferrer=mt,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=eo,t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*g-f*d,M=u*m-h*d,A=u*v-p*d,S=f*m-h*g,E=f*v-p*g,C=h*v-p*m,L=y*C-x*E+b*S+_*A-w*M+T*k;return L?(t[0]=(s*C-l*E+c*S)*(L=1/L),t[1]=(i*E-n*C-a*S)*L,t[2]=(g*T-m*w+v*_)*L,t[3]=(h*w-f*T-p*_)*L,t[4]=(l*A-o*C-c*M)*L,t[5]=(r*C-i*A+a*M)*L,t[6]=(m*b-d*T-v*x)*L,t[7]=(u*T-h*b+p*x)*L,t[8]=(o*E-s*A+c*k)*L,t[9]=(n*A-r*E-a*k)*L,t[10]=(d*w-g*b+v*y)*L,t[11]=(f*b-u*w-p*y)*L,t[12]=(s*M-o*S-l*k)*L,t[13]=(r*S-n*M+i*k)*L,t[14]=(g*x-d*_-m*y)*L,t[15]=(u*_-f*x+h*y)*L,t):null},t.isChar=Vn,t.isMapboxURL=H,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=vt,t.mapObject=v,t.mercatorXfromLng=Dc,t.mercatorYfromLat=Rc,t.mercatorZfromAltitude=Fc,t.mul=io,t.multiply=ro,t.mvt=gs,t.normalize=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;return a>0&&(a=1/Math.sqrt(a)),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a,t},t.number=Ue,t.offscreenCanvasSupported=ft,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Hs(t).readFields(ll,[])},t.pbf=Hs,t.performSymbolLayout=function(t,e,r,n,i,a,o){t.createArrays(),t.tilePixelRatio=8192/(512*t.overscaling),t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new ii(u.minZoom),o),l[\"text-size\"].possiblyEvaluate(new ii(f),o)]}if(\"composite\"===t.iconSizeData.kind){var h=t.iconSizeData,p=h.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new ii(h.minZoom),o),l[\"icon-size\"].possiblyEvaluate(new ii(p),o)]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new ii(t.zoom+1),o),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new ii(t.zoom+1),o),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new ii(18));for(var d=24*s.get(\"text-line-height\"),g=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),m=s.get(\"text-keep-upright\"),v=s.get(\"text-size\"),y=function(){var a=b[x],l=s.get(\"text-font\").evaluate(a,{},o).join(\",\"),u=v.evaluate(a,{},o),f=c.layoutTextSize.evaluate(a,{},o),h=c.layoutIconSize.evaluate(a,{},o),p={horizontal:{},vertical:void 0},y=a.text,w=[0,0];if(y){var T=y.toString(),k=24*s.get(\"text-letter-spacing\").evaluate(a,{},o),M=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n=r[e].charCodeAt(0),Vn.Arabic(n)||Vn[\"Arabic Supplement\"](n)||Vn[\"Arabic Extended-A\"](n)||Vn[\"Arabic Presentation Forms-A\"](n)||Vn[\"Arabic Presentation Forms-B\"](n))return!1;var n;return!0}(T)?k:0,A=s.get(\"text-anchor\").evaluate(a,{},o),S=s.get(\"text-variable-anchor\");if(!S){var E=s.get(\"text-radial-offset\").evaluate(a,{},o);w=E?$l(A,[24*E,Ql]):s.get(\"text-offset\").evaluate(a,{},o).map((function(t){return 24*t}))}var C=g?\"center\":s.get(\"text-justify\").evaluate(a,{},o),L=s.get(\"symbol-placement\"),I=\"point\"===L?24*s.get(\"text-max-width\").evaluate(a,{},o):0,P=function(){t.allowVerticalPlacement&&qn(T)&&(p.vertical=yl(y,e,r,i,l,I,d,A,\"left\",M,w,gl.vertical,!0,L,f,u))};if(!g&&S){for(var z=\"auto\"===C?S.map((function(t){return tc(t)})):[C],O=!1,D=0;D<z.length;D++){var R=z[D];if(!p.horizontal[R])if(O)p.horizontal[R]=p.horizontal[0];else{var F=yl(y,e,r,i,l,I,d,\"center\",R,M,w,gl.horizontal,!1,L,f,u);F&&(p.horizontal[R]=F,O=1===F.positionedLines.length)}}P()}else{\"auto\"===C&&(C=tc(A));var B=yl(y,e,r,i,l,I,d,A,C,M,w,gl.horizontal,!1,L,f,u);B&&(p.horizontal[C]=B),P(),qn(T)&&g&&m&&(p.vertical=yl(y,e,r,i,l,I,d,A,C,M,w,gl.vertical,!1,L,f,u))}}var N=void 0,j=!1;if(a.icon&&a.icon.name){var U=n[a.icon.name];U&&(N=function(t,e,r){var n=Al(r),i=e[0]-t.displaySize[0]*n.horizontalAlign,a=e[1]-t.displaySize[1]*n.verticalAlign;return{image:t,top:a,bottom:a+t.displaySize[1],left:i,right:i+t.displaySize[0]}}(i[a.icon.name],s.get(\"icon-offset\").evaluate(a,{},o),s.get(\"icon-anchor\").evaluate(a,{},o)),j=U.sdf,void 0===t.sdfIcons?t.sdfIcons=U.sdf:t.sdfIcons!==U.sdf&&_(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),(U.pixelRatio!==t.pixelRatio||0!==s.get(\"icon-rotate\").constantOr(1))&&(t.iconsNeedLinear=!0))}var V=rc(p.horizontal)||p.vertical;t.iconsInText=!!V&&V.iconsInText,(V||N)&&function(t,e,r,n,i,a,o,s,l,c,u){var f=a.textMaxSize.evaluate(e,{});void 0===f&&(f=o);var h,p=t.layers[0].layout,d=p.get(\"icon-offset\").evaluate(e,{},u),g=rc(r.horizontal),m=o/24,v=t.tilePixelRatio*m,y=t.tilePixelRatio*f/24,x=t.tilePixelRatio*s,b=t.tilePixelRatio*p.get(\"symbol-spacing\"),w=p.get(\"text-padding\")*t.tilePixelRatio,T=p.get(\"icon-padding\")*t.tilePixelRatio,k=p.get(\"text-max-angle\")/180*Math.PI,M=\"map\"===p.get(\"text-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),A=\"map\"===p.get(\"icon-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),S=p.get(\"symbol-placement\"),E=b/2,C=p.get(\"icon-text-fit\");n&&\"none\"!==C&&(t.allowVerticalPlacement&&r.vertical&&(h=El(n,r.vertical,C,p.get(\"icon-text-fit-padding\"),d,m)),g&&(n=El(n,g,C,p.get(\"icon-text-fit-padding\"),d,m)));var L=function(s,f){f.x<0||f.x>=8192||f.y<0||f.y>=8192||function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,w,T,k,M){var A,S,E,C,L,I=t.addToLineVertexArray(e,r),P=0,z=0,O=0,D=0,R=-1,F=-1,B={},N=ca(\"\"),j=0,U=0;if(void 0===s._unevaluatedLayout.getValue(\"text-radial-offset\")?(j=(A=s.layout.get(\"text-offset\").evaluate(b,{},k).map((function(t){return 24*t})))[0],U=A[1]):(j=24*s.layout.get(\"text-radial-offset\").evaluate(b,{},k),U=Ql),t.allowVerticalPlacement&&n.vertical){var V=s.layout.get(\"text-rotate\").evaluate(b,{},k)+90;C=new Yl(l,e,c,u,f,n.vertical,h,p,d,V),o&&(L=new Yl(l,e,c,u,f,o,m,v,d,V))}if(i){var q=s.layout.get(\"icon-rotate\").evaluate(b,{}),H=\"none\"!==s.layout.get(\"icon-text-fit\"),G=Ul(i,q,T,H),Y=o?Ul(o,q,T,H):void 0;E=new Yl(l,e,c,u,f,i,m,v,!1,q),P=4*G.length;var W=t.iconSizeData,X=null;\"source\"===W.kind?(X=[128*s.layout.get(\"icon-size\").evaluate(b,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'):\"composite\"===W.kind&&((X=[128*w.compositeIconSizes[0].evaluate(b,{},k),128*w.compositeIconSizes[1].evaluate(b,{},k)])[0]>32640||X[1]>32640)&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'),t.addSymbols(t.icon,G,X,x,y,b,!1,e,I.lineStartIndex,I.lineLength,-1,k),R=t.icon.placedSymbolArray.length-1,Y&&(z=4*Y.length,t.addSymbols(t.icon,Y,X,x,y,b,gl.vertical,e,I.lineStartIndex,I.lineLength,-1,k),F=t.icon.placedSymbolArray.length-1)}for(var Z in n.horizontal){var J=n.horizontal[Z];if(!S){N=ca(J.text);var K=s.layout.get(\"text-rotate\").evaluate(b,{},k);S=new Yl(l,e,c,u,f,J,h,p,d,K)}var Q=1===J.positionedLines.length;if(O+=ec(t,e,J,a,s,d,b,g,I,n.vertical?gl.horizontal:gl.horizontalOnly,Q?Object.keys(n.horizontal):[Z],B,R,w,k),Q)break}n.vertical&&(D+=ec(t,e,n.vertical,a,s,d,b,g,I,gl.vertical,[\"vertical\"],B,F,w,k));var $=S?S.boxStartIndex:t.collisionBoxArray.length,tt=S?S.boxEndIndex:t.collisionBoxArray.length,et=C?C.boxStartIndex:t.collisionBoxArray.length,rt=C?C.boxEndIndex:t.collisionBoxArray.length,nt=E?E.boxStartIndex:t.collisionBoxArray.length,it=E?E.boxEndIndex:t.collisionBoxArray.length,at=L?L.boxStartIndex:t.collisionBoxArray.length,ot=L?L.boxEndIndex:t.collisionBoxArray.length,st=-1,lt=function(t,e){return t&&t.circleDiameter?Math.max(t.circleDiameter,e):e};st=lt(S,st),st=lt(C,st),st=lt(E,st);var ct=(st=lt(L,st))>-1?1:0;ct&&(st*=M/24),t.glyphOffsetArray.length>=fc.MAX_GLYPHS&&_(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),void 0!==b.sortKey&&t.addToSortKeyRanges(t.symbolInstances.length,b.sortKey),t.symbolInstances.emplaceBack(e.x,e.y,B.right>=0?B.right:-1,B.center>=0?B.center:-1,B.left>=0?B.left:-1,B.vertical||-1,R,F,N,$,tt,et,rt,nt,it,at,ot,c,O,D,P,z,ct,0,h,j,U,st)}(t,f,s,r,n,i,h,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,v,w,M,l,x,T,A,d,e,a,c,u,o)};if(\"line\"===S)for(var I=0,P=jl(e.geometry,0,0,8192,8192);I<P.length;I+=1)for(var z=P[I],O=0,D=Nl(z,b,k,r.vertical||g,n,24,y,t.overscaling,8192);O<D.length;O+=1){var R=D[O];g&&nc(t,g.text,E,R)||L(z,R)}else if(\"line-center\"===S)for(var F=0,B=e.geometry;F<B.length;F+=1){var N=B[F];if(N.length>1){var j=Bl(N,k,r.vertical||g,n,24,y);j&&L(N,j)}}else if(\"Polygon\"===e.type)for(var U=0,V=Qo(e.geometry,0);U<V.length;U+=1){var q=V[U],H=Zl(q,16);L(q[0],new Cl(H.x,H.y,0))}else if(\"LineString\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1){var W=Y[G];L(W,new Cl(W[0].x,W[0].y,0))}else if(\"Point\"===e.type)for(var X=0,Z=e.geometry;X<Z.length;X+=1)for(var J=0,K=Z[X];J<K.length;J+=1){var Q=K[J];L([Q],new Cl(Q.x,Q.y,0))}}(t,a,p,N,n,c,f,h,w,j,o)},x=0,b=t.features;x<b.length;x+=1)y();a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(t[10]=(i+n)*(a=1/(n-i)),t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=ni,t.polygonIntersectsPolygon=Ba,t.postMapLoadEvent=it,t.postTurnstileEvent=rt,t.potpack=fl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=Dn,t.registerForPluginStateChange=function(t){return t({pluginStatus:Jn,pluginURL:Kn}),ti.on(\"pluginStateChange\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.scale$1=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t},t.scale$2=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t},t.setCacheLimits=function(t,e){at=t,ot=e},t.setRTLTextPlugin=function(t,e,r){if(void 0===r&&(r=!1),\"deferred\"===Jn||\"loading\"===Jn||\"loaded\"===Jn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Kn=R.resolveURL(t),Jn=\"deferred\",Zn=e,$n(),r||ri()},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.sqrLen=function(t){var e=t[0],r=t[1];return e*e+r*r},t.styleSpec=At,t.sub=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t},t.symbolSize=zl,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=ao,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,g=r[0],m=r[1],v=r[2];return e===t?(t[12]=e[0]*g+e[4]*m+e[8]*v+e[12],t[13]=e[1]*g+e[5]*m+e[9]*v+e[13],t[14]=e[2]*g+e[6]*m+e[10]*v+e[14],t[15]=e[3]*g+e[7]*m+e[11]*v+e[15]):(i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n=e[0],t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*g+s*m+f*v+e[12],t[13]=i*g+l*m+h*v+e[13],t[14]=a*g+c*m+p*v+e[14],t[15]=o*g+u*m+d*v+e[15]),t},t.triggerPluginCompletionEvent=Qn,t.uniqueId=h,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=An,t.validateStyle=Mn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=gs,t.version=\"1.10.1\",t.warnOnce=_,t.webpSupported=B,t.window=self,t.wrap=c})),n(0,(function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var f=u[c];delete this.keyCache[f],delete this._layerConfigs[f],delete this._layers[f]}this.familiesBySource={};for(var h=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);h<p.length;h+=1){var d=p[h].map((function(t){return i._layers[t.id]})),g=d[0];if(\"none\"!==g.visibility){var m=g.source||\"\",v=this.familiesBySource[m];v||(v=this.familiesBySource[m]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=v[y];x||(x=v[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),f=new t.AlphaImage({width:u.w||1,height:u.h||1});for(var h in e){var p=e[h];for(var d in p){var g=p[+d];if(g&&0!==g.bitmap.width&&0!==g.bitmap.height){var m=r[h][d].rect;t.AlphaImage.copy(g.bitmap,f,{x:0,y:0},{x:m.x+1,y:m.y+1},g.bitmap)}}}this.image=f,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies,this.promoteId=e.promoteId};function o(e,r,n){for(var i=new t.EvaluationParameters(r),a=0,o=e;a<o.length;a+=1)o[a].recalculate(i,n)}function s(e,r){var n=t.getArrayBuffer(e.request,(function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})}));return function(){n.cancel(),r()}}a.prototype.parse=function(e,r,n,a,s){var l=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var c=new t.DictionaryCoder(Object.keys(e.layers).sort()),u=new t.FeatureIndex(this.tileID,this.promoteId);u.bucketLayerIDs=[];var f,h,p,d,g={},m={featureIndex:u,iconDependencies:{},patternDependencies:{},glyphDependencies:{},availableImages:n},v=r.familiesBySource[this.source];for(var y in v){var x=e.layers[y];if(x){1===x.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+y+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var b=c.encode(y),_=[],w=0;w<x.length;w++){var T=x.feature(w),k=u.getId(T,y);_.push({feature:T,id:k,index:w,sourceLayerIndex:b})}for(var M=0,A=v[y];M<A.length;M+=1){var S=A[M],E=S[0];E.minzoom&&this.zoom<Math.floor(E.minzoom)||E.maxzoom&&this.zoom>=E.maxzoom||\"none\"!==E.visibility&&(o(S,this.zoom,n),(g[E.id]=E.createBucket({index:u.bucketLayerIDs.length,layers:S,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:b,sourceID:this.source})).populate(_,m,this.tileID.canonical),u.bucketLayerIDs.push(S.map((function(t){return t.id}))))}}}var C=t.mapObject(m.glyphDependencies,(function(t){return Object.keys(t).map(Number)}));Object.keys(C).length?a.send(\"getGlyphs\",{uid:this.uid,stacks:C},(function(t,e){f||(f=t,h=e,P.call(l))})):h={};var L=Object.keys(m.iconDependencies);L.length?a.send(\"getImages\",{icons:L,source:this.source,tileID:this.tileID,type:\"icons\"},(function(t,e){f||(f=t,p=e,P.call(l))})):p={};var I=Object.keys(m.patternDependencies);function P(){if(f)return s(f);if(h&&p&&d){var e=new i(h),r=new t.ImageAtlas(p,d);for(var a in g){var l=g[a];l instanceof t.SymbolBucket?(o(l.layers,this.zoom,n),t.performSymbolLayout(l,h,e.positions,p,r.iconPositions,this.showCollisionBoxes,this.tileID.canonical)):l.hasPattern&&(l instanceof t.LineBucket||l instanceof t.FillBucket||l instanceof t.FillExtrusionBucket)&&(o(l.layers,this.zoom,n),l.addFeatures(m,this.tileID.canonical,r.patternPositions))}this.status=\"done\",s(null,{buckets:t.values(g).filter((function(t){return!t.isEmpty()})),featureIndex:u,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?p:null,glyphPositions:this.returnDependencies?e.positions:null})}}I.length?a.send(\"getImages\",{icons:I,source:this.source,tileID:this.tileID,type:\"patterns\"},(function(t,e){f||(f=t,d=e,P.call(l))})):d={},P.call(this)};var l=function(t,e,r,n){this.actor=t,this.layerIndex=e,this.availableImages=r,this.loadVectorData=n||s,this.loading={},this.loaded={}};l.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new t.RequestPerformance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,(function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var f=o.finish();f&&(u.resourceTiming=JSON.parse(JSON.stringify(f)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.availableImages,n.actor,(function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))})),n.loaded=n.loaded||{},n.loaded[i]=s}))},l.prototype.reloadTile=function(t,e){var r=this,n=this.loaded,i=t.uid,a=this;if(n&&n[i]){var o=n[i];o.showCollisionBoxes=t.showCollisionBoxes;var s=function(t,n){var i=o.reloadCallback;i&&(delete o.reloadCallback,o.parse(o.vectorTile,a.layerIndex,r.availableImages,a.actor,i)),e(t,n)};\"parsing\"===o.status?o.reloadCallback=s:\"done\"===o.status&&(o.vectorTile?o.parse(o.vectorTile,this.layerIndex,this.availableImages,this.actor,s):s())}},l.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},l.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var c=t.window.ImageBitmap,u=function(){this.loaded={}};function f(t,e){if(0!==t.length){h(t[0],e);for(var r=1;r<t.length;r++)h(t[r],!e)}}function h(t,e){for(var r=0,n=0,i=t.length,a=i-1;n<i;a=n++)r+=(t[n][0]-t[a][0])*(t[a][1]+t[n][1]);r>=0!=!!e&&t.reverse()}u.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=c&&a instanceof c?this.getImageData(a):a,s=new t.DEMData(n,o,i);this.loaded=this.loaded||{},this.loaded[n]=s,r(null,s)},u.prototype.getImageData=function(e){this.offscreenCanvas&&this.offscreenCanvasContext||(this.offscreenCanvas=new OffscreenCanvas(e.width,e.height),this.offscreenCanvasContext=this.offscreenCanvas.getContext(\"2d\")),this.offscreenCanvas.width=e.width,this.offscreenCanvas.height=e.height,this.offscreenCanvasContext.drawImage(e,0,0,e.width,e.height);var r=this.offscreenCanvasContext.getImageData(-1,-1,e.width+2,e.height+2);return this.offscreenCanvasContext.clearRect(0,0,this.offscreenCanvas.width,this.offscreenCanvas.height),new t.RGBAImage({width:r.width,height:r.height},r.data)},u.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,d=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};d.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var f=u[c];l.push(new t.Point$1(f[0],f[1]))}a.push(l)}return a},d.prototype.toGeoJSON=function(t,e,r){return p.call(this,t,e,r)};var g=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};g.prototype.feature=function(t){return new d(this._features[t])};var m=t.vectorTile.VectorTileFeature,v=y;function y(t,e){this.options=e||{},this.features=t,this.length=t.length}function x(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}y.prototype.feature=function(t){return new x(this.features[t],this.options.extent)},x.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},x.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},x.prototype.toGeoJSON=m.prototype.toGeoJSON;var b=w,_=v;function w(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,T,t.layers[r])}(e,r),r.finish()}function T(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,k,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,C,a[r])}function k(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,M,t),e.writeVarintField(3,r.type),e.writeMessage(4,E,r)}function M(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),a[s]=l=n.length-1),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var f=u+\":\"+c,h=o[f];void 0===h&&(i.push(c),o[f]=h=i.length-1),e.writeVarint(h)}}function A(t,e){return(e<<3)+(7&t)}function S(t){return t<<1^t>>31}function E(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(A(1,c));for(var u=3===n?l.length-1:l.length,f=0;f<u;f++){1===f&&1!==n&&e.writeVarint(A(2,u-1));var h=l[f].x-i,p=l[f].y-a;e.writeVarint(S(h)),e.writeVarint(S(p)),i+=h,a+=p}3===n&&e.writeVarint(A(7,1))}}function C(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function L(t,e,r,n){I(t,r,n),I(e,2*r,2*n),I(e,2*r+1,2*n+1)}function I(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function P(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}b.fromVectorTileJs=w,b.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new v(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return w({layers:r})},b.GeoJSONWrapper=_;var z=function(t){return t[0]},O=function(t){return t[1]},D=function(t,e,r,n,i){void 0===e&&(e=z),void 0===r&&(r=O),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),f=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+f)),Math.min(a,Math.floor(n+(s-l)*u/s+f)),o)}var h=r[2*n+o],p=i,d=a;for(L(e,r,i,n),r[2*a+o]>h&&L(e,r,i,a);p<d;){for(L(e,r,p,d),p++,d--;r[2*p+o]<h;)p++;for(;r[2*d+o]>h;)d--}r[2*i+o]===h?L(e,r,i,d):L(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};D.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var f=c.pop(),h=c.pop(),p=c.pop();if(h-p<=o)for(var d=p;d<=h;d++)l=e[2*d+1],(s=e[2*d])>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+h)/2);l=e[2*g+1],(s=e[2*g])>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var m=(f+1)%2;(0===f?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(m)),(0===f?i>=s:a>=l)&&(c.push(g+1),c.push(h),c.push(m))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},D.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),f=o.pop();if(u-f<=a)for(var h=f;h<=u;h++)P(e[2*h],e[2*h+1],r,n)<=l&&s.push(t[h]);else{var p=Math.floor((f+u)/2),d=e[2*p],g=e[2*p+1];P(d,g,r,n)<=l&&s.push(t[p]);var m=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(f),o.push(p-1),o.push(m)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(m))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var R={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,generateId:!1,reduce:null,map:function(t){return t}},F=function(t){this.options=H(Object.create(R),t),this.trees=new Array(this.options.maxZoom+1)};function B(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function N(t,e){var r=t.geometry.coordinates,n=r[1];return{x:V(r[0]),y:q(n),zoom:1/0,index:e,parentId:-1}}function j(t){return{type:\"Feature\",id:t.id,properties:U(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function U(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return H(H({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function V(t){return t/360+.5}function q(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function H(t,e){for(var r in e)t[r]=e[r];return t}function G(t){return t.x}function Y(t){return t.y}function W(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function X(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)Z(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)Z(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)Z(t,e[n][i])}(i),i}function Z(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function J(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)K(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)K(i[c],s);else if(\"LineString\"===a)Q(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)Q(i[c],s=[],o,!1),t.push(X(l,\"LineString\",s,e.properties));return}$(i,s,o,!1)}else if(\"Polygon\"===a)$(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)J(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];$(i[c],u,o,!0),s.push(u)}}t.push(X(l,a,s,e.properties))}}function K(t,e){e.push(tt(t[0])),e.push(et(t[1])),e.push(0)}function Q(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=tt(t[s][0]),c=et(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],f=e[n],h=e[n+1],p=r+3;p<n;p+=3){var d=W(e[p],e[p+1],c,u,f,h);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function $(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];Q(t[i],a,r,n),e.push(a)}}function tt(t){return t/360+.5}function et(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function rt(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===h||\"MultiPoint\"===h)nt(f,g,r,n,i);else if(\"LineString\"===h)it(f,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===h)ot(f,g,r,n,i,!1);else if(\"Polygon\"===h)ot(f,g,r,n,i,!0);else if(\"MultiPolygon\"===h)for(var m=0;m<f.length;m++){var v=[];ot(f[m],v,r,n,i,!0),v.length&&g.push(v)}if(g.length){if(s.lineMetrics&&\"LineString\"===h){for(m=0;m<g.length;m++)l.push(X(u.id,h,g[m],u.tags));continue}\"LineString\"!==h&&\"MultiLineString\"!==h||(1===g.length?(h=\"LineString\",g=g[0]):h=\"MultiLineString\"),\"Point\"!==h&&\"MultiPoint\"!==h||(h=3===g.length?\"Point\":\"MultiPoint\"),l.push(X(u.id,h,g,u.tags))}}}return l.length?l:null}function nt(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function it(t,e,r,n,i,a,o){for(var s,l,c=at(t),u=0===i?lt:ct,f=t.start,h=0;h<t.length-3;h+=3){var p=t[h],d=t[h+1],g=t[h+2],m=t[h+3],v=t[h+4],y=0===i?p:d,x=0===i?m:v,b=!1;o&&(s=Math.sqrt(Math.pow(p-m,2)+Math.pow(d-v,2))),y<r?x>r&&(l=u(c,p,d,m,v,r),o&&(c.start=f+s*l)):y>n?x<n&&(l=u(c,p,d,m,v,n),o&&(c.start=f+s*l)):st(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,m,v,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,m,v,n),b=!0),!a&&b&&(o&&(c.end=f+s*l),e.push(c),c=at(t)),o&&(f+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&st(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&st(c,c[0],c[1],c[2]),c.length&&e.push(c)}function at(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function ot(t,e,r,n,i,a){for(var o=0;o<t.length;o++)it(t[o],e,r,n,i,a,!1)}function st(t,e,r,n){t.push(e),t.push(r),t.push(n)}function lt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function ct(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function ut(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=ft(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(ft(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(ft(a.geometry[s][c],e));i.push(l)}r.push(X(a.id,o,i,a.tags))}return r}function ft(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function ht(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(pt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var f=[];for(i=0;i<c[n].length;i+=2)f.push(pt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(f)}}return t.transformed=!0,t}function pt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function dt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,gt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,f=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),f>o.maxY&&(o.maxY=f)}return o}function gt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)mt(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)mt(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)mt(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var f in u={},e.tags)u[f]=e.tags[f];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var h={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(h.id=e.id),t.features.push(h)}}function mt(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function vt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)J(r,t.features[n],e,n);else J(r,\"Feature\"===t.type?t:{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=rt(t,1,-1-r,r,0,-1,2,e),a=rt(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=rt(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=ut(i,1).concat(n)),a&&(n=n.concat(ut(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function yt(t,e,r){return 32*((1<<t)*r+e)+t}function xt(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new g(n.features),a=b(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}F.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(N(t[l],l));this.trees[i+1]=new D(s,G,Y,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new D(s,G,Y,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},F.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,f=l.range(V(r),q(a),V(i),q(n));u<f.length;u+=1){var h=l.points[f[u]];c.push(h.numPoints?j(h):this.points[h.index])}return c},F.prototype.getChildren=function(t){var e=this._getOriginId(t),r=this._getOriginZoom(t),n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=i.points[c[l]];u.parentId===t&&s.push(u.numPoints?j(u):this.points[u.index])}if(0===s.length)throw new Error(n);return s},F.prototype.getLeaves=function(t,e,r){var n=[];return this._appendLeaves(n,t,e=e||10,r=r||0,0),n},F.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.radius/a.extent,s=(r-o)/i,l=(r+1+o)/i,c={features:[]};return this._addTileFeatures(n.range((e-o)/i,s,(e+1+o)/i,l),n.points,e,r,i,c),0===e&&this._addTileFeatures(n.range(1-o/i,s,1,l),n.points,i,r,i,c),e===i-1&&this._addTileFeatures(n.range(0,s,o/i,l),n.points,-1,r,i,c),c.features.length?c:null},F.prototype.getClusterExpansionZoom=function(t){for(var e=this._getOriginZoom(t)-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},F.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},F.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c=l.numPoints,u={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:c?U(l):this.points[l.index].properties},f=void 0;c?f=l.id:this.options.generateId?f=l.index:this.points[l.index].id&&(f=this.points[l.index].id),void 0!==f&&(u.id=f),a.features.push(u)}},F.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},F.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.reduce,a=n.radius/(n.extent*Math.pow(2,e)),o=0;o<t.length;o++){var s=t[o];if(!(s.zoom<=e)){s.zoom=e;for(var l=this.trees[e+1],c=l.within(s.x,s.y,a),u=s.numPoints||1,f=s.x*u,h=s.y*u,p=i&&u>1?this._map(s,!0):null,d=(o<<5)+(e+1)+this.points.length,g=0,m=c;g<m.length;g+=1){var v=l.points[m[g]];if(!(v.zoom<=e)){v.zoom=e;var y=v.numPoints||1;f+=v.x*y,h+=v.y*y,u+=y,v.parentId=d,i&&(p||(p=this._map(s,!0)),i(p,this._map(v)))}}1===u?r.push(s):(s.parentId=d,r.push(B(f/u,h/u,d,u,p)))}}return r},F.prototype._getOriginId=function(t){return t-this.points.length>>5},F.prototype._getOriginZoom=function(t){return(t-this.points.length)%32},F.prototype._map=function(t,e){if(t.numPoints)return e?H({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?H({},n):n},vt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},vt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,f=yt(e,r,n),h=this.tiles[f];if(!h&&(c>1&&console.time(\"creation\"),h=this.tiles[f]=dt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,h.numFeatures,h.numPoints,h.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(h.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||h.numPoints<=l.indexMaxPoints)continue;if(h.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,m,v,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,T=.5+_,k=1+_;g=m=v=y=null,x=rt(t,u,r-_,r+T,0,h.minX,h.maxX,l),b=rt(t,u,r+w,r+k,0,h.minX,h.maxX,l),t=null,x&&(g=rt(x,u,n-_,n+T,1,h.minY,h.maxY,l),m=rt(x,u,n+w,n+k,1,h.minY,h.maxY,l),x=null),b&&(v=rt(b,u,n-_,n+T,1,h.minY,h.maxY,l),y=rt(b,u,n+w,n+k,1,h.minY,h.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(m||[],e+1,2*r,2*n+1),s.push(v||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},vt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=yt(t,e=(e%o+o)%o,r);if(this.tiles[s])return ht(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,f=r;!l&&c>0;)c--,u=Math.floor(u/2),f=Math.floor(f/2),l=this.tiles[yt(c,u,f)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,f),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,f,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?ht(this.tiles[s],i):null):null};var bt=function(e){function r(t,r,n,i){e.call(this,t,r,n,xt),i&&(this.loadGeoJSON=i)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new t.RequestPerformance(n.request);this.loadGeoJSON(n,(function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){var n,i=e&&e.type;if(\"FeatureCollection\"===i)for(n=0;n<e.features.length;n++)t(e.features[n],r);else if(\"GeometryCollection\"===i)for(n=0;n<e.geometries.length;n++)t(e.geometries[n],r);else if(\"Feature\"===i)t(e.geometry,r);else if(\"Polygon\"===i)f(e.coordinates,r);else if(\"MultiPolygon\"===i)for(n=0;n<e.coordinates.length;n++)f(e.coordinates[n],r);return e}(o,!0);try{e._geoJSONIndex=n.cluster?new F(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var f=u[c],h=n[f],p=h[0],d=t.createExpression(h[1]),g=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",f]]:p);i[f]=d.value,a[f]=g.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):function(t,e){return new vt(t,e)}(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)}))}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded;return n&&n[t.uid]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){try{e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterChildren=function(t,e){try{e(null,this._geoJSONIndex.getChildren(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterLeaves=function(t,e){try{e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))}catch(t){e(t)}},r}(l),_t=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.availableImages={},this.workerSourceTypes={vector:l,geojson:bt},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isParsed())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return _t.prototype.setReferrer=function(t,e){this.referrer=e},_t.prototype.setImages=function(t,e,r){for(var n in this.availableImages[t]=e,this.workerSources[t]){var i=this.workerSources[t][n];for(var a in i)i[a].availableImages=e}r()},_t.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},_t.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},_t.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},_t.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},_t.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},_t.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},_t.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},_t.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},_t.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},_t.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},_t.prototype.syncRTLPluginState=function(e,r,n){try{t.plugin.setState(r);var i=t.plugin.getPluginURL();if(t.plugin.isLoaded()&&!t.plugin.isParsed()&&null!=i){this.self.importScripts(i);var a=t.plugin.isParsed();n(a?void 0:new Error(\"RTL Text Plugin failed to import scripts from \"+i),a)}}catch(t){n(t.toString())}},_t.prototype.getAvailableImages=function(t){var e=this.availableImages[t];return e||(e=[]),e},_t.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},_t.prototype.getWorkerSource=function(t,e,r){var n=this;return this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),this.workerSources[t][e][r]||(this.workerSources[t][e][r]=new this.workerSourceTypes[e]({send:function(e,r,i){n.actor.send(e,r,i,t)}},this.getLayerIndex(t),this.getAvailableImages(t))),this.workerSources[t][e][r]},_t.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new u),this.demWorkerSources[t][e]},_t.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new _t(t.window)),_t})),n(0,(function(t){var e=t.createCommonjsModule((function(t){function e(t){return!r(t)}function r(t){return\"undefined\"==typeof window||\"undefined\"==typeof document?\"not a browser\":Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray?Function.prototype&&Function.prototype.bind?Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions?\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON?function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()?\"Uint8ClampedArray\"in window?ArrayBuffer.isView?function(){var t=document.createElement(\"canvas\");t.width=t.height=1;var e=t.getContext(\"2d\");if(!e)return!1;var r=e.getImageData(0,0,1,1);return r&&r.width===t.width}()?(void 0===n[r=t&&t.failIfMajorPerformanceCaveat]&&(n[r]=function(t){var r=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t);if(!r)return!1;var n=r.createShader(r.VERTEX_SHADER);return!(!n||r.isContextLost())&&(r.shaderSource(n,\"void main() {}\"),r.compileShader(n),!0===r.getShaderParameter(n,r.COMPILE_STATUS))}(r)),n[r]?void 0:\"insufficient WebGL support\"):\"insufficient Canvas/getImageData support\":\"insufficient ArrayBuffer support\":\"insufficient Uint8ClampedArray support\":\"insufficient worker support\":\"insufficient JSON support\":\"insufficient Object support\":\"insufficient Function support\":\"insufficent Array support\";var r}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e,window.mapboxgl.notSupportedReason=r);var n={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}})),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),t.addEventListener(e,r,\"passive\"in n&&l?n:n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),t.removeEventListener(e,r,\"passive\"in n&&l?n:n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function f(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout((function(){t.window.removeEventListener(\"click\",u,!0)}),0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect();return new t.Point(r.clientX-n.left-e.clientLeft,r.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=0;a<r.length;a++)i.push(new t.Point(r[a].clientX-n.left-e.clientLeft,r[a].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var h=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e];this._notify(n.ids,n.callback)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this._validate(t,e)&&(this.images[t]=e)},r.prototype._validate=function(e,r){var n=!0;return this._validateStretch(r.stretchX,r.data&&r.data.width)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchX\" value'))),n=!1),this._validateStretch(r.stretchY,r.data&&r.data.height)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchY\" value'))),n=!1),this._validateContent(r.content,r)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"content\" value'))),n=!1),n},r.prototype._validateStretch=function(t,e){if(!t)return!0;for(var r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];if(a[0]<r||a[1]<a[0]||e<a[1])return!1;r=a[1]}return!0},r.prototype._validateContent=function(t,e){return!(t&&(4!==t.length||t[0]<0||e.data.width<t[0]||t[1]<0||e.data.height<t[1]||t[2]<0||e.data.width<t[2]||t[3]<0||e.data.height<t[3]||t[2]<t[0]||t[3]<t[1]))},r.prototype.updateImage=function(t,e){e.version=this.images[t].version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1)this.images[i[n]]||(r=!1);this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,stretchX:s.stretchX,stretchY:s.stretchY,content:s.content,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,f=this.images[s].data,h=f.width,p=f.height;t.RGBAImage.copy(f,o,{x:0,y:0},{x:c,y:u},{width:h,height:p}),t.RGBAImage.copy(f,o,{x:0,y:p-1},{x:c,y:u-1},{width:h,height:1}),t.RGBAImage.copy(f,o,{x:0,y:0},{x:c,y:u+p},{width:h,height:1}),t.RGBAImage.copy(f,o,{x:h-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(f,o,{x:0,y:0},{x:c+h,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];f(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=m,d=m,g=1e20;function m(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(y(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(y(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function y(t,e,r,n,i){r[0]=0,n[0]=-g,n[1]=+g;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+g}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}m.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?g:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?g:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++)r[n]=Math.max(0,Math.min(255,Math.round(255-255*((this.gridOuter[n]-this.gridInner[n])/this.radius+this.cutoff))));return r},p.default=d;var x=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};x.prototype.setURL=function(t){this.url=t},x.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1)i.push({stack:a,id:s[o]});t.asyncAll(i,(function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{},ranges:{}});var o=a.glyphs[i];if(void 0===o){if(o=n._tinySDF(a,r,i))return a.glyphs[i]=o,void e(null,{stack:r,id:i,glyph:o});var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else if(a.ranges[s])e(null,{stack:r,id:i,glyph:o});else{var l=a.requests[s];l||(l=a.requests[s]=[],x.loadGlyphRange(r,s,n.url,n.requestManager,(function(t,e){if(e){for(var r in e)n._doesCharSupportLocalGlyph(+r)||(a.glyphs[+r]=e[+r]);a.ranges[s]=!0}for(var i=0,o=l;i<o.length;i+=1)(0,o[i])(t,e);delete a.requests[s]}))),l.push((function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})}))}}else e(null,{stack:r,id:i,glyph:o})}),(function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}}))},x.prototype._doesCharSupportLocalGlyph=function(e){return!!this.localIdeographFontFamily&&(t.isChar[\"CJK Unified Ideographs\"](e)||t.isChar[\"Hangul Syllables\"](e)||t.isChar.Hiragana(e)||t.isChar.Katakana(e))},x.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&this._doesCharSupportLocalGlyph(n)){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new x.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},x.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,(function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}}))},x.TinySDF=p;var b=function(){this.specification=t.styleSpec.light.position};b.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},b.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var _=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new b,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),w=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(_),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),T=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.data=new Uint8Array(this.width*this.height),this.dashEntry={}};T.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.dashEntry[r]||(this.dashEntry[r]=this.addDash(t,e)),this.dashEntry[r]},T.prototype.getDashRanges=function(t,e,r){var n=[],i=t.length%2==1?-t[t.length-1]*r:0,a=t[0]*r,o=!0;n.push({left:i,right:a,isDash:o,zeroLength:0===t[0]});for(var s=t[0],l=1;l<t.length;l++){var c=t[l];n.push({left:i=s*r,right:a=(s+=c)*r,isDash:o=!o,zeroLength:0===c})}return n},T.prototype.addRoundDash=function(t,e,r){for(var n=e/2,i=-r;i<=r;i++)for(var a=this.width*(this.nextRow+r+i),o=0,s=t[o],l=0;l<this.width;l++){l/s.right>1&&(s=t[++o]);var c=Math.abs(l-s.left),u=Math.abs(l-s.right),f=Math.min(c,u),h=void 0,p=i/r*(n+1);if(s.isDash){var d=n-Math.abs(p);h=Math.sqrt(f*f+d*d)}else h=n-Math.sqrt(f*f+p*p);this.data[a+l]=Math.max(0,Math.min(255,h+128))}},T.prototype.addRegularDash=function(t){for(var e=t.length-1;e>=0;--e){var r=t[e],n=t[e+1];r.zeroLength?t.splice(e,1):n&&n.isDash===r.isDash&&(n.left=r.left,t.splice(e,1))}var i=t[0],a=t[t.length-1];i.isDash===a.isDash&&(i.left=a.left-this.width,a.right=i.right+this.width);for(var o=this.width*this.nextRow,s=0,l=t[s],c=0;c<this.width;c++){c/l.right>1&&(l=t[++s]);var u=Math.abs(c-l.left),f=Math.abs(c-l.right),h=Math.min(u,f);this.data[o+c]=Math.max(0,Math.min(255,(l.isDash?h:-h)+128))}},T.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];if(0!==a){var s=this.width/a,l=this.getDashRanges(e,this.width,s);r?this.addRoundDash(l,s,n):this.addRegularDash(l)}var c={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,c},T.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.ALPHA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.ALPHA,this.width,this.height,0,e.ALPHA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=new e.Actor(i[a],n,this.id);o.name=\"Worker \"+a,this.actors.push(o)}};function M(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(t.extend(a,e),[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\",\"scheme\",\"tileSize\",\"encoding\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map((function(t){return t.id}))),o.tiles=r.canonicalizeTileset(o,e.url),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame((function(){return i(null,e)}))}k.prototype.broadcast=function(e,r,n){t.asyncAll(this.actors,(function(t,n){t.send(e,r,n)}),n=n||function(){})},k.prototype.getActor=function(){return this.currentActor=(this.currentActor+1)%this.actors.length,this.actors[this.currentActor]},k.prototype.remove=function(){this.actors.forEach((function(t){t.remove()})),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var S=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,this._loaded=!1,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\",\"promoteId\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles,e.map._requestManager._customAccessToken),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken,e.map._requestManager._customAccessToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme)),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};function a(n,i){return delete e.request,e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,e.actor&&\"expired\"!==e.state?\"loading\"===e.state?e.reloadCallback=r:e.request=e.actor.send(\"reloadTile\",i,a.bind(this)):(e.actor=this.dispatcher.getActor(),e.request=e.actor.send(\"loadTile\",i,a.bind(this)))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.actor&&t.actor.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.unloadTile=function(t){t.unloadVectorData(),t.actor&&t.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({type:\"raster\"},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),(function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}}))},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),C=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({type:\"raster-dem\"},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);function i(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(a){this.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=t.window.ImageBitmap&&a instanceof t.window.ImageBitmap&&t.offscreenCanvasSupported()?a:t.browser.getImageData(a,1),s={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:o,encoding:this.encoding};e.actor&&\"expired\"!==e.state||(e.actor=this.dispatcher.getActor(),e.actor.send(\"loadDEMTile\",s,i.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",t.actor&&t.actor.send(\"removeDEMTile\",{uid:t.uid,source:this.id})},r}(E),L=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this._loaded=!1,this.actor=i.getActor(),this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution),this.promoteId=n.promoteId;var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1,generateId:n.generateId||!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}}))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}})),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.actor.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterChildren=function(t,e){return this.actor.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.actor.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n),this},r.prototype._updateWorkerData=function(e){var r=this;this._loaded=!1;var n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.actor.send(this.type+\".loadData\",n,(function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.actor.send(r.type+\".coalesce\",{source:n.source},null),e(t))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.loadTile=function(e,r){var n=this,i=e.actor?\"reloadTile\":\"loadTile\";e.actor=this.actor,e.request=this.actor.send(i,{type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId},(function(t,a){return delete e.request,e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))}))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id})},r.prototype.onRemove=function(){this._removed=!0,this.actor.send(\"removeSource\",{type:this.type,source:this.id})},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),I=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),P=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this._loaded=!1,this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(e,r){var n=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),(function(i,a){n._loaded=!0,i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())}))},r.prototype.loaded=function(){return this._loaded},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,(function(){e.texture=null})),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=Math.max(i-r,a-n),u=Math.max(0,Math.floor(-Math.log(c)/Math.LN2)),f=Math.pow(2,u);return new t.CanonicalTileID(u,Math.floor((r+i)/2*f),Math.floor((n+a)/2*f))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map((function(t){return r.tileID.getTilePoint(t)._round()}));return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),z=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1;var r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1)this.urls.push(this.map._requestManager.transformRequest(i[n],t.ResourceType.Source).url);t.getVideo(this.urls,(function(r,n){e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",(function(){e.map.triggerRepaint()})),e.map&&e.video.play(),e._finishLoading())}))},r.prototype.pause=function(){this.video&&this.video.pause()},r.prototype.play=function(){this.video&&this.video.play()},r.prototype.seek=function(e){if(this.video){var r=this.video.seekable;e<r.start(0)||e>r.end(0)?this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+this.id,null,\"Playback for this video can be set only between the \"+r.start(0)+\" and \"+r.end(0)+\"-second mark.\"))):this.video.currentTime=e}},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(P),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some((function(t){return!Array.isArray(t)||2!==t.length||t.some((function(t){return\"number\"!=typeof t}))}))||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){this._loaded=!0,this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(P),D={vector:S,raster:E,\"raster-dem\":C,geojson:L,video:z,image:P,canvas:O};function R(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function F(t,e,r,n,i,a){var o=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(i&&i.layers,e,t.id),s=a.maxPitchScaleFactor(),l=t.tilesIn(n,s,o);l.sort(B);for(var c=[],u=0,f=l;u<f.length;u+=1){var h=f[u];c.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,r,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,i,a,s,R(t.transform,h.tileID))})}var p=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],f=l[c]=l[c]||{},h=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];f[g.featureIndex]||(f[g.featureIndex]=!0,h.push(g))}}return e}(c);for(var d in p)p[d].forEach((function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n}));return p}function B(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var N=function(t,e){this.max=t,this.onRemove=e,this.reset()};N.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},N.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout((function(){n.remove(t,a)}),r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},N.prototype.has=function(t){return t.wrapped().key in this.data},N.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},N.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},N.prototype.getByKey=function(t){var e=this.data[t];return e?e[0].value:null},N.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},N.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},N.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this},N.prototype.filter=function(t){var e=[];for(var r in this.data)for(var n=0,i=this.data[r];n<i.length;n+=1){var a=i[n];t(a.value)||e.push(a)}for(var o=0,s=e;o<s.length;o+=1){var l=s[o];this.remove(l.value.tileID,l)}};var j=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};j.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},j.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},j.prototype.destroy=function(){this.buffer&&(this.context.gl.deleteBuffer(this.buffer),delete this.buffer)};var U={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},V=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};V.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},V.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},V.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=e.attributes[this.attributes[r].name];void 0!==n&&t.enableVertexAttribArray(n)}},V.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[U[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},V.prototype.destroy=function(){this.buffer&&(this.context.gl.deleteBuffer(this.buffer),delete this.buffer)};var q=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};q.prototype.get=function(){return this.current},q.prototype.set=function(t){},q.prototype.getDefault=function(){return this.default},q.prototype.setDefault=function(){this.set(this.default)};var H=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(q),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(q),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(q),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(q),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(q),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(q),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(q),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(q),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(q),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(q),nt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),it=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(q),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(q),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(q),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(q),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(q),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(q),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(q),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(q),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(q),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(q),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(q),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(q),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(q),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),bt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),_t=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e}(q),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(_t),Tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(_t),kt=function(t,e,r,n){this.context=t,this.width=e,this.height=r;var i=this.framebuffer=t.gl.createFramebuffer();this.colorAttachment=new wt(t,i),n&&(this.depthAttachment=new Tt(t,i))};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();if(e&&t.deleteTexture(e),this.depthAttachment){var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r)}t.deleteFramebuffer(this.framebuffer)};var Mt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Mt.ReadOnly=!1,Mt.ReadWrite=!0,Mt.disabled=new Mt(519,Mt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var St=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};St.disabled=new St(St.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),St.unblended=new St(St.Replace,t.Color.transparent,[!0,!0,!0,!0]),St.alphaBlended=new St([1,771],t.Color.transparent,[!0,!0,!0,!0]);var Et=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};Et.disabled=new Et(!1,1029,2305),Et.backCCW=new Et(!0,1029,2305);var Ct=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new H(this),this.clearDepth=new G(this),this.clearStencil=new Y(this),this.colorMask=new W(this),this.depthMask=new X(this),this.stencilMask=new Z(this),this.stencilFunc=new J(this),this.stencilOp=new K(this),this.stencilTest=new Q(this),this.depthRange=new $(this),this.depthTest=new tt(this),this.depthFunc=new et(this),this.blend=new rt(this),this.blendFunc=new nt(this),this.blendColor=new it(this),this.blendEquation=new at(this),this.cullFace=new ot(this),this.cullFaceSide=new st(this),this.frontFace=new lt(this),this.program=new ct(this),this.activeTexture=new ut(this),this.viewport=new ft(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new pt(this),this.bindTexture=new dt(this),this.bindVertexBuffer=new gt(this),this.bindElementBuffer=new mt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new yt(this),this.pixelStoreUnpackPremultiplyAlpha=new xt(this),this.pixelStoreUnpackFlipY=new bt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&(t.getExtension(\"OES_texture_half_float_linear\"),this.extRenderToTextureHalfFloat=t.getExtension(\"EXT_color_buffer_half_float\")),this.extTimerQuery=t.getExtension(\"EXT_disjoint_timer_query\")};Ct.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Ct.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Ct.prototype.createIndexBuffer=function(t,e){return new j(this,t,e)},Ct.prototype.createVertexBuffer=function(t,e,r){return new V(this,t,e,r)},Ct.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Ct.prototype.createFramebuffer=function(t,e,r){return new kt(this,t,e,r)},Ct.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Ct.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Ct.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Ct.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Ct.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,St.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Ct.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Lt=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",(function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))})),this.on(\"error\",(function(){a._sourceErrored=!0})),this._source=function(e,r,n,i){var a=new D[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a}(r,n,i,this),this._tiles={},this._cache=new N(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._loadedParentTiles={},this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;if(!this._source.loaded())return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,(function(){}))},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,(function(){}))},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return t.values(this._tiles).map((function(t){return t.tileID})).sort(It).map((function(t){return t.key}))},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(i,e)&&n.push(this._tiles[i]);return e?n.sort((function(e,n){var i=e.tileID,a=n.tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x})).map((function(t){return t.tileID.key})):n.map((function(t){return t.tileID})).sort(It).map((function(t){return t.key}))},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){if(t.key in this._loadedParentTiles){var r=this._loadedParentTiles[t.key];return r&&r.tileID.overscaledZ>=e?r:null}for(var n=t.overscaledZ-1;n>=e;n--){var i=t.scaledTo(n),a=this._getLoadedTile(i);if(a)return a}},r.prototype._getLoadedTile=function(t){var e=this._tiles[t.key];return e&&e.hasData()?e:this._cache.getByKey(t.wrapped().key)},r.prototype.updateCacheSize=function(t){var e=Math.ceil(t.width/this._source.tileSize)+1,r=Math.ceil(t.height/this._source.tileSize)+1,n=Math.floor(e*r*5),i=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,n):n;this._cache.setMaxSize(i)},r.prototype.handleWrapJump=function(t){var e=Math.round((t-(void 0===this._prevLng?t:this._prevLng))/360);if(this._prevLng=t,e){var r={};for(var n in this._tiles){var i=this._tiles[n];i.tileID=i.tileID.unwrapTo(i.tileID.wrap+e),r[i.tileID.key]=i}for(var a in this._tiles=r,this._timers)clearTimeout(this._timers[a]),delete this._timers[a];for(var o in this._tiles)this._setTileReloadTimer(o,this._tiles[o])}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map((function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)})):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter((function(t){return n._source.hasTile(t)})))):i=[];var a=e.coveringZoomLevel(this._source),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},f=0,h=Object.keys(l);f<h.length;f+=1){var p=h[f],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var m=this.findLoadedParent(d,o);m&&(this._addTile(m.tileID),c[m.tileID.key]=m.tileID),u[p]=d}}for(var v in this._retainLoadedChildren(u,a,s,l),c)l[v]||(this._coveredTiles[v]=!0,l[v]=c[v])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}this._updateLoadedParentTileCache()}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],f=this._addTile(u);n[u.key]=u,f.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var h=0,p=t;h<p.length;h+=1){var d=p[h],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var m=d.children(this._source.maxzoom)[0],v=this.getTile(m);if(v&&v.hasData()){n[m.key]=m;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._updateLoadedParentTileCache=function(){for(var t in this._loadedParentTiles={},this._tiles){for(var e=[],r=void 0,n=this._tiles[t].tileID;n.overscaledZ>0;){if(n.key in this._loadedParentTiles){r=this._loadedParentTiles[n.key];break}e.push(n.key);var i=n.scaledTo(n.overscaledZ-1);if(r=this._getLoadedTile(i))break;n=i}for(var a=0,o=e;a<o.length;a+=1)this._loadedParentTiles[o[a]]=r}},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout((function(){r._reloadTile(t,\"expired\"),delete r._timers[t]}),n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()&&\"reloading\"!==e.state?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map((function(t){return o.pointCoordinate(t)})),c=s.map((function(t){return o.pointCoordinate(t)})),u=this.getIds(),f=1/0,h=1/0,p=-1/0,d=-1/0,g=0,m=c;g<m.length;g+=1){var v=m[g];f=Math.min(f,v.x),h=Math.min(h,v.y),p=Math.max(p,v.x),d=Math.max(d,v.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),m=r*n.queryPadding*t.EXTENT/n.tileSize/g,v=[s.getTilePoint(new t.MercatorCoordinate(f,h)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(v[0].x-m<t.EXTENT&&v[0].y-m<t.EXTENT&&v[1].x+m>=0&&v[1].y+m>=0){var y=l.map((function(t){return s.getTilePoint(t)})),x=c.map((function(t){return s.getTilePoint(t)}));a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map((function(t){return e._tiles[t].tileID})),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){this._state.updateState(t=t||\"_geojsonTileLayer\",e,r)},r.prototype.removeFeatureState=function(t,e,r){this._state.removeFeatureState(t=t||\"_geojsonTileLayer\",e,r)},r.prototype.getFeatureState=function(t,e){return this._state.getState(t=t||\"_geojsonTileLayer\",e)},r.prototype.setDependencies=function(t,e,r){var n=this._tiles[t];n&&n.setDependencies(e,r)},r.prototype.reloadTilesForDependencies=function(t,e){for(var r in this._tiles)this._tiles[r].hasDependency(t,e)&&this._reloadTile(r,\"reloading\");this._cache.filter((function(r){return!r.hasDependency(t,e)}))},r}(t.Evented);function It(t,e){var r=Math.abs(2*t.wrap)-+(t.wrap<0),n=Math.abs(2*e.wrap)-+(e.wrap<0);return t.overscaledZ-e.overscaledZ||n-r||e.canonical.y-t.canonical.y||e.canonical.x-t.canonical.x}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function zt(){return new t.window.Worker(Yi.workerUrl)}Lt.maxOverzooming=10,Lt.maxUnderzooming=3;var Ot=\"mapboxgl_preloaded_worker_pool\",Dt=function(){this.active={}};Dt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<Dt.workerCount;)this.workers.push(new zt);return this.active[t]=!0,this.workers.slice()},Dt.prototype.release=function(t){delete this.active[t],0===this.numActive()&&(this.workers.forEach((function(t){t.terminate()})),this.workers=null)},Dt.prototype.isPreloaded=function(){return!!this.active[Ot]},Dt.prototype.numActive=function(){return Object.keys(this.active).length};var Rt,Ft=Math.floor(t.browser.hardwareConcurrency/2);function Bt(){return Rt||(Rt=new Dt),Rt}function Nt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach((function(t){t in r&&(n[t]=r[t])})),n}function jt(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Nt(t[n],e[t[n].ref]));return t}Dt.workerCount=Math.max(Math.min(Ft,6),1);var Ut={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Vt(t,e,r){r.push({command:Ut.addSource,args:[t,e[t]]})}function qt(t,e,r){e.push({command:Ut.removeSource,args:[t]}),r[t]=!0}function Ht(t,e,r,n){qt(t,r,n),Vt(t,e,r)}function Gt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function Yt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Wt(t){return t.id}function Xt(t,e){return t[e.id]=e,t}var Zt=function(t,e){this.reset(t,e)};Zt.prototype.reset=function(t,e){this.points=t||[],this._distances=[0];for(var r=1;r<this.points.length;r++)this._distances[r]=this._distances[r-1]+this.points[r].dist(this.points[r-1]);this.length=this._distances[this._distances.length-1],this.padding=Math.min(e||0,.5*this.length),this.paddedLength=this.length-2*this.padding},Zt.prototype.lerp=function(e){if(1===this.points.length)return this.points[0];e=t.clamp(e,0,1);for(var r=1,n=this._distances[r],i=e*this.paddedLength+this.padding;n<i&&r<this._distances.length;)n=this._distances[++r];var a=r-1,o=this._distances[a],s=n-o,l=s>0?(i-o)/s:0;return this.points[a].mult(1-l).add(this.points[r].mult(l))};var Jt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Kt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Qt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function $t(e,r){var n=[e.x,e.y,0,1];ue(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function te(t,e){return.5+t/e*.5}function ee(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function re(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),f=[256/n.width*2+1,256/n.height*2+1],h=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;h.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,m=!1,v=0;v<d.length;v++){var y=d.get(v);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!m)ce(y.numGlyphs,h);else{m=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),ee(x,f)){var b=te(n.transform.cameraToCenterDistance,x[3]),_=t.evaluateSizeForFeature(c,u,y),w=s?_/b:_*b,T=new t.Point(y.anchorX,y.anchorY),k=$t(T,a).point,M={},A=ae(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,h,k,T,M,g);m=A.useVertical,(A.notEnoughRoom||m||A.needsFlipping&&ae(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,h,k,T,M,g).notEnoughRoom)&&ce(y.numGlyphs,h)}else ce(y.numGlyphs,h)}}i?e.text.dynamicLayoutVertexBuffer.updateData(h):e.icon.dynamicLayoutVertexBuffer.updateData(h)}function ne(t,e,r,n,i,a,o,s,l,c,u){var f=s.glyphStartIndex+s.numGlyphs,h=s.lineStartIndex,p=s.lineStartIndex+s.lineLength,d=e.getoffsetX(s.glyphStartIndex),g=e.getoffsetX(f-1),m=se(t*d,r,n,i,a,o,s.segment,h,p,l,c,u);if(!m)return null;var v=se(t*g,r,n,i,a,o,s.segment,h,p,l,c,u);return v?{first:m,last:v}:null}function ie(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function ae(e,r,n,i,a,o,s,l,c,u,f,h,p,d){var g,m=r/24,v=e.lineOffsetX*m,y=e.lineOffsetY*m;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=ne(m,l,v,y,n,f,h,e,c,o,p);if(!w)return{notEnoughRoom:!0};var T=$t(w.first.point,s).point,k=$t(w.last.point,s).point;if(i&&!n){var M=ie(e.writingMode,T,k,d);if(M)return M}g=[w.first];for(var A=e.glyphStartIndex+1;A<x-1;A++)g.push(se(m*l.getoffsetX(A),v,y,n,f,h,e.segment,b,_,c,o,p));g.push(w.last)}else{if(i&&!n){var S=$t(h,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=$t(C,a),I=L.signedDistanceFromCamera>0?L.point:oe(h,C,S,1,a),P=ie(e.writingMode,S,I,d);if(P)return P}var z=se(m*l.getoffsetX(e.glyphStartIndex),v,y,n,f,h,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p);if(!z)return{notEnoughRoom:!0};g=[z]}for(var O=0,D=g;O<D.length;O+=1){var R=D[O];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function oe(t,e,r,n,i){var a=$t(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function se(e,r,n,i,a,o,s,l,c,u,f,h){var p=i?e-r:e+r,d=p>0?1:-1,g=0;i&&(d*=-1,g=Math.PI),d<0&&(g+=Math.PI);for(var m=d>0?l+s:l+s+1,v=a,y=a,x=0,b=0,_=Math.abs(p),w=[];x+b<=_;){if((m+=d)<l||m>=c)return null;if(y=v,w.push(v),void 0===(v=h[m])){var T=new t.Point(u.getx(m),u.gety(m)),k=$t(T,f);if(k.signedDistanceFromCamera>0)v=h[m]=k.point;else{var M=m-d;v=oe(0===x?o:new t.Point(u.getx(M),u.gety(M)),T,y,_-x+1,f)}}x+=b,b=y.dist(v)}var A=(_-x)/b,S=v.sub(y),E=S.mult(A)._add(y);E._add(S._unit()._perp()._mult(n*d));var C=g+Math.atan2(v.y-y.y,v.x-y.x);return w.push(E),{point:E,angle:C,path:w}}Jt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Jt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Jt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Jt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Jt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Jt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],f=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-f,y1:u-f,x2:c+f,y2:u+f})}return a?o.filter(a):o}return this._forEachCell(t,e,r,n,this._queryCell,o,{hitTest:i,seenUids:{box:{},circle:{}}},a),i?o.length>0:o},Jt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[];return this._forEachCell(a,s,o,l,this._queryCellCircle,c,{hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}},i),n?c.length>0:c},Jt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Jt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Jt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Jt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,f=0,h=c;f<h.length;f+=1){var p=h[f];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var m=this.circles,v=0,y=g;v<y.length;v+=1){var x=y[v];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(m[b],m[b+1],m[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=m[b],w=m[b+1],T=m[b+2];a.push({key:this.circleKeys[x],x1:_-T,y1:w-T,x2:_+T,y2:w+T})}}}},Jt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var f=this.bboxes,h=0,p=u;h<p.length;h+=1){var d=p[h];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,f[g+0],f[g+1],f[g+2],f[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var m=this.circleCells[i];if(null!==m)for(var v=this.circles,y=0,x=m;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(v[_],v[_+1],v[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Jt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),f=this._convertToYCellCoord(n),h=l;h<=u;h++)for(var p=c;p<=f;p++)if(i.call(this,t,e,r,n,this.xCellCount*p+h,a,o,s))return},Jt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Jt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Jt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Jt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var f=l-s,h=u-c;return f*f+h*h<=r*r};var le=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ce(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(le,3*n)}}function ue(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var fe=function(t,e,r){void 0===e&&(e=new Jt(t.width+200,t.height+200,25)),void 0===r&&(r=new Jt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function he(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}fe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},fe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,f,h,p){var d=[],g=new t.Point(r.anchorX,r.anchorY),m=$t(g,o),v=te(this.transform.cameraToCenterDistance,m.signedDistanceFromCamera),y=(u?a/v:a*v)/t.ONE_EM,x=$t(g,s).point,b=ne(y,i,r.lineOffsetX*y,r.lineOffsetY*y,!1,x,g,r,n,s,{}),_=!1,w=!1,T=!0;if(b){for(var k=.5*h*v+p,M=new t.Point(-100,-100),A=new t.Point(this.screenRightBoundary,this.screenBottomBoundary),S=new Zt,E=b.first,C=b.last,L=[],I=E.path.length-1;I>=1;I--)L.push(E.path[I]);for(var P=1;P<C.path.length;P++)L.push(C.path[P]);var z=2.5*k;if(l){var O=L.map((function(t){return $t(t,l)}));L=O.some((function(t){return t.signedDistanceFromCamera<=0}))?[]:O.map((function(t){return t.point}))}var D=[];if(L.length>0){for(var R=L[0].clone(),F=L[0].clone(),B=1;B<L.length;B++)R.x=Math.min(R.x,L[B].x),R.y=Math.min(R.y,L[B].y),F.x=Math.max(F.x,L[B].x),F.y=Math.max(F.y,L[B].y);D=R.x>=M.x&&F.x<=A.x&&R.y>=M.y&&F.y<=A.y?[L]:F.x<M.x||R.x>A.x||F.y<M.y||R.y>A.y?[]:t.clipLine([L],M.x,M.y,A.x,A.y)}for(var N=0,j=D;N<j.length;N+=1){var U;S.reset(j[N],.25*k),U=S.length<=.5*k?1:Math.ceil(S.paddedLength/z)+1;for(var V=0;V<U;V++){var q=V/Math.max(U-1,1),H=S.lerp(q),G=H.x+100,Y=H.y+100;d.push(G,Y,k,0);var W=G-k,X=Y-k,Z=G+k,J=Y+k;if(T=T&&this.isOffscreen(W,X,Z,J),w=w||this.isInsideGrid(W,X,Z,J),!e&&this.grid.hitTestCircle(G,Y,k,f)&&(_=!0,!c))return{circles:[],offscreen:!1,collisionDetected:_}}}}return{circles:!c&&_||!w?[]:d,offscreen:T,collisionDetected:_}},fe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var f={},h={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],m=g.key;if(void 0===f[m.bucketInstanceId]&&(f[m.bucketInstanceId]={}),!f[m.bucketInstanceId][m.featureIndex]){var v=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,v)&&(f[m.bucketInstanceId][m.featureIndex]=!0,void 0===h[m.bucketInstanceId]&&(h[m.bucketInstanceId]=[]),h[m.bucketInstanceId].push(m.featureIndex))}}return h},fe.prototype.insertCollisionBox=function(t,e,r,n,i){(e?this.ignoredGrid:this.grid).insert({bucketInstanceId:r,featureIndex:n,collisionGroupID:i},t[0],t[1],t[2],t[3])},fe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},fe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ue(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},fe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},fe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary},fe.prototype.getViewportMatrix=function(){var e=t.identity([]);return t.translate(e,e,[-100,-100,0]),e};var pe=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};pe.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var de=function(t,e,r,n,i){this.text=new pe(t?t.text:null,e,r,i),this.icon=new pe(t?t.icon:null,e,n,i)};de.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var ge=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},me=function(){this.invProjMatrix=t.create(),this.viewportMatrix=t.create(),this.circles=[]},ve=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},ye=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function xe(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateVariableOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}function be(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,f=e.anchorPointX,h=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:f,anchorPointY:h}}ye.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var _e=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new fe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new ye(r),this.collisionCircleArrays={},this.prevPlacement=n,n&&(n.prevPlacement=void 0),this.placedOrientations={}};function we(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}_e.prototype.getBucketParts=function(e,r,n,i){var a=n.getBucket(r),o=n.latestFeatureIndex;if(a&&o&&r.id===a.layerIds[0]){var s=n.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-n.tileID.overscaledZ),u=n.tileSize/t.EXTENT,f=this.transform.calculatePosMatrix(n.tileID.toUnwrapped()),h=\"map\"===l.get(\"text-pitch-alignment\"),p=\"map\"===l.get(\"text-rotation-alignment\"),d=he(n,1,this.transform.zoom),g=Kt(f,h,p,this.transform,d),m=null;if(h){var v=Qt(f,h,p,this.transform,d);m=t.multiply([],this.transform.labelPlaneMatrix,v)}this.retainedQueryData[a.bucketInstanceId]=new ve(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,n.tileID);var y={bucket:a,layout:l,posMatrix:f,textLabelPlaneMatrix:g,labelToScreenMatrix:m,scale:c,textPixelRatio:u,holdingForFade:n.holdingForFade(),collisionBoxArray:s,partiallyEvaluatedTextSize:t.evaluateSizeForZoom(a.textSizeData,this.transform.zoom),collisionGroup:this.collisionGroups.get(a.sourceID)};if(i)for(var x=0,b=a.sortKeyRanges;x<b.length;x+=1){var _=b[x];e.push({sortKey:_.sortKey,symbolInstanceStart:_.symbolInstanceStart,symbolInstanceEnd:_.symbolInstanceEnd,parameters:y})}else e.push({symbolInstanceStart:0,symbolInstanceEnd:a.symbolInstances.length,parameters:y})}},_e.prototype.attemptAnchorPlacement=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d){var g,m=[f.textOffset0,f.textOffset1],v=xe(t,r,n,m,i),y=this.collisionIndex.placeCollisionBox(be(e,v.x,v.y,a,o,this.transform.angle),u,s,l,c.predicate);if(!d||0!==this.collisionIndex.placeCollisionBox(be(d,v.x,v.y,a,o,this.transform.angle),u,s,l,c.predicate).box.length)return y.box.length>0?(this.prevPlacement&&this.prevPlacement.variableOffsets[f.crossTileID]&&this.prevPlacement.placements[f.crossTileID]&&this.prevPlacement.placements[f.crossTileID].text&&(g=this.prevPlacement.variableOffsets[f.crossTileID].anchor),this.variableOffsets[f.crossTileID]={textOffset:m,width:r,height:n,anchor:t,textBoxScale:i,prevAnchor:g},this.markUsedJustification(h,t,f,p),h.allowVerticalPlacement&&(this.markUsedOrientation(h,p,f),this.placedOrientations[f.crossTileID]=p),{shift:v,placedGlyphBoxes:y}):void 0},_e.prototype.placeLayerBucketPart=function(e,r,n){var i=this,a=e.parameters,o=a.bucket,s=a.layout,l=a.posMatrix,c=a.textLabelPlaneMatrix,u=a.labelToScreenMatrix,f=a.textPixelRatio,h=a.holdingForFade,p=a.collisionBoxArray,d=a.partiallyEvaluatedTextSize,g=a.collisionGroup,m=s.get(\"text-optional\"),v=s.get(\"icon-optional\"),y=s.get(\"text-allow-overlap\"),x=s.get(\"icon-allow-overlap\"),b=\"map\"===s.get(\"text-rotation-alignment\"),_=\"map\"===s.get(\"text-pitch-alignment\"),w=\"none\"!==s.get(\"icon-text-fit\"),T=\"viewport-y\"===s.get(\"symbol-z-order\"),k=y&&(x||!o.hasIconData()||v),M=x&&(y||!o.hasTextData()||m);!o.collisionArrays&&p&&o.deserializeCollisionBoxes(p);var A=function(e,a){if(!r[e.crossTileID])if(h)i.placements[e.crossTileID]=new ge(!1,!1,!1);else{var p,T=!1,A=!1,S=!0,E=null,C={box:null,offscreen:null},L={box:null,offscreen:null},I=null,P=null,z=0,O=0,D=0;a.textFeatureIndex?z=a.textFeatureIndex:e.useRuntimeCollisionCircles&&(z=e.featureIndex),a.verticalTextFeatureIndex&&(O=a.verticalTextFeatureIndex);var R=a.textBox;if(R){var F=function(r){var n=t.WritingMode.horizontal;if(o.allowVerticalPlacement&&!r&&i.prevPlacement){var a=i.prevPlacement.placedOrientations[e.crossTileID];a&&(i.placedOrientations[e.crossTileID]=a,i.markUsedOrientation(o,n=a,e))}return n},B=function(r,n){if(o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&a.verticalTextBox)for(var i=0,s=o.writingModes;i<s.length&&(s[i]===t.WritingMode.vertical?(C=n(),L=C):C=r(),!(C&&C.box&&C.box.length));i+=1);else C=r()};if(s.get(\"text-variable-anchor\")){var N=s.get(\"text-variable-anchor\");if(i.prevPlacement&&i.prevPlacement.variableOffsets[e.crossTileID]){var j=i.prevPlacement.variableOffsets[e.crossTileID];N.indexOf(j.anchor)>0&&(N=N.filter((function(t){return t!==j.anchor}))).unshift(j.anchor)}var U=function(t,r,n){for(var a=t.x2-t.x1,s=t.y2-t.y1,c=e.textBoxScale,u=w&&!x?r:null,h={box:[],offscreen:!1},p=y?2*N.length:N.length,d=0;d<p;++d){var m=i.attemptAnchorPlacement(N[d%N.length],t,a,s,c,b,_,f,l,g,d>=N.length,e,o,n,u);if(m&&(h=m.placedGlyphBoxes)&&h.box&&h.box.length){T=!0,E=m.shift;break}}return h};B((function(){return U(R,a.iconBox,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox;return o.allowVerticalPlacement&&!(C&&C.box&&C.box.length)&&e.numVerticalGlyphVertices>0&&r?U(r,a.verticalIconBox,t.WritingMode.vertical):{box:null,offscreen:null}})),C&&(T=C.box,S=C.offscreen);var V=F(C&&C.box);if(!T&&i.prevPlacement){var q=i.prevPlacement.variableOffsets[e.crossTileID];q&&(i.variableOffsets[e.crossTileID]=q,i.markUsedJustification(o,q.anchor,e,V))}}else{var H=function(t,r){var n=i.collisionIndex.placeCollisionBox(t,y,f,l,g.predicate);return n&&n.box&&n.box.length&&(i.markUsedOrientation(o,r,e),i.placedOrientations[e.crossTileID]=r),n};B((function(){return H(R,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox;return o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&r?H(r,t.WritingMode.vertical):{box:null,offscreen:null}})),F(C&&C.box&&C.box.length)}}if(T=(p=C)&&p.box&&p.box.length>0,S=p&&p.offscreen,e.useRuntimeCollisionCircles){var G=o.text.placedSymbolArray.get(e.centerJustifiedTextSymbolIndex),Y=t.evaluateSizeForFeature(o.textSizeData,d,G),W=s.get(\"text-padding\");I=i.collisionIndex.placeCollisionCircles(y,G,o.lineVertexArray,o.glyphOffsetArray,Y,l,c,u,n,_,g.predicate,e.collisionCircleDiameter,W),T=y||I.circles.length>0&&!I.collisionDetected,S=S&&I.offscreen}if(a.iconFeatureIndex&&(D=a.iconFeatureIndex),a.iconBox){var X=function(t){var e=w&&E?be(t,E.x,E.y,b,_,i.transform.angle):t;return i.collisionIndex.placeCollisionBox(e,x,f,l,g.predicate)};A=L&&L.box&&L.box.length&&a.verticalIconBox?(P=X(a.verticalIconBox)).box.length>0:(P=X(a.iconBox)).box.length>0,S=S&&P.offscreen}var Z=m||0===e.numHorizontalGlyphVertices&&0===e.numVerticalGlyphVertices,J=v||0===e.numIconVertices;if(Z||J?J?Z||(A=A&&T):T=A&&T:A=T=A&&T,T&&p&&p.box&&i.collisionIndex.insertCollisionBox(p.box,s.get(\"text-ignore-placement\"),o.bucketInstanceId,L&&L.box&&O?O:z,g.ID),A&&P&&i.collisionIndex.insertCollisionBox(P.box,s.get(\"icon-ignore-placement\"),o.bucketInstanceId,D,g.ID),I&&(T&&i.collisionIndex.insertCollisionCircles(I.circles,s.get(\"text-ignore-placement\"),o.bucketInstanceId,z,g.ID),n)){var K=o.bucketInstanceId,Q=i.collisionCircleArrays[K];void 0===Q&&(Q=i.collisionCircleArrays[K]=new me);for(var $=0;$<I.circles.length;$+=4)Q.circles.push(I.circles[$+0]),Q.circles.push(I.circles[$+1]),Q.circles.push(I.circles[$+2]),Q.circles.push(I.collisionDetected?1:0)}i.placements[e.crossTileID]=new ge(T||k,A||M,S||o.justReloaded),r[e.crossTileID]=!0}};if(T)for(var S=o.getSortedSymbolIndexes(this.transform.angle),E=S.length-1;E>=0;--E){var C=S[E];A(o.symbolInstances.get(C),o.collisionArrays[C])}else for(var L=e.symbolInstanceStart;L<e.symbolInstanceEnd;L++)A(o.symbolInstances.get(L),o.collisionArrays[L]);if(n&&o.bucketInstanceId in this.collisionCircleArrays){var I=this.collisionCircleArrays[o.bucketInstanceId];t.invert(I.invProjMatrix,l),I.viewportMatrix=this.collisionIndex.getViewportMatrix()}o.justReloaded=!1},_e.prototype.markUsedJustification=function(e,r,n,i){var a;a=i===t.WritingMode.vertical?n.verticalPlacedTextSymbolIndex:{left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex}[t.getAnchorJustification(r)];for(var o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex,n.verticalPlacedTextSymbolIndex];o<s.length;o+=1){var l=s[o];l>=0&&(e.text.placedSymbolArray.get(l).crossTileID=a>=0&&l!==a?0:n.crossTileID)}},_e.prototype.markUsedOrientation=function(e,r,n){for(var i=r===t.WritingMode.horizontal||r===t.WritingMode.horizontalOnly?r:0,a=r===t.WritingMode.vertical?r:0,o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex];o<s.length;o+=1)e.text.placedSymbolArray.get(s[o]).placedOrientation=i;n.verticalPlacedTextSymbolIndex&&(e.text.placedSymbolArray.get(n.verticalPlacedTextSymbolIndex).placedOrientation=a)},_e.prototype.commit=function(t){this.commitTime=t,this.zoomAtLastRecencyCheck=this.transform.zoom;var e=this.prevPlacement,r=!1;this.prevZoomAdjustment=e?e.zoomAdjustment(this.transform.zoom):0;var n=e?e.symbolFadeChange(t):1,i=e?e.opacities:{},a=e?e.variableOffsets:{},o=e?e.placedOrientations:{};for(var s in this.placements){var l=this.placements[s],c=i[s];c?(this.opacities[s]=new de(c,n,l.text,l.icon),r=r||l.text!==c.text.placed||l.icon!==c.icon.placed):(this.opacities[s]=new de(null,n,l.text,l.icon,l.skipFade),r=r||l.text||l.icon)}for(var u in i){var f=i[u];if(!this.opacities[u]){var h=new de(f,n,!1,!1);h.isHidden()||(this.opacities[u]=h,r=r||f.text.placed||f.icon.placed)}}for(var p in a)this.variableOffsets[p]||!this.opacities[p]||this.opacities[p].isHidden()||(this.variableOffsets[p]=a[p]);for(var d in o)this.placedOrientations[d]||!this.opacities[d]||this.opacities[d].isHidden()||(this.placedOrientations[d]=o[d]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},_e.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},_e.prototype.updateBucketOpacities=function(e,r,n){var i=this;e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexArray.clear(),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexArray.clear();var a=e.layers[0].layout,o=new de(null,0,!1,!1,!0),s=a.get(\"text-allow-overlap\"),l=a.get(\"icon-allow-overlap\"),c=a.get(\"text-variable-anchor\"),u=\"map\"===a.get(\"text-rotation-alignment\"),f=\"map\"===a.get(\"text-pitch-alignment\"),h=\"none\"!==a.get(\"icon-text-fit\"),p=new de(null,0,s&&(l||!e.hasIconData()||a.get(\"icon-optional\")),l&&(s||!e.hasTextData()||a.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData())&&e.deserializeCollisionBoxes(n);for(var d=function(t,e,r){for(var n=0;n<e/4;n++)t.opacityVertexArray.emplaceBack(r)},g=function(n){var a=e.symbolInstances.get(n),s=a.numHorizontalGlyphVertices,l=a.numVerticalGlyphVertices,g=a.crossTileID,m=i.opacities[g];r[g]?m=o:m||(i.opacities[g]=m=p),r[g]=!0;var v=a.numIconVertices>0,y=i.placedOrientations[a.crossTileID],x=y===t.WritingMode.vertical,b=y===t.WritingMode.horizontal||y===t.WritingMode.horizontalOnly;if(s>0||l>0){var _=Le(m.text);d(e.text,s,x?Ie:_),d(e.text,l,b?Ie:_);var w=m.text.isHidden();[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach((function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=w||x?1:0)})),a.verticalPlacedTextSymbolIndex>=0&&(e.text.placedSymbolArray.get(a.verticalPlacedTextSymbolIndex).hidden=w||b?1:0);var T=i.variableOffsets[a.crossTileID];T&&i.markUsedJustification(e,T.anchor,a,y);var k=i.placedOrientations[a.crossTileID];k&&(i.markUsedJustification(e,\"left\",a,k),i.markUsedOrientation(e,k,a))}if(v){var M=Le(m.icon),A=!(h&&a.verticalPlacedIconSymbolIndex&&x);a.placedIconSymbolIndex>=0&&(d(e.icon,a.numIconVertices,A?M:Ie),e.icon.placedSymbolArray.get(a.placedIconSymbolIndex).hidden=m.icon.isHidden()),a.verticalPlacedIconSymbolIndex>=0&&(d(e.icon,a.numVerticalIconVertices,A?Ie:M),e.icon.placedSymbolArray.get(a.verticalPlacedIconSymbolIndex).hidden=m.icon.isHidden())}if(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData()){var S=e.collisionArrays[n];if(S){var E=new t.Point(0,0);if(S.textBox||S.verticalTextBox){var C=!0;if(c){var L=i.variableOffsets[g];L?(E=xe(L.anchor,L.width,L.height,L.textOffset,L.textBoxScale),u&&E._rotate(f?i.transform.angle:-i.transform.angle)):C=!1}S.textBox&&we(e.textCollisionBox.collisionVertexArray,m.text.placed,!C||x,E.x,E.y),S.verticalTextBox&&we(e.textCollisionBox.collisionVertexArray,m.text.placed,!C||b,E.x,E.y)}var I=Boolean(!b&&S.verticalIconBox);S.iconBox&&we(e.iconCollisionBox.collisionVertexArray,m.icon.placed,I,h?E.x:0,h?E.y:0),S.verticalIconBox&&we(e.iconCollisionBox.collisionVertexArray,m.icon.placed,!I,h?E.x:0,h?E.y:0)}}},m=0;m<e.symbolInstances.length;m++)g(m);if(e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexBuffer&&e.iconCollisionBox.collisionVertexBuffer.updateData(e.iconCollisionBox.collisionVertexArray),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexBuffer&&e.textCollisionBox.collisionVertexBuffer.updateData(e.textCollisionBox.collisionVertexArray),e.bucketInstanceId in this.collisionCircleArrays){var v=this.collisionCircleArrays[e.bucketInstanceId];e.placementInvProjMatrix=v.invProjMatrix,e.placementViewportMatrix=v.viewportMatrix,e.collisionCircleArray=v.circles,delete this.collisionCircleArrays[e.bucketInstanceId]}},_e.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration+this.prevZoomAdjustment},_e.prototype.zoomAdjustment=function(t){return Math.max(0,(this.transform.zoom-t)/1.5)},_e.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},_e.prototype.stillRecent=function(t,e){var r=this.zoomAtLastRecencyCheck===e?1-this.zoomAdjustment(e):1;return this.zoomAtLastRecencyCheck=e,this.commitTime+this.fadeDuration*r>t},_e.prototype.setStale=function(){this.stale=!0};var Te=Math.pow(2,25),ke=Math.pow(2,24),Me=Math.pow(2,17),Ae=Math.pow(2,16),Se=Math.pow(2,9),Ee=Math.pow(2,8),Ce=Math.pow(2,1);function Le(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*Te+e*ke+r*Me+e*Ae+r*Se+e*Ee+r*Ce+e}var Ie=0,Pe=function(t){this._sortAcrossTiles=\"viewport-y\"!==t.layout.get(\"symbol-z-order\")&&void 0!==t.layout.get(\"symbol-sort-key\").constantOr(1),this._currentTileIndex=0,this._currentPartIndex=0,this._seenCrossTileIDs={},this._bucketParts=[]};Pe.prototype.continuePlacement=function(t,e,r,n,i){for(var a=this._bucketParts;this._currentTileIndex<t.length;)if(e.getBucketParts(a,n,t[this._currentTileIndex],this._sortAcrossTiles),this._currentTileIndex++,i())return!0;for(this._sortAcrossTiles&&(this._sortAcrossTiles=!1,a.sort((function(t,e){return t.sortKey-e.sortKey})));this._currentPartIndex<a.length;)if(e.placeLayerBucketPart(a[this._currentPartIndex],this._seenCrossTileIDs,r),this._currentPartIndex++,i())return!0;return!1};var ze=function(t,e,r,n,i,a,o){this.placement=new _e(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};ze.prototype.isDone=function(){return this._done},ze.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Pe(s)),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},ze.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Oe=512/t.EXTENT/2,De=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};De.prototype.getScaledCoordinates=function(e,r){var n=Oe/Math.pow(2,r.canonical.z-this.tileID.canonical.z);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*n),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*n)}},De.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Re=function(){this.maxCrossTileID=0};Re.prototype.generate=function(){return++this.maxCrossTileID};var Fe=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Fe.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Fe.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var f=e.symbolInstances.get(u);f.crossTileID||(f.crossTileID=r.generate(),i[f.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new De(t,e.symbolInstances,e.bucketInstanceId),!0},Fe.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1)delete this.usedCrossTileIDs[t][i[n].crossTileID]},Fe.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Be=function(){this.layerIndexes={},this.crossTileIDs=new Re,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Be.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Fe);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Be.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach((function(t){e[t]=!0})),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Ne=function(e,r){return t.emitValidationErrors(e,r&&r.filter((function(t){return\"source.canvas\"!==t.identifier})))},je=t.pick(Ut,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ue=t.pick(Ut,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),Ve=function(){var e={},r=t.styleSpec.$version;for(var n in t.styleSpec.$root){var i,a=t.styleSpec.$root[n];a.required&&null!=(i=\"version\"===n?r:\"array\"===a.type?[]:{})&&(e[n]=i)}return e}(),qe=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k(Bt(),this),this.imageManager=new h,this.imageManager.setEventedParent(this),this.glyphManager=new x(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new T(256,512),this.crossTileSymbolIndex=new Be,this._layers={},this._serializedLayers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._availableImages=[],this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginStateChange((function(e){o.dispatcher.broadcast(\"syncRTLPluginState\",{pluginStatus:e.pluginStatus,pluginURL:e.pluginURL},(function(e,r){if(t.triggerPluginCompletionEvent(e),r&&r.every((function(t){return t})))for(var n in o.sourceCaches)o.sourceCaches[n].reload()}))})),this.on(\"data\",(function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}}))}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,(function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)}))},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame((function(){n._request=null,n._load(e,!1!==r.validate)}))},r.prototype.loadEmpty=function(){this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._load(Ve,!1)},r.prototype._load=function(e,r){if(!r||!Ne(this,t.validateStyle(e))){for(var n in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(n,e.sources[n],{validate:!1});e.sprite?this._loadSprite(e.sprite):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var i=jt(this.stylesheet.layers);this._order=i.map((function(t){return t.id})),this._layers={},this._serializedLayers={};for(var a=0,o=i;a<o.length;a+=1){var s=o[a];(s=t.createStyleLayer(s)).setEventedParent(this,{layer:{id:s.id}}),this._layers[s.id]=s,this._serializedLayers[s.id]=s.serialize()}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new w(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._loadSprite=function(e){var r=this;this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),(function(t,e){l=null,o||(o=t,i=e,u())})),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),(function(t,e){c=null,o||(o=t,a=e,u())}));function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,f=l.x,h=l.y,p=l.sdf,d=l.pixelRatio,g=l.stretchX,m=l.stretchY,v=l.content,y=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,y,{x:f,y:h},{x:0,y:0},{width:c,height:u}),r[s]={data:y,pixelRatio:d,sdf:p,stretchX:g,stretchY:m,content:v}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e,this.map._requestManager,(function(e,n){if(r._spriteRequest=null,e)r.fire(new t.ErrorEvent(e));else if(n)for(var i in n)r.imageManager.addImage(i,n[i]);r.imageManager.setLoaded(!0),r._availableImages=r.imageManager.listImages(),r.dispatcher.broadcast(\"setImages\",r._availableImages),r.fire(new t.Event(\"data\",{dataType:\"style\"}))}))},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=this._layers[n[r]];\"custom\"!==i.type&&e.push(i.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updateTilesForChangedImages(),this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var f=this._layers[u[c]];f.recalculate(e,this._availableImages),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateTilesForChangedImages=function(){var t=Object.keys(this._changedImages);if(t.length){for(var e in this.sourceCaches)this.sourceCaches[e].reloadTilesForDependencies([\"icons\",\"patterns\"],t);this._changedImages={}}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={},this._changedImages={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Ne(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=jt(e.layers);var n=function(e,r){if(!e)return[{command:Ut.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Ut.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Ut.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Ut.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Ut.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Ut.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Ut.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Ut.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Ut.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Ut.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||qt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Gt(e,r,a)?n.push({command:Ut.setGeoJSONSourceData,args:[a,r[a].data]}):Ht(a,r,n,i)):Vt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach((function(t){i[t.source]?n.push({command:Ut.removeLayer,args:[t.id]}):o.push(t)})),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,f=(e=e||[]).map(Wt),h=r.map(Wt),p=e.reduce(Xt,{}),d=r.reduce(Xt,{}),g=f.slice(),m=Object.create(null);for(i=0,a=0;i<f.length;i++)d.hasOwnProperty(o=f[i])?a++:(n.push({command:Ut.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<h.length;i++)g[g.length-1-i]!==(o=h[h.length-1-i])&&(p.hasOwnProperty(o)?(n.push({command:Ut.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,n.push({command:Ut.addLayer,args:[d[o],c=g[g.length-i]]}),g.splice(g.length-i,0,o),m[o]=!0);for(i=0;i<h.length;i++)if(s=p[o=h[i]],l=d[o],!m[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in Yt(s.layout,l.layout,n,o,null,Ut.setLayoutProperty),Yt(s.paint,l.paint,n,o,null,Ut.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Ut.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Ut.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Ut.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Ut.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Ut.setStyle,args:[r]}]}return n}(this.serialize(),e).filter((function(t){return!(t.command in Ue)}));if(0===n.length)return!1;var i=n.filter((function(t){return!(t.command in je)}));if(i.length>0)throw new Error(\"Unimplemented: \"+i.map((function(t){return t.command})).join(\", \")+\".\");return n.forEach((function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)})),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Lt(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,(function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}})),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Ne(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}}),this._serializedLayers[a.id]=a.serialize()}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._serializedLayers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.hasLayer=function(t){return t in this._layers},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n];if(void 0!==a){var o=a.getSource().type;\"geojson\"===o&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==o||i?(void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),a.setFeatureState(i,e.id,r)):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0;\"vector\"!==a||o?r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,e.id,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r];if(void 0!==i){if(\"vector\"!==i.getSource().type||n)return void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),i.getFeatureState(n,e.id);this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,(function(t){return t.serialize()})),layers:this._serializeLayers(this._order)},(function(t){return void 0!==t}))},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&\"raster\"!==this.sourceCaches[t.source].getSource().type&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,f=c;u<f.length;u+=1)i.push(f[u])}}}i.sort((function(t,e){return e.intersectionZ-t.intersectionZ}));for(var h=[],p=this._order.length-1;p>=0;p--){var d=this._order[p];if(r(d))for(var g=i.length-1;g>=0;g--){var m=i[g].feature;if(n[m.layer.id]<p)break;h.push(m),i.pop()}else for(var v=0,y=t;v<y.length;v+=1){var x=y[v][d];if(x)for(var b=0,_=x;b<_.length;b+=1)h.push(_[b].feature)}}return h},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in r.availableImages=this._availableImages,this.sourceCaches)r.layers&&!i[u]||c.push(F(this.sourceCaches[u],this._layers,this._serializedLayers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a,o){for(var s={},l=a.queryRenderedSymbols(n),c=[],u=0,f=Object.keys(l).map(Number);u<f.length;u+=1)c.push(o[f[u]]);c.sort(B);for(var h=function(){var r=d[p],n=r.featureIndex.lookupSymbolFeatures(l[r.bucketInstanceId],e,r.bucketIndex,r.sourceLayerIndex,i.filter,i.layers,i.availableImages,t);for(var a in n){var o=s[a]=s[a]||[],c=n[a];c.sort((function(t,e){var n=r.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(e.featureIndex)-i}return e.featureIndex-t.featureIndex}));for(var u=0,f=c;u<f.length;u+=1)o.push(f[u])}},p=0,d=c;p<d.length;p+=1)h();var g=function(e){s[e].forEach((function(n){var i=n.feature,a=r[t[e].source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=a}))};for(var m in s)g(m);return s}(this._layers,this._serializedLayers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map((function(e){return t.getTileByID(e)})),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Ne(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginStateChange\",this._rtlTextPluginCallback),this._layers)this._layers[e].setEventedParent(null);for(var r in this.sourceCaches)this.sourceCaches[r].clearTiles(),this.sourceCaches[r].setEventedParent(null);this.imageManager.setEventedParent(null),this.setEventedParent(null),this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i,a){void 0===a&&(a=!1);for(var o=!1,s=!1,l={},c=0,u=this._order;c<u.length;c+=1){var f=this._layers[u[c]];if(\"symbol\"===f.type){if(!l[f.source]){var h=this.sourceCaches[f.source];l[f.source]=h.getRenderableIds(!0).map((function(t){return h.getTileByID(t)})).sort((function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)}))}var p=this.crossTileSymbolIndex.addLayer(f,l[f.source],e.center.lng);o=o||p}}if(this.crossTileSymbolIndex.pruneUnusedLayers(this._order),((a=a||this._layerOrderChanged||0===n)||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now(),e.zoom))&&(this.pauseablePlacement=new ze(e,this._order,a,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,l),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),s=!0),o&&this.pauseablePlacement.placement.setStale()),s||o)for(var d=0,g=this._order;d<g.length;d+=1){var m=this._layers[g[d]];\"symbol\"===m.type&&this.placement.updateLayerOpacities(m,l[m.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r),this._updateTilesForChangedImages();var n=this.sourceCaches[e.source];n&&n.setDependencies(e.tileID.key,e.type,e.icons)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);qe.getSourceType=function(t){return D[t]},qe.setSourceType=function(t,e){D[t]=e},qe.registerForPluginStateChange=t.registerForPluginStateChange;var He=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Ge=vr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Ye=vr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=vr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),Xe=vr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ze=vr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Je=vr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),Ke=vr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),Qe=vr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),$e=vr(\"varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;void main() {float alpha=0.5*min(v_perspective_ratio,1.0);float stroke_radius=0.9*max(v_perspective_ratio,1.0);float distance_to_center=length(v_extrude);float distance_to_edge=abs(distance_to_center-v_radius);float opacity_t=smoothstep(-stroke_radius,0.0,-distance_to_edge);vec4 color=mix(vec4(0.0,0.0,1.0,0.5),vec4(1.0,0.0,0.0,1.0),v_collision);gl_FragColor=color*alpha*opacity_t;}\",\"attribute vec2 a_pos;attribute float a_radius;attribute vec2 a_flags;uniform mat4 u_matrix;uniform mat4 u_inv_matrix;uniform vec2 u_viewport_size;uniform float u_camera_to_center_distance;varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;vec3 toTilePosition(vec2 screenPos) {vec4 rayStart=u_inv_matrix*vec4(screenPos,-1.0,1.0);vec4 rayEnd  =u_inv_matrix*vec4(screenPos, 1.0,1.0);rayStart.xyz/=rayStart.w;rayEnd.xyz  /=rayEnd.w;highp float t=(0.0-rayStart.z)/(rayEnd.z-rayStart.z);return mix(rayStart.xyz,rayEnd.xyz,t);}void main() {vec2 quadCenterPos=a_pos;float radius=a_radius;float collision=a_flags.x;float vertexIdx=a_flags.y;vec2 quadVertexOffset=vec2(mix(-1.0,1.0,float(vertexIdx >=2.0)),mix(-1.0,1.0,float(vertexIdx >=1.0 && vertexIdx <=2.0)));vec2 quadVertexExtent=quadVertexOffset*radius;vec3 tilePos=toTilePosition(quadCenterPos);vec4 clipPos=u_matrix*vec4(tilePos,1.0);highp float camera_to_anchor_distance=clipPos.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);float padding_factor=1.2;v_radius=radius;v_extrude=quadVertexExtent*padding_factor;v_perspective_ratio=collision_perspective_ratio;v_collision=collision;gl_Position=vec4(clipPos.xyz/clipPos.w,1.0)+vec4(quadVertexExtent*padding_factor/u_viewport_size*2.0,0.0,0.0);}\"),tr=vr(\"uniform highp vec4 u_color;uniform sampler2D u_overlay;varying vec2 v_uv;void main() {vec4 overlay_color=texture2D(u_overlay,v_uv);gl_FragColor=mix(u_color,overlay_color,overlay_color.a);}\",\"attribute vec2 a_pos;varying vec2 v_uv;uniform mat4 u_matrix;uniform float u_overlay_scale;void main() {v_uv=a_pos/8192.0;gl_Position=u_matrix*vec4(a_pos*u_overlay_scale,0,1);}\"),er=vr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),rr=vr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),nr=vr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),ir=vr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),ar=vr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),or=vr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec3 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),sr=vr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;uniform vec4 u_unpack;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;data.a=-1.0;return dot(data,u_unpack)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),lr=vr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),cr=vr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),ur=vr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),fr=vr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec3 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float aspect_a=display_size_a.y/v_width;float aspect_b=display_size_b.y/v_width;float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x*aspect_a,1.0);float x_b=mod(v_linesofar/pattern_size_b.x*aspect_b,1.0);float y=0.5*v_normal.y+0.5;vec2 texel_size=1.0/u_texsize;vec2 pos_a=mix(pattern_tl_a*texel_size-texel_size,pattern_br_a*texel_size+texel_size,vec2(x_a,y));vec2 pos_b=mix(pattern_tl_b*texel_size-texel_size,pattern_br_b*texel_size+texel_size,vec2(x_b,y));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);v_width=floorwidth;}\"),hr=vr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),pr=vr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),dr=vr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;vec2 a_minFontScale=a_pixeloffset.zw/256.0;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*max(a_minFontScale,fontScale)+a_pxoffset/16.0),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),gr=vr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale+a_pxoffset),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=a_tex/u_texsize;v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\"),mr=vr(\"#define SDF_PX 8.0\\n#define SDF 1.0\\n#define ICON 0.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform sampler2D u_texture_icon;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat fade_opacity=v_data1[2];if (v_data1.w==ICON) {vec2 tex_icon=v_data0.zw;lowp float alpha=opacity*fade_opacity;gl_FragColor=texture2D(u_texture_icon,tex_icon)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\nreturn;}vec2 tex=v_data0.xy;float EDGE_GAMMA=0.105/u_device_pixel_ratio;float gamma_scale=v_data1.x;float size=v_data1.y;float fontScale=size/24.0;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;uniform vec2 u_texsize_icon;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);float is_sdf=a_size[0]-2.0*a_size_min;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=size/24.0;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0.xy=a_tex/u_texsize;v_data0.zw=a_tex/u_texsize_icon;v_data1=vec4(gamma_scale,size,interpolated_fade_opacity,is_sdf);}\");function vr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,(function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})),vertexSource:e=e.replace(r,(function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}))}}var yr=Object.freeze({__proto__:null,prelude:Ge,background:Ye,backgroundPattern:We,circle:Xe,clippingMask:Ze,heatmap:Je,heatmapTexture:Ke,collisionBox:Qe,collisionCircle:$e,debug:tr,fill:er,fillOutline:rr,fillOutlinePattern:nr,fillPattern:ir,fillExtrusion:ar,fillExtrusionPattern:or,hillshadePrepare:sr,hillshade:lr,line:cr,lineGradient:ur,linePattern:fr,lineSDF:hr,raster:pr,symbolIcon:dr,symbolSDF:gr,symbolTextAndIcon:mr}),xr=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};xr.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);t.extVertexArrayObject&&this.vao&&this.boundProgram===e&&this.boundLayoutVertexBuffer===r&&!l&&this.boundIndexBuffer===i&&this.boundVertexOffset===a&&this.boundDynamicVertexBuffer===o&&this.boundDynamicVertexBuffer2===s?(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind()):this.freshBind(e,r,n,i,a,o,s)},xr.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var f=l;f<s;f++)u.disableVertexAttribArray(f)}e.enableAttributes(u,t);for(var h=0,p=r;h<p.length;h+=1)p[h].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var m=g[d];m.bind(),m.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},xr.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var br=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r?r.defines():[];i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Ge.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Ge.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);if(a.isContextLost())this.failedToCreate=!0;else{a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);if(a.isContextLost())this.failedToCreate=!0;else{a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var f=r?r.layoutAttributes:[],h=0;h<f.length;h++)a.bindAttribLocation(this.program,h,f[h].name);a.linkProgram(this.program),a.deleteShader(u),a.deleteShader(c),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var m=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),v=0;v<m;v++){var y=a.getActiveUniform(this.program,v);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r?r.getUniforms(t,p):[]}}};function _r(t,e,r){var n=1/he(r,1,e.transform.tileZoom),i=Math.pow(2,r.tileID.overscaledZ),a=r.tileSize*Math.pow(2,e.transform.tileZoom)/i,o=a*(r.tileID.canonical.x+r.tileID.wrap*i),s=a*r.tileID.canonical.y;return{u_image:0,u_texsize:r.imageAtlasTexture.size,u_scale:[n,t.fromScale,t.toScale],u_fade:t.t,u_pixel_coord_upper:[o>>16,s>>16],u_pixel_coord_lower:[65535&o,65535&s]}}br.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g){var m,v=t.gl;if(!this.failedToCreate){for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,f,{zoom:h});for(var x=(m={},m[v.LINES]=2,m[v.TRIANGLES]=3,m[v.LINE_STRIP]=1,m)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],T=w.vaos||(w.vaos={});(T[s]||(T[s]=new xr)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),v.drawElements(e,w.primitiveLength*x,v.UNSIGNED_SHORT,w.primitiveOffset*x*2)}}};var wr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},Tr=function(e,r,n,i,a,o,s){return t.extend(wr(e,r,n,i),_r(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},kr=function(t){return{u_matrix:t}},Mr=function(e,r,n,i){return t.extend(kr(e),_r(n,r,i))},Ar=function(t,e){return{u_matrix:t,u_world:e}},Sr=function(e,r,n,i,a){return t.extend(Mr(e,r,n,i),{u_world:a})},Er=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=he(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},Cr=function(t,e,r){var n=he(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},Lr=function(t,e,r){return{u_matrix:t,u_inv_matrix:e,u_camera_to_center_distance:r.cameraToCenterDistance,u_viewport_size:[r.width,r.height]}},Ir=function(t,e,r){return void 0===r&&(r=1),{u_matrix:t,u_color:e,u_overlay:0,u_overlay_scale:r}},Pr=function(t){return{u_matrix:t}},zr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:he(e,1,r),u_intensity:n}},Or=function(e,r,n){var i=e.transform;return{u_matrix:Nr(e,r,n),u_ratio:1/he(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Dr=function(e,r,n){return t.extend(Or(e,r,n),{u_image:0})},Rr=function(e,r,n,i){var a=e.transform,o=Br(r,a);return{u_matrix:Nr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/he(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Fr=function(e,r,n,i,a){var o=e.lineAtlas,s=Br(r,e.transform),l=\"round\"===n.layout.get(\"line-cap\"),c=o.getDash(i.from,l),u=o.getDash(i.to,l),f=c.width*a.fromScale,h=u.width*a.toScale;return t.extend(Or(e,r,n),{u_patternscale_a:[s/f,-c.height/2],u_patternscale_b:[s/h,-u.height/2],u_sdfgamma:o.width/(256*Math.min(f,h)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:c.y,u_tex_y_b:u.y,u_mix:a.t})};function Br(t,e){return 1/he(t,1,e.tileZoom)}function Nr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var jr=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:Ur(i.paint.get(\"raster-hue-rotate\"))};var a,o};function Ur(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}var Vr,qr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Hr=function(e,r,n,i,a,o,s,l,c,u,f){var h=a.transform;return t.extend(qr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(h._pitch)*h.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+f})},Gr=function(e,r,n,i,a,o,s,l,c,u){return t.extend(Hr(e,r,n,i,a,o,s,l,!0,c,!0),{u_texsize_icon:u,u_texture_icon:1})},Yr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Wr=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from.toString()),a=r.imageManager.getPattern(t.to.toString()),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,f=u*(n.tileID.canonical.x+n.tileID.wrap*c),h=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/he(n,1,r.transform.tileZoom),u_pixel_coord_upper:[f>>16,h>>16],u_pixel_coord_lower:[65535&f,65535&h]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Xr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},collisionCircle:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_inv_matrix:new t.UniformMatrix4f(e,r.u_inv_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_viewport_size:new t.Uniform2f(e,r.u_viewport_size)}},debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_overlay:new t.Uniform1i(e,r.u_overlay),u_overlay_scale:new t.Uniform1f(e,r.u_overlay_scale)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom),u_unpack:new t.Uniform4f(e,r.u_unpack)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},symbolTextAndIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texsize_icon:new t.Uniform2f(e,r.u_texsize_icon),u_texture:new t.Uniform1i(e,r.u_texture),u_texture_icon:new t.Uniform1i(e,r.u_texture_icon),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function Zr(e,r,n,i,a,o,s){for(var l=e.context,c=l.gl,u=e.useProgram(\"collisionBox\"),f=[],h=0,p=0,d=0;d<i.length;d++){var g=i[d],m=r.getTile(g),v=m.getBucket(n);if(v){var y=g.posMatrix;0===a[0]&&0===a[1]||(y=e.translatePosMatrix(g.posMatrix,m,a,o));var x=s?v.textCollisionBox:v.iconCollisionBox,b=v.collisionCircleArray;if(b.length>0){var _=t.create(),w=y;t.mul(_,v.placementInvProjMatrix,e.transform.glCoordMatrix),t.mul(_,_,v.placementViewportMatrix),f.push({circleArray:b,circleOffset:p,transform:w,invTransform:_}),p=h+=b.length/4}x&&u.draw(l,c.LINES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,Cr(y,e.transform,m),n.id,x.layoutVertexBuffer,x.indexBuffer,x.segments,null,e.transform.zoom,null,null,x.collisionVertexBuffer)}}if(s&&f.length){var T=e.useProgram(\"collisionCircle\"),k=new t.StructArrayLayout2f1f2i16;k.resize(4*h),k._trim();for(var M=0,A=0,S=f;A<S.length;A+=1)for(var E=S[A],C=0;C<E.circleArray.length/4;C++){var L=4*C,I=E.circleArray[L+0],P=E.circleArray[L+1],z=E.circleArray[L+2],O=E.circleArray[L+3];k.emplace(M++,I,P,z,O,0),k.emplace(M++,I,P,z,O,1),k.emplace(M++,I,P,z,O,2),k.emplace(M++,I,P,z,O,3)}(!Vr||Vr.length<2*h)&&(Vr=function(e){var r=2*e,n=new t.StructArrayLayout3ui6;n.resize(r),n._trim();for(var i=0;i<r;i++){var a=6*i;n.uint16[a+0]=4*i+0,n.uint16[a+1]=4*i+1,n.uint16[a+2]=4*i+2,n.uint16[a+3]=4*i+2,n.uint16[a+4]=4*i+3,n.uint16[a+5]=4*i+0}return n}(h));for(var D=l.createIndexBuffer(Vr,!0),R=l.createVertexBuffer(k,t.collisionCircleLayout.members,!0),F=0,B=f;F<B.length;F+=1){var N=B[F],j=Lr(N.transform,N.invTransform,e.transform);T.draw(l,c.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,j,n.id,R,D,t.SegmentVector.simpleSegment(0,2*N.circleOffset,N.circleArray.length,N.circleArray.length/2),null,e.transform.zoom,null,null,null)}R.destroy(),D.destroy()}}var Jr=t.identity(new Float32Array(16));function Kr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateVariableOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Qr(e,r,n,i,a,o,s,l,c,u,f){var h=e.text.placedSymbolArray,p=e.text.dynamicLayoutVertexArray,d=e.icon.dynamicLayoutVertexArray,g={};p.clear();for(var m=0;m<h.length;m++){var v=h.get(m),y=v.hidden||!v.crossTileID||e.allowVerticalPlacement&&!v.placedOrientation?null:i[v.crossTileID];if(y){var x=new t.Point(v.anchorX,v.anchorY),b=$t(x,n?l:s),_=te(o.cameraToCenterDistance,b.signedDistanceFromCamera),w=a.evaluateSizeForFeature(e.textSizeData,u,v)*_/t.ONE_EM;n&&(w*=e.tilePixelRatio/c);for(var T=Kr(y.anchor,y.width,y.height,y.textOffset,y.textBoxScale,w),k=n?$t(x.add(T),s).point:b.point.add(r?T.rotate(-o.angle):T),M=e.allowVerticalPlacement&&v.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,A=0;A<v.numGlyphs;A++)t.addDynamicAttributes(p,k,M);f&&v.associatedIconIndex>=0&&(g[v.associatedIconIndex]={shiftedAnchor:k,angle:M})}else ce(v.numGlyphs,p)}if(f){d.clear();for(var S=e.icon.placedSymbolArray,E=0;E<S.length;E++){var C=S.get(E);if(C.hidden)ce(C.numGlyphs,d);else{var L=g[E];if(L)for(var I=0;I<C.numGlyphs;I++)t.addDynamicAttributes(d,L.shiftedAnchor,L.angle);else ce(C.numGlyphs,d)}}e.icon.dynamicLayoutVertexBuffer.updateData(d)}e.text.dynamicLayoutVertexBuffer.updateData(p)}function $r(t,e,r){return r.iconsInText&&e?\"symbolTextAndIcon\":t?\"symbolSDF\":\"symbolIcon\"}function tn(e,r,n,i,a,o,s,l,c,u,f,h){for(var p=e.context,d=p.gl,g=e.transform,m=\"map\"===l,v=\"map\"===c,y=m&&\"point\"!==n.layout.get(\"symbol-placement\"),x=m&&!v&&!y,b=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),_=e.depthModeForSublayer(0,Mt.ReadOnly),w=n.layout.get(\"text-variable-anchor\"),T=[],k=0,M=i;k<M.length;k+=1){var A=M[k],S=r.getTile(A),E=S.getBucket(n);if(E){var C=a?E.text:E.icon;if(C&&C.segments.get().length){var L=C.programConfigurations.get(n.id),I=a||E.sdfIcons,P=a?E.textSizeData:E.iconSizeData,z=v||0!==g.pitch,O=e.useProgram($r(I,a,E),L),D=t.evaluateSizeForZoom(P,g.zoom),R=void 0,F=[0,0],B=void 0,N=void 0,j=null,U=void 0;if(a)B=S.glyphAtlasTexture,N=d.LINEAR,R=S.glyphAtlasTexture.size,E.iconsInText&&(F=S.imageAtlasTexture.size,j=S.imageAtlasTexture,U=z||e.options.rotating||e.options.zooming||\"composite\"===P.kind||\"camera\"===P.kind?d.LINEAR:d.NEAREST);else{var V=1!==n.layout.get(\"icon-size\").constantOr(0)||E.iconsNeedLinear;B=S.imageAtlasTexture,N=I||e.options.rotating||e.options.zooming||V||z?d.LINEAR:d.NEAREST,R=S.imageAtlasTexture.size}var q=he(S,1,e.transform.zoom),H=Kt(A.posMatrix,v,m,e.transform,q),G=Qt(A.posMatrix,v,m,e.transform,q),Y=w&&E.hasTextData(),W=\"none\"!==n.layout.get(\"icon-text-fit\")&&Y&&E.hasIconData();y&&re(E,A.posMatrix,e,a,H,G,v,u);var X=e.translatePosMatrix(A.posMatrix,S,o,s),Z=y||a&&w||W?Jr:H,J=e.translatePosMatrix(G,S,o,s,!0),K=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Q={program:O,buffers:C,uniformValues:I?E.iconsInText?Gr(P.kind,D,x,v,e,X,Z,J,R,F):Hr(P.kind,D,x,v,e,X,Z,J,a,R,!0):qr(P.kind,D,x,v,e,X,Z,J,a,R),atlasTexture:B,atlasTextureIcon:j,atlasInterpolation:N,atlasInterpolationIcon:U,isSDF:I,hasHalo:K};if(b)for(var $=0,tt=C.segments.get();$<tt.length;$+=1){var et=tt[$];T.push({segments:new t.SegmentVector([et]),sortKey:et.sortKey,state:Q})}else T.push({segments:C.segments,sortKey:0,state:Q})}}}b&&T.sort((function(t,e){return t.sortKey-e.sortKey}));for(var rt=0,nt=T;rt<nt.length;rt+=1){var it=nt[rt],at=it.state;if(p.activeTexture.set(d.TEXTURE0),at.atlasTexture.bind(at.atlasInterpolation,d.CLAMP_TO_EDGE),at.atlasTextureIcon&&(p.activeTexture.set(d.TEXTURE1),at.atlasTextureIcon&&at.atlasTextureIcon.bind(at.atlasInterpolationIcon,d.CLAMP_TO_EDGE)),at.isSDF){var ot=at.uniformValues;at.hasHalo&&(ot.u_is_halo=1,en(at.buffers,it.segments,n,e,at.program,_,f,h,ot)),ot.u_is_halo=0}en(at.buffers,it.segments,n,e,at.program,_,f,h,at.uniformValues)}}function en(t,e,r,n,i,a,o,s,l){var c=n.context;i.draw(c,c.gl.TRIANGLES,a,o,s,Et.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function rn(t,e,r,n,i,a,o){var s,l,c,u,f,h=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=h.LINES):(l=d?\"fillPattern\":\"fill\",s=h.TRIANGLES);for(var m=0,v=n;m<v.length;m+=1){var y=v[m],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(h.TEXTURE0),x.imageAtlasTexture.bind(h.LINEAR,h.CLAMP_TO_EDGE),_.updatePaintBuffers(g));var T=p.constantOr(null);if(T&&x.imageAtlas){var k=x.imageAtlas,M=k.patternPositions[T.to.toString()],A=k.patternPositions[T.from.toString()];M&&A&&_.setConstantPatternPositions(M,A)}var S=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,f=b.segments2;var E=[h.drawingBufferWidth,h.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?Sr(S,t,g,x,E):Ar(S,E)}else u=b.indexBuffer,f=b.segments,c=d?Mr(S,t,g,x):kr(S);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,Et.disabled,c,r.id,b.layoutVertexBuffer,u,f,r.paint,t.transform.zoom,_)}}}}function nn(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),f=r.getCrossfadeParameters(),h=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],m=e.getTile(g),v=m.getBucket(r);if(v){var y=v.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),m.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePaintBuffers(f));var b=c.constantOr(null);if(b&&m.imageAtlas){var _=m.imageAtlas,w=_.patternPositions[b.to.toString()],T=_.patternPositions[b.from.toString()];w&&T&&y.setConstantPatternPositions(w,T)}var k=t.translatePosMatrix(g.posMatrix,m,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),M=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?Tr(k,t,M,h,g,f,m):wr(k,t,M,h);x.draw(s,s.gl.TRIANGLES,i,a,o,Et.backCCW,A,r.id,v.layoutVertexBuffer,v.indexBuffer,v.segments,r.paint,t.transform.zoom,y)}}}function an(e,r,n,i,a,o){var s=e.context,l=s.gl,c=r.fbo;if(c){var u=e.useProgram(\"hillshade\");s.activeTexture.set(l.TEXTURE0),l.bindTexture(l.TEXTURE_2D,c.colorAttachment.get());var f=function(e,r,n){var i=n.paint.get(\"hillshade-shadow-color\"),a=n.paint.get(\"hillshade-highlight-color\"),o=n.paint.get(\"hillshade-accent-color\"),s=n.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===n.paint.get(\"hillshade-illumination-anchor\")&&(s-=e.transform.angle);var l,c,u,f=!e.options.moving;return{u_matrix:e.transform.calculatePosMatrix(r.tileID.toUnwrapped(),f),u_image:0,u_latrange:(l=r.tileID,c=Math.pow(2,l.canonical.z),u=l.canonical.y,[new t.MercatorCoordinate(0,u/c).toLngLat().lat,new t.MercatorCoordinate(0,(u+1)/c).toLngLat().lat]),u_light:[n.paint.get(\"hillshade-exaggeration\"),s],u_shadow:i,u_highlight:a,u_accent:o}}(e,r,n);u.draw(s,l.TRIANGLES,i,a,o,Et.disabled,f,n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments)}}function on(e,r,n,i,a,o,s){var l=e.context,c=l.gl,u=r.dem;if(u&&u.data){var f=u.dim,h=u.stride,p=u.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var d=r.demTexture;d.update(p,{premultiply:!1}),d.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,p,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var g=r.fbo;if(!g){var m=new t.Texture(l,{width:f,height:f,data:null},c.RGBA);m.bind(c.LINEAR,c.CLAMP_TO_EDGE),(g=r.fbo=l.createFramebuffer(f,f,!0)).colorAttachment.set(m.texture)}l.bindFramebuffer.set(g.framebuffer),l.viewport.set([0,0,f,f]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,Et.disabled,function(e,r,n){var i=r.stride,a=t.create();return t.ortho(a,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(a,a,[0,-t.EXTENT,0]),{u_matrix:a,u_image:1,u_dimension:[i,i],u_zoom:e.overscaledZ,u_maxzoom:n,u_unpack:r.getUnpackVector()}}(r.tileID,u,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function sn(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),f=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),h=!r||Math.abs(r.tileID.overscaledZ-f)>Math.abs(e.tileID.overscaledZ-f),p=h&&e.refreshedUponExpiration?1:t.clamp(h?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}var ln=new t.Color(1,0,0,1),cn=new t.Color(0,1,0,1),un=new t.Color(0,0,1,1),fn=new t.Color(1,0,1,1),hn=new t.Color(0,1,1,1);function pn(t,e,r,n){gn(t,0,e+r/2,t.transform.width,r,n)}function dn(t,e,r,n){gn(t,e-r/2,0,r,t.transform.height,n)}function gn(e,r,n,i,a,o){var s=e.context,l=s.gl;l.enable(l.SCISSOR_TEST),l.scissor(r*t.browser.devicePixelRatio,n*t.browser.devicePixelRatio,i*t.browser.devicePixelRatio,a*t.browser.devicePixelRatio),s.clear({color:o}),l.disable(l.SCISSOR_TEST)}function mn(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Mt.disabled,c=At.disabled,u=e.colorModeForRenderPass();i.activeTexture.set(a.TEXTURE0),e.emptyTexture.bind(a.LINEAR,a.CLAMP_TO_EDGE),s.draw(i,a.LINE_STRIP,l,c,u,Et.disabled,Ir(o,t.Color.red),\"$debug\",e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);var f=r.getTileByID(n.key).latestRawTileData,h=Math.floor((f&&f.byteLength||0)/1024),p=r.getTile(n).tileSize,d=512/Math.min(p,512)*(n.overscaledZ/e.transform.zoom)*.5,g=n.canonical.toString();n.overscaledZ!==n.canonical.z&&(g+=\" => \"+n.overscaledZ),function(t,e){t.initDebugOverlayCanvas();var r=t.debugOverlayCanvas,n=t.context.gl,i=t.debugOverlayCanvas.getContext(\"2d\");i.clearRect(0,0,r.width,r.height),i.shadowColor=\"white\",i.shadowBlur=2,i.lineWidth=1.5,i.strokeStyle=\"white\",i.textBaseline=\"top\",i.font=\"bold 36px Open Sans, sans-serif\",i.fillText(e,5,5),i.strokeText(e,5,5),t.debugOverlayTexture.update(r),t.debugOverlayTexture.bind(n.LINEAR,n.CLAMP_TO_EDGE)}(e,g+\" \"+h+\"kb\"),s.draw(i,a.TRIANGLES,l,c,St.alphaBlended,Et.disabled,Ir(o,t.Color.transparent,d),\"$debug\",e.debugBuffer,e.quadTriangleIndexBuffer,e.debugSegments)}var vn={symbol:function(e,r,n,i,a){if(\"translucent\"===e.renderPass){var o=At.disabled,s=e.colorModeForRenderPass();n.layout.get(\"text-variable-anchor\")&&function(e,r,n,i,a,o,s){for(var l=r.transform,c=\"map\"===a,u=\"map\"===o,f=0,h=e;f<h.length;f+=1){var p=h[f],d=i.getTile(p),g=d.getBucket(n);if(g&&g.text&&g.text.segments.get().length){var m=t.evaluateSizeForZoom(g.textSizeData,l.zoom),v=he(d,1,r.transform.zoom),y=Kt(p.posMatrix,u,c,r.transform,v),x=\"none\"!==n.layout.get(\"icon-text-fit\")&&g.hasIconData();if(m){var b=Math.pow(2,l.zoom-d.tileID.overscaledZ);Qr(g,c,u,s,t.symbolSize,l,y,p.posMatrix,b,m,x)}}}}(i,e,n,r,n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),a),0!==n.paint.get(\"icon-opacity\").constantOr(1)&&tn(e,r,n,i,!1,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),n.layout.get(\"icon-rotation-alignment\"),n.layout.get(\"icon-pitch-alignment\"),n.layout.get(\"icon-keep-upright\"),o,s),0!==n.paint.get(\"text-opacity\").constantOr(1)&&tn(e,r,n,i,!0,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),n.layout.get(\"text-keep-upright\"),o,s),r.map.showCollisionBoxes&&(Zr(e,r,n,i,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),!0),Zr(e,r,n,i,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),!1))}},circle:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"circle-opacity\"),o=n.paint.get(\"circle-stroke-width\"),s=n.paint.get(\"circle-stroke-opacity\"),l=void 0!==n.layout.get(\"circle-sort-key\").constantOr(1);if(0!==a.constantOr(1)||0!==o.constantOr(1)&&0!==s.constantOr(1)){for(var c=e.context,u=c.gl,f=e.depthModeForSublayer(0,Mt.ReadOnly),h=At.disabled,p=e.colorModeForRenderPass(),d=[],g=0;g<i.length;g++){var m=i[g],v=r.getTile(m),y=v.getBucket(n);if(y){var x=y.programConfigurations.get(n.id),b={programConfiguration:x,program:e.useProgram(\"circle\",x),layoutVertexBuffer:y.layoutVertexBuffer,indexBuffer:y.indexBuffer,uniformValues:Er(e,m,v,n)};if(l)for(var _=0,w=y.segments.get();_<w.length;_+=1){var T=w[_];d.push({segments:new t.SegmentVector([T]),sortKey:T.sortKey,state:b})}else d.push({segments:y.segments,sortKey:0,state:b})}}l&&d.sort((function(t,e){return t.sortKey-e.sortKey}));for(var k=0,M=d;k<M.length;k+=1){var A=M[k],S=A.state;S.program.draw(c,u.TRIANGLES,f,h,p,Et.disabled,S.uniformValues,n.id,S.layoutVertexBuffer,S.indexBuffer,A.segments,n.paint,e.transform.zoom,S.programConfiguration)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=At.disabled,l=new St([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4,!1),function(t,e,r,n){var i=t.gl;i.texImage2D(i.TEXTURE_2D,0,i.RGBA,e.width/4,e.height/4,0,i.RGBA,t.extRenderToTextureHalfFloat?t.extTextureHalfFloat.HALF_FLOAT_OES:i.UNSIGNED_BYTE,null),n.colorAttachment.set(r)}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var c=0;c<i.length;c++){var u=i[c];if(!r.hasRenderableParent(u)){var f=r.getTile(u),h=f.getBucket(n);if(h){var p=h.programConfigurations.get(n.id);e.useProgram(\"heatmap\",p).draw(a,o.TRIANGLES,Mt.disabled,s,l,Et.disabled,zr(u.posMatrix,f,e.transform.zoom,n.paint.get(\"heatmap-intensity\")),n.id,h.layoutVertexBuffer,h.indexBuffer,h.segments,n.paint,e.transform.zoom,p)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:0,u_color_ramp:1,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Mt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),f=u.constantOr(1),h=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=f?\"linePattern\":c?\"lineSDF\":h?\"lineGradient\":\"line\",g=e.context,m=g.gl,v=!0;if(h){g.activeTexture.set(m.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,m.RGBA)),y.bind(m.LINEAR,m.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!f||w.patternsLoaded()){var T=w.getBucket(n);if(T){var k=T.programConfigurations.get(n.id),M=e.context.program.get(),A=e.useProgram(d,k),S=v||A.program!==M,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas,L=C.patternPositions[E.to.toString()],I=C.patternPositions[E.from.toString()];L&&I&&k.setConstantPatternPositions(L,I)}var P=f?Rr(e,w,n,p):c?Fr(e,w,n,c,p):h?Dr(e,w,n):Or(e,w,n);f?(g.activeTexture.set(m.TEXTURE0),w.imageAtlasTexture.bind(m.LINEAR,m.CLAMP_TO_EDGE),k.updatePaintBuffers(p)):c&&(S||e.lineAtlas.dirty)&&(g.activeTexture.set(m.TEXTURE0),e.lineAtlas.bind(g)),A.draw(g,m.TRIANGLES,s,e.stencilModeForClipping(_),l,Et.disabled,P,n.id,T.layoutVertexBuffer,T.indexBuffer,T.segments,n.paint,e.transform.zoom,k),v=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Mt.ReadWrite:Mt.ReadOnly);rn(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var f=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Mt.ReadOnly);rn(e,r,n,i,f,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))nn(t,e,r,n,a,At.disabled,St.disabled),nn(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();nn(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Mt.ReadOnly),s=t.colorModeForRenderPass(),l=\"translucent\"===t.renderPass?t.stencilConfigForOverlap(n):[{},n],c=l[0],u=0,f=l[1];u<f.length;u+=1){var h=f[u],p=e.getTile(h);p.needsHillshadePrepare&&\"offscreen\"===t.renderPass?on(t,p,r,a,o,At.disabled,s):\"translucent\"===t.renderPass&&an(t,p,r,o,c[h.overscaledZ],s)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\")&&n.length)for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=t.colorModeForRenderPass(),c=o instanceof P?[{},n]:t.stencilConfigForOverlap(n),u=c[0],f=c[1],h=f[f.length-1].overscaledZ,p=!t.options.moving,d=0,g=f;d<g.length;d+=1){var m=g[d],v=t.depthModeForSublayer(m.overscaledZ-h,1===r.paint.get(\"raster-opacity\")?Mt.ReadWrite:Mt.ReadOnly,a.LESS),y=e.getTile(m),x=t.transform.calculatePosMatrix(m.toUnwrapped(),p);y.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var b=e.findLoadedParent(m,0),_=sn(y,b,e,r,t.transform),w=void 0,T=void 0,k=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),y.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),b?(b.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),w=Math.pow(2,b.tileID.overscaledZ-y.tileID.overscaledZ),T=[y.tileID.canonical.x*w%1,y.tileID.canonical.y*w%1]):y.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var M=jr(x,T||[0,0],w||1,_,r);o instanceof P?s.draw(i,a.TRIANGLES,v,At.disabled,l,Et.disabled,M,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):s.draw(i,a.TRIANGLES,v,u[m.overscaledZ],l,Et.disabled,M,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=!c&&1===n.a&&1===i&&t.opaquePassEnabledForLayer()?\"opaque\":\"translucent\";if(t.renderPass===u){var f=At.disabled,h=t.depthModeForSublayer(0,\"opaque\"===u?Mt.ReadWrite:Mt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var m=r.getCrossfadeParameters(),v=0,y=g;v<y.length;v+=1){var x=y[v],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Wr(b,i,t,c,{tileID:x,tileSize:l},m):Yr(b,i,n);d.draw(a,o.TRIANGLES,h,f,p,Et.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)mn(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Mt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},yn=function(t,e){this.context=new Ct(t),this.transform=e,this._tileTextures={},this.setup(),this.numSublayers=Lt.maxUnderzooming+Lt.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.crossTileSymbolIndex=new Be,this.gpuTimers={}};yn.prototype.resize=function(e,r){if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var n=0,i=this.style._order;n<i.length;n+=1)this.style._layers[i[n]].resize()},yn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,He.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,He.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,I.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,He.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s),this.emptyTexture=new t.Texture(e,{width:1,height:1,data:new Uint8Array([0,0,0,0])},e.gl.RGBA);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},yn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Mt.disabled,this.stencilClearMode,St.disabled,Et.disabled,Pr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},yn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(St.disabled),r.setDepthMode(Mt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Mt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),St.disabled,Et.disabled,Pr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},yn.prototype.stencilModeFor3D=function(){this.currentStencilSource=void 0,this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},yn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},yn.prototype.stencilConfigForOverlap=function(t){var e,r=this.context.gl,n=t.sort((function(t,e){return e.overscaledZ-t.overscaledZ})),i=n[n.length-1].overscaledZ,a=n[0].overscaledZ-i+1;if(a>1){this.currentStencilSource=void 0,this.nextStencilID+a>256&&this.clearStencil();for(var o={},s=0;s<a;s++)o[s+i]=new At({func:r.GEQUAL,mask:255},s+this.nextStencilID,255,r.KEEP,r.KEEP,r.REPLACE);return this.nextStencilID+=a,[o,n]}return[(e={},e[i]=At.disabled,e),n]},yn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new St([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?St.unblended:St.alphaBlended},yn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Mt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Mt(r||this.context.gl.LEQUAL,e,[n,n])},yn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},yn.prototype.render=function(e,r){var n=this;this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var i=this.style._order,a=this.style.sourceCaches;for(var o in a){var s=a[o];s.used&&s.prepare(this.context)}var l,c,u={},f={},h={};for(var p in a){var d=a[p];u[p]=d.getVisibleCoordinates(),f[p]=u[p].slice().reverse(),h[p]=d.getVisibleCoordinates(!0).reverse()}this.opaquePassCutoff=1/0;for(var g=0;g<i.length;g++)if(this.style._layers[i[g]].is3D()){this.opaquePassCutoff=g;break}this.renderPass=\"offscreen\";for(var m=0,v=i;m<v.length;m+=1){var y=this.style._layers[v[m]];if(y.hasOffscreenPass()&&!y.isHidden(this.transform.zoom)){var x=f[y.source];(\"custom\"===y.type||x.length)&&this.renderLayer(this,a[y.source],y,x)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=i.length-1;this.currentLayer>=0;this.currentLayer--){var b=this.style._layers[i[this.currentLayer]],_=a[b.source],w=u[b.source];this._renderTileClippingMasks(b,w),this.renderLayer(this,_,b,w)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<i.length;this.currentLayer++){var T=this.style._layers[i[this.currentLayer]],k=a[T.source],M=(\"symbol\"===T.type?h:f)[T.source];this._renderTileClippingMasks(T,u[T.source]),this.renderLayer(this,k,T,M)}this.options.showTileBoundaries&&(t.values(this.style._layers).forEach((function(t){t.source&&!t.isHidden(n.transform.zoom)&&(t.source!==(c&&c.id)&&(c=n.style.sourceCaches[t.source]),(!l||l.getSource().maxzoom<c.getSource().maxzoom)&&(l=c))})),l&&vn.debug(this,l,l.getVisibleCoordinates())),this.options.showPadding&&function(t){var e=t.transform.padding;pn(t,t.transform.height-(e.top||0),3,ln),pn(t,e.bottom||0,3,cn),dn(t,e.left||0,3,un),dn(t,t.transform.width-(e.right||0),3,fn);var r=t.transform.centerPoint;!function(t,e,r,n){gn(t,e-1,r-10,2,20,n),gn(t,e-10,r-1,20,2,n)}(t,r.x,t.transform.height-r.y,hn)}(this),this.context.setDefault()},yn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,this.gpuTimingStart(r),vn[r.type](t,e,r,n,this.style.placement.variableOffsets),this.gpuTimingEnd())},yn.prototype.gpuTimingStart=function(t){if(this.options.gpuTiming){var e=this.context.extTimerQuery,r=this.gpuTimers[t.id];r||(r=this.gpuTimers[t.id]={calls:0,cpuTime:0,query:e.createQueryEXT()}),r.calls++,e.beginQueryEXT(e.TIME_ELAPSED_EXT,r.query)}},yn.prototype.gpuTimingEnd=function(){if(this.options.gpuTiming){var t=this.context.extTimerQuery;t.endQueryEXT(t.TIME_ELAPSED_EXT)}},yn.prototype.collectGpuTimers=function(){var t=this.gpuTimers;return this.gpuTimers={},t},yn.prototype.queryGpuTimers=function(t){var e={};for(var r in t){var n=t[r],i=this.context.extTimerQuery,a=i.getQueryObjectEXT(n.query,i.QUERY_RESULT_EXT)/1e6;i.deleteQueryEXT(n.query),e[r]=a}return e},yn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:he(r,n[0],this.transform.zoom),a?n[1]:he(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},yn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},yn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},yn.prototype.isPatternMissing=function(t){if(!t)return!1;if(!t.from||!t.to)return!0;var e=this.imageManager.getPattern(t.from.toString()),r=this.imageManager.getPattern(t.to.toString());return!e||!r},yn.prototype.useProgram=function(t,e){this.cache=this.cache||{};var r=\"\"+t+(e?e.cacheKey:\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new br(this.context,yr[t],e,Xr[t],this._showOverdrawInspector)),this.cache[r]},yn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},yn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)},yn.prototype.initDebugOverlayCanvas=function(){null==this.debugOverlayCanvas&&(this.debugOverlayCanvas=t.window.document.createElement(\"canvas\"),this.debugOverlayCanvas.width=512,this.debugOverlayCanvas.height=512,this.debugOverlayTexture=new t.Texture(this.context,this.debugOverlayCanvas,this.context.gl.RGBA))},yn.prototype.destroy=function(){this.emptyTexture.destroy(),this.debugOverlayTexture&&this.debugOverlayTexture.destroy()};var xn=function(t,e){this.points=t,this.planes=e};xn.fromInvProjectionMatrix=function(e,r,n){var i=Math.pow(2,n),a=[[-1,1,-1,1],[1,1,-1,1],[1,-1,-1,1],[-1,-1,-1,1],[-1,1,1,1],[1,1,1,1],[1,-1,1,1],[-1,-1,1,1]].map((function(r){return t.transformMat4([],r,e)})).map((function(e){return t.scale$1([],e,1/e[3]/r*i)})),o=[[0,1,2],[6,5,4],[0,3,7],[2,1,5],[3,2,6],[0,4,5]].map((function(e){var r=t.sub([],a[e[0]],a[e[1]]),n=t.sub([],a[e[2]],a[e[1]]),i=t.normalize([],t.cross([],r,n)),o=-t.dot(i,a[e[1]]);return i.concat(o)}));return new xn(a,o)};var bn=function(e,r){this.min=e,this.max=r,this.center=t.scale$2([],t.add([],this.min,this.max),.5)};bn.prototype.quadrant=function(e){for(var r=[e%2==0,e<2],n=t.clone$2(this.min),i=t.clone$2(this.max),a=0;a<r.length;a++)n[a]=r[a]?this.min[a]:this.center[a],i[a]=r[a]?this.center[a]:this.max[a];return i[2]=this.max[2],new bn(n,i)},bn.prototype.distanceX=function(t){return Math.max(Math.min(this.max[0],t[0]),this.min[0])-t[0]},bn.prototype.distanceY=function(t){return Math.max(Math.min(this.max[1],t[1]),this.min[1])-t[1]},bn.prototype.intersects=function(e){for(var r=[[this.min[0],this.min[1],0,1],[this.max[0],this.min[1],0,1],[this.max[0],this.max[1],0,1],[this.min[0],this.max[1],0,1]],n=!0,i=0;i<e.planes.length;i++){for(var a=e.planes[i],o=0,s=0;s<r.length;s++)o+=t.dot$1(a,r[s])>=0;if(0===o)return 0;o!==r.length&&(n=!1)}if(n)return 2;for(var l=0;l<3;l++){for(var c=Number.MAX_VALUE,u=-Number.MAX_VALUE,f=0;f<e.points.length;f++){var h=e.points[f][l]-this.min[l];c=Math.min(c,h),u=Math.max(u,h)}if(u<0||c>this.max[l]-this.min[l])return 0}return 1};var _n=function(t,e,r,n){if(void 0===t&&(t=0),void 0===e&&(e=0),void 0===r&&(r=0),void 0===n&&(n=0),isNaN(t)||t<0||isNaN(e)||e<0||isNaN(r)||r<0||isNaN(n)||n<0)throw new Error(\"Invalid value for edge-insets, top, bottom, left and right must all be numbers\");this.top=t,this.bottom=e,this.left=r,this.right=n};_n.prototype.interpolate=function(e,r,n){return null!=r.top&&null!=e.top&&(this.top=t.number(e.top,r.top,n)),null!=r.bottom&&null!=e.bottom&&(this.bottom=t.number(e.bottom,r.bottom,n)),null!=r.left&&null!=e.left&&(this.left=t.number(e.left,r.left,n)),null!=r.right&&null!=e.right&&(this.right=t.number(e.right,r.right,n)),this},_n.prototype.getCenter=function(e,r){var n=t.clamp((this.left+e-this.right)/2,0,e),i=t.clamp((this.top+r-this.bottom)/2,0,r);return new t.Point(n,i)},_n.prototype.equals=function(t){return this.top===t.top&&this.bottom===t.bottom&&this.left===t.left&&this.right===t.right},_n.prototype.clone=function(){return new _n(this.top,this.bottom,this.left,this.right)},_n.prototype.toJSON=function(){return{top:this.top,bottom:this.bottom,left:this.left,right:this.right}};var wn=function(e,r,n,i,a){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===a||a,this._minZoom=e||0,this._maxZoom=r||22,this._minPitch=null==n?0:n,this._maxPitch=null==i?60:i,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._edgeInsets=new _n,this._posMatrixCache={},this._alignedPosMatrixCache={}},Tn={minZoom:{configurable:!0},maxZoom:{configurable:!0},minPitch:{configurable:!0},maxPitch:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerOffset:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},padding:{configurable:!0},centerPoint:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};wn.prototype.clone=function(){var t=new wn(this._minZoom,this._maxZoom,this._minPitch,this.maxPitch,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._edgeInsets=this._edgeInsets.clone(),t._calcMatrices(),t},Tn.minZoom.get=function(){return this._minZoom},Tn.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},Tn.maxZoom.get=function(){return this._maxZoom},Tn.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},Tn.minPitch.get=function(){return this._minPitch},Tn.minPitch.set=function(t){this._minPitch!==t&&(this._minPitch=t,this.pitch=Math.max(this.pitch,t))},Tn.maxPitch.get=function(){return this._maxPitch},Tn.maxPitch.set=function(t){this._maxPitch!==t&&(this._maxPitch=t,this.pitch=Math.min(this.pitch,t))},Tn.renderWorldCopies.get=function(){return this._renderWorldCopies},Tn.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},Tn.worldSize.get=function(){return this.tileSize*this.scale},Tn.centerOffset.get=function(){return this.centerPoint._sub(this.size._div(2))},Tn.size.get=function(){return new t.Point(this.width,this.height)},Tn.bearing.get=function(){return-this.angle/Math.PI*180},Tn.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},Tn.pitch.get=function(){return this._pitch/Math.PI*180},Tn.pitch.set=function(e){var r=t.clamp(e,this.minPitch,this.maxPitch)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},Tn.fov.get=function(){return this._fov/Math.PI*180},Tn.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},Tn.zoom.get=function(){return this._zoom},Tn.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},Tn.center.get=function(){return this._center},Tn.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},Tn.padding.get=function(){return this._edgeInsets.toJSON()},Tn.padding.set=function(t){this._edgeInsets.equals(t)||(this._unmodified=!1,this._edgeInsets.interpolate(this._edgeInsets,t,1),this._calcMatrices())},Tn.centerPoint.get=function(){return this._edgeInsets.getCenter(this.width,this.height)},wn.prototype.isPaddingEqual=function(t){return this._edgeInsets.equals(t)},wn.prototype.interpolatePadding=function(t,e,r){this._unmodified=!1,this._edgeInsets.interpolate(t,e,r),this._constrain(),this._calcMatrices()},wn.prototype.coveringZoomLevel=function(t){var e=(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize));return Math.max(0,e)},wn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},wn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=[a*i.x,a*i.y,0],s=xn.fromInvProjectionMatrix(this.invProjMatrix,this.worldSize,r),l=e.minzoom||0;this.pitch<=60&&this._edgeInsets.top<.1&&(l=r);var c=function(t){return{aabb:new bn([t*a,0,0],[(t+1)*a,a,0]),zoom:0,x:0,y:0,wrap:t,fullyVisible:!1}},u=[],f=[],h=r,p=e.reparseOverscaled?n:r;if(this._renderWorldCopies)for(var d=1;d<=3;d++)u.push(c(-d)),u.push(c(d));for(u.push(c(0));u.length>0;){var g=u.pop(),m=g.x,v=g.y,y=g.fullyVisible;if(!y){var x=g.aabb.intersects(s);if(0===x)continue;y=2===x}var b=g.aabb.distanceX(o),_=g.aabb.distanceY(o),w=Math.max(Math.abs(b),Math.abs(_));if(g.zoom===h||w>3+(1<<h-g.zoom)-2&&g.zoom>=l)f.push({tileID:new t.OverscaledTileID(g.zoom===h?p:g.zoom,g.wrap,g.zoom,m,v),distanceSq:t.sqrLen([o[0]-.5-m,o[1]-.5-v])});else for(var T=0;T<4;T++){var k=(m<<1)+T%2,M=(v<<1)+(T>>1);u.push({aabb:g.aabb.quadrant(T),zoom:g.zoom+1,x:k,y:M,wrap:g.wrap,fullyVisible:y})}}return f.sort((function(t,e){return t.distanceSq-e.distanceSq})).map((function(t){return t.tileID}))},wn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},Tn.unmodified.get=function(){return this._unmodified},wn.prototype.zoomScale=function(t){return Math.pow(2,t)},wn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},wn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},wn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},Tn.point.get=function(){return this.project(this.center)},wn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},wn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},wn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},wn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},wn.prototype.coordinateLocation=function(t){return t.toLngLat()},wn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[1]/i,s=n[1]/a,l=r[2]/i,c=n[2]/a,u=l===c?0:(0-l)/(c-l);return new t.MercatorCoordinate(t.number(r[0]/i,n[0]/a,u)/this.worldSize,t.number(o,s,u)/this.worldSize)},wn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},wn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},wn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},wn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},wn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},wn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},wn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var f=this.latRange;a=t.mercatorYfromLat(f[1])*this.worldSize,e=(o=t.mercatorYfromLat(f[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var h=this.lngRange;s=t.mercatorXfromLng(h[0])*this.worldSize,r=(l=t.mercatorXfromLng(h[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,m=c.y/2;g-m<a&&(i=a+m),g+m>o&&(i=o-m)}if(this.lngRange){var v=p.x,y=c.x/2;v-y<s&&(n=s+y),v+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},wn.prototype._calcMatrices=function(){if(this.height){var e=this.centerOffset;this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var r=Math.PI/2+this._pitch,n=this._fov*(.5+e.y/this.height),i=Math.sin(n)*this.cameraToCenterDistance/Math.sin(t.clamp(Math.PI-r-n,.01,Math.PI-.01)),a=this.point,o=a.x,s=a.y,l=1.01*(Math.cos(Math.PI/2-this._pitch)*i+this.cameraToCenterDistance),c=this.height/50,u=new Float64Array(16);t.perspective(u,this._fov,this.width/this.height,c,l),u[8]=2*-e.x/this.width,u[9]=2*e.y/this.height,t.scale(u,u,[1,-1,1]),t.translate(u,u,[0,0,-this.cameraToCenterDistance]),t.rotateX(u,u,this._pitch),t.rotateZ(u,u,this.angle),t.translate(u,u,[-o,-s,0]),this.mercatorMatrix=t.scale([],u,[this.worldSize,this.worldSize,this.worldSize]),t.scale(u,u,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=u,this.invProjMatrix=t.invert([],this.projMatrix);var f=this.width%2/2,h=this.height%2/2,p=Math.cos(this.angle),d=Math.sin(this.angle),g=o-Math.round(o)+p*f+d*h,m=s-Math.round(s)+p*h+d*f,v=new Float64Array(u);if(t.translate(v,v,[g>.5?g-1:g,m>.5?m-1:m,0]),this.alignedProjMatrix=v,u=t.create(),t.scale(u,u,[this.width/2,-this.height/2,1]),t.translate(u,u,[1,-1,0]),this.labelPlaneMatrix=u,u=t.create(),t.scale(u,u,[1,-1,1]),t.translate(u,u,[-1,-1,0]),t.scale(u,u,[2/this.width,2/this.height,1]),this.glCoordMatrix=u,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(u=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=u,this._posMatrixCache={},this._alignedPosMatrixCache={}}},wn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},wn.prototype.getCameraPoint=function(){var e=Math.tan(this._pitch)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,e))},wn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(wn.prototype,Tn);var kn=function(e){var r,n,i,a;this._hashName=e&&encodeURIComponent(e),t.bindAll([\"_getCurrentHash\",\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(r=this._updateHashUnthrottled.bind(this),n=!1,i=null,a=function(){i=null,n&&(r(),i=setTimeout(a,300),n=!1)},function(){return n=!0,i||a(),i})};kn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},kn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},kn.prototype.getHashString=function(e){var r=this._map.getCenter(),n=Math.round(100*this._map.getZoom())/100,i=Math.ceil((n*Math.LN2+Math.log(512/360/.5))/Math.LN10),a=Math.pow(10,i),o=Math.round(r.lng*a)/a,s=Math.round(r.lat*a)/a,l=this._map.getBearing(),c=this._map.getPitch(),u=\"\";if(u+=e?\"/\"+o+\"/\"+s+\"/\"+n:n+\"/\"+s+\"/\"+o,(l||c)&&(u+=\"/\"+Math.round(10*l)/10),c&&(u+=\"/\"+Math.round(c)),this._hashName){var f=this._hashName,h=!1,p=t.window.location.hash.slice(1).split(\"&\").map((function(t){var e=t.split(\"=\")[0];return e===f?(h=!0,e+\"=\"+u):t})).filter((function(t){return t}));return h||p.push(f+\"=\"+u),\"#\"+p.join(\"&\")}return\"#\"+u},kn.prototype._getCurrentHash=function(){var e,r=this,n=t.window.location.hash.replace(\"#\",\"\");return this._hashName?(n.split(\"&\").map((function(t){return t.split(\"=\")})).forEach((function(t){t[0]===r._hashName&&(e=t)})),(e&&e[1]||\"\").split(\"/\")):n.split(\"/\")},kn.prototype._onHashChange=function(){var t=this._getCurrentHash();if(t.length>=3&&!t.some((function(t){return isNaN(t)}))){var e=this._map.dragRotate.isEnabled()&&this._map.touchZoomRotate.isEnabled()?+(t[3]||0):this._map.getBearing();return this._map.jumpTo({center:[+t[2],+t[1]],zoom:+t[0],bearing:e,pitch:+(t[4]||0)}),!0}return!1},kn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var Mn={linearity:.3,easing:t.bezier(0,0,.3,1)},An=t.extend({deceleration:2500,maxSpeed:1400},Mn),Sn=t.extend({deceleration:20,maxSpeed:1400},Mn),En=t.extend({deceleration:1e3,maxSpeed:360},Mn),Cn=t.extend({deceleration:1e3,maxSpeed:90},Mn),Ln=function(t){this._map=t,this.clear()};function In(t,e){(!t.duration||t.duration<e.duration)&&(t.duration=e.duration,t.easing=e.easing)}function Pn(e,r,n){var i=n.maxSpeed,a=n.linearity,o=n.deceleration,s=t.clamp(e*a/(r/1e3),-i,i),l=Math.abs(s)/(o*a);return{easing:n.easing,duration:1e3*l,amount:s*(l/2)}}Ln.prototype.clear=function(){this._inertiaBuffer=[]},Ln.prototype.record=function(e){this._drainInertiaBuffer(),this._inertiaBuffer.push({time:t.browser.now(),settings:e})},Ln.prototype._drainInertiaBuffer=function(){for(var e=this._inertiaBuffer,r=t.browser.now();e.length>0&&r-e[0].time>160;)e.shift()},Ln.prototype._onMoveEnd=function(e){if(this._drainInertiaBuffer(),!(this._inertiaBuffer.length<2)){for(var r={zoom:0,bearing:0,pitch:0,pan:new t.Point(0,0),pinchAround:void 0,around:void 0},n=0,i=this._inertiaBuffer;n<i.length;n+=1){var a=i[n].settings;r.zoom+=a.zoomDelta||0,r.bearing+=a.bearingDelta||0,r.pitch+=a.pitchDelta||0,a.panDelta&&r.pan._add(a.panDelta),a.around&&(r.around=a.around),a.pinchAround&&(r.pinchAround=a.pinchAround)}var o=this._inertiaBuffer[this._inertiaBuffer.length-1].time-this._inertiaBuffer[0].time,s={};if(r.pan.mag()){var l=Pn(r.pan.mag(),o,t.extend({},An,e||{}));s.offset=r.pan.mult(l.amount/r.pan.mag()),s.center=this._map.transform.center,In(s,l)}if(r.zoom){var c=Pn(r.zoom,o,Sn);s.zoom=this._map.transform.zoom+c.amount,In(s,c)}if(r.bearing){var u=Pn(r.bearing,o,En);s.bearing=this._map.transform.bearing+t.clamp(u.amount,-179,179),In(s,u)}if(r.pitch){var f=Pn(r.pitch,o,Cn);s.pitch=this._map.transform.pitch+f.amount,In(s,f)}if(s.zoom||s.bearing){var h=void 0===r.pinchAround?r.around:r.pinchAround;s.around=h?this._map.unproject(h):this._map.getCenter()}return this.clear(),t.extend(s,{noMoveStart:!0})}};var zn=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),On=function(e){function n(n,i,a){var o=\"touchend\"===n?a.changedTouches:a.touches,s=r.touchPos(i.getCanvasContainer(),o),l=s.map((function(t){return i.unproject(t)})),c=s.reduce((function(t,e,r,n){return t.add(e.div(n.length))}),new t.Point(0,0)),u=i.unproject(c);e.call(this,n,{points:s,point:c,lngLats:l,lngLat:u,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),Dn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),Rn=function(t,e){this._map=t,this._clickTolerance=e.clickTolerance};Rn.prototype.reset=function(){delete this._mousedownPos},Rn.prototype.wheel=function(t){return this._firePreventable(new Dn(t.type,this._map,t))},Rn.prototype.mousedown=function(t,e){return this._mousedownPos=e,this._firePreventable(new zn(t.type,this._map,t))},Rn.prototype.mouseup=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.click=function(t,e){this._mousedownPos&&this._mousedownPos.dist(e)>=this._clickTolerance||this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.dblclick=function(t){return this._firePreventable(new zn(t.type,this._map,t))},Rn.prototype.mouseover=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.mouseout=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.touchstart=function(t){return this._firePreventable(new On(t.type,this._map,t))},Rn.prototype.touchmove=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype.touchend=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype.touchcancel=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype._firePreventable=function(t){if(this._map.fire(t),t.defaultPrevented)return{}},Rn.prototype.isEnabled=function(){return!0},Rn.prototype.isActive=function(){return!1},Rn.prototype.enable=function(){},Rn.prototype.disable=function(){};var Fn=function(t){this._map=t};Fn.prototype.reset=function(){this._delayContextMenu=!1,delete this._contextMenuEvent},Fn.prototype.mousemove=function(t){this._map.fire(new zn(t.type,this._map,t))},Fn.prototype.mousedown=function(){this._delayContextMenu=!0},Fn.prototype.mouseup=function(){this._delayContextMenu=!1,this._contextMenuEvent&&(this._map.fire(new zn(\"contextmenu\",this._map,this._contextMenuEvent)),delete this._contextMenuEvent)},Fn.prototype.contextmenu=function(t){this._delayContextMenu?this._contextMenuEvent=t:this._map.fire(new zn(t.type,this._map,t)),this._map.listens(\"contextmenu\")&&t.preventDefault()},Fn.prototype.isEnabled=function(){return!0},Fn.prototype.isActive=function(){return!1},Fn.prototype.enable=function(){},Fn.prototype.disable=function(){};var Bn=function(t,e){this._map=t,this._el=t.getCanvasContainer(),this._container=t.getContainer(),this._clickTolerance=e.clickTolerance||1};function Nn(t,e){for(var r={},n=0;n<t.length;n++)r[t[n].identifier]=e[n];return r}Bn.prototype.isEnabled=function(){return!!this._enabled},Bn.prototype.isActive=function(){return!!this._active},Bn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},Bn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Bn.prototype.mousedown=function(t,e){this.isEnabled()&&t.shiftKey&&0===t.button&&(r.disableDrag(),this._startPos=this._lastPos=e,this._active=!0)},Bn.prototype.mousemoveWindow=function(t,e){if(this._active){var n=e;if(!(this._lastPos.equals(n)||!this._box&&n.dist(this._startPos)<this._clickTolerance)){var i=this._startPos;this._lastPos=n,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var a=Math.min(i.x,n.x),o=Math.max(i.x,n.x),s=Math.min(i.y,n.y),l=Math.max(i.y,n.y);r.setTransform(this._box,\"translate(\"+a+\"px,\"+s+\"px)\"),this._box.style.width=o-a+\"px\",this._box.style.height=l-s+\"px\"}}},Bn.prototype.mouseupWindow=function(e,n){var i=this;if(this._active&&0===e.button){var a=this._startPos,o=n;if(this.reset(),r.suppressClick(),a.x!==o.x||a.y!==o.y)return this._map.fire(new t.Event(\"boxzoomend\",{originalEvent:e})),{cameraAnimation:function(t){return t.fitScreenCoordinates(a,o,i._map.getBearing(),{linear:!0})}};this._fireEvent(\"boxzoomcancel\",e)}},Bn.prototype.keydown=function(t){this._active&&27===t.keyCode&&(this.reset(),this._fireEvent(\"boxzoomcancel\",t))},Bn.prototype.reset=function(){this._active=!1,this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},Bn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var jn=function(t){this.reset(),this.numTouches=t.numTouches};jn.prototype.reset=function(){delete this.centroid,delete this.startTime,delete this.touches,this.aborted=!1},jn.prototype.touchstart=function(e,r,n){(this.centroid||n.length>this.numTouches)&&(this.aborted=!0),this.aborted||(void 0===this.startTime&&(this.startTime=e.timeStamp),n.length===this.numTouches&&(this.centroid=function(e){for(var r=new t.Point(0,0),n=0,i=e;n<i.length;n+=1)r._add(i[n]);return r.div(e.length)}(r),this.touches=Nn(n,r)))},jn.prototype.touchmove=function(t,e,r){if(!this.aborted&&this.centroid){var n=Nn(r,e);for(var i in this.touches){var a=n[i];(!a||a.dist(this.touches[i])>30)&&(this.aborted=!0)}}},jn.prototype.touchend=function(t,e,r){if((!this.centroid||t.timeStamp-this.startTime>500)&&(this.aborted=!0),0===r.length){var n=!this.aborted&&this.centroid;if(this.reset(),n)return n}};var Un=function(t){this.singleTap=new jn(t),this.numTaps=t.numTaps,this.reset()};Un.prototype.reset=function(){this.lastTime=1/0,delete this.lastTap,this.count=0,this.singleTap.reset()},Un.prototype.touchstart=function(t,e,r){this.singleTap.touchstart(t,e,r)},Un.prototype.touchmove=function(t,e,r){this.singleTap.touchmove(t,e,r)},Un.prototype.touchend=function(t,e,r){var n=this.singleTap.touchend(t,e,r);if(n){var i=t.timeStamp-this.lastTime<500,a=!this.lastTap||this.lastTap.dist(n)<30;if(i&&a||this.reset(),this.count++,this.lastTime=t.timeStamp,this.lastTap=n,this.count===this.numTaps)return this.reset(),n}};var Vn=function(){this._zoomIn=new Un({numTouches:1,numTaps:2}),this._zoomOut=new Un({numTouches:2,numTaps:1}),this.reset()};Vn.prototype.reset=function(){this._active=!1,this._zoomIn.reset(),this._zoomOut.reset()},Vn.prototype.touchstart=function(t,e,r){this._zoomIn.touchstart(t,e,r),this._zoomOut.touchstart(t,e,r)},Vn.prototype.touchmove=function(t,e,r){this._zoomIn.touchmove(t,e,r),this._zoomOut.touchmove(t,e,r)},Vn.prototype.touchend=function(t,e,r){var n=this,i=this._zoomIn.touchend(t,e,r),a=this._zoomOut.touchend(t,e,r);return i?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()+1,around:e.unproject(i)},{originalEvent:t})}}):a?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()-1,around:e.unproject(a)},{originalEvent:t})}}):void 0},Vn.prototype.touchcancel=function(){this.reset()},Vn.prototype.enable=function(){this._enabled=!0},Vn.prototype.disable=function(){this._enabled=!1,this.reset()},Vn.prototype.isEnabled=function(){return this._enabled},Vn.prototype.isActive=function(){return this._active};var qn=function(t){this.reset(),this._clickTolerance=t.clickTolerance||1};qn.prototype.reset=function(){this._active=!1,this._moved=!1,delete this._lastPoint,delete this._eventButton},qn.prototype._correctButton=function(t,e){return!1},qn.prototype._move=function(t,e){return{}},qn.prototype.mousedown=function(t,e){if(!this._lastPoint){var n=r.mouseButton(t);this._correctButton(t,n)&&(this._lastPoint=e,this._eventButton=n)}},qn.prototype.mousemoveWindow=function(t,e){var r=this._lastPoint;if(r&&(t.preventDefault(),this._moved||!(e.dist(r)<this._clickTolerance)))return this._moved=!0,this._lastPoint=e,this._move(r,e)},qn.prototype.mouseupWindow=function(t){r.mouseButton(t)===this._eventButton&&(this._moved&&r.suppressClick(),this.reset())},qn.prototype.enable=function(){this._enabled=!0},qn.prototype.disable=function(){this._enabled=!1,this.reset()},qn.prototype.isEnabled=function(){return this._enabled},qn.prototype.isActive=function(){return this._active};var Hn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.mousedown=function(e,r){t.prototype.mousedown.call(this,e,r),this._lastPoint&&(this._active=!0)},e.prototype._correctButton=function(t,e){return 0===e&&!t.ctrlKey},e.prototype._move=function(t,e){return{around:e,panDelta:e.sub(t)}},e}(qn),Gn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=.8*(e.x-t.x);if(r)return this._active=!0,{bearingDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(qn),Yn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=-.5*(e.y-t.y);if(r)return this._active=!0,{pitchDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(qn),Wn=function(t){this._minTouches=1,this._clickTolerance=t.clickTolerance||1,this.reset()};Wn.prototype.reset=function(){this._active=!1,this._touches={},this._sum=new t.Point(0,0)},Wn.prototype.touchstart=function(t,e,r){return this._calculateTransform(t,e,r)},Wn.prototype.touchmove=function(t,e,r){if(this._active)return t.preventDefault(),this._calculateTransform(t,e,r)},Wn.prototype.touchend=function(t,e,r){this._calculateTransform(t,e,r),this._active&&r.length<this._minTouches&&this.reset()},Wn.prototype.touchcancel=function(){this.reset()},Wn.prototype._calculateTransform=function(e,r,n){n.length>0&&(this._active=!0);var i=Nn(n,r),a=new t.Point(0,0),o=new t.Point(0,0),s=0;for(var l in i){var c=i[l],u=this._touches[l];u&&(a._add(c),o._add(c.sub(u)),s++,i[l]=c)}if(this._touches=i,!(s<this._minTouches)&&o.mag()){var f=o.div(s);if(this._sum._add(f),!(this._sum.mag()<this._clickTolerance))return{around:a.div(s),panDelta:f}}},Wn.prototype.enable=function(){this._enabled=!0},Wn.prototype.disable=function(){this._enabled=!1,this.reset()},Wn.prototype.isEnabled=function(){return this._enabled},Wn.prototype.isActive=function(){return this._active};var Xn=function(){this.reset()};function Zn(t,e,r){for(var n=0;n<t.length;n++)if(t[n].identifier===r)return e[n]}function Jn(t,e){return Math.log(t/e)/Math.LN2}Xn.prototype.reset=function(){this._active=!1,delete this._firstTwoTouches},Xn.prototype._start=function(t){},Xn.prototype._move=function(t,e,r){return{}},Xn.prototype.touchstart=function(t,e,r){this._firstTwoTouches||r.length<2||(this._firstTwoTouches=[r[0].identifier,r[1].identifier],this._start([e[0],e[1]]))},Xn.prototype.touchmove=function(t,e,r){if(this._firstTwoTouches){t.preventDefault();var n=this._firstTwoTouches,i=n[1],a=Zn(r,e,n[0]),o=Zn(r,e,i);if(a&&o){var s=this._aroundCenter?null:a.add(o).div(2);return this._move([a,o],s,t)}}},Xn.prototype.touchend=function(t,e,n){if(this._firstTwoTouches){var i=this._firstTwoTouches,a=i[1],o=Zn(n,e,i[0]),s=Zn(n,e,a);o&&s||(this._active&&r.suppressClick(),this.reset())}},Xn.prototype.touchcancel=function(){this.reset()},Xn.prototype.enable=function(t){this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around},Xn.prototype.disable=function(){this._enabled=!1,this.reset()},Xn.prototype.isEnabled=function(){return this._enabled},Xn.prototype.isActive=function(){return this._active};var Kn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._distance,delete this._startDistance},e.prototype._start=function(t){this._startDistance=this._distance=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._distance;if(this._distance=t[0].dist(t[1]),this._active||!(Math.abs(Jn(this._distance,this._startDistance))<.1))return this._active=!0,{zoomDelta:Jn(this._distance,r),pinchAround:e}},e}(Xn);function Qn(t,e){return 180*t.angleWith(e)/Math.PI}var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._minDiameter,delete this._startVector,delete this._vector},e.prototype._start=function(t){this._startVector=this._vector=t[0].sub(t[1]),this._minDiameter=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._vector;if(this._vector=t[0].sub(t[1]),this._active||!this._isBelowThreshold(this._vector))return this._active=!0,{bearingDelta:Qn(this._vector,r),pinchAround:e}},e.prototype._isBelowThreshold=function(t){this._minDiameter=Math.min(this._minDiameter,t.mag());var e=25/(Math.PI*this._minDiameter)*360,r=Qn(t,this._startVector);return Math.abs(r)<e},e}(Xn);function ti(t){return Math.abs(t.y)>Math.abs(t.x)}var ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),this._valid=void 0,delete this._firstMove,delete this._lastPoints},e.prototype._start=function(t){this._lastPoints=t,ti(t[0].sub(t[1]))&&(this._valid=!1)},e.prototype._move=function(t,e,r){var n=t[0].sub(this._lastPoints[0]),i=t[1].sub(this._lastPoints[1]);if(this._valid=this.gestureBeginsVertically(n,i,r.timeStamp),this._valid)return this._lastPoints=t,this._active=!0,{pitchDelta:(n.y+i.y)/2*-.5}},e.prototype.gestureBeginsVertically=function(t,e,r){if(void 0!==this._valid)return this._valid;var n=t.mag()>=2,i=e.mag()>=2;if(n||i){if(!n||!i)return void 0===this._firstMove&&(this._firstMove=r),r-this._firstMove<100&&void 0;var a=t.y>0==e.y>0;return ti(t)&&ti(e)&&a}},e}(Xn),ri={panStep:100,bearingStep:15,pitchStep:10},ni=function(){var t=ri;this._panStep=t.panStep,this._bearingStep=t.bearingStep,this._pitchStep=t.pitchStep};function ii(t){return t*(2-t)}ni.prototype.reset=function(){this._active=!1},ni.prototype.keydown=function(t){var e=this;if(!(t.altKey||t.ctrlKey||t.metaKey)){var r=0,n=0,i=0,a=0,o=0;switch(t.keyCode){case 61:case 107:case 171:case 187:r=1;break;case 189:case 109:case 173:r=-1;break;case 37:t.shiftKey?n=-1:(t.preventDefault(),a=-1);break;case 39:t.shiftKey?n=1:(t.preventDefault(),a=1);break;case 38:t.shiftKey?i=1:(t.preventDefault(),o=-1);break;case 40:t.shiftKey?i=-1:(t.preventDefault(),o=1);break;default:return}return{cameraAnimation:function(s){var l=s.getZoom();s.easeTo({duration:300,easeId:\"keyboardHandler\",easing:ii,zoom:r?Math.round(l)+r*(t.shiftKey?2:1):l,bearing:s.getBearing()+n*e._bearingStep,pitch:s.getPitch()+i*e._pitchStep,offset:[-a*e._panStep,-o*e._panStep],center:s.getCenter()},{originalEvent:t})}}}},ni.prototype.enable=function(){this._enabled=!0},ni.prototype.disable=function(){this._enabled=!1,this.reset()},ni.prototype.isEnabled=function(){return this._enabled},ni.prototype.isActive=function(){return this._active};var ai=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._handler=r,this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};ai.prototype.setZoomRate=function(t){this._defaultZoomRate=t},ai.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},ai.prototype.isEnabled=function(){return!!this._enabled},ai.prototype.isActive=function(){return!!this._active||void 0!==this._finishTimeout},ai.prototype.isZooming=function(){return!!this._zooming},ai.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},ai.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},ai.prototype.wheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this._active||this._start(e)),e.preventDefault()}},ai.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this._active||this._start(t)},ai.prototype._start=function(e){if(this._delta){this._frameId&&(this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0),this._finishTimeout&&(clearTimeout(this._finishTimeout),delete this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=!0,this._handler._triggerRenderFrame())}},ai.prototype.renderFrame=function(){return this._onScrollFrame()},ai.prototype._onScrollFrame=function(){var e=this;if(this._frameId&&(this._frameId=null,this.isActive())){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o,s=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,l=this._startZoom,c=this._easing,u=!1;if(\"wheel\"===this._type&&l&&c){var f=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=c(f);o=t.number(l,s,h),f<1?this._frameId||(this._frameId=!0):u=!0}else o=s,u=!0;return this._active=!0,u&&(this._active=!1,this._finishTimeout=setTimeout((function(){e._zooming=!1,e._handler._triggerRenderFrame(),delete e._targetZoom,delete e._finishTimeout}),200)),{noInertia:!0,needsRenderFrame:!u,zoomDelta:o-r.zoom,around:this._aroundPoint,originalEvent:this._lastWheelEvent}}},ai.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r},ai.prototype.reset=function(){this._active=!1};var oi=function(t,e){this._clickZoom=t,this._tapZoom=e};oi.prototype.enable=function(){this._clickZoom.enable(),this._tapZoom.enable()},oi.prototype.disable=function(){this._clickZoom.disable(),this._tapZoom.disable()},oi.prototype.isEnabled=function(){return this._clickZoom.isEnabled()&&this._tapZoom.isEnabled()},oi.prototype.isActive=function(){return this._clickZoom.isActive()||this._tapZoom.isActive()};var si=function(){this.reset()};si.prototype.reset=function(){this._active=!1},si.prototype.dblclick=function(t,e){return t.preventDefault(),{cameraAnimation:function(r){r.easeTo({duration:300,zoom:r.getZoom()+(t.shiftKey?-1:1),around:r.unproject(e)},{originalEvent:t})}}},si.prototype.enable=function(){this._enabled=!0},si.prototype.disable=function(){this._enabled=!1,this.reset()},si.prototype.isEnabled=function(){return this._enabled},si.prototype.isActive=function(){return this._active};var li=function(){this._tap=new Un({numTouches:1,numTaps:1}),this.reset()};li.prototype.reset=function(){this._active=!1,delete this._swipePoint,delete this._swipeTouch,delete this._tapTime,this._tap.reset()},li.prototype.touchstart=function(t,e,r){this._swipePoint||(this._tapTime&&t.timeStamp-this._tapTime>500&&this.reset(),this._tapTime?r.length>0&&(this._swipePoint=e[0],this._swipeTouch=r[0].identifier):this._tap.touchstart(t,e,r))},li.prototype.touchmove=function(t,e,r){if(this._tapTime){if(this._swipePoint){if(r[0].identifier!==this._swipeTouch)return;var n=e[0],i=n.y-this._swipePoint.y;return this._swipePoint=n,t.preventDefault(),this._active=!0,{zoomDelta:i/128}}}else this._tap.touchmove(t,e,r)},li.prototype.touchend=function(t,e,r){this._tapTime?this._swipePoint&&0===r.length&&this.reset():this._tap.touchend(t,e,r)&&(this._tapTime=t.timeStamp)},li.prototype.touchcancel=function(){this.reset()},li.prototype.enable=function(){this._enabled=!0},li.prototype.disable=function(){this._enabled=!1,this.reset()},li.prototype.isEnabled=function(){return this._enabled},li.prototype.isActive=function(){return this._active};var ci=function(t,e,r){this._el=t,this._mousePan=e,this._touchPan=r};ci.prototype.enable=function(t){this._inertiaOptions=t||{},this._mousePan.enable(),this._touchPan.enable(),this._el.classList.add(\"mapboxgl-touch-drag-pan\")},ci.prototype.disable=function(){this._mousePan.disable(),this._touchPan.disable(),this._el.classList.remove(\"mapboxgl-touch-drag-pan\")},ci.prototype.isEnabled=function(){return this._mousePan.isEnabled()&&this._touchPan.isEnabled()},ci.prototype.isActive=function(){return this._mousePan.isActive()||this._touchPan.isActive()};var ui=function(t,e,r){this._pitchWithRotate=t.pitchWithRotate,this._mouseRotate=e,this._mousePitch=r};ui.prototype.enable=function(){this._mouseRotate.enable(),this._pitchWithRotate&&this._mousePitch.enable()},ui.prototype.disable=function(){this._mouseRotate.disable(),this._mousePitch.disable()},ui.prototype.isEnabled=function(){return this._mouseRotate.isEnabled()&&(!this._pitchWithRotate||this._mousePitch.isEnabled())},ui.prototype.isActive=function(){return this._mouseRotate.isActive()||this._mousePitch.isActive()};var fi=function(t,e,r,n){this._el=t,this._touchZoom=e,this._touchRotate=r,this._tapDragZoom=n,this._rotationDisabled=!1,this._enabled=!0};fi.prototype.enable=function(t){this._touchZoom.enable(t),this._rotationDisabled||this._touchRotate.enable(t),this._tapDragZoom.enable(),this._el.classList.add(\"mapboxgl-touch-zoom-rotate\")},fi.prototype.disable=function(){this._touchZoom.disable(),this._touchRotate.disable(),this._tapDragZoom.disable(),this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\")},fi.prototype.isEnabled=function(){return this._touchZoom.isEnabled()&&(this._rotationDisabled||this._touchRotate.isEnabled())&&this._tapDragZoom.isEnabled()},fi.prototype.isActive=function(){return this._touchZoom.isActive()||this._touchRotate.isActive()||this._tapDragZoom.isActive()},fi.prototype.disableRotation=function(){this._rotationDisabled=!0,this._touchRotate.disable()},fi.prototype.enableRotation=function(){this._rotationDisabled=!1,this._touchZoom.isEnabled()&&this._touchRotate.enable()};var hi=function(t){return t.zoom||t.drag||t.pitch||t.rotate},pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(t.Event);function di(t){return t.panDelta&&t.panDelta.mag()||t.zoomDelta||t.bearingDelta||t.pitchDelta}var gi=function(e,n){this._map=e,this._el=this._map.getCanvasContainer(),this._handlers=[],this._handlersById={},this._changes=[],this._inertia=new Ln(e),this._bearingSnap=n.bearingSnap,this._previousActiveHandlers={},this._eventsInProgress={},this._addDefaultHandlers(n),t.bindAll([\"handleEvent\",\"handleWindowEvent\"],this);var i=this._el;this._listeners=[[i,\"touchstart\",{passive:!1}],[i,\"touchmove\",{passive:!1}],[i,\"touchend\",void 0],[i,\"touchcancel\",void 0],[i,\"mousedown\",void 0],[i,\"mousemove\",void 0],[i,\"mouseup\",void 0],[t.window.document,\"mousemove\",{capture:!0}],[t.window.document,\"mouseup\",void 0],[i,\"mouseover\",void 0],[i,\"mouseout\",void 0],[i,\"dblclick\",void 0],[i,\"click\",void 0],[i,\"keydown\",{capture:!1}],[i,\"keyup\",void 0],[i,\"wheel\",{passive:!1}],[i,\"contextmenu\",void 0],[t.window,\"blur\",void 0]];for(var a=0,o=this._listeners;a<o.length;a+=1){var s=o[a],l=s[0];r.addEventListener(l,s[1],l===t.window.document?this.handleWindowEvent:this.handleEvent,s[2])}};gi.prototype.destroy=function(){for(var e=0,n=this._listeners;e<n.length;e+=1){var i=n[e],a=i[0];r.removeEventListener(a,i[1],a===t.window.document?this.handleWindowEvent:this.handleEvent,i[2])}},gi.prototype._addDefaultHandlers=function(t){var e=this._map,r=e.getCanvasContainer();this._add(\"mapEvent\",new Rn(e,t));var n=e.boxZoom=new Bn(e,t);this._add(\"boxZoom\",n);var i=new Vn,a=new si;e.doubleClickZoom=new oi(a,i),this._add(\"tapZoom\",i),this._add(\"clickZoom\",a);var o=new li;this._add(\"tapDragZoom\",o);var s=e.touchPitch=new ei;this._add(\"touchPitch\",s);var l=new Gn(t),c=new Yn(t);e.dragRotate=new ui(t,l,c),this._add(\"mouseRotate\",l,[\"mousePitch\"]),this._add(\"mousePitch\",c,[\"mouseRotate\"]);var u=new Hn(t),f=new Wn(t);e.dragPan=new ci(r,u,f),this._add(\"mousePan\",u),this._add(\"touchPan\",f,[\"touchZoom\",\"touchRotate\"]);var h=new $n,p=new Kn;e.touchZoomRotate=new fi(r,p,h,o),this._add(\"touchRotate\",h,[\"touchPan\",\"touchZoom\"]),this._add(\"touchZoom\",p,[\"touchPan\",\"touchRotate\"]);var d=e.scrollZoom=new ai(e,this);this._add(\"scrollZoom\",d,[\"mousePan\"]);var g=e.keyboard=new ni;this._add(\"keyboard\",g),this._add(\"blockableMapEvent\",new Fn(e));for(var m=0,v=[\"boxZoom\",\"doubleClickZoom\",\"tapDragZoom\",\"touchPitch\",\"dragRotate\",\"dragPan\",\"touchZoomRotate\",\"scrollZoom\",\"keyboard\"];m<v.length;m+=1){var y=v[m];t.interactive&&t[y]&&e[y].enable(t[y])}},gi.prototype._add=function(t,e,r){this._handlers.push({handlerName:t,handler:e,allowed:r}),this._handlersById[t]=e},gi.prototype.stop=function(){if(!this._updatingCamera){for(var t=0,e=this._handlers;t<e.length;t+=1)e[t].handler.reset();this._inertia.clear(),this._fireEvents({},{}),this._changes=[]}},gi.prototype.isActive=function(){for(var t=0,e=this._handlers;t<e.length;t+=1)if(e[t].handler.isActive())return!0;return!1},gi.prototype.isZooming=function(){return!!this._eventsInProgress.zoom||this._map.scrollZoom.isZooming()},gi.prototype.isRotating=function(){return!!this._eventsInProgress.rotate},gi.prototype.isMoving=function(){return Boolean(hi(this._eventsInProgress))||this.isZooming()},gi.prototype._blockedByActive=function(t,e,r){for(var n in t)if(n!==r&&(!e||e.indexOf(n)<0))return!0;return!1},gi.prototype.handleWindowEvent=function(t){this.handleEvent(t,t.type+\"Window\")},gi.prototype._getMapTouches=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r];this._el.contains(i.target)&&e.push(i)}return e},gi.prototype.handleEvent=function(t,e){if(\"blur\"!==t.type){this._updatingCamera=!0;for(var n=\"renderFrame\"===t.type?void 0:t,i={needsRenderFrame:!1},a={},o={},s=t.touches?this._getMapTouches(t.touches):void 0,l=s?r.touchPos(this._el,s):r.mousePos(this._el,t),c=0,u=this._handlers;c<u.length;c+=1){var f=u[c],h=f.handlerName,p=f.handler,d=f.allowed;if(p.isEnabled()){var g=void 0;this._blockedByActive(o,d,h)?p.reset():p[e||t.type]&&(g=p[e||t.type](t,l,s),this.mergeHandlerResult(i,a,g,h,n),g&&g.needsRenderFrame&&this._triggerRenderFrame()),(g||p.isActive())&&(o[h]=p)}}var m={};for(var v in this._previousActiveHandlers)o[v]||(m[v]=n);this._previousActiveHandlers=o,(Object.keys(m).length||di(i))&&(this._changes.push([i,a,m]),this._triggerRenderFrame()),(Object.keys(o).length||di(i))&&this._map._stop(!0),this._updatingCamera=!1;var y=i.cameraAnimation;y&&(this._inertia.clear(),this._fireEvents({},{}),this._changes=[],y(this._map))}else this.stop()},gi.prototype.mergeHandlerResult=function(e,r,n,i,a){if(n){t.extend(e,n);var o={handlerName:i,originalEvent:n.originalEvent||a};void 0!==n.zoomDelta&&(r.zoom=o),void 0!==n.panDelta&&(r.drag=o),void 0!==n.pitchDelta&&(r.pitch=o),void 0!==n.bearingDelta&&(r.rotate=o)}},gi.prototype._applyChanges=function(){for(var e={},r={},n={},i=0,a=this._changes;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=o[2];s.panDelta&&(e.panDelta=(e.panDelta||new t.Point(0,0))._add(s.panDelta)),s.zoomDelta&&(e.zoomDelta=(e.zoomDelta||0)+s.zoomDelta),s.bearingDelta&&(e.bearingDelta=(e.bearingDelta||0)+s.bearingDelta),s.pitchDelta&&(e.pitchDelta=(e.pitchDelta||0)+s.pitchDelta),void 0!==s.around&&(e.around=s.around),void 0!==s.pinchAround&&(e.pinchAround=s.pinchAround),s.noInertia&&(e.noInertia=s.noInertia),t.extend(r,l),t.extend(n,c)}this._updateMapTransform(e,r,n),this._changes=[]},gi.prototype._updateMapTransform=function(t,e,r){var n=this._map,i=n.transform;if(!di(t))return this._fireEvents(e,r);var a=t.panDelta,o=t.zoomDelta,s=t.bearingDelta,l=t.pitchDelta,c=t.around,u=t.pinchAround;void 0!==u&&(c=u),n._stop(!0),c=c||n.transform.centerPoint;var f=i.pointLocation(a?c.sub(a):c);s&&(i.bearing+=s),l&&(i.pitch+=l),o&&(i.zoom+=o),i.setLocationAtPoint(f,c),this._map._update(),t.noInertia||this._inertia.record(t),this._fireEvents(e,r)},gi.prototype._fireEvents=function(e,r){var n=this,i=hi(this._eventsInProgress),a=hi(e),o={};for(var s in e)this._eventsInProgress[s]||(o[s+\"start\"]=e[s].originalEvent),this._eventsInProgress[s]=e[s];for(var l in!i&&a&&this._fireEvent(\"movestart\",a.originalEvent),o)this._fireEvent(l,o[l]);for(var c in e.rotate&&(this._bearingChanged=!0),a&&this._fireEvent(\"move\",a.originalEvent),e)this._fireEvent(c,e[c].originalEvent);var u,f={};for(var h in this._eventsInProgress){var p=this._eventsInProgress[h],d=p.handlerName,g=p.originalEvent;this._handlersById[d].isActive()||(delete this._eventsInProgress[h],f[h+\"end\"]=u=r[d]||g)}for(var m in f)this._fireEvent(m,f[m]);var v=hi(this._eventsInProgress);if((i||a)&&!v){this._updatingCamera=!0;var y=this._inertia._onMoveEnd(this._map.dragPan._inertiaOptions),x=function(t){return 0!==t&&-n._bearingSnap<t&&t<n._bearingSnap};y?(x(y.bearing||this._map.getBearing())&&(y.bearing=0),this._map.easeTo(y,{originalEvent:u})):(this._map.fire(new t.Event(\"moveend\",{originalEvent:u})),x(this._map.getBearing())&&this._map.resetNorth()),this._bearingChanged=!1,this._updatingCamera=!1}},gi.prototype._fireEvent=function(e,r){this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},gi.prototype._triggerRenderFrame=function(){var t=this;void 0===this._frameId&&(this._frameId=this._map._requestRenderFrame((function(e){delete t._frameId,t.handleEvent(new pi(\"renderFrame\",{timeStamp:e})),t._applyChanges()})))};var mi=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.getPadding=function(){return this.transform.padding},r.prototype.setPadding=function(t,e){return this.jumpTo({padding:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.resetNorthPitch=function(e,r){return this.easeTo(t.extend({bearing:0,pitch:0,duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){var a={top:0,bottom:0,right:0,left:0};if(\"number\"==typeof(i=t.extend({padding:a,offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var o=i.padding;i.padding={top:o,bottom:o,right:o,left:o}}i.padding=t.extend(a,i.padding);var s=this.transform,l=s.padding,c=s.project(t.LngLat.convert(e)),u=s.project(t.LngLat.convert(r)),f=c.rotate(-n*Math.PI/180),h=u.rotate(-n*Math.PI/180),p=new t.Point(Math.max(f.x,h.x),Math.max(f.y,h.y)),d=new t.Point(Math.min(f.x,h.x),Math.min(f.y,h.y)),g=p.sub(d),m=(s.width-(l.left+l.right+i.padding.left+i.padding.right))/g.x,v=(s.height-(l.top+l.bottom+i.padding.top+i.padding.bottom))/g.y;if(!(v<0||m<0)){var y=Math.min(s.scaleZoom(s.scale*Math.min(m,v)),i.maxZoom),x=t.Point.convert(i.offset),b=new t.Point(x.x+(i.padding.left-i.padding.right)/2,x.y+(i.padding.top-i.padding.bottom)/2).mult(s.scale/s.zoomScale(y));return{center:s.unproject(c.add(u).div(2).sub(b)),zoom:y,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(delete(r=t.extend(e,r)).padding,r.linear?this.easeTo(r,n):this.flyTo(r,n)):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),null==e.padding||n.isPaddingEqual(e.padding)||(n.padding=e.padding),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this._stop(!1,e.easeId),(!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate||!e.essential&&t.browser.prefersReducedMotion)&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=this.getPadding(),c=\"zoom\"in e?+e.zoom:a,u=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,f=\"pitch\"in e?+e.pitch:s,h=\"padding\"in e?e.padding:i.padding,p=t.Point.convert(e.offset),d=i.centerPoint.add(p),g=i.pointLocation(d),m=t.LngLat.convert(e.center||g);this._normalizeCenter(m);var v,y,x=i.project(g),b=i.project(m).sub(x),_=i.zoomScale(c-a);e.around&&(v=t.LngLat.convert(e.around),y=i.locationPoint(v));var w={moving:this._moving,zooming:this._zooming,rotating:this._rotating,pitching:this._pitching};return this._zooming=this._zooming||c!==a,this._rotating=this._rotating||o!==u,this._pitching=this._pitching||f!==s,this._padding=!i.isPaddingEqual(h),this._easeId=e.easeId,this._prepareEase(r,e.noMoveStart,w),clearTimeout(this._easeEndTimeoutID),this._ease((function(e){if(n._zooming&&(i.zoom=t.number(a,c,e)),n._rotating&&(i.bearing=t.number(o,u,e)),n._pitching&&(i.pitch=t.number(s,f,e)),n._padding&&(i.interpolatePadding(l,h,e),d=i.centerPoint.add(p)),v)i.setLocationAtPoint(v,y);else{var g=i.zoomScale(i.zoom-a),m=c>a?Math.min(2,_):Math.max(.5,_),w=Math.pow(m,1-e),T=i.unproject(x.add(b.mult(e*w)).mult(g));i.setLocationAtPoint(i.renderWorldCopies?T.wrap():T,d)}n._fireMoveEvents(r)}),(function(t){n._afterEase(r,t)}),e),this},r.prototype._prepareEase=function(e,r,n){void 0===n&&(n={}),this._moving=!0,r||n.moving||this.fire(new t.Event(\"movestart\",e)),this._zooming&&!n.zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&!n.rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&!n.pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e,r){if(!this._easeId||!r||this._easeId!==r){delete this._easeId;var n=this._zooming,i=this._rotating,a=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,this._padding=!1,n&&this.fire(new t.Event(\"zoomend\",e)),i&&this.fire(new t.Event(\"rotateend\",e)),a&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))}},r.prototype.flyTo=function(e,r){var n=this;if(!e.essential&&t.browser.prefersReducedMotion){var i=t.pick(e,[\"center\",\"zoom\",\"bearing\",\"pitch\",\"around\"]);return this.jumpTo(i,r)}this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var a=this.transform,o=this.getZoom(),s=this.getBearing(),l=this.getPitch(),c=this.getPadding(),u=\"zoom\"in e?t.clamp(+e.zoom,a.minZoom,a.maxZoom):o,f=\"bearing\"in e?this._normalizeBearing(e.bearing,s):s,h=\"pitch\"in e?+e.pitch:l,p=\"padding\"in e?e.padding:a.padding,d=a.zoomScale(u-o),g=t.Point.convert(e.offset),m=a.centerPoint.add(g),v=a.pointLocation(m),y=t.LngLat.convert(e.center||v);this._normalizeCenter(y);var x=a.project(v),b=a.project(y).sub(x),_=e.curve,w=Math.max(a.width,a.height),T=w/d,k=b.mag();if(\"minZoom\"in e){var M=t.clamp(Math.min(e.minZoom,o,u),a.minZoom,a.maxZoom),A=w/a.zoomScale(M-o);_=Math.sqrt(A/k*2)}var S=_*_;function E(t){var e=(T*T-w*w+(t?-1:1)*S*S*k*k)/(2*(t?T:w)*S*k);return Math.log(Math.sqrt(e*e+1)-e)}function C(t){return(Math.exp(t)-Math.exp(-t))/2}function L(t){return(Math.exp(t)+Math.exp(-t))/2}var I=E(0),P=function(t){return L(I)/L(I+_*t)},z=function(t){return w*((L(I)*(C(e=I+_*t)/L(e))-C(I))/S)/k;var e},O=(E(1)-I)/_;if(Math.abs(k)<1e-6||!isFinite(O)){if(Math.abs(w-T)<1e-6)return this.easeTo(e,r);var D=T<w?-1:1;O=Math.abs(Math.log(T/w))/_,z=function(){return 0},P=function(t){return Math.exp(D*_*t)}}return e.duration=\"duration\"in e?+e.duration:1e3*O/(\"screenSpeed\"in e?+e.screenSpeed/_:+e.speed),e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=s!==f,this._pitching=h!==l,this._padding=!a.isPaddingEqual(p),this._prepareEase(r,!1),this._ease((function(e){var i=e*O,d=1/P(i);a.zoom=1===e?u:o+a.scaleZoom(d),n._rotating&&(a.bearing=t.number(s,f,e)),n._pitching&&(a.pitch=t.number(l,h,e)),n._padding&&(a.interpolatePadding(c,p,e),m=a.centerPoint.add(g));var v=1===e?y:a.unproject(x.add(b.mult(z(i))).mult(d));a.setLocationAtPoint(a.renderWorldCopies?v.wrap():v,m),n._fireMoveEvents(r)}),(function(){return n._afterEase(r)}),e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){return this._stop()},r.prototype._stop=function(t,e){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var r=this._onEaseEnd;delete this._onEaseEnd,r.call(this,e)}if(!t){var n=this.handlers;n&&n.stop()}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),vi=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};vi.prototype.getDefaultPosition=function(){return\"bottom-right\"},vi.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},vi.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0,this._attribHTML=void 0},vi.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:this._map._requestManager._customAccessToken||t.config.ACCESS_TOKEN}];if(e){var n=r.reduce((function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t}),\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},vi.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},vi.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map((function(t){return\"string\"!=typeof t?\"\":t}))):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort((function(t,e){return t.length-e.length}));var o=(t=t.filter((function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0}))).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},vi.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var yi=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};yi.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",this._map._getUIString(\"LogoControl.Title\")),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},yi.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},yi.prototype.getDefaultPosition=function(){return\"bottom-left\"},yi.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},yi.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},yi.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var xi=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};xi.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},xi.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},xi.prototype.run=function(t){void 0===t&&(t=0);var e=this._currentlyRunning=this._queue;this._queue=[];for(var r=0,n=e;r<n.length;r+=1){var i=n[r];if(!i.cancelled&&(i.callback(t),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},xi.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var bi={\"FullscreenControl.Enter\":\"Enter fullscreen\",\"FullscreenControl.Exit\":\"Exit fullscreen\",\"GeolocateControl.FindMyLocation\":\"Find my location\",\"GeolocateControl.LocationNotAvailable\":\"Location not available\",\"LogoControl.Title\":\"Mapbox logo\",\"NavigationControl.ResetBearing\":\"Reset bearing to north\",\"NavigationControl.ZoomIn\":\"Zoom in\",\"NavigationControl.ZoomOut\":\"Zoom out\",\"ScaleControl.Feet\":\"ft\",\"ScaleControl.Meters\":\"m\",\"ScaleControl.Kilometers\":\"km\",\"ScaleControl.Miles\":\"mi\",\"ScaleControl.NauticalMiles\":\"nm\"},_i=t.window.HTMLImageElement,wi=t.window.HTMLElement,Ti=t.window.ImageBitmap,ki={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:-2,maxZoom:22,minPitch:0,maxPitch:60,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,touchPitch:!0,bearingSnap:7,clickTolerance:3,pitchWithRotate:!0,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,accessToken:null,fadeDuration:300,crossSourceCollisions:!0},Mi=function(n){function i(e){var r=this;if(null!=(e=t.extend({},ki,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than or equal to minZoom\");if(null!=e.minPitch&&null!=e.maxPitch&&e.minPitch>e.maxPitch)throw new Error(\"maxPitch must be greater than or equal to minPitch\");if(null!=e.minPitch&&e.minPitch<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(null!=e.maxPitch&&e.maxPitch>60)throw new Error(\"maxPitch must be less than or equal to 60\");var i=new wn(e.minZoom,e.maxZoom,e.minPitch,e.maxPitch,e.renderWorldCopies);if(n.call(this,i,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new xi,this._controls=[],this._mapId=t.uniqueId(),this._locale=t.extend({},bi,e.locale),this._requestManager=new t.RequestManager(e.transformRequest,e.accessToken),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof wi))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",(function(){return r._update(!1)})),this.on(\"moveend\",(function(){return r._update(!1)})),this.on(\"zoom\",(function(){return r._update(!0)})),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),this.handlers=new gi(this,e),this._hash=e.hash&&new kn(\"string\"==typeof e.hash&&e.hash||void 0).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new vi({customAttribution:e.customAttribution})),this.addControl(new yi,e.logoPosition),this.on(\"style.load\",(function(){r.transform.unmodified&&r.jumpTo(r.style.stylesheet)})),this.on(\"data\",(function(e){r._update(\"style\"===e.dataType),r.fire(new t.Event(e.dataType+\"data\",e))})),this.on(\"dataloading\",(function(e){r.fire(new t.Event(e.dataType+\"dataloading\",e))}))}n&&(i.__proto__=n),(i.prototype=Object.create(n&&n.prototype)).constructor=i;var a={showTileBoundaries:{configurable:!0},showPadding:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0},version:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i);var a=!this._moving;return a&&(this.stop(),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e))),this.fire(new t.Event(\"resize\",e)),a&&this.fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?-2:t)>=-2&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between -2 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.setMinPitch=function(t){if((t=null==t?0:t)<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(t>=0&&t<=this.transform.maxPitch)return this.transform.minPitch=t,this._update(),this.getPitch()<t&&this.setPitch(t),this;throw new Error(\"minPitch must be between 0 and the current maxPitch, inclusive\")},i.prototype.getMinPitch=function(){return this.transform.minPitch},i.prototype.setMaxPitch=function(t){if((t=null==t?60:t)>60)throw new Error(\"maxPitch must be less than or equal to 60\");if(t>=this.transform.minPitch)return this.transform.maxPitch=t,this._update(),this.getPitch()>t&&this.setPitch(t),this;throw new Error(\"maxPitch must be greater than the current minPitch\")},i.prototype.getMaxPitch=function(){return this.transform.maxPitch},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.handlers.isMoving()},i.prototype.isZooming=function(){return this._zooming||this.handlers.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.handlers.isRotating()},i.prototype._createDelegatedListener=function(t,e,r){var n,i=this;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new zn(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new zn(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new zn(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}},i.prototype.on=function(t,e,r){if(void 0===r)return n.prototype.on.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(i),i.delegates)this.on(a,i.delegates[a]);return this},i.prototype.once=function(t,e,r){if(void 0===r)return n.prototype.once.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in i.delegates)this.once(a,i.delegates[a]);return this},i.prototype.off=function(t,e,r){var i=this;return void 0===r?n.prototype.off.call(this,t,e):(this._delegatedListeners&&this._delegatedListeners[t]&&function(n){for(var a=n[t],o=0;o<a.length;o++){var s=a[o];if(s.layer===e&&s.listener===r){for(var l in s.delegates)i.off(l,s.delegates[l]);return a.splice(o,1),i}}}(this._delegatedListeners),this)},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:this._localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._getUIString=function(t){var e=this._locale[t];if(null==e)throw new Error(\"Missing UI string '\"+t+\"'\");return e},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new qe(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._lazyInitEmptyStyle=function(){this.style||(this.style=new qe(this,{}),this.style.setEventedParent(this,{style:this.style}),this.style.loadEmpty())},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,(function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)}))}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this._lazyInitEmptyStyle(),this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this._lazyInitEmptyStyle(),this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;void 0===a&&(a=!1);var o=n.stretchX,s=n.stretchY,l=n.content;if(this._lazyInitEmptyStyle(),r instanceof _i||Ti&&r instanceof Ti){var c=t.browser.getImageData(r);this.style.addImage(e,{data:new t.RGBAImage({width:c.width,height:c.height},c.data),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r;this.style.addImage(e,{data:new t.RGBAImage({width:r.width,height:r.height},new Uint8Array(r.data)),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0,userImage:u}),u.onAdd&&u.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof _i||Ti&&r instanceof Ti?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;return void 0===a||void 0===o?this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\"))):a!==n.data.width||o!==n.data.height?this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\"))):(n.data.replace(s,!(r instanceof _i||Ti&&r instanceof Ti)),void this.style.updateImage(e,n))},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this._lazyInitEmptyStyle(),this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this._lazyInitEmptyStyle(),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach((function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)}))},i.prototype._resizeCanvas=function(e,r){var n=t.browser.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new yn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(e){var r,n=this,i=0,a=this.painter.context.extTimerQuery;if(this.listens(\"gpu-timing-frame\")&&(r=a.createQueryEXT(),a.beginQueryEXT(a.TIME_ELAPSED_EXT,r),i=t.browser.now()),this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run(e),!this._removed){var o=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var s=this.transform.zoom,l=t.browser.now();this.style.zoomHistory.update(s,l);var c=new t.EvaluationParameters(s,{now:l,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),u=c.crossFadingFactor();1===u&&u===this._crossFadingFactor||(o=!0,this._crossFadingFactor=u),this.style.update(c)}if(this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration,showPadding:this.showPadding,gpuTiming:!!this.listens(\"gpu-timing-layer\")}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||o)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this.listens(\"gpu-timing-frame\")){var f=t.browser.now()-i;a.endQueryEXT(a.TIME_ELAPSED_EXT,r),setTimeout((function(){var e=a.getQueryObjectEXT(r,a.QUERY_RESULT_EXT)/1e6;a.deleteQueryEXT(r),n.fire(new t.Event(\"gpu-timing-frame\",{cpuTime:f,gpuTime:e}))}),50)}if(this.listens(\"gpu-timing-layer\")){var h=this.painter.collectGpuTimers();setTimeout((function(){var e=n.painter.queryGpuTimers(h);n.fire(new t.Event(\"gpu-timing-layer\",{layerTimes:e}))}),50)}return this._sourcesDirty||this._styleDirty||this._placementDirty||this._repaint?this.triggerRepaint():!this.isMoving()&&this.loaded()&&(this._fullyLoaded||(this._fullyLoaded=!0),this.fire(new t.Event(\"idle\"))),this}},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.painter.destroy(),this.handlers.destroy(),delete this.handlers,this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),Ai(this._canvasContainer),Ai(this._controlContainer),Ai(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this._removed=!0,this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame((function(t){e._frame=null,e._render(t)})))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(t){this._trackResize&&this.resize({originalEvent:t})._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showPadding.get=function(){return!!this._showPadding},a.showPadding.set=function(t){this._showPadding!==t&&(this._showPadding=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},a.version.get=function(){return t.version},Object.defineProperties(i.prototype,a),i}(mi);function Ai(t){t.parentNode&&t.parentNode.removeChild(t)}var Si={showCompass:!0,showZoom:!0,visualizePitch:!1},Ei=function(e){var n=this;this.options=t.extend({},Si,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this.options.showZoom&&(t.bindAll([\"_setButtonTitle\",\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-zoom-in\",(function(t){return n._map.zoomIn({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomInButton).setAttribute(\"aria-hidden\",!0),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-zoom-out\",(function(t){return n._map.zoomOut({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomOutButton).setAttribute(\"aria-hidden\",!0)),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-compass\",(function(t){n.options.visualizePitch?n._map.resetNorthPitch({},{originalEvent:t}):n._map.resetNorth({},{originalEvent:t})})),this._compassIcon=r.create(\"span\",\"mapboxgl-ctrl-icon\",this._compass),this._compassIcon.setAttribute(\"aria-hidden\",!0))};Ei.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.disabled=t===this._map.getMaxZoom(),this._zoomOutButton.disabled=t===this._map.getMinZoom()},Ei.prototype._rotateCompassArrow=function(){var t=this.options.visualizePitch?\"scale(\"+1/Math.pow(Math.cos(this._map.transform.pitch*(Math.PI/180)),.5)+\") rotateX(\"+this._map.transform.pitch+\"deg) rotateZ(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\":\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassIcon.style.transform=t},Ei.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._setButtonTitle(this._zoomInButton,\"ZoomIn\"),this._setButtonTitle(this._zoomOutButton,\"ZoomOut\"),this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._setButtonTitle(this._compass,\"ResetBearing\"),this.options.visualizePitch&&this._map.on(\"pitch\",this._rotateCompassArrow),this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new Ci(this._map,this._compass,this.options.visualizePitch)),this._container},Ei.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this.options.visualizePitch&&this._map.off(\"pitch\",this._rotateCompassArrow),this._map.off(\"rotate\",this._rotateCompassArrow),this._handler.off(),delete this._handler),delete this._map},Ei.prototype._createButton=function(t,e){var n=r.create(\"button\",t,this._container);return n.type=\"button\",n.addEventListener(\"click\",e),n},Ei.prototype._setButtonTitle=function(t,e){var r=this._map._getUIString(\"NavigationControl.\"+e);t.title=r,t.setAttribute(\"aria-label\",r)};var Ci=function(e,n,i){void 0===i&&(i=!1),this._clickTolerance=10,this.element=n,this.mouseRotate=new Gn({clickTolerance:e.dragRotate._mouseRotate._clickTolerance}),this.map=e,i&&(this.mousePitch=new Yn({clickTolerance:e.dragRotate._mousePitch._clickTolerance})),t.bindAll([\"mousedown\",\"mousemove\",\"mouseup\",\"touchstart\",\"touchmove\",\"touchend\",\"reset\"],this),r.addEventListener(n,\"mousedown\",this.mousedown),r.addEventListener(n,\"touchstart\",this.touchstart,{passive:!1}),r.addEventListener(n,\"touchmove\",this.touchmove),r.addEventListener(n,\"touchend\",this.touchend),r.addEventListener(n,\"touchcancel\",this.reset)};function Li(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Ci.prototype.down=function(t,e){this.mouseRotate.mousedown(t,e),this.mousePitch&&this.mousePitch.mousedown(t,e),r.disableDrag()},Ci.prototype.move=function(t,e){var r=this.map,n=this.mouseRotate.mousemoveWindow(t,e);if(n&&n.bearingDelta&&r.setBearing(r.getBearing()+n.bearingDelta),this.mousePitch){var i=this.mousePitch.mousemoveWindow(t,e);i&&i.pitchDelta&&r.setPitch(r.getPitch()+i.pitchDelta)}},Ci.prototype.off=function(){var t=this.element;r.removeEventListener(t,\"mousedown\",this.mousedown),r.removeEventListener(t,\"touchstart\",this.touchstart,{passive:!1}),r.removeEventListener(t,\"touchmove\",this.touchmove),r.removeEventListener(t,\"touchend\",this.touchend),r.removeEventListener(t,\"touchcancel\",this.reset),this.offTemp()},Ci.prototype.offTemp=function(){r.enableDrag(),r.removeEventListener(t.window,\"mousemove\",this.mousemove),r.removeEventListener(t.window,\"mouseup\",this.mouseup)},Ci.prototype.mousedown=function(e){this.down(t.extend({},e,{ctrlKey:!0,preventDefault:function(){return e.preventDefault()}}),r.mousePos(this.element,e)),r.addEventListener(t.window,\"mousemove\",this.mousemove),r.addEventListener(t.window,\"mouseup\",this.mouseup)},Ci.prototype.mousemove=function(t){this.move(t,r.mousePos(this.element,t))},Ci.prototype.mouseup=function(t){this.mouseRotate.mouseupWindow(t),this.mousePitch&&this.mousePitch.mouseupWindow(t),this.offTemp()},Ci.prototype.touchstart=function(t){1!==t.targetTouches.length?this.reset():(this._startPos=this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.down({type:\"mousedown\",button:0,ctrlKey:!0,preventDefault:function(){return t.preventDefault()}},this._startPos))},Ci.prototype.touchmove=function(t){1!==t.targetTouches.length?this.reset():(this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.move({preventDefault:function(){return t.preventDefault()}},this._lastPos))},Ci.prototype.touchend=function(t){0===t.targetTouches.length&&this._startPos&&this._lastPos&&this._startPos.dist(this._lastPos)<this._clickTolerance&&this.element.click(),this.reset()},Ci.prototype.reset=function(){this.mouseRotate.reset(),this.mousePitch&&this.mousePitch.reset(),delete this._startPos,delete this._lastPos,this.offTemp()};var Ii={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Pi(t,e,r){var n=t.classList;for(var i in Ii)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var zi,Oi=function(e){function n(n,i){var a=this;if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\",\"_onKeyPress\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",this._rotation=n&&n.rotation||0,this._rotationAlignment=n&&n.rotationAlignment||\"auto\",this._pitchAlignment=n&&n.pitchAlignment&&\"auto\"!==n.pitchAlignment?n.pitchAlignment:this._rotationAlignment,n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\"),this._element.setAttribute(\"aria-label\",\"Map marker\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");o.setAttributeNS(null,\"display\",\"block\"),o.setAttributeNS(null,\"height\",\"41px\"),o.setAttributeNS(null,\"width\",\"27px\"),o.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"stroke\",\"none\"),s.setAttributeNS(null,\"stroke-width\",\"1\"),s.setAttributeNS(null,\"fill\",\"none\"),s.setAttributeNS(null,\"fill-rule\",\"evenodd\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"fill-rule\",\"nonzero\");var c=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");c.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),c.setAttributeNS(null,\"fill\",\"#000000\");for(var u=0,f=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];u<f.length;u+=1){var h=f[u],p=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");p.setAttributeNS(null,\"opacity\",\"0.04\"),p.setAttributeNS(null,\"cx\",\"10.5\"),p.setAttributeNS(null,\"cy\",\"5.80029008\"),p.setAttributeNS(null,\"rx\",h.rx),p.setAttributeNS(null,\"ry\",h.ry),c.appendChild(p)}var d=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");d.setAttributeNS(null,\"fill\",this._color);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");g.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),d.appendChild(g);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"opacity\",\"0.25\"),m.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),m.appendChild(v);var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),y.setAttributeNS(null,\"fill\",\"#FFFFFF\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");x.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#000000\"),b.setAttributeNS(null,\"opacity\",\"0.25\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\");var _=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");_.setAttributeNS(null,\"fill\",\"#FFFFFF\"),_.setAttributeNS(null,\"cx\",\"5.5\"),_.setAttributeNS(null,\"cy\",\"5.5\"),_.setAttributeNS(null,\"r\",\"5.4999962\"),x.appendChild(b),x.appendChild(_),l.appendChild(c),l.appendChild(d),l.appendChild(m),l.appendChild(y),l.appendChild(x),o.appendChild(l),this._element.appendChild(o),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",(function(t){t.preventDefault()})),this._element.addEventListener(\"mousedown\",(function(t){t.preventDefault()})),this._element.addEventListener(\"focus\",(function(){var t=a._map.getContainer();t.scrollTop=0,t.scrollLeft=0})),Pi(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null,this._element.removeEventListener(\"keypress\",this._onKeyPress),this._originalTabIndex||this._element.removeAttribute(\"tabindex\")),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat),this._originalTabIndex=this._element.getAttribute(\"tabindex\"),this._originalTabIndex||this._element.setAttribute(\"tabindex\",\"0\"),this._element.addEventListener(\"keypress\",this._onKeyPress)}return this},n.prototype._onKeyPress=function(t){var e=t.code,r=t.charCode||t.keyCode;\"Space\"!==e&&\"Enter\"!==e&&32!==r&&13!==r||this.togglePopup()},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){if(this._map){this._map.transform.renderWorldCopies&&(this._lngLat=Li(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset);var e=\"\";\"viewport\"===this._rotationAlignment||\"auto\"===this._rotationAlignment?e=\"rotateZ(\"+this._rotation+\"deg)\":\"map\"===this._rotationAlignment&&(e=\"rotateZ(\"+(this._rotation-this._map.getBearing())+\"deg)\");var n=\"\";\"viewport\"===this._pitchAlignment||\"auto\"===this._pitchAlignment?n=\"rotateX(0deg)\":\"map\"===this._pitchAlignment&&(n=\"rotateX(\"+this._map.getPitch()+\"deg)\"),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Ii[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px) \"+n+\" \"+e)}},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n.prototype.setRotation=function(t){return this._rotation=t||0,this._update(),this},n.prototype.getRotation=function(){return this._rotation},n.prototype.setRotationAlignment=function(t){return this._rotationAlignment=t||\"auto\",this._update(),this},n.prototype.getRotationAlignment=function(){return this._rotationAlignment},n.prototype.setPitchAlignment=function(t){return this._pitchAlignment=t&&\"auto\"!==t?t:this._rotationAlignment,this._update(),this},n.prototype.getPitchAlignment=function(){return this._pitchAlignment},n}(t.Evented),Di={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showAccuracyCircle:!0,showUserLocation:!0},Ri=0,Fi=!1,Bi=function(e){function n(r){e.call(this),this.options=t.extend({},Di,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_onZoom\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==zi?n(zi):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then((function(t){n(zi=\"denied\"!==t.state)})):n(zi=!!t.window.navigator.geolocation),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),this.options.showAccuracyCircle&&this._accuracyCircleMarker&&this._accuracyCircleMarker.remove(),r.remove(this._container),this._map.off(\"zoom\",this._onZoom),this._map=void 0,Ri=0,Fi=!1},n.prototype._isOutOfMapMaxBounds=function(t){var e=this._map.getMaxBounds(),r=t.coords;return e&&(r.longitude<e.getWest()||r.longitude>e.getEast()||r.latitude<e.getSouth()||r.latitude>e.getNorth())},n.prototype._setErrorState=function(){switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}},n.prototype._onSuccess=function(e){if(this._map){if(this._isOutOfMapMaxBounds(e))return this._setErrorState(),this.fire(new t.Event(\"outofmaxbounds\",e)),this._updateMarker(),void this._finish();if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()}},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(e){if(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude);this._accuracyCircleMarker.setLngLat(r).addTo(this._map),this._userLocationDotMarker.setLngLat(r).addTo(this._map),this._accuracy=e.coords.accuracy,this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()}else this._userLocationDotMarker.remove(),this._accuracyCircleMarker.remove()},n.prototype._updateCircleRadius=function(){var t=this._map._container.clientHeight/2,e=this._map.unproject([0,t]),r=this._map.unproject([1,t]),n=e.distanceTo(r),i=Math.ceil(2*this._accuracy/n);this._circleElement.style.width=i+\"px\",this._circleElement.style.height=i+\"px\"},n.prototype._onZoom=function(){this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()},n.prototype._onError=function(e){if(this._map){if(this.options.trackUserLocation)if(1===e.code){this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.disabled=!0;var r=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.title=r,this._geolocateButton.setAttribute(\"aria-label\",r),void 0!==this._geolocationWatchID&&this._clearWatch()}else{if(3===e.code&&Fi)return;this._setErrorState()}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()}},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;if(this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-geolocate\",this._container),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._geolocateButton).setAttribute(\"aria-hidden\",!0),this._geolocateButton.type=\"button\",!1===e){t.warnOnce(\"Geolocation support is not available so the GeolocateControl will be disabled.\");var i=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.disabled=!0,this._geolocateButton.title=i,this._geolocateButton.setAttribute(\"aria-label\",i)}else{var a=this._map._getUIString(\"GeolocateControl.FindMyLocation\");this._geolocateButton.title=a,this._geolocateButton.setAttribute(\"aria-label\",a)}this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new Oi(this._dotElement),this._circleElement=r.create(\"div\",\"mapboxgl-user-location-accuracy-circle\"),this._accuracyCircleMarker=new Oi({element:this._circleElement,pitchAlignment:\"map\"}),this.options.trackUserLocation&&(this._watchState=\"OFF\"),this._map.on(\"zoom\",this._onZoom)),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",(function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||e.originalEvent&&\"resize\"===e.originalEvent.type||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))}))},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":Ri--,Fi=!1,this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}if(\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID)this._clearWatch();else if(void 0===this._geolocationWatchID){var e;this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),++Ri>1?(e={maximumAge:6e5,timeout:0},Fi=!0):(e=this.options.positionOptions,Fi=!1),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,e)}}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),Ni={maxWidth:100,unit:\"metric\"},ji=function(e){this.options=t.extend({},Ni,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Ui(t,e,r){var n=r&&r.maxWidth||100,i=t._container.clientHeight/2,a=t.unproject([0,i]),o=t.unproject([n,i]),s=a.distanceTo(o);if(r&&\"imperial\"===r.unit){var l=3.2808*s;l>5280?Vi(e,n,l/5280,t._getUIString(\"ScaleControl.Miles\")):Vi(e,n,l,t._getUIString(\"ScaleControl.Feet\"))}else r&&\"nautical\"===r.unit?Vi(e,n,s/1852,t._getUIString(\"ScaleControl.NauticalMiles\")):s>=1e3?Vi(e,n,s/1e3,t._getUIString(\"ScaleControl.Kilometers\")):Vi(e,n,s,t._getUIString(\"ScaleControl.Meters\"))}function Vi(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o)));t.style.width=e*(s/r)+\"px\",t.innerHTML=s+\"&nbsp;\"+n}ji.prototype.getDefaultPosition=function(){return\"bottom-left\"},ji.prototype._onMove=function(){Ui(this._map,this._container,this.options)},ji.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},ji.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},ji.prototype.setUnit=function(t){this.options.unit=t,Ui(this._map,this._container,this.options)};var qi=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\")};qi.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},qi.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},qi.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},qi.prototype._setupUI=function(){var e=this._fullscreenButton=r.create(\"button\",\"mapboxgl-ctrl-fullscreen\",this._controlContainer);r.create(\"span\",\"mapboxgl-ctrl-icon\",e).setAttribute(\"aria-hidden\",!0),e.type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},qi.prototype._updateTitle=function(){var t=this._getTitle();this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},qi.prototype._getTitle=function(){return this._map._getUIString(this._isFullscreen()?\"FullscreenControl.Exit\":\"FullscreenControl.Enter\")},qi.prototype._isFullscreen=function(){return this._fullscreen},qi.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-shrink\"),this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-fullscreen\"),this._updateTitle())},qi.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Hi={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Gi=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Hi),r),t.bindAll([\"_update\",\"_onClose\",\"remove\",\"_onMouseMove\",\"_onMouseUp\",\"_onDrag\"],this)}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.addTo=function(e){return this._map&&this.remove(),this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClose),this.options.closeOnMove&&this._map.on(\"move\",this._onClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"mouseup\",this._onMouseUp),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"move\",this._onClose),this._map.off(\"click\",this._onClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\",this._onMouseMove),this._map.off(\"mouseup\",this._onMouseUp),this._map.off(\"drag\",this._onDrag),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._trackPointer=!1,this._update(),this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\",this._onMouseMove),this._container&&this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this},n.prototype.trackPointer=function(){return this._trackPointer=!0,this._pos=null,this._update(),this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"drag\",this._onDrag),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container&&this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype.addClassName=function(t){this._container&&this._container.classList.add(t)},n.prototype.removeClassName=function(t){this._container&&this._container.classList.remove(t)},n.prototype.toggleClassName=function(t){if(this._container)return this._container.classList.toggle(t)},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClose))},n.prototype._onMouseUp=function(t){this._update(t.point)},n.prototype._onMouseMove=function(t){this._update(t.point)},n.prototype._onDrag=function(t){this._update(t.point)},n.prototype._update=function(e){var n=this;if(this._map&&(this._lngLat||this._trackPointer)&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach((function(t){return n._container.classList.add(t)})),this._trackPointer&&this._container.classList.add(\"mapboxgl-popup-track-pointer\")),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Li(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var i=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),a=this.options.anchor,o=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!a){var s,l=this._container.offsetWidth,c=this._container.offsetHeight;s=i.y+o.bottom.y<c?[\"top\"]:i.y>this._map.transform.height-c?[\"bottom\"]:[],i.x<l/2?s.push(\"left\"):i.x>this._map.transform.width-l/2&&s.push(\"right\"),a=0===s.length?\"bottom\":s.join(\"-\")}var u=i.add(o[a]).round();r.setTransform(this._container,Ii[a]+\" translate(\"+u.x+\"px,\"+u.y+\"px)\"),Pi(this._container,a,\"popup\")}},n.prototype._onClose=function(){this.remove()},n}(t.Evented),Yi={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,getRTLTextPluginStatus:t.getRTLTextPluginStatus,Map:Mi,NavigationControl:Ei,GeolocateControl:Bi,AttributionControl:vi,ScaleControl:ji,FullscreenControl:qi,Popup:Gi,Marker:Oi,Style:qe,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,prewarm:function(){Bt().acquire(Ot)},clearPrewarmedResources:function(){var t=Rt;t&&(t.isPreloaded()&&1===t.numActive()?(t.release(Ot),Rt=null):console.warn(\"Could not clear WebWorkers since there are active Map instances that still reference it. The pre-warmed WebWorker pool can only be cleared when all map instances have been removed with map.remove()\"))},get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return Dt.workerCount},set workerCount(t){Dt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Yi})),r}))},{}],474:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],f=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;f.push(a[u[s]].slice())}c.push(f)}return c}},{\"convex-hull\":135}],475:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),f=i(),h=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,m,v){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),m||(m=[0,0,0,1]),v||(v=[0,0,0,1]),!n(u,t))return!1;if(a(f,u),f[3]=0,f[7]=0,f[11]=0,f[15]=1,Math.abs(o(f)<1e-8))return!1;var y,x,b,_,w,T,k,M=u[3],A=u[7],S=u[11],E=u[12],C=u[13],L=u[14],I=u[15];if(0!==M||0!==A||0!==S){if(h[0]=M,h[1]=A,h[2]=S,h[3]=I,!s(f,f))return!1;l(f,f),y=m,b=f,_=(x=h)[0],w=x[1],T=x[2],k=x[3],y[0]=b[0]*_+b[4]*w+b[8]*T+b[12]*k,y[1]=b[1]*_+b[5]*w+b[9]*T+b[13]*k,y[2]=b[2]*_+b[6]*w+b[10]*T+b[14]*k,y[3]=b[3]*_+b[7]*w+b[11]*T+b[15]*k}else m[0]=m[1]=m[2]=0,m[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var P=0;P<3;P++)r[P]*=-1,p[P][0]*=-1,p[P][1]*=-1,p[P][2]*=-1;return v[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),v[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),v[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),v[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(v[0]=-v[0]),p[0][2]>p[2][0]&&(v[1]=-v[1]),p[1][0]>p[0][1]&&(v[2]=-v[2]),!0}},{\"./normalize\":476,\"gl-mat4/clone\":278,\"gl-mat4/create\":280,\"gl-mat4/determinant\":281,\"gl-mat4/invert\":293,\"gl-mat4/transpose\":306,\"gl-vec3/cross\":365,\"gl-vec3/dot\":370,\"gl-vec3/length\":380,\"gl-vec3/normalize\":387}],476:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],477:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=f(),c=f(),u=f();function f(){return{translate:h(),scale:h(1),skew:h(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function h(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,f){if(0===o(e)||0===o(r))return!1;var h=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!h||!p)&&(n(u.translate,l.translate,c.translate,f),n(u.skew,l.skew,c.skew,f),n(u.scale,l.scale,c.scale,f),n(u.perspective,l.perspective,c.perspective,f),s(u.quaternion,l.quaternion,c.quaternion,f),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),!0)}},{\"gl-mat4/determinant\":281,\"gl-vec3/lerp\":381,\"mat4-decompose\":475,\"mat4-recompose\":478,\"quat-slerp\":527}],478:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":280,\"gl-mat4/fromRotationTranslation\":284,\"gl-mat4/identity\":291,\"gl-mat4/multiply\":295,\"gl-mat4/scale\":303,\"gl-mat4/translate\":305}],479:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],480:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),f=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),h=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],h=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)h[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&h[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=h[c];else i(o,h,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],f(g,g);var m=this.computedInverse;a(m,o);var v=this.computedEye,y=m[15];v[0]=m[12]/y,v[1]=m[13]/y,v[2]=m[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=v[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||h,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":481,\"gl-mat4/invert\":293,\"gl-mat4/lookAt\":294,\"gl-mat4/rotateX\":300,\"gl-mat4/rotateY\":301,\"gl-mat4/rotateZ\":302,\"gl-mat4/scale\":303,\"gl-mat4/translate\":305,\"gl-vec3/normalize\":387,\"mat4-interpolate\":477}],481:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],482:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}var a=new Array(e);for(i=0;i<e;++i)a[i]=i;a.sort((function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]}));var o=[a[0],a[1]],s=[a[0],a[1]];for(i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}r=new Array(s.length+o.length-2);for(var f=0,h=(i=0,o.length);i<h;++i)r[f++]=o[i];for(var p=s.length-2;p>0;--p)r[f++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":548}],483:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function f(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function h(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function m(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",f),t.addEventListener(\"keyup\",h),t.addEventListener(\"keydown\",h),t.addEventListener(\"keypress\",h),t!==window&&(window.addEventListener(\"blur\",f),window.addEventListener(\"keyup\",h),window.addEventListener(\"keydown\",h),window.addEventListener(\"keypress\",h)))}m();var v={element:t};return Object.defineProperties(v,{enabled:{get:function(){return s},set:function(e){e?m():function(){if(!s)return;s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",f),t.removeEventListener(\"keyup\",h),t.removeEventListener(\"keydown\",h),t.removeEventListener(\"keypress\",h),t!==window&&(window.removeEventListener(\"blur\",f),window.removeEventListener(\"keyup\",h),window.removeEventListener(\"keydown\",h),window.removeEventListener(\"keypress\",h))}()},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),v};var n=t(\"mouse-event\")},{\"mouse-event\":485}],484:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],485:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],486:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=1;switch(t.deltaMode){case 1:s=i;break;case 2:s=window.innerHeight}if(a*=s,o*=s,(n*=s)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":578}],487:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function f(t){return\"p\"+t}function h(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function m(t){return\"y\"+t}function v(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var b=t.arrayArguments||1;b<1&&e(\"Must have at least one array argument\");var _=t.scalarArguments||0;_<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var w=t.getters||[],T=new Array(b),k=0;k<b;++k)w.indexOf(k)>=0?T[k]=!0:T[k]=!1;return function(t,e,r,b,_,w){var T=w.length,k=_.length;if(k<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var M=\"extractContour\"+_.join(\"_\"),A=[],S=[],E=[],C=0;C<T;++C)E.push(i(C));for(C=0;C<b;++C)E.push(u(C));for(C=0;C<k;++C)S.push(s(C)+\"=\"+i(0)+\".shape[\"+C+\"]|0\");for(C=0;C<T;++C){S.push(a(C)+\"=\"+i(C)+\".data\",c(C)+\"=\"+i(C)+\".offset|0\");for(var L=0;L<k;++L)S.push(l(C,L)+\"=\"+i(C)+\".stride[\"+L+\"]|0\")}for(C=0;C<T;++C){S.push(f(C)+\"=\"+c(C)),S.push(o(C,0));for(L=1;L<1<<k;++L){for(var I=[],P=0;P<k;++P)L&1<<P&&I.push(\"-\"+l(C,P));S.push(h(C,L)+\"=(\"+I.join(\"\")+\")|0\"),S.push(o(C,L)+\"=0\")}}for(C=0;C<T;++C)for(L=0;L<k;++L){var z=[l(C,_[L])];L>0&&z.push(l(C,_[L-1])+\"*\"+s(_[L-1])),S.push(d(C,_[L])+\"=(\"+z.join(\"-\")+\")|0\")}for(C=0;C<k;++C)S.push(p(C)+\"=0\");S.push(\"N=0\");var O=[\"2\"];for(C=k-2;C>=0;--C)O.push(s(_[C]));S.push(\"Q=(\"+O.join(\"*\")+\")|0\",\"P=mallocUint32(Q)\",\"V=mallocUint32(Q)\",\"X=0\"),S.push(g(0)+\"=0\");for(L=1;L<1<<k;++L){var D=[],R=[];for(P=0;P<k;++P)L&1<<P&&(0===R.length?D.push(\"1\"):D.unshift(R.join(\"*\"))),R.push(s(_[P]));var F=\"\";D[0].indexOf(s(_[k-2]))<0&&(F=\"-\");var B=x(k,L,_);S.push(v(B)+\"=(-\"+D.join(\"-\")+\")|0\",m(B)+\"=(\"+F+D.join(\"-\")+\")|0\",g(B)+\"=0\")}function N(t,e){A.push(\"for(\",p(_[t]),\"=\",e,\";\",p(_[t]),\"<\",s(_[t]),\";\",\"++\",p(_[t]),\"){\")}function j(t){for(var e=0;e<T;++e)A.push(f(e),\"+=\",d(e,_[t]),\";\");A.push(\"}\")}function U(){for(var t=1;t<1<<k;++t)A.push(\"T\",\"=\",v(t),\";\",v(t),\"=\",m(t),\";\",m(t),\"=\",\"T\",\";\")}S.push(y(0)+\"=0\",\"T=0\"),function t(e,r){if(e<0)!function(t){for(var e=0;e<T;++e)w[e]?A.push(o(e,0),\"=\",a(e),\".get(\",f(e),\");\"):A.push(o(e,0),\"=\",a(e),\"[\",f(e),\"];\");var r=[];for(e=0;e<T;++e)r.push(o(e,0));for(e=0;e<b;++e)r.push(u(e));A.push(g(0),\"=\",\"P\",\"[\",\"X\",\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<k;++n)A.push(g(n),\"=\",\"P\",\"[\",\"X\",\"+\",v(n),\"];\");var i=[];for(n=1;n<1<<k;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");A.push(\"if(\",i.join(\"||\"),\"){\");var s=[];for(e=0;e<k;++e)s.push(p(e));for(e=0;e<T;++e){s.push(o(e,0));for(n=1;n<1<<k;++n)w[e]?A.push(o(e,n),\"=\",a(e),\".get(\",f(e),\"+\",h(e,n),\");\"):A.push(o(e,n),\"=\",a(e),\"[\",f(e),\"+\",h(e,n),\"];\"),s.push(o(e,n))}for(e=0;e<1<<k;++e)s.push(g(e));for(e=0;e<b;++e)s.push(u(e));A.push(\"vertex(\",s.join(),\");\",y(0),\"=\",\"V\",\"[\",\"X\",\"]=\",\"N\",\"++;\");var l=(1<<k)-1,c=g(l);for(n=0;n<k;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,m=g(d),x=[],_=d;_>0;_=_-1&d)x.push(\"V[X+\"+v(_)+\"]\");x.push(y(0));for(_=0;_<T;++_)1&n?x.push(o(_,l),o(_,d)):x.push(o(_,d),o(_,l));1&n?x.push(c,m):x.push(m,c);for(_=0;_<b;++_)x.push(u(_));A.push(\"if(\",c,\"!==\",m,\"){\",\"face(\",x.join(),\")}\")}A.push(\"}\",\"X\",\"+=1;\")}(r);else{!function(t){for(var e=t-1;e>=0;--e)N(e,0);var r=[];for(e=0;e<T;++e)w[e]?r.push(a(e)+\".get(\"+f(e)+\")\"):r.push(a(e)+\"[\"+f(e)+\"]\");for(e=0;e<b;++e)r.push(u(e));for(A.push(\"P\",\"[\",\"X\",\"++]=phase(\",r.join(),\");\"),e=0;e<t;++e)j(e);for(var n=0;n<T;++n)A.push(f(n),\"+=\",d(n,_[t]),\";\")}(e),A.push(\"if(\",s(_[e]),\">0){\",p(_[e]),\"=1;\"),t(e-1,r|1<<_[e]);for(var n=0;n<T;++n)A.push(f(n),\"+=\",d(n,_[e]),\";\");e===k-1&&(A.push(\"X\",\"=0;\"),U()),N(e,2),t(e-1,r),e===k-1&&(A.push(\"if(\",p(_[k-1]),\"&1){\",\"X\",\"=0;}\"),U()),j(e),A.push(\"}\")}}(k-1,0),A.push(\"freeUint32(\",\"V\",\");freeUint32(\",\"P\",\");\");var V=[\"'use strict';\",\"function \",M,\"(\",E.join(),\"){\",\"var \",S.join(),\";\",A.join(\"\"),\"}\",\"return \",M].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",V)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,_,r,T)};function x(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":595}],488:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(v=o[e])return v;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(l=0;l<e.length;++l){var u=Math.abs(e[l])-1,f=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var h=s.slice(),p=s.slice();e[l]<0?h[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",h.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",f,\",src.pick(\",h.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",f,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",f,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",f,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",f,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var f=[],h=0;h<r;++h)s&1<<h&&f.push(h+1);for(var p=0;p<1<<f.length;++p){var d=f.slice();for(h=0;h<f.length;++h)p&1<<h&&(d[h]=-d[h]);i(d)}}n.push(\"return dst;};return gradient\");var g=[\"diff\",\"zero\"],m=[l,c];for(s=1;s<=r;++s)g.push(\"grad\"+s),m.push(u(s));g.push(n.join(\"\"));var v=Function.apply(void 0,g).apply(void 0,m);return a[e]=v,v}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map((function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}})),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":151,dup:176}],489:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],f=a&&c?t.get(n,s):0,h=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*f+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*h+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],f=0<=l+1&&l+1<t.shape[1],h=Math.floor(n),p=n-h,d=0<=h&&h<t.shape[2],g=0<=h+1&&h+1<t.shape[2],m=o&&u&&d?t.get(i,l,h):0,v=o&&f&&d?t.get(i,l+1,h):0,y=s&&u&&d?t.get(i+1,l,h):0,x=s&&f&&d?t.get(i+1,l+1,h):0,b=o&&u&&g?t.get(i,l,h+1):0,_=o&&f&&g?t.get(i,l+1,h+1):0;return(1-p)*((1-c)*((1-a)*m+a*y)+c*((1-a)*v+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,h+1):0))+c*((1-a)*_+a*(s&&f&&g?t.get(i+1,l+1,h+1):0)))}function o(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,f=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}f+=c*t.data[u]}return f}e.exports=function(t,e,r,s){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,s);default:return o.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],490:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var f=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var h=[\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":151}],491:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":492,ndarray:495}],492:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":151}],493:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l){0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p))}var f=-1,h=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(f>0?s.push([\"d\",d,\"=s\",d,\"-d\",f,\"*n\",f].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),f=d),0!==(p=t.length-1-l)&&(h>0?s.push([\"e\",p,\"=s\",p,\"-e\",h,\"*n\",h,\",f\",p,\"=\",c[p],\"-f\",h,\"*n\",h].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),h=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var m=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),v=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function f(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function h(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){r.push(\"dptr=0;sptr=ptr\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(\"scratch[dptr++]=\",f(\"sptr\"));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\")}r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\");for(u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));r.push([\"a=\",f(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\"));for(u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");r.push(\"dptr=cptr;sptr=cptr-s0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(h(\"dptr\",f(\"sptr\")));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\")}r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(h(\"dptr\",\"scratch[sptr++]\"));for(u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+f(\"ptr\"),\"while((j--\\x3eleft)&&(\"+f(\"cptr-s0\")+\">scratch)){\",h(\"cptr\",f(\"cptr-s0\")),\"cptr-=s0\",\"}\",h(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var f=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var h=[],p=1;p<t.length;++p)h.push(\"n\"+p),f.push(\"i\"+p);for(p=0;p<8;++p)f.push(\"b_ptr\"+p);f.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+h.join(\"*\")),c?f.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):f.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else f.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function m(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function v(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\");for(a=t.length-1;a>=0;--a){0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"))}if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));n.push(i),r&&n.push(\"++pivot_ptr\");for(a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\");for(o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));n.push(a);for(o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?v([e,r],!1,m(\"ptr0\",g(\"ptr1\"))):n.push(m(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function T(e,r){t.length>1?v([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",\"tmp\")].join(\"\"))}function k(e,r,i){t.length>1?(v([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",g(\"ptr2\")),\"\\n\",m(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",g(\"ptr2\")),\"\\n\",m(\"ptr2\",\"tmp\")].join(\"\"))}function M(t,e){T(t,e),n.push(\"--\"+e)}function A(e,r,i){t.length>1?v([e,r],!0,[m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(m(d(e),g(d(r))),m(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),v([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+f.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?v([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",m(\"ptr5\",\"x\"),\"\\n\",m(\"ptr6\",\"y\"),\"\\n\",m(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",m(d(\"index1\"),\"x\"),\"\\n\",m(d(\"index3\"),\"y\"),\"\\n\",m(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),A(\"left\",\"(less-1)\",1),A(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,v);return m(v,y)}},{\"typedarray-pool\":595}],494:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":493}],495:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map((function(t){return\"i\"+t})),u=\"this.offset+\"+o.map((function(t){return\"this.stride[\"+t+\"]*i\"+t})).join(\"+\"),f=o.map((function(t){return\"b\"+t})).join(\",\"),h=o.map((function(t){return\"c\"+t})).join(\",\");a.push(\"function \"+r+\"(a,\"+f+\",\"+h+\",d){this.data=a\",\"this.shape=[\"+f+\"]\",\"this.stride=[\"+h+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map((function(t){return\"this.shape[\"+t+\"]\"})).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map((function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")})).join(\",\")+\",\"+o.map((function(t){return\"this.stride[\"+t+\"]\"})).join(\",\")+\",this.offset)}\");var p=o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})),d=o.map((function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"}));a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"c\"+t})).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"})).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t})).join(\",\")+\",c)}\");var m=new Array(e),v=new Array(e);for(g=0;g<e;++g)m[g]=\"a[i\"+g+\"]\",v[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map((function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"})).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+m.join(\",\")+\",\"+v.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map((function(t){return\"shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"stride[\"+t+\"]\"})).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],bigint64:[],biguint64:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n){n=0;for(s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s])}for(var f=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\";case\"[object BigInt64Array]\":return\"bigint64\";case\"[object BigUint64Array]\":return\"biguint64\"}return Array.isArray(t)?\"array\":\"generic\"}(t),h=c[f];h.length<=o+1;)h.push(l(f,h.length-1));return(0,h[o+1])(t,e,r,n)}},{\"iota-array\":463,\"is-buffer\":465}],496:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074);e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),a=n.lo(t);e>t==t>0?a===-1>>>0?(r+=1,a=0):a+=1:0===a?(a=-1>>>0,r-=1):a-=1;return n.pack(a,r)}},{\"double-bits\":173}],497:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,f,h,p){if(p)T=p[0],k=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(f=(d=l(f,h,-o)).x))/2,m=(e-(h=d.y))/2,v=g*g/(r*r)+m*m/(a*a);v>1&&(r*=v=Math.sqrt(v),a*=v);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*m*m-x*g*g)/(y*m*m+x*g*g)));b==1/0&&(b=1);var _=b*r*m/a+(t+f)/2,w=b*-a*g/r+(e+h)/2,T=Math.asin(((e-w)/a).toFixed(9)),k=Math.asin(((h-w)/a).toFixed(9));(T=t<_?n-T:T)<0&&(T=2*n+T),(k=f<_?n-k:k)<0&&(k=2*n+k),u&&T>k&&(T-=2*n),!u&&k>T&&(k-=2*n)}if(Math.abs(k-T)>i){var M=k,A=f,S=h;k=T+i*(u&&k>T?1:-1);var E=s(f=_+r*Math.cos(k),h=w+a*Math.sin(k),r,a,o,0,u,A,S,[k,M,_,w])}var C=Math.tan((k-T)/4),L=4/3*r*C,I=4/3*a*C,P=[2*t-(t+L*Math.sin(T)),2*e-(e-I*Math.cos(T)),f+L*Math.sin(k),h-I*Math.cos(k),f,h];if(p)return P;E&&(P=P.concat(E));for(var z=0;z<P.length;){var O=l(P[z],P[z+1],o);P[z++]=O.x,P[z++]=O.y}return P}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,f=null,h=null,p=0,d=0,g=0,m=t.length;g<m;g++){var v=t[g],y=v[0];switch(y){case\"M\":l=v[1],u=v[2];break;case\"A\":(v=s(p,d,v[1],v[2],c(v[3]),v[4],v[5],v[6],v[7])).unshift(\"C\"),v.length>7&&(r.push(v.splice(0,7)),v.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),v=[\"C\",x,b,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(f=2*p-f,h=2*d-h):(f=p,h=d),v=o(p,d,f,h,v[1],v[2]);break;case\"Q\":f=v[1],h=v[2],v=o(p,d,v[1],v[2],v[3],v[4]);break;case\"L\":v=a(p,d,v[1],v[2]);break;case\"H\":v=a(p,d,v[1],d);break;case\"V\":v=a(p,d,p,v[1]);break;case\"Z\":v=a(p,d,l,u)}e=y,p=v[v.length-2],d=v[v.length-1],v.length>4?(n=v[v.length-4],i=v[v.length-3]):(n=p,i=d),r.push(v)}return r}},{}],498:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],f=0;f<s.length;++f){l=c,c=u,u=s[(f+1)%s.length];for(var h=e[l],p=e[c],d=e[u],g=new Array(3),m=0,v=new Array(3),y=0,x=0;x<3;++x)g[x]=h[x]-p[x],m+=g[x]*g[x],v[x]=d[x]-p[x],y+=v[x]*v[x];if(m*y>a){var b=i[c],_=1/Math.sqrt(m*y);for(x=0;x<3;++x){var w=(x+1)%3,T=(x+2)%3;b[x]+=_*(v[w]*g[T]-v[T]*g[w])}}}for(o=0;o<n;++o){b=i[o];var k=0;for(x=0;x<3;++x)k+=b[x]*b[x];if(k>a)for(_=1/Math.sqrt(k),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),f=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],f[c]=l[2][c]-l[0][c];var h=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;h[c]=u[d]*f[g]-u[g]*f[d],p+=h[c]*h[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)h[c]*=p;i[o]=h}return i}},{}],499:[function(t,e,r){\n",
       "/*\n",
       "object-assign\n",
       "(c) Sindre Sorhus\n",
       "@license MIT\n",
       "*/\n",
       "\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;function o(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map((function(t){return e[t]})).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach((function(t){n[t]=t})),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,s,l=o(t),c=1;c<arguments.length;c++){for(var u in r=Object(arguments[c]))i.call(r,u)&&(l[u]=r[u]);if(n){s=n(r);for(var f=0;f<s.length;f++)a.call(r,s[f])&&(l[s[f]]=r[s[f]])}}return l}},{}],500:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(f>0){var f=Math.sqrt(u+1);t[0]=.5*(o-l)/f,t[1]=.5*(s-n)/f,t[2]=.5*(r-a)/f,t[3]=.5*f}else{var h=Math.max(e,a,c);f=Math.sqrt(2*h-u+1);e>=h?(t[0]=.5*f,t[1]=.5*(i+r)/f,t[2]=.5*(s+n)/f,t[3]=.5*(o-l)/f):a>=h?(t[0]=.5*(r+i)/f,t[1]=.5*f,t[2]=.5*(l+o)/f,t[3]=.5*(s-n)/f):(t[0]=.5*(n+s)/f,t[1]=.5*(o+l)/f,t[2]=.5*f,t[3]=.5*(r-i)/f)}return t}},{}],501:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new f(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function f(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var h=f.prototype;h.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},h.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,f=0;f<3;++f)c+=r[l+4*f]*i[f];r[12+l]=-c}},h.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},h.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},h.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},h.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=l(u-=a*p,f-=o*p,h-=s*p);u/=d,f/=d,h/=d;var g=i[2],m=i[6],v=i[10],y=g*a+m*o+v*s,x=g*u+m*f+v*h,b=l(g-=y*a+x*u,m-=y*o+x*f,v-=y*s+x*h);g/=b,m/=b,v/=b;var _=u*e+a*r,w=f*e+o*r,T=h*e+s*r;this.center.move(t,_,w,T);var k=Math.exp(this.computedRadius[0]);k=Math.max(1e-4,k+n),this.radius.set(t,Math.log(k))},h.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],f=i[5],h=i[9],p=i[2],d=i[6],g=i[10],m=e*a+r*u,v=e*o+r*f,y=e*s+r*h,x=-(d*y-g*v),b=-(g*m-p*y),_=-(p*v-d*m),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),T=c(x,b,_,w);T>1e-6?(x/=T,b/=T,_/=T,w/=T):(x=b=_=0,w=1);var k=this.computedRotation,M=k[0],A=k[1],S=k[2],E=k[3],C=M*w+E*x+A*_-S*b,L=A*w+E*b+S*x-M*_,I=S*w+E*_+M*b-A*x,P=E*w-M*x-A*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,P=P*(w=Math.cos(e))-(C=C*w+P*x+L*_-I*b)*x-(L=L*w+P*b+I*x-C*_)*b-(I=I*w+P*_+C*b-L*x)*_}var O=c(C,L,I,P);O>1e-6?(C/=O,L/=O,I/=O,P/=O):(C=L=I=0,P=1),this.rotation.set(t,C,L,I,P)},h.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},h.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},h.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var f=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*f,l-n[6]*f,c-n[10]*f),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},h.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},h.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},h.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},h.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},h.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":500,\"filtered-vector\":242,\"gl-mat4/fromQuat\":282,\"gl-mat4/invert\":293,\"gl-mat4/lookAt\":294}],502:[function(t,e,r){\n",
       "/*!\n",
       " * pad-left <https://github.com/jonschlinkert/pad-left>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT license.\n",
       " */\n",
       "\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":541}],503:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach((function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach((function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t})),n=n.reverse(),r=r.map((function(e){return n.forEach((function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])})),e}))}));var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce((function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r}),\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],504:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":511}],505:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,(function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}})),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],506:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],507:[function(t,e,r){(function(t){(function(){\"use strict\";function r(t){if(\"string\"!=typeof t)throw new TypeError(\"Path must be a string. Received \"+JSON.stringify(t))}function n(t,e){for(var r,n=\"\",i=0,a=-1,o=0,s=0;s<=t.length;++s){if(s<t.length)r=t.charCodeAt(s);else{if(47===r)break;r=47}if(47===r){if(a===s-1||1===o);else if(a!==s-1&&2===o){if(n.length<2||2!==i||46!==n.charCodeAt(n.length-1)||46!==n.charCodeAt(n.length-2))if(n.length>2){var l=n.lastIndexOf(\"/\");if(l!==n.length-1){-1===l?(n=\"\",i=0):i=(n=n.slice(0,l)).length-1-n.lastIndexOf(\"/\"),a=s,o=0;continue}}else if(2===n.length||1===n.length){n=\"\",i=0,a=s,o=0;continue}e&&(n.length>0?n+=\"/..\":n=\"..\",i=2)}else n.length>0?n+=\"/\"+t.slice(a+1,s):n=t.slice(a+1,s),i=s-a-1;a=s,o=0}else 46===r&&-1!==o?++o:o=-1}return n}var i={resolve:function(){for(var e,i=\"\",a=!1,o=arguments.length-1;o>=-1&&!a;o--){var s;o>=0?s=arguments[o]:(void 0===e&&(e=t.cwd()),s=e),r(s),0!==s.length&&(i=s+\"/\"+i,a=47===s.charCodeAt(0))}return i=n(i,!a),a?i.length>0?\"/\"+i:\"/\":i.length>0?i:\".\"},normalize:function(t){if(r(t),0===t.length)return\".\";var e=47===t.charCodeAt(0),i=47===t.charCodeAt(t.length-1);return 0!==(t=n(t,!e)).length||e||(t=\".\"),t.length>0&&i&&(t+=\"/\"),e?\"/\"+t:t},isAbsolute:function(t){return r(t),t.length>0&&47===t.charCodeAt(0)},join:function(){if(0===arguments.length)return\".\";for(var t,e=0;e<arguments.length;++e){var n=arguments[e];r(n),n.length>0&&(void 0===t?t=n:t+=\"/\"+n)}return void 0===t?\".\":i.normalize(t)},relative:function(t,e){if(r(t),r(e),t===e)return\"\";if((t=i.resolve(t))===(e=i.resolve(e)))return\"\";for(var n=1;n<t.length&&47===t.charCodeAt(n);++n);for(var a=t.length,o=a-n,s=1;s<e.length&&47===e.charCodeAt(s);++s);for(var l=e.length-s,c=o<l?o:l,u=-1,f=0;f<=c;++f){if(f===c){if(l>c){if(47===e.charCodeAt(s+f))return e.slice(s+f+1);if(0===f)return e.slice(s+f)}else o>c&&(47===t.charCodeAt(n+f)?u=f:0===f&&(u=0));break}var h=t.charCodeAt(n+f);if(h!==e.charCodeAt(s+f))break;47===h&&(u=f)}var p=\"\";for(f=n+u+1;f<=a;++f)f!==a&&47!==t.charCodeAt(f)||(0===p.length?p+=\"..\":p+=\"/..\");return p.length>0?p+e.slice(s+u):(s+=u,47===e.charCodeAt(s)&&++s,e.slice(s))},_makeLong:function(t){return t},dirname:function(t){if(r(t),0===t.length)return\".\";for(var e=t.charCodeAt(0),n=47===e,i=-1,a=!0,o=t.length-1;o>=1;--o)if(47===(e=t.charCodeAt(o))){if(!a){i=o;break}}else a=!1;return-1===i?n?\"/\":\".\":n&&1===i?\"//\":t.slice(0,i)},basename:function(t,e){if(void 0!==e&&\"string\"!=typeof e)throw new TypeError('\"ext\" argument must be a string');r(t);var n,i=0,a=-1,o=!0;if(void 0!==e&&e.length>0&&e.length<=t.length){if(e.length===t.length&&e===t)return\"\";var s=e.length-1,l=-1;for(n=t.length-1;n>=0;--n){var c=t.charCodeAt(n);if(47===c){if(!o){i=n+1;break}}else-1===l&&(o=!1,l=n+1),s>=0&&(c===e.charCodeAt(s)?-1==--s&&(a=n):(s=-1,a=l))}return i===a?a=l:-1===a&&(a=t.length),t.slice(i,a)}for(n=t.length-1;n>=0;--n)if(47===t.charCodeAt(n)){if(!o){i=n+1;break}}else-1===a&&(o=!1,a=n+1);return-1===a?\"\":t.slice(i,a)},extname:function(t){r(t);for(var e=-1,n=0,i=-1,a=!0,o=0,s=t.length-1;s>=0;--s){var l=t.charCodeAt(s);if(47!==l)-1===i&&(a=!1,i=s+1),46===l?-1===e?e=s:1!==o&&(o=1):-1!==e&&(o=-1);else if(!a){n=s+1;break}}return-1===e||-1===i||0===o||1===o&&e===i-1&&e===n+1?\"\":t.slice(e,i)},format:function(t){if(null===t||\"object\"!=typeof t)throw new TypeError('The \"pathObject\" argument must be of type Object. Received type '+typeof t);return function(t,e){var r=e.dir||e.root,n=e.base||(e.name||\"\")+(e.ext||\"\");return r?r===e.root?r+n:r+t+n:n}(\"/\",t)},parse:function(t){r(t);var e={root:\"\",dir:\"\",base:\"\",ext:\"\",name:\"\"};if(0===t.length)return e;var n,i=t.charCodeAt(0),a=47===i;a?(e.root=\"/\",n=1):n=0;for(var o=-1,s=0,l=-1,c=!0,u=t.length-1,f=0;u>=n;--u)if(47!==(i=t.charCodeAt(u)))-1===l&&(c=!1,l=u+1),46===i?-1===o?o=u:1!==f&&(f=1):-1!==o&&(f=-1);else if(!c){s=u+1;break}return-1===o||-1===l||0===f||1===f&&o===l-1&&o===s+1?-1!==l&&(e.base=e.name=0===s&&a?t.slice(1,l):t.slice(s,l)):(0===s&&a?(e.name=t.slice(1,o),e.base=t.slice(1,l)):(e.name=t.slice(s,o),e.base=t.slice(s,l)),e.ext=t.slice(o,l)),s>0?e.dir=t.slice(0,s-1):a&&(e.dir=\"/\"),e},sep:\"/\",delimiter:\":\",win32:null,posix:null};i.posix=i,e.exports=i}).call(this)}).call(this,t(\"_process\"))},{_process:526}],508:[function(t,e,r){(function(t){(function(){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this)}).call(this,t(\"_process\"))},{_process:526}],509:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<32){for(var r=1,i=0;i<e;++i)for(var a=0;a<i;++a)if(t[i]<t[a])r=-r;else if(t[i]===t[a])return 0;return r}var o=n.mallocUint8(e);for(i=0;i<e;++i)o[i]=0;for(r=1,i=0;i<e;++i)if(!o[i]){var s=1;o[i]=1;for(a=t[i];a!==i;a=t[a]){if(o[a])return n.freeUint8(o),0;s+=1,o[a]=1}1&s||(r=-r)}return n.freeUint8(o),r};var n=t(\"typedarray-pool\")},{\"typedarray-pool\":595}],510:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":462,\"typedarray-pool\":595}],511:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var f=a;f<c.length;f++)l[c[f]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],512:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}var l=[];for(o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var f=0;f<2;++f)for(var h=a[f][r],p=0;p<h.length;++p){var d=h[p],g=d[1^f];n(e[t],e[r],e[s],e[g])>0&&(o=d,s=g,l=f)}return i||o&&c(o,l),s}function f(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],f=t,h=o[1],p=u(l,f,!0);if(n(e[l],e[f],e[h],e[p])<0)break;o.push(t),s=u(l,f)}return o}function h(t,e){return e[1]===e[e.length-1]}for(o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=f(o,p);h(0,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":132}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;var u=r[c];for(s=0;s<u.length;++s){var f=u[s];0==--a[f]&&o.push(f)}}var h=new Array(e.length),p=[];for(s=0;s<e.length;++s)if(i[s]){c=p.length;h[s]=c,p.push(e[s])}else h[s]=-1;var d=[];for(s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([h[g[0]],h[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":178}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var f=(e=r[1]).length,h=(t.length,n(t,e.length)),p=0;p<f;++p)if(h[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);var g=(d=d.filter((function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),f=o(l[0],a[1]),h=o(l[0],l[1]);n=s(n,s(s(c,u),s(f,h)))}return n[n.length-1]>0}))).length,m=new Array(g),v=new Array(g);for(p=0;p<g;++p){m[p]=p;var y=new Array(g),x=d[p].map((function(t){return e[t]})),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var T=(q=d[w]).length,k=0;k<T;++k){var M=b(e[q[k]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}v[p]=[_,p,y]}v.sort((function(t,e){return e[0]-t[0]}));for(p=0;p<g;++p){var A=(y=v[p])[1],S=y[2];for(w=0;w<g;++w)S[w]&&(m[w]=A)}var E=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g);for(p=0;p<g;++p)E[p].push(m[p]),E[m[p]].push(p);var C={},L=u(f,!1);for(p=0;p<g;++p)for(T=(q=d[p]).length,w=0;w<T;++w){var I=q[w],P=q[(w+1)%T],z=Math.min(I,P)+\":\"+Math.max(I,P);if(z in C){var O=C[z];E[O].push(p),E[p].push(O),L[I]=L[P]=!0}else C[z]=p}function D(t){for(var e=t.length,r=0;r<e;++r)if(!L[t[r]])return!1;return!0}var R=[],F=u(g,-1);for(p=0;p<g;++p)m[p]!==p||D(d[p])?F[p]=-1:(R.push(p),F[p]=0);r=[];for(;R.length>0;){var B=R.pop(),N=E[B];l(N,(function(t,e){return t-e}));var j,U=N.length,V=F[B];if(0===V){var q=d[B];j=[q]}for(p=0;p<U;++p){var H=N[p];if(!(F[H]>=0))if(F[H]=1^V,R.push(H),0===V)D(q=d[H])||(q.reverse(),j.push(q))}0===V&&r.push(j)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":513,\"edges-to-adjacency-list\":178,\"planar-dual\":512,\"point-in-big-polygon\":516,\"robust-sum\":553,\"two-product\":582,uniq:597}],515:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],516:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],f=u.length,h=f-1,p=0;p<f;h=p++){var d=u[h],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(m=l(a),function(t){return m(t[0],t[1])?0:1});var m;var v=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(v.slabs,v.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},f=Object.keys(e);for(r=0;r<f.length;++r){var h=e[f[r]];u[f[r]]=a(h)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":515,\"interval-tree-1d\":460,\"robust-orientation\":548,\"slab-decomposition\":565}],517:[function(t,e,r){\n",
       "/*\n",
       " * @copyright 2016 Sean Connelly (@voidqk), http://syntheti.cc\n",
       " * @license MIT\n",
       " * @preserve Project Home: https://github.com/voidqk/polybooljs\n",
       " */\n",
       "var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,f=a();function h(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return f.epsilon(t)},segments:function(t){var e=o(!0,f,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,f,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,f,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,f,t)},union:function(t,e){return h(t,e,n.selectUnion)},intersect:function(t,e){return h(t,e,n.selectIntersect)},difference:function(t,e){return h(t,e,n.selectDifference)},differenceRev:function(t,e){return h(t,e,n.selectDifferenceRev)},xor:function(t,e){return h(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":518,\"./lib/epsilon\":519,\"./lib/geojson\":520,\"./lib/intersecter\":521,\"./lib/segment-chainer\":523,\"./lib/segment-selector\":524}],518:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],519:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t)&&!(l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],f=e[1]-n[1],h=(s*f-l*u)/c,p=(a*f-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+h*a,e[1]+h*o]};return d.alongA=h<=-t?-2:h<t?-1:h-1<=-t?0:h-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],520:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function f(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(h(t.children[r]))}function h(t){for(var e=0;e<t.children.length;e++)f(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)f(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],521:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,(function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0}))}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition((function(r){var n,i,a,o,s,l;return(n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)||e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0}))}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var f=e.linesIntersect(o,s,c,u);if(!1===f){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var h=e.pointsSame(o,c),p=e.pointsSame(s,u);if(h&&p)return n;var d=!h&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(h)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===f.alongA&&(-1===f.alongB?l(t,c):0===f.alongB?l(t,f.pt):1===f.alongB&&l(t,u)),0===f.alongB&&(-1===f.alongA?l(n,o):0===f.alongA?l(n,f.pt):1===f.alongA&&l(n,s));return!1}for(var f=[];!a.isEmpty();){var h=a.getHead();if(r&&r.vert(h.pt[0]),h.isStart){r&&r.segmentNew(h.seg,h.primary);var p=c(h),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function m(){if(d){var t=u(h,d);if(t)return t}return!!g&&u(h,g)}r&&r.tempStatus(h.seg,!!d&&d.seg,!!g&&g.seg);var v,y=m();if(y){var x;if(t)(x=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below)&&(y.seg.myFill.above=!y.seg.myFill.above);else y.seg.otherFill=h.seg.myFill;r&&r.segmentUpdate(y.seg),h.other.remove(),h.remove()}if(a.getHead()!==h){r&&r.rewind(h.seg);continue}if(t)x=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below,h.seg.myFill.below=g?g.seg.myFill.above:i,h.seg.myFill.above=x?!h.seg.myFill.below:h.seg.myFill.below;else if(null===h.seg.otherFill)v=g?h.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:h.primary?o:i,h.seg.otherFill={above:v,below:v};r&&r.status(h.seg,!!d&&d.seg,!!g&&g.seg),h.other.status=p.insert(n.node({ev:h}))}else{var b=h.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!h.primary){var _=h.seg.myFill;h.seg.myFill=h.seg.otherFill,h.seg.otherFill=_}f.push(h.seg)}a.getHead().remove()}return r&&r.done(),f}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach((function(t){s(i(t.start,t.end,t),!0)})),r.forEach((function(t){s(i(t.start,t.end,t),!1)})),c(e,n)}}}},{\"./linked-list\":522}],522:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],523:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach((function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var f=(m=n[u])[0],h=(m[1],m[m.length-1]);m[m.length-2];if(e.pointsSame(f,a)){if(k(u,!0,!0))break}else if(e.pointsSame(f,o)){if(k(u,!0,!1))break}else if(e.pointsSame(h,a)){if(k(u,!1,!0))break}else if(e.pointsSame(h,o)&&k(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,m=n[p],v=g?m[0]:m[m.length-1],y=g?m[1]:m[m.length-2],x=g?m[m.length-1]:m[0],b=g?m[m.length-2]:m[1];return e.pointsCollinear(y,v,d)&&(g?(r&&r.chainRemoveHead(s.index,d),m.shift()):(r&&r.chainRemoveTail(s.index,d),m.pop()),v=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,v)&&(g?(r&&r.chainRemoveTail(s.index,v),m.pop()):(r&&r.chainRemoveHead(s.index,v),m.shift())),r&&r.chainClose(s.index),void i.push(m)):void(g?(r&&r.chainAddHead(s.index,d),m.unshift(d)):(r&&r.chainAddTail(s.index,d),m.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var T=n[_].length<n[w].length;s.matches_head?l.matches_head?T?(M(_),A(_,w)):(M(w),A(w,_)):A(w,_):l.matches_head?A(_,w):T?(M(_),A(w,_)):(M(w),A(_,w))}function k(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function M(t){r&&r.chainReverse(t),n[t].reverse()}function A(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}})),i}},{}],524:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach((function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})})),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],525:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,f=0,h=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],m=a[l],v=n[l];c+=g*g,u+=g*m,f+=m*m,h+=v*g,p+=v*m,d+=v*v}var y,x,b,_,w,T=Math.abs(c*f-u*u),k=u*p-f*h,M=u*h-c*p;if(k+M<=T)if(k<0)M<0&&h<0?(M=0,-h>=c?(k=1,y=c+2*h+d):y=h*(k=-h/c)+d):(k=0,p>=0?(M=0,y=d):-p>=f?(M=1,y=f+2*p+d):y=p*(M=-p/f)+d);else if(M<0)M=0,h>=0?(k=0,y=d):-h>=c?(k=1,y=c+2*h+d):y=h*(k=-h/c)+d;else{var A=1/T;y=(k*=A)*(c*k+u*(M*=A)+2*h)+M*(u*k+f*M+2*p)+d}else k<0?(b=f+p)>(x=u+h)?(_=b-x)>=(w=c-2*u+f)?(k=1,M=0,y=c+2*h+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*h)+M*(u*k+f*M+2*p)+d:(k=0,b<=0?(M=1,y=f+2*p+d):p>=0?(M=0,y=d):y=p*(M=-p/f)+d):M<0?(b=c+h)>(x=u+p)?(_=b-x)>=(w=c-2*u+f)?(M=1,k=0,y=f+2*p+d):y=(k=1-(M=_/w))*(c*k+u*M+2*h)+M*(u*k+f*M+2*p)+d:(M=0,b<=0?(k=1,y=c+2*h+d):h>=0?(k=0,y=d):y=h*(k=-h/c)+d):(_=f+p-u-h)<=0?(k=0,M=1,y=f+2*p+d):_>=(w=c-2*u+f)?(k=1,M=0,y=c+2*h+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*h)+M*(u*k+f*M+2*p)+d;var S=1-k-M;for(l=0;l<o.length;++l)s[l]=S*t[l]+k*e[l]+M*r[l];return y<0?0:y}},{}],526:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],f=!1,h=-1;function p(){f&&c&&(f=!1,c.length?u=c.concat(u):h=-1,u.length&&d())}function d(){if(!f){var t=l(p);f=!0;for(var e=u.length;e;){for(c=u,u=[];++h<e;)c&&c[h].run();h=-1,e=u.length}c=null,f=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function m(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||f||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=m,a.addListener=m,a.once=m,a.off=m,a.removeListener=m,a.removeAllListeners=m,a.emit=m,a.prependListener=m,a.prependOnceListener=m,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],527:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":325}],528:[function(t,e,r){(function(r){(function(){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,f=0,h=[];s=function(t){if(0===h.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout((function(){var t=h.slice(0);h.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout((function(){throw t}),0)}}),Math.round(r))}return h.push({handle:++f,callback:t,cancelled:!1}),f},l=function(t){for(var e=0;e<h.length;e++)h[e].handle===t&&(h[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":508}],529:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":80}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":83}],531:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":83,\"big-rat/mul\":92}],532:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":94}],533:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":117,\"compare-cell\":133,\"compare-oriented-cell\":134}],534:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,f=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,m,v=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),m=t.buffer({usage:\"static\",type:\"float\",data:h}),T(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:m,stride:24,offset:0},lineOffset:{buffer:m,stride:24,offset:8},capOffset:{buffer:m,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:h.length}),s(b,{update:T,draw:_,destroy:k,regl:t,gl:v,canvas:v.canvas,groups:x}),b;function b(t){t?T(t):null===t&&k(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach((function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)}))}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function T(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map((function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=f(e.scale),e.translateFract=f(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:v.drawingBufferWidth,height:v.drawingBufferHeight},e}}]),u):u})),e||r){var h=x.reduce((function(t,e,r){return t+(e?e.count:0)}),0),m=new Float64Array(2*h),_=new Uint8Array(4*h),w=new Float32Array(4*h);x.forEach((function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),m.set(r,2*i))}})),c(u(m)),p(f(m)),d(_),g(w)}}}function k(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),m.destroy()}};var h=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":70,\"color-normalize\":125,\"flatten-vertex-data\":244,\"object-assign\":499,\"pick-by-alias\":511,\"to-float32\":577,\"update-diff\":599}],535:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),f=t(\"to-float32\"),h=f.float32,p=f.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function m(t,e){if(!(this instanceof m))return new m(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=m.shaders.has(t)?m.shaders.get(t):m.shaders.set(t,m.createShaders(t)).get(t),this.update(e)}e.exports=m,m.dashMult=2,m.maxPatternLength=256,m.precisionThreshold=3e6,m.maxPoints=1e4,m.maxLines=2048,m.shaders=new d,m.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},m.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},m.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},m.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach((function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>m.precisionThreshold||e.scale[1]*e.viewport.height>m.precisionThreshold||\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=m.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))})),this},m.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach((function(t,f){var d=e.passes[f];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[f]=d={id:f,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},m.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,f<m.maxLines&&(d.depth=2*(m.maxLines-1-f%m.maxLines)/m.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var v,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),v=new Float64Array(2*y);for(var _=0;_<y;_++)v[2*_]=x[_],v[2*_+1]=b[_]}else v=l(t.positions,\"float64\"),y=d.count=Math.floor(v.length/2);var w=d.bounds=i(v,2);if(d.fill){for(var T=[],k={},M=0,A=0,S=0,E=d.count;A<E;A++){var C=v[2*A],L=v[2*A+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=v[2*M],L=v[2*M+1],k[A]=M):M=A,T[S++]=C,T[S++]=L}for(var I=c(T,d.hole||[]),P=0,z=I.length;P<z;P++)null!=k[I[P]]&&(I[P]=k[I[P]]);d.triangles=I}var O=new Float64Array(v);u(O,2,w);var D=new Float64Array(2*y+6);d.close?v[0]===v[2*y-2]&&v[1]===v[2*y-1]?(D[0]=O[2*y-4],D[1]=O[2*y-3]):(D[0]=O[2*y-2],D[1]=O[2*y-1]):(D[0]=O[0],D[1]=O[1]),D.set(O,2),d.close?v[0]===v[2*y-2]&&v[1]===v[2*y-1]?(D[2*y+2]=O[2],D[2*y+3]=O[3],d.count-=1):(D[2*y+2]=O[0],D[2*y+3]=O[1],D[2*y+4]=O[2],D[2*y+5]=O[3]):(D[2*y+2]=O[2*y-2],D[2*y+3]=O[2*y-1],D[2*y+4]=O[2*y-2],D[2*y+5]=O[2*y-1]),d.positionBuffer(h(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*m.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*m.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var Q=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var $=0;$<J;$++){var tt=n(K[$],\"uint8\");Q.set(tt,4*$)}Q.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)Q.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:Q})}}else e.passes[f]=null})),t.length<this.passes.length){for(var f=t.length;f<this.passes.length;f++){var d=this.passes[f];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var v=[],y=0;y<this.passes.length;y++)null!==this.passes[y]&&v.push(this.passes[y]);return this.passes=v,this}},m.prototype.destroy=function(){return this.passes.forEach((function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()})),this.passes.length=0,this}},{\"array-bounds\":70,\"array-normalize\":71,\"color-normalize\":125,earcut:177,\"es6-weak-map\":233,\"flatten-vertex-data\":244,glslify:536,\"object-assign\":499,\"parse-rect\":504,\"pick-by-alias\":511,\"to-float32\":577}],536:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],537:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){if(\"undefined\"==typeof Symbol||!(Symbol.iterator in Object(t)))return;var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||a(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function i(t){return function(t){if(Array.isArray(t))return o(t)}(t)||function(t){if(\"undefined\"!=typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}(t)||a(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function a(t,e){if(t){if(\"string\"==typeof t)return o(t,e);var r=Object.prototype.toString.call(t).slice(8,-1);return\"Object\"===r&&t.constructor&&(r=t.constructor.name),\"Map\"===r||\"Set\"===r?Array.from(t):\"Arguments\"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?o(t,e):void 0}}function o(t,e){(null==e||e>t.length)&&(e=t.length);for(var r=0,n=new Array(e);r<e;r++)n[r]=t[r];return n}var s=t(\"color-normalize\"),l=t(\"array-bounds\"),c=t(\"color-id\"),u=t(\"@plotly/point-cluster\"),f=t(\"object-assign\"),h=t(\"glslify\"),p=t(\"pick-by-alias\"),d=t(\"update-diff\"),g=t(\"flatten-vertex-data\"),m=t(\"is-iexplorer\"),v=t(\"to-float32\"),y=t(\"parse-rect\"),x=b;function b(t,e){var r=this;if(!(this instanceof b))return new b(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=m,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),f(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{constPointSize:!!e.constPointSize,pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=f({},o);s.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pointSizeScale;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=f({},o);l.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pointSizeScale;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),m&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}b.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},b.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},b.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach((function(e,r){t.drawItem(r)}));return this},b.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},b.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,c=e.count;this.regl;if(!a)return r?[f({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[f({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var u=[],h=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(c),g=0;g<r.length;g++){var m=r[g];d[m]=p?p[m]:1}l.subdata(d)}for(var v=h.length;v--;){var y=n(h[v],2),x=y[0],b=y[1];u.push(f({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return u},b.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,o=this.regl,s=this.maxSize,c=this.maxColors,h=this.palette;this.groups=i=r.map((function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=p(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:o.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=f({},b.defaults,e)),e.positions&&!(\"marker\"in e)&&(e.marker=n.marker,delete n.marker),e.marker&&!(\"positions\"in e)&&(e.positions=n.positions,delete n.positions);var m=0,x=0;if(d(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=b.defaults.size),m+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=b.defaults.borderSize),m+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=b.defaults.color),e=t.updateColor(e),x++,e},borderColor:function(e,r){return null==e&&(e=b.defaults.borderColor),e=t.updateColor(e),x++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,s=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:o.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:o.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=g(t,\"float64\");var c=e.count=Math.floor(t.length/2),f=e.bounds=c?l(t,2):null;if(r.range||e.range||(delete e.range,r.range=f),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||c>n)?e.tree=u(t,{bounds:f}):n&&n.length&&(e.tree=n),e.tree){var h={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(h):e.elements=o.elements(h)}return i({data:v.float(t),usage:\"dynamic\"}),a({data:v.fract(t),usage:\"dynamic\"}),s({data:new Uint8Array(c),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach((function(t){return t&&t.destroy&&t.destroy()})),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],s=0,l=Math.min(e.length,r.count);s<l;s++){var c=t.addMarker(e[s]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][s]=1}for(var u=0;u<a.length;u++)if(a[u]){var f={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](f):i[u]=o.buffer(f),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=v.fract(e.scale),e.translateFract=v.fract(e.translate),t},viewport:function(t){return y(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),m){var _=n,w=_.count,T=_.size,k=_.borderSize,M=_.sizeBuffer,A=new Uint8Array(2*w);if(T.length||k.length)for(var S=0;S<w;S++)A[2*S]=Math.round(255*(null==T[S]?T:T[S])/s),A[2*S+1]=Math.round(255*(null==k[S]?k:k[S])/s);M({data:A,usage:\"dynamic\"})}if(x){var E,C=n,L=C.count,I=C.color,P=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(I.length||P.length){E=new Uint8Array(8*L);for(var O=0;O<L;O++){var D=I[O];E[8*O]=h[4*D],E[8*O+1]=h[4*D+1],E[8*O+2]=h[4*D+2],E[8*O+3]=h[4*D+3];var R=P[O];E[8*O+4]=h[4*R],E[8*O+5]=h[4*R+1],E[8*O+6]=h[4*R+2],E[8*O+7]=h[4*R+3]}}}else if(I.length||P.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=I[F]&&(E[4*F]=I[F]%c,E[4*F+1]=Math.floor(I[F]/c)),null!=P[F]&&(E[4*F+2]=P[F]%c,E[4*F+3]=Math.floor(P[F]/c))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n}))}},b.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},b.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var a=[];if(Array.isArray(t))for(var o=0;o<t.length;o+=4)a.push(t.slice(o,o+4));else for(var l=0;l<t.length;l+=4)a.push(t.subarray(l,l+4));t=a}for(var u=0;u<t.length;u++){var f=t[u];f=s(f,\"uint8\");var h=c(f,!1);if(null==e[h]){var p=r.length;e[h]=Math.floor(p/4),r[p]=f[0],r[p+1]=f[1],r[p+2]=f[2],r[p+3]=f[3]}i[u]=e[h]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},b.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},b.prototype.destroy=function(){return this.groups.forEach((function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach((function(t){return t&&t.destroy&&t.destroy()})),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()})),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach((function(t){return t&&t.destroy&&t.destroy()})),this};var _=t(\"object-assign\");e.exports=function(t,e){var r=new x(t,e),n=r.render.bind(r);return _(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"@plotly/point-cluster\":57,\"array-bounds\":70,\"color-id\":123,\"color-normalize\":125,\"flatten-vertex-data\":244,glslify:538,\"is-iexplorer\":466,\"object-assign\":499,\"parse-rect\":504,\"pick-by-alias\":511,\"to-float32\":577,\"update-diff\":599}],538:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],539:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function f(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function h(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o((function(){e.draw(),e.dirty=!0,e.planned=null}))):(this.draw(),this.dirty=!0,o((function(){e.dirty=!1}))),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,m=s.count,v=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=v/g,w=y/g;s.passes=[];for(var T=0;T<g;T++)for(var k=0;k<g;k++)if((s.diagonal||k!==T)&&(s.upper||!(T>k))&&(s.lower||!(T<k))){var M=f(s.id,T,k),A=this.passes[M]||(this.passes[M]={});if(o.data&&(o.transpose?A.positions={x:{buffer:s.buffer,offset:k,count:m,stride:g},y:{buffer:s.buffer,offset:T,count:m,stride:g}}:A.positions={x:{buffer:s.buffer,offset:k*m,count:m},y:{buffer:s.buffer,offset:T*m,count:m}},A.bounds=h(s.bounds,T,k)),o.domain||o.viewport||o.data){var S=d?h(s.padding,T,k):s.padding;if(s.domain){var E=h(s.domain,T,k),C=E[0],L=E[1],I=E[2],P=E[3];A.viewport=[x+C*v+S[0],b+L*y+S[1],x+I*v-S[2],b+P*y-S[3]]}else A.viewport=[x+k*_+_*S[0],b+T*w+w*S[1],x+(k+1)*_-_*S[2],b+(T+1)*w-w*S[3]]}o.color&&(A.color=s.color),o.size&&(A.size=s.size),o.marker&&(A.marker=s.marker),o.borderSize&&(A.borderSize=s.borderSize),o.borderColor&&(A.borderColor=s.borderColor),o.opacity&&(A.opacity=s.opacity),o.range&&(A.range=n?h(s.range,T,k):s.range||A.bounds),s.passes.push(M)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],f=u.passes,h=u.passOffset;f=f.map((function(t,e){n[h+e]=c}))}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach((function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()})),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":70,\"array-range\":72,\"flatten-vertex-data\":244,\"parse-rect\":504,\"pick-by-alias\":511,raf:528,\"regl-scatter2d\":537}],540:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.createREGL=n()}(this,(function(){function t(t,e){this.id=V++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,f=!1,h=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(h=s.onDone),\"profile\"in s&&(f=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),a.width=r*e,a.height=r*n,U(a.style,{width:e+\"px\",height:n+\"px\"})}var i,a=document.createElement(\"canvas\");return U(a.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(a),t===document.body&&(a.style.position=\"absolute\",U(t.style,{margin:0,padding:0})),t!==document.body&&\"function\"==typeof ResizeObserver?(i=new ResizeObserver((function(){setTimeout(n)}))).observe(t):window.addEventListener(\"resize\",n,!1),n(),{canvas:a,onDestroy:function(){i?i.disconnect():window.removeEventListener(\"resize\",n),t.removeChild(a)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}void 0===t.premultipliedAlpha&&(t.premultipliedAlpha=!0),o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:f,onDone:h,onDestroy:p}:(p(),h(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,(function(){return[]}));return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||X(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|K[Object.prototype.toString.call(t)]}function f(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function h(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=et(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=tt(e,i,t.dtype),r),o?t.persistentData=e:Y.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,f(i=Y.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:Y.freeType(i)):X(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=tt(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:Y.freeType(e))}else if(X(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,m=0;1===i.length?(p=i[0],d=1,g=c[0],m=0):2===i.length&&(p=i[0],d=i[1],g=c[0],m=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,h(i=Y.allocType(t.dtype,p*d),e.data,p,d,g,m,s),a(t,i,r),o?t.persistentData=i:Y.freeType(i)}else e instanceof ArrayBuffer&&(t.dtype=5121,t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e))))}function s(r){e.bufferCount--,n(r),t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach((function(e){t+=p[e].stats.size})),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||X(e)||l(e)||e instanceof ArrayBuffer?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=Q[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),m.bind(),i?o(m,i,n,s,c,d):(a&&t.bufferData(m.type,a,n),m.dtype=s||5121,m.usage=n,m.dimension=c,m.byteLength=a),r.profile&&(m.stats.size=m.byteLength*rt[m.dtype]),g}e.bufferCount++;var m=new i(a);return p[m.id]=m,c||g(n),g._reglType=\"buffer\",g._buffer=m,g.subdata=function(e,r){var n,i=0|(r||0);if(m.bind(),X(e)||e instanceof ArrayBuffer)t.bufferSubData(m.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=Y.allocType(m.dtype,e.length);f(a,e),t.bufferSubData(m.type,i,a),Y.freeType(a)}else(Array.isArray(e[0])||X(e[0]))&&(n=et(e),a=tt(e,n,m.dtype),t.bufferSubData(m.type,i,a),Y.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?m.dtype:u(e.data),h(n=Y.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(m.type,i,n),Y.freeType(n)}return g},r.profile&&(g.stats=m.stats),g.destroy=function(){s(m)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){Z(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){Z(p).forEach((function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)}))},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){var f;if(n.buffer.bind(),i?((f=u)||X(i)&&(!l(i)||X(i.data))||(f=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,f,3)):(t.bufferData(34963,c,a),n.buffer.dtype=f||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c),f=u,!u){switch(n.buffer.dtype){case 5121:case 5120:f=5121;break;case 5123:case 5122:f=5123;break;case 5125:case 5124:f=5125}n.buffer.dtype=f}n.type=f,0>(i=s)&&(i=n.buffer.byteLength,5123===f?i>>=1:5125===f&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var f=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),f.primType=4,f.vertCount=0|t,f.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,h=0;Array.isArray(t)||X(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=nt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(h=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===h||5122===h?o*=2:5125!==h&&5124!==h||(o*=4))),a(f,e,r,n,i,o,h)}else c(),f.primType=4,f.vertCount=0,f.type=5121;return s}var c=r.create(null,34963,!0),f=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=f,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(f)},s},createStream:function(t){var e=f.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){f.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){Z(s).forEach(o)}}}function g(t){for(var e=Y.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{it[0]=t[r];var n=(a=at[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function m(t){return Array.isArray(t)||X(t)}function v(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!m(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=gt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),Y.freeType(e)):t.data=e}function T(t,e,r,n,i,a){if(t=\"undefined\"!=typeof vt[t]?vt[t]:lt[t]*mt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function k(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=G[r],t.format=at[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in W&&(t.compressed=!0),r=!0),!a&&r?t.channels=lt[t.format]:a&&!r&&t.channels!==st[t.format]&&(t.format=t.internalformat=st[t.channels])}}function f(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function h(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(X(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=Y.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,f,h=r.stride;3===a.length?(c=a[2],f=h[2]):f=c=1,o=a[0],s=a[1],a=h[0],h=h[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=st[c],t.needsFree=!0,o=f,r=r.offset,c=t.width,f=t.height,s=t.channels;for(var p=Y.allocType(36193===t.type?5126:t.type,c*f*s),d=0,v=0;v<f;++v)for(var T=0;T<c;++T)for(var k=0;k<s;++k)p[d++]=n[a*T+h*v+o*k+r];w(t,p)}else if(b(r)===ct||b(r)===ut||b(r)===ft)b(r)===ct||b(r)===ut?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===pt)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===dt)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,h=t.channels,h=m(r[0][0])?h||r[0][0].length:h||1,o=J.shape(r),c=1,f=0;f<o.length;++f)c*=o[f];c=Y.allocType(36193===t.type?5126:t.type,c),J.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=h,t.format=t.internalformat=st[h],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,h=e.type,p=e.width,d=e.height;f(e),s?t.texSubImage2D(r,o,i,a,u,h,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,h,l)}function v(){return gt.pop()||new h}function k(t){t.needsFree&&Y.freeType(t.data),h.call(t),gt.push(t)}function M(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function A(t,e,r){var n=t.images[0]=v();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=v(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,h=o.internalformat,p=o.format,d=o.type,g=o.width,m=o.height;f(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,h,g,m,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,m,0)):t.texImage2D(s,l,p,g,m,0,p,d,u||null)}}function C(){var t=mt.pop()||new M;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&k(e[r]),e[r]=null;mt.push(t)}function I(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function P(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=ot.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=j[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function O(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new I,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=bt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),bt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete yt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},j={nearest:9728,linear:9729},V=U({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},j),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},G={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},W={};e.ext_srgb&&(G.srgb=35904,G.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(U(G,{depth:6402,\"depth stencil\":34041}),U(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&U(W,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&U(W,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&U(W,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(W[\"rgb etc1\"]=36196);var Q=Array.prototype.slice.call(t.getParameter(34467));Object.keys(W).forEach((function(t){var e=W[t];0<=Q.indexOf(e)&&(G[t]=e)}));var $=Object.keys(G);r.textureFormats=$;var tt=[];Object.keys(G).forEach((function(t){tt[G[t]]=t}));var et=[];Object.keys(H).forEach((function(t){et[H[t]]=t}));var rt=[];Object.keys(j).forEach((function(t){rt[j[t]]=t}));var nt=[];Object.keys(V).forEach((function(t){nt[V[t]]=t}));var it=[];Object.keys(N).forEach((function(t){it[N[t]]=t}));var at=$.reduce((function(t,r){var n=G[r];return 6409===n||6406===n||6409===n||6410===n||6402===n||34041===n||e.ext_srgb&&(35904===n||35906===n)?t[n]=n:32855===n||0<=r.indexOf(\"rgba\")?t[n]=6408:t[n]=6407,t}),{}),gt=[],mt=[],vt=0,yt={},xt=r.maxTextureUnits,bt=Array(xt).map((function(){return null}));return U(O.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<xt;++r){var n=bt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}bt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(yt).forEach((function(e){t+=yt[e].stats.size})),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;I.call(r);var a=C();return\"number\"==typeof t?A(a,0|t,\"number\"==typeof e?0|e:0|t):t?(P(r,t),S(a,t)):A(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=T(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new O(3553);return yt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=v();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),k(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l=0;i.mipmask>>l;++l){var c=a>>l,u=s>>l;if(!c||!u)break;t.texImage2D(3553,l,i.format,c,u,0,i.format,i.type,null)}return R(),o.profile&&(i.stats.size=T(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function f(t,e,r,n,i,a){var s,l=h.texInfo;for(I.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(P(l,t),u(h,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],h),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)A(g[s],t,t);for(c(h,g[0]),h.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,h.internalformat=g[0].internalformat,f.width=g[0].width,f.height=g[0].height,D(h),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(h.stats.size=T(h.internalformat,h.type,f.width,f.height,l.genMipmaps,!0)),f.format=tt[h.internalformat],f.type=et[h.type],f.mag=rt[l.magFilter],f.min=nt[l.minFilter],f.wrapS=it[l.wrapS],f.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return f}var h=new O(34067);yt[h.id]=h,a.cubeCount++;var g=Array(6);return f(e,r,n,i,s,l),f.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=v();return c(a,h),a.width=0,a.height=0,p(a,e),a.width=a.width||(h.width>>i)-r,a.height=a.height||(h.height>>i)-n,D(h),d(a,34069+t,r,n,i),R(),k(a),f},f.resize=function(e){if((e|=0)!==h.width){f.width=h.width=e,f.height=h.height=e,D(h);for(var r=0;6>r;++r)for(var n=0;h.mipmask>>n;++n)t.texImage2D(34069+r,n,h.format,e>>n,e>>n,0,h.format,h.type,null);return R(),o.profile&&(h.stats.size=T(h.internalformat,h.type,f.width,f.height,!1,!0)),f}},f._reglType=\"textureCube\",f._texture=h,o.profile&&(f.stats=h.stats),f.destroy=function(){h.decRef()},f},clear:function(){for(var e=0;e<xt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),bt[e]=null;Z(yt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<xt;++e){var r=bt[e];r&&(r.bindCount=0,r.unit=-1,bt[e]=null)}Z(yt).forEach((function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)}))}}}function M(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)||\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function f(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function h(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=T++,k[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function m(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete k[e.id]}function v(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",m=\"uint8\",y=1,x=null,w=null,T=null,k=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(m=t.colorType,!p)&&(\"half float\"===m||\"float16\"===m?d=\"rgba16f\":\"float\"!==m&&\"float32\"!==m||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(k=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(T=t.depthStencil,c=s=!1))):a=o=1;var M=null,A=null,S=null,E=null;if(Array.isArray(i))M=i.map(u);else if(i)M=[u(i)];else for(M=Array(y),i=0;i<y;++i)M[i]=f(a,o,p,d,m);for(a=a||M[0].width,o=o||M[0].height,x?A=u(x):s&&!c&&(A=f(a,o,k,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=f(a,o,!1,\"stencil\",\"uint8\")),T?E=u(T):!x&&!w&&c&&s&&(E=f(a,o,k,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<M.length;++i)l(M[i]),M[i]&&M[i].texture&&(c=bt[M[i].texture._texture.format]*_t[M[i].texture._texture.type],null===s&&(s=c));return l(A),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=M,n.depthAttachment=A,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=M.map(h),r.depth=h(A),r.stencil=h(S),r.depthStencil=h(E),r.width=n.width,r.height=n.height,v(n),r}var n=new d;return a.framebufferCount++,r(t,e),U(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,v(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){m(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var T=0,k={};return U(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return U(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),U(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach((function(t){t.destroy()}))}})},clear:function(){Z(k).forEach(m)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,Z(k).forEach((function(e){e.framebuffer=t.createFramebuffer(),v(e)}))}})}function A(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n,i){function a(){this.id=++c,this.attributes=[];var t=e.oes_vertex_array_object;this.vao=t?t.createVertexArrayOES():null,u[this.id]=this,this.buffers=[]}var o=r.maxAttributes,s=Array(o);for(r=0;r<o;++r)s[r]=new A;var c=0,u={},f={Record:A,scope:{},state:s,currentVAO:null,targetVAO:null,restore:e.oes_vertex_array_object?function(){e.oes_vertex_array_object&&Z(u).forEach((function(t){t.refresh()}))}:function(){},createVAO:function(t){function e(t){for(var n=0;n<r.buffers.length;++n)r.buffers[n].destroy();r.buffers.length=0,(n=r.attributes).length=t.length;for(var a=0;a<t.length;++a){var o=t[a],s=n[a]=new A;Array.isArray(o)||X(o)||l(o)?(o=i.create(o,34962,!1,!0),s.buffer=i.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1,r.buffers.push(o)):i.getBuffer(o)?(s.buffer=i.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1):i.getBuffer(o.buffer)?(s.buffer=i.getBuffer(o.buffer),s.size=0|(+o.size||s.buffer.dimension),s.normalized=!!o.normalized||!1,s.type=\"type\"in o?Q[o.type]:s.buffer.dtype,s.offset=0|(o.offset||0),s.stride=0|(o.stride||0),s.divisor=0|(o.divisor||0),s.state=1):\"x\"in o&&(s.x=+o.x||0,s.y=+o.y||0,s.z=+o.z||0,s.w=+o.w||0,s.state=2)}return r.refresh(),e}var r=new a;return n.vaoCount+=1,e.destroy=function(){r.destroy()},e._vao=r,e._reglType=\"vao\",e(t)},getVAO:function(t){return\"function\"==typeof t&&t._vao?t._vao:null},destroyBuffer:function(e){for(var r=0;r<s.length;++r){var n=s[r];n.buffer===e&&(t.disableVertexAttribArray(r),n.buffer=null)}},setVAO:e.oes_vertex_array_object?function(t){if(t!==f.currentVAO){var r=e.oes_vertex_array_object;t?r.bindVertexArrayOES(t.vao):r.bindVertexArrayOES(null),f.currentVAO=t}}:function(r){if(r!==f.currentVAO){if(r)r.bindAttrs();else for(var n=e.angle_instanced_arrays,i=0;i<s.length;++i){var a=s[i];a.buffer?(t.enableVertexAttribArray(i),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offfset),n&&n.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}f.currentVAO=r}},clear:e.oes_vertex_array_object?function(){Z(u).forEach((function(t){t.destroy()}))}:function(){}};return a.prototype.bindAttrs=function(){for(var r=e.angle_instanced_arrays,n=this.attributes,i=0;i<n.length;++i){var a=n[i];a.buffer?(t.enableVertexAttribArray(i),t.bindBuffer(34962,a.buffer.buffer),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offset),r&&r.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}for(r=n.length;r<o;++r)t.disableVertexAttribArray(r)},a.prototype.refresh=function(){var t=e.oes_vertex_array_object;t&&(t.bindVertexArrayOES(this.vao),this.bindAttrs(),f.currentVAO=this)},a.prototype.destroy=function(){if(this.vao){var t=e.oes_vertex_array_object;this===f.currentVAO&&(f.currentVAO=null,t.bindVertexArrayOES(null)),t.deleteVertexArrayOES(this.vao),this.vao=null}u[this.id]&&(delete u[this.id],--n.vaoCount)},f}function E(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s,l){var c;c=o(35632,r.fragId);var u=o(35633,r.vertId);if(s=r.program=t.createProgram(),t.attachShader(s,c),t.attachShader(s,u),l)for(c=0;c<l.length;++c)u=l[c],t.bindAttribLocation(s,u[0],u[1]);t.linkProgram(s),u=t.getProgramParameter(s,35718),n.profile&&(r.stats.uniformsCount=u);var f=r.uniforms;for(c=0;c<u;++c)if(l=t.getActiveUniform(s,c))if(1<l.size)for(var h=0;h<l.size;++h){var p=l.name.replace(\"[0]\",\"[\"+h+\"]\");a(f,new i(p,e.id(p),t.getUniformLocation(s,p),l))}else a(f,new i(l.name,e.id(l.name),t.getUniformLocation(s,l.name),l));for(u=t.getProgramParameter(s,35721),n.profile&&(r.stats.attributesCount=u),r=r.attributes,c=0;c<u;++c)(l=t.getActiveAttrib(s,c))&&a(r,new i(l.name,e.id(l.name),t.getAttribLocation(s,l.name),l))}var c={},u={},f={},h=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return h.forEach((function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)})),t},r.getMaxAttributesCount=function(){var t=0;return h.forEach((function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)})),t}),{clear:function(){var e=t.deleteShader.bind(t);Z(c).forEach(e),c={},Z(u).forEach(e),u={},h.forEach((function(e){t.deleteProgram(e.program)})),h.length=0,f={},r.shaderCount=0},program:function(t,e,n,i){var a=f[e];a||(a=f[e]={});var o=a[t];return o&&!i?o:(e=new s(e,t),r.shaderCount++,l(e,n,i),o||(a[t]=e),h.push(e),e)},restore:function(){c={},u={};for(var t=0;t<h.length;++t)l(h[t],null,h[t].attributes.map((function(t){return[t.location,t.name]})))},shader:o,frag:-1,vert:-1}}function C(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return X(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},(function(){r=s(t)})),r}(t):s(t)}}function L(t){return Array.prototype.slice.call(t)}function I(t){return L(t).join(\"\")}function P(){function t(){var t=[],e=[];return U((function(){t.push.apply(t,L(arguments))}),{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,L(arguments)),t.push(\";\")),n},toString:function(){return I([0<e.length?\"var \"+e.join(\",\")+\";\":\"\",I(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return U((function(){r.apply(r,L(arguments))}),{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=U(a,{arg:n,toString:function(){return I([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=I(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return U(r,{then:function(){return r.apply(r,L(arguments)),this},else:function(){return n.apply(n,L(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),I([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach((function(e){t.push('\"',e,'\":',o[e].toString(),\",\")})),t.push(\"}\");var e=I(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function z(t){return Array.isArray(t)||X(t)||l(t)}function O(t){return t.sort((function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1}))}function D(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function R(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function F(t){return new D(!1,!1,!1,t)}function B(t,e){var r=t.type;return 0===r?new D(!0,1<=(r=t.data.length),2<=r,e):4===r?new D((r=t.data).thisDep,r.contextDep,r.propDep,e):new D(3===r,2===r,1===r,e)}function N(t,e,r,n,i,o,s,l,c,u,f,h,p,d,g){function v(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=v(t);rt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=v(t);rt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach((function(t){a[t]=n.def(i,\".\",t)}));var o=t.next={},s=t.current={};Object.keys(at).forEach((function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))}));var l=t.constants={};Object.keys(st).forEach((function(t){l[t]=n.def(JSON.stringify(st[t]))})),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),F((function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r}))):F((function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"}))}if(\"framebuffer\"in n){var a=n.framebuffer;return B(a,(function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r}))}return null}function w(t,r,n){function i(t){if(t in a){var r=e.id(a[t]);return(t=F((function(){return r}))).id=r,t}if(t in o){var n=o[t];return B(n,(function(t,e){var r=t.invoke(e,n);return e.def(t.shared.strings,\".id(\",r,\")\")}))}return null}var a=t.static,o=t.dynamic,s=i(\"frag\"),l=i(\"vert\"),c=null;return R(s)&&R(l)?(c=f.program(l.id,s.id,null,n),t=F((function(t,e){return t.link(c)}))):t=new D(s&&s.thisDep||l&&l.thisDep,s&&s.contextDep||l&&l.contextDep,s&&s.propDep||l&&l.propDep,(function(t,e){var r,n,i=t.shared.shader;return r=s?s.append(t,e):e.def(i,\".\",\"frag\"),n=l?l.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")})),{frag:s,vert:l,progVar:t,program:c}}function T(t,e){function r(t,e){if(t in n){var r=0|n[t];return F((function(t,n){return e&&(t.OFFSET=r),r}))}if(t in i){var o=i[t];return B(o,(function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n}))}return e&&a?F((function(t,e){return t.OFFSET=\"0\",0})):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;z(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=F((function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null}));return e.value=t,e}if(\"elements\"in i){var r=i.elements;return B(r,(function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o}))}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return F((function(e,r){return nt[t]}))}if(\"primitive\"in i){var e=i.primitive;return B(e,(function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")}))}return a?R(a)?a.value?F((function(t,e){return e.def(t.ELEMENTS,\".primType\")})):F((function(){return 4})):new D(a.thisDep,a.contextDep,a.propDep,(function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)})):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return F((function(){return t}))}if(\"count\"in i){var e=i.count;return B(e,(function(t,r){return t.invoke(r,e)}))}return a?R(a)?a?s?new D(s.thisDep,s.contextDep,s.propDep,(function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)})):F((function(t,e){return e.def(t.ELEMENTS,\".vertCount\")})):F((function(){return-1})):new D(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,(function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")})):null}(),instances:r(\"instances\",!1),offset:s}}function k(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach((function(t){var r=n[t],a=e.id(t),s=new Z;if(z(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:wt.forEach((function(t,e){e<l.length&&(s[t]=l[e])}))}else{var c=z(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,f=0|r.stride,h=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=Q[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=h,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=f,s.divisor=r}o[t]=F((function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach((function(t){n[t]=s[t]})),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n}))})),Object.keys(a).forEach((function(t){var e=a[t];o[t]=B(e,(function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=t.constants,s=a.isBufferArgs,l=(a=a.buffer,{isStream:r.def(!1)}),c=new Z;c.state=1,Object.keys(c).forEach((function(t){l[t]=r.def(\"\"+c[t])}));var u=l.buffer,f=l.type;return r(\"if(\",s,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",a,\".createStream(\",34962,\",\",i,\");\",f,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",f,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[wt[0]],\"=\",i,\".constant;\",wt.slice(1).map((function(t){return l[t]})).join(\"=\"),\"=0;\",\"}else{\",wt.map((function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"})).join(\"\"),\"}}else{\",\"if(\",s,\"(\",i,\".buffer)){\",u,\"=\",a,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\".buffer);\",\"}\",f,'=\"type\" in ',i,\"?\",o.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",a,\".destroyStream(\",u,\");\",\"}\"),l}))})),o}function M(t,e,n,i,o){function s(t){var e=c[t];e&&(h[t]=e)}var l=function(t,e){if(\"string\"==typeof(r=t.static).frag&&\"string\"==typeof r.vert){if(0<Object.keys(e.dynamic).length)return null;var r=e.static,n=Object.keys(r);if(0<n.length&&\"number\"==typeof r[n[0]]){for(var i=[],a=0;a<n.length;++a)i.push([0|r[n[a]],n[a]]);return i}}return null}(t,e),c=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new D(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,(function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]}))}if(t in a){var c=a[t];return t=B(c,(function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]})),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new D(e.thisDep,e.contextDep,e.propDep,(function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]})):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new D(t.thisDep,t.contextDep,t.propDep,(function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r}))}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,d=_(t)),f=T(t),h=function(t,e){var r=t.static,n=t.dynamic,i={};return rt.forEach((function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=F((function(){return s}))}else if(t in n){var l=n[t];i[o]=B(l,(function(t,e){return a(t,e,t.invoke(e,l))}))}}var o=v(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e((function(t){return t}),(function(t,e,r){return r}));case\"depth.func\":return e((function(t){return Mt[t]}),(function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")}));case\"depth.range\":return e((function(t){return t}),(function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]}));case\"blend.func\":return e((function(t){return[kt[\"srcRGB\"in t?t.srcRGB:t.src],kt[\"dstRGB\"in t?t.dstRGB:t.dst],kt[\"srcAlpha\"in t?t.srcAlpha:t.src],kt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]}),(function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]}));case\"blend.equation\":return e((function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0}),(function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]}));case\"blend.color\":return e((function(t){return a(4,(function(e){return+t[e]}))}),(function(t,e,r){return a(4,(function(t){return e.def(\"+\",r,\"[\",t,\"]\")}))}));case\"stencil.mask\":return e((function(t){return 0|t}),(function(t,e,r){return e.def(r,\"|0\")}));case\"stencil.func\":return e((function(t){return[Mt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]}),(function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]}));case\"stencil.opFront\":case\"stencil.opBack\":return e((function(e){return[\"stencil.opBack\"===t?1029:1028,At[e.fail||\"keep\"],At[e.zfail||\"keep\"],At[e.zpass||\"keep\"]]}),(function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]}));case\"polygonOffset.offset\":return e((function(t){return[0|t.factor,0|t.units]}),(function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]}));case\"cull.face\":return e((function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e}),(function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)}));case\"lineWidth\":return e((function(t){return t}),(function(t,e,r){return r}));case\"frontFace\":return e((function(t){return St[t]}),(function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')}));case\"colorMask\":return e((function(t){return t.map((function(t){return!!t}))}),(function(t,e,r){return a(4,(function(t){return\"!!\"+r+\"[\"+t+\"]\"}))}));case\"sample.coverage\":return e((function(t){return[\"value\"in t?t.value:1,!!t.invert]}),(function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]}))}})),i}(t),p=w(t,0,l);s(\"viewport\"),s(v(\"scissor.box\"));var d,g=0<Object.keys(h).length;if((d={framebuffer:d,draw:f,shader:p,state:h,dirty:g,scopeVAO:null,drawVAO:null,useVAO:!1,attributes:{}}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=F((function(t,e){return n}))).enable=n}else if(\"profile\"in t){var i=t.profile;e=B(i,(function(t,e){return t.invoke(e,i)}))}return e}(t),d.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach((function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=F((function(){return n}));else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=F((function(t){return t.link(n)})):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=F((function(t){return t.link(n.color[0])})))}else m(n)&&(e=F((function(t){return t.global.def(\"[\",a(n.length,(function(t){return n[t]})),\"]\")})));e.value=n,i[t]=e})),Object.keys(n).forEach((function(t){var e=n[t];i[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),i}(n),d.drawVAO=d.scopeVAO=function(t,e){var r=t.static,n=t.dynamic;if(\"vao\"in r){var i=r.vao;return null!==i&&null===u.getVAO(i)&&(i=u.createVAO(i)),F((function(t){return t.link(u.getVAO(i))}))}if(\"vao\"in n){var a=n.vao;return B(a,(function(t,e){var r=t.invoke(e,a);return e.def(t.shared.vao+\".getVAO(\"+r+\")\")}))}return null}(t),!d.drawVAO&&p.program&&!l&&r.angle_instanced_arrays){var y=!0;if(t=p.program.attributes.map((function(t){return t=e.static[t],y=y&&!!t,t})),y&&0<t.length){var x=u.getVAO(u.createVAO(t));d.drawVAO=new D(null,null,null,(function(t,e){return t.link(x)})),d.useVAO=!0}}return l?d.useVAO=!0:d.attributes=k(e),d.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach((function(t){var r=e[t];n[t]=F((function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)}))})),Object.keys(r).forEach((function(t){var e=r[t];n[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),n}(i),d}function A(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach((function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")})),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;$&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),$&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),$&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");rt.forEach((function(e){var n,f;if(!((e=v(e))in r.state))if(e in s){n=s[e],f=o[e];var h=a(tt[e].length,(function(t){return u.def(n,\"[\",t,\"]\")}));u(t.cond(h.map((function(t,e){return t+\"!==\"+f+\"[\"+e+\"]\"})).join(\"||\")).then(i,\".\",at[e],\"(\",h,\");\",h.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\"))}else n=u.def(c,\".\",e),h=t.cond(n,\"!==\",l,\".\",e),u(h),e in it?h(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):h(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")})),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;O(Object.keys(r)).forEach((function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];R(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(m(c)){var f=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}}))}function L(t,e){K&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function I(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(h,\".count+=\",i,\";\"):t(h,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",h,\");\"))}function s(t){t(h,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",h,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,f=t.shared,h=t.stats,p=f.current,g=f.timer;if(r=r.profile){if(R(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(f=t.block()),e(\"if(\",r,\"){\",f,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map((function(t){return u+\".\"+t+\"!==\"+i[t]})).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",f,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map((function(t){return u+\".\"+t+\"=\"+i[t]+\";\"})).join(\"\"),\"}\"),K&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",u,\".buffer=null;\",\"}if(\",wt.map((function(t,e){return u+\".\"+t+\"!==\"+h[e]})).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",h,\");\",wt.map((function(t,e){return u+\".\"+t+\"=\"+h[e]+\";\"})).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var f=i.buffer,h=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach((function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Et))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach((function(t){o[t]=e.def(c,\".\",t)}))}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)}))}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var f,h=(g=i[u]).name,p=g.info.type,d=n.uniforms[h],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(R(d)){if(h=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(h._texture||h.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",h=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(h)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",m(h)?Array.prototype.slice.call(h):h,\");\")}continue}f=d.append(t,r)}else{if(!o(Et))continue;f=r.def(l.uniforms,\"[\",e.id(h),\"]\")}switch(35678===p?r(\"if(\",f,\"&&\",f,'._reglType===\"framebuffer\"){',f,\"=\",f,\".color[0];\",\"}\"):35680===p&&r(\"if(\",f,\"&&\",f,'._reglType===\"framebufferCube\"){',f,\"=\",f,\".color[0];\",\"}\"),h=1,p){case 35678:case 35680:p=r.def(f,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",h=2;break;case 35668:case 35672:s=\"3i\",h=3;break;case 35669:case 35673:s=\"4i\",h=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",h=2;break;case 35665:s=\"3f\",h=3;break;case 35666:s=\"4f\",h=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var v=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",f,\")||\",f,\" instanceof Float32Array)?\",f,\":(\",a(g,(function(t){return v+\"[\"+t+\"]=\"+f+\"[\"+t+\"]\"})),\",\",v,\")\")}else r(1<h?a(h,(function(t){return f+\"[\"+t+\"]\"})):f);r(\");\")}}function U(t,e,r,n){function i(i){var a=h[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(f,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,m,v,g+\"<<((\"+v+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,m,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,m,v,g+\"<<((\"+v+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,m]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,f=c.draw,h=n.draw,p=function(){var i=h.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),m=function(){var i=h.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"count\"),i}();if(\"number\"==typeof m){if(0===m)return}else r(\"if(\",m,\"){\"),r.exit(\"}\");K&&(s=i(\"instances\"),l=t.instancing);var v=p+\".type\",y=h.elements&&R(h.elements);K&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function V(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),K&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),r.useVAO?r.drawVAO?e(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,e),\");\"):e(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(e(t.shared.vao,\".setVAO(null);\"),N(t,e,r,n.attributes,(function(){return!0}))),j(t,e,r,n.uniforms,(function(){return!0})),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&A(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&I(t,u,r,!1,!0),n?(r.useVAO?r.drawVAO?i(r.drawVAO)?u(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,u),\");\"):c(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,c),\");\"):c(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(c(t.shared.vao,\".setVAO(null);\"),N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i)),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link((function(e){return V(G,t,r,e,2)})),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;A(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),O(Object.keys(r.state)).forEach((function(e){var n=r.state[e].append(t,i);m(n)?n.forEach((function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)})):i.set(a.next,\".\"+e,n)})),I(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach((function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))})),Object.keys(r.uniforms).forEach((function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))})),Object.keys(r.attributes).forEach((function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach((function(t){i.set(a,\".\"+t,n[t])}))})),r.scopeVAO&&i.set(a.vao,\".targetVAO\",r.scopeVAO.append(t,i)),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!m(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(q.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach((function(e){var r=n[e];if(q.isDynamic(r))\"function\"==typeof r&&(r=n[e]=q.unbox(r)),e=B(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}})),e.dynamic[r]=new q.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach((function(r){var i=n[r];q.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))}))}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var K=r.angle_instanced_arrays,$=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},rt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:h,elements:o,buffer:i,shader:f,attributes:u.state,vao:u,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:z},st={primTypes:nt,compareFuncs:Mt,blendFuncs:kt,blendEquations:J,stencilOps:At,glTypes:Q,orientationType:St};$&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,(function(t){return 0===t?[0]:a(t,(function(t){return 36064+t}))})));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),i=t.proc(\"refresh\"),o=t.block();e(o),i(o);var s,l=t.shared,c=l.gl,u=l.next,f=l.current;o(f,\".dirty=false;\"),S(t,e),S(t,i,null,!0),K&&(s=t.link(K)),r.oes_vertex_array_object&&i(t.link(r.oes_vertex_array_object),\".bindVertexArrayOES(null);\");for(var h=0;h<n.maxAttributes;++h){var p=i.def(l.attributes,\"[\",h,\"]\"),d=t.cond(p,\".buffer\");d.then(c,\".enableVertexAttribArray(\",h,\");\",c,\".bindBuffer(\",34962,\",\",p,\".buffer.buffer);\",c,\".vertexAttribPointer(\",h,\",\",p,\".size,\",p,\".type,\",p,\".normalized,\",p,\".stride,\",p,\".offset);\").else(c,\".disableVertexAttribArray(\",h,\");\",c,\".vertexAttrib4f(\",h,\",\",p,\".x,\",p,\".y,\",p,\".z,\",p,\".w);\",p,\".buffer=null;\"),i(d),K&&i(s,\".vertexAttribDivisorANGLE(\",h,\",\",p,\".divisor);\")}return i(t.shared.vao,\".currentVAO=null;\",t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"),Object.keys(it).forEach((function(r){var n=it[r],a=o.def(u,\".\",r),s=t.block();s(\"if(\",a,\"){\",c,\".enable(\",n,\")}else{\",c,\".disable(\",n,\")}\",f,\".\",r,\"=\",a,\";\"),i(s),e(\"if(\",a,\"!==\",f,\".\",r,\"){\",s,\"}\")})),Object.keys(at).forEach((function(r){var n,s,l=at[r],h=tt[r],p=t.block();p(c,\".\",l,\"(\"),m(h)?(l=h.length,n=t.global.def(u,\".\",r),s=t.global.def(f,\".\",r),p(a(l,(function(t){return n+\"[\"+t+\"]\"})),\");\",a(l,(function(t){return s+\"[\"+t+\"]=\"+n+\"[\"+t+\"];\"})).join(\"\")),e(\"if(\",a(l,(function(t){return n+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"})).join(\"||\"),\"){\",p,\"}\")):(n=o.def(u,\".\",r),s=o.def(f,\".\",r),p(n,\");\",f,\".\",r,\"=\",n,\";\"),e(\"if(\",n,\"!==\",s,\"){\",p,\"}\")),i(p)})),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach((function(t){X(a,e,t)})),Tt.forEach((function(e){X(a,t,e)})),r=M(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),A(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),I(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{r(t.shared.vao,\".setVAO(null);\");var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link((function(r){return V(H,t,e,r,1)})),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach((function(t){i=i||e.context[t].propDep})),i||(A(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,(function(t){return!r(t)})),e.profile&&r(e.profile)||I(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{n(t.shared.vao,\".setVAO(null);\");var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link((function(r){return V(Y,t,e,r,2)})),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function j(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var U=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},V=0,q={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},H={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},G=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},Y=s();Y.zero=s();var W=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=Y.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),Y.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=Y.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),Y.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter((function(t){return!!e[t]})),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},X=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},Z=function(t){return Object.keys(t).map((function(e){return t[e]}))},J={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||Y.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],f=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,f,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},K={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},Q={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},tt=J.flatten,et=J.shape,rt=[];rt[5120]=1,rt[5122]=2,rt[5124]=4,rt[5121]=1,rt[5123]=2,rt[5125]=4,rt[5126]=4;var nt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},it=new Float32Array(1),at=new Uint32Array(it.buffer),ot=[9984,9986,9985,9987],st=[0,6409,6410,6407,6408],lt={};lt[6409]=lt[6406]=lt[6402]=1,lt[34041]=lt[6410]=2,lt[6407]=lt[35904]=3,lt[6408]=lt[35906]=4;var ct=v(\"HTMLCanvasElement\"),ut=v(\"OffscreenCanvas\"),ft=v(\"CanvasRenderingContext2D\"),ht=v(\"ImageBitmap\"),pt=v(\"HTMLImageElement\"),dt=v(\"HTMLVideoElement\"),gt=Object.keys(K).concat([ct,ut,ft,ht,pt,dt]),mt=[];mt[5121]=1,mt[5126]=4,mt[36193]=2,mt[5123]=2,mt[5125]=4;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[34041]=4,vt[33776]=.5,vt[33777]=.5,vt[33778]=1,vt[33779]=1,vt[35986]=.5,vt[35987]=1,vt[34798]=1,vt[35840]=.5,vt[35841]=.25,vt[35842]=.5,vt[35843]=.25,vt[36196]=.5;var yt=[];yt[32854]=2,yt[32855]=2,yt[36194]=2,yt[33189]=2,yt[36168]=1,yt[34041]=4,yt[35907]=4,yt[34836]=16,yt[34842]=8,yt[34843]=6;var xt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach((function(t){l[s[t]]=t}));var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach((function(e){t+=u[e].stats.size})),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=yt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height||(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=yt[c.format]*c.width*c.height)),o},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){Z(u).forEach(o)},restore:function(){Z(u).forEach((function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)})),t.bindRenderbuffer(36161,null)}}},bt=[];bt[6408]=4,bt[6407]=3;var _t=[];_t[5121]=1,_t[5126]=4,_t[36193]=2;var wt=[\"x\",\"y\",\"z\",\"w\"],Tt=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),kt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},Mt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},At={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},St={cw:2304,ccw:2305},Et=new D(!1,!1,!1,(function(){}));return function(t){function e(){if(0===J.length)w&&w.update(),tt=null;else{tt=H.next(e),f();for(var t=J.length-1;0<=t;--t){var r=J[t];r&&r(I,null,0)}m.flush(),w&&w.update()}}function r(){!tt&&0<J.length&&(tt=H.next(e))}function n(){tt&&(H.cancel(e),tt=null)}function a(t){t.preventDefault(),n(),K.forEach((function(t){t()}))}function o(t){m.getError(),y.restore(),R.restore(),z.restore(),F.restore(),B.restore(),V.restore(),O.restore(),w&&w.restore(),Y.procs.refresh(),r(),Q.forEach((function(t){t()}))}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach((function(n){var i=t[n];q.isDynamic(i)?r[n]=q.unbox(i,n):e[n]=i})),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach((function(n){r[t+\".\"+n]=e[n]}))}}var r=U({},t);return delete r.uniforms,delete r.attributes,delete r.context,delete r.vao,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),\"vao\"in t&&(r.vao=t.vao),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=Y.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return U((function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}}),{stats:t})}function l(t,e){var r=0;Y.procs.poll();var n=e.color;n&&(m.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(m.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(m.clearStencil(0|e.stencil),r|=1024),m.clear(r)}function c(t){return J.push(t),r(),{cancel:function(){var e=j(J,t);J[e]=function t(){var e=j(J,t);J[e]=J[J.length-1],--J.length,0>=J.length&&n()}}}}function u(){var t=X.viewport,e=X.scissor_box;t[0]=t[1]=e[0]=e[1]=0,I.viewportWidth=I.framebufferWidth=I.drawingBufferWidth=t[2]=e[2]=m.drawingBufferWidth,I.viewportHeight=I.framebufferHeight=I.drawingBufferHeight=t[3]=e[3]=m.drawingBufferHeight}function f(){I.tick+=1,I.time=g(),u(),Y.procs.poll()}function h(){u(),Y.procs.refresh(),w&&w.update()}function g(){return(G()-T)/1e3}if(!(t=i(t)))return null;var m=t.gl,v=m.getContextAttributes();m.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach((function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)}))}}}(m,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={vaoCount:0,bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var f=(n=s[r]).startQueryIndex;u=n.endQueryIndex;n.sum+=l[u]-l[f],f=c[f],(u=c[u])===f?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=f,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),T=G(),A=m.drawingBufferWidth,L=m.drawingBufferHeight,I={tick:0,time:0,viewportWidth:A,viewportHeight:L,framebufferWidth:A,framebufferHeight:L,drawingBufferWidth:A,drawingBufferHeight:L,pixelRatio:t.pixelRatio},P=W(m,_),z=p(m,b,t,(function(t){return O.destroyBuffer(t)})),O=S(m,_,P,b,z),D=d(m,_,z,b),R=E(m,x,b,t),F=k(m,_,P,(function(){Y.procs.poll()}),I,b,t),B=xt(m,_,0,b,t),V=M(m,_,P,F,B,b),Y=N(m,x,_,P,z,D,0,V,{},O,R,{elements:null,primitive:4,count:-1,offset:0,instances:-1},I,w,t),X=(x=C(m,V,Y.procs.poll,I),Y.next),Z=m.canvas,J=[],K=[],Q=[],$=[t.onDestroy],tt=null;Z&&(Z.addEventListener(\"webglcontextlost\",a,!1),Z.addEventListener(\"webglcontextrestored\",o,!1));var et=V.setFBO=s({framebuffer:q.define.call(null,1,\"framebuffer\")});return h(),v=U(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)et(U({framebuffer:t.framebuffer.faces[e]},t),l);else et(t,l);else l(0,t)},prop:q.define.bind(null,1),context:q.define.bind(null,2),this:q.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return D.create(t,!1)},texture:F.create2D,cube:F.createCube,renderbuffer:B.create,framebuffer:V.create,framebufferCube:V.createCube,vao:O.createVAO,attributes:v,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=K;break;case\"restore\":r=Q;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:P,hasExtension:function(t){return 0<=P.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){J.length=0,n(),Z&&(Z.removeEventListener(\"webglcontextlost\",a),Z.removeEventListener(\"webglcontextrestored\",o)),R.clear(),V.clear(),B.clear(),F.clear(),D.clear(),z.clear(),O.clear(),w&&w.clear(),$.forEach((function(t){t()}))},_gl:m,_refresh:h,poll:function(){f(),w&&w.update()},now:g,stats:b}),t.onDone(null,v),v}}))},{}],541:[function(t,e,r){\n",
       "/*!\n",
       " * repeat-string <https://github.com/jonschlinkert/repeat-string>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT License.\n",
       " */\n",
       "\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],542:[function(t,e,r){(function(t){(function(){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],543:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i];(l=o-((r=a+o)-a))&&(t[--n]=r,r=l)}var s=0;for(i=n;i<e;++i){var l;a=t[i];(l=(o=r)-((r=a+o)-a))&&(t[s++]=l)}return t[s++]=r,t.length=s,t}},{}],544:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(s(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(l(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var f=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;f.length<6;)f.push(u(f.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<6;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,f.concat([f,u])),n=0;n<f.length;++n)e.exports[n]=f[n]}()},{\"robust-compress\":543,\"robust-scale\":550,\"robust-sum\":553,\"two-product\":582}],545:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":553,\"two-product\":582}],546:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return c(e,t)}function u(t){if(2===t.length)return[[\"diff(\",c(t[0][0],t[1][1]),\",\",c(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(u(s(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return l(r)}function h(t){for(var e=[],r=[],c=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),h=0;h<t;++h)c[0][h]=\"1\",c[t-1][h]=\"w\"+h;for(h=0;h<t;++h)0==(1&h)?e.push.apply(e,u(s(c,h))):r.push.apply(r,u(s(c,h)));var p=l(e),d=l(r),g=\"exactInSphere\"+t,m=[];for(h=0;h<t;++h)m.push(\"m\"+h);var v=[\"function \",g,\"(\",m.join(),\"){\"];for(h=0;h<t;++h){v.push(\"var w\",h,\"=\",f(h,t),\";\");for(var y=0;y<t;++y)y!==h&&v.push(\"var w\",h,\"m\",y,\"=scale(w\",h,\",m\",y,\"[0]);\")}return v.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",v.join(\"\"))(i,a,n,o)}var p=[function(){return 0},function(){return 0},function(){return 0}];function d(t){var e=p[t.length];return e||(e=p[t.length]=h(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=6;)p.push(h(p.length));for(var t=[],r=[\"slow\"],n=0;n<=6;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=6;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[d].concat(p)),n=0;n<=6;++n)e.exports[n]=p[n]}()},{\"robust-scale\":550,\"robust-subtract\":552,\"robust-sum\":553,\"two-product\":582}],547:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\");function i(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var a=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;a.length<6;)a.push(i(a.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<6;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var o=Function.apply(void 0,t);for(e.exports=o.apply(void 0,a.concat([a,i])),n=0;n<6;++n)e.exports[n]=a[n]}()},{\"robust-determinant\":544}],548:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(c(s(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function u(t){for(var e=[],r=[],u=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),f=[],h=0;h<t;++h)0==(1&h)?e.push.apply(e,c(s(u,h))):r.push.apply(r,c(s(u,h))),f.push(\"m\"+h);var p=l(e),d=l(r),g=\"orientation\"+t+\"Exact\",m=[\"function \",g,\"(\",f.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",m)(i,n,a,o)}var f=u(3),h=u(4),p=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=33306690738754716e-32*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],f=e[2]-n[2],p=r[2]-n[2],d=a*c,g=o*l,m=o*s,v=i*c,y=i*l,x=a*s,b=u*(d-g)+f*(m-v)+p*(y-x),_=7771561172376103e-31*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(m)+Math.abs(v))*Math.abs(f)+(Math.abs(y)+Math.abs(x))*Math.abs(p));return b>_||-b>_?b:h(t,e,r,n)}];function d(t){var e=p[t.length];return e||(e=p[t.length]=u(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=5;)p.push(u(p.length));for(var t=[],r=[\"slow\"],n=0;n<=5;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=5;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[d].concat(p)),n=0;n<=5;++n)e.exports[n]=p[n]}()},{\"robust-scale\":550,\"robust-subtract\":552,\"robust-sum\":553,\"two-product\":582}],549:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":550,\"robust-sum\":553}],550:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var f=s[1];i(f,l[0],s),s[0]&&(o[c++]=s[0]);var h=l[1],p=s[1],d=h+p,g=p-(d-h);s[1]=d,g&&(o[c++]=g)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":582,\"two-sum\":583}],551:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],f=Math.min(c,u);if(Math.max(c,u)<s||l<f)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":548}],552:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=-e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,m,v=i+a,y=v-i,x=a-y,b=x,_=v;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(v=i+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g;for(;l<r;)(x=(a=b)-(y=(v=(i=f)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(v=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],553:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,m,v=i+a,y=v-i,x=a-y,b=x,_=v;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(v=i+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g;for(;l<r;)(x=(a=b)-(y=(v=(i=f)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(v=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],554:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],555:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":100,\"reduce-simplicial-complex\":533}],556:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],f=(e=u.length,0);f<e;++f)for(var h=0;h<f;++h){var p=u[h],d=u[f];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));var g=2;for(c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var f=o[2*u],h=o[2*u+1];if(r[f]!==r[h]){var p=e[f],d=e[h];o[2*c]=f,o[2*c+1]=h,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),f=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),h=o(s)(t,c.data,f,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(f),{cells:h,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":557,ndarray:495,\"ndarray-sort\":494,\"typedarray-pool\":595}],557:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");var u=[];for(s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":474,\"typedarray-pool\":595}],558:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var f=e.slice(0);f.sort();for(var h=0;h<r;++h)if(n=u[h]-f[h])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],f=u.length,h=1,p=1<<f;h<p;++h){s.length=n.popCount(h);for(var d=0,g=0;g<f;++g)h&1<<g&&(s[d++]=u[g]);var m=c(t,s);if(!(m<0))for(;r[m++].push(i),!(m>=t.length||0!==a(t[m],s)););}return r}function f(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,f=0;f<o.length;++f)l&1<<f&&(c[u++]=o[f]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(f(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=f,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(f(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),h=o+1;h<a.length;++h)r.link(u,c(e,[a[h]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":97,\"union-find\":596}],559:[function(t,e,r){arguments[4][97][0].apply(r,arguments)},{dup:97}],560:[function(t,e,r){arguments[4][558][0].apply(r,arguments)},{\"bit-twiddle\":559,dup:558,\"union-find\":561}],561:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],562:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),f=0;f<a;++f)s[f]=l[f]=-1,c[f]=1/0,u[f]=!1;for(f=0;f<o;++f){var h=t[f];if(2!==h.length)throw new Error(\"Input must be a graph\");var p=h[1],d=h[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,f=s[t],h=l[t];return f<0||h<0?1/0:(r=e[t],i=e[f],a=e[h],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function m(t,e){var r=k[t],n=k[e];k[t]=n,k[e]=r,M[r]=e,M[n]=t}function v(t){return c[k[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=v(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<A){var o=v(n);o<r&&(a=n,r=o)}if(i<A)v(i)<r&&(a=i);if(a===t)return t;m(t,a),t=a}}function b(t){for(var e=v(t);t>0;){var r=y(t);if(r>=0)if(e<v(r)){m(t,r),t=r;continue}return t}}function _(){if(A>0){var t=k[0];return m(0,A-1),A-=1,x(0),t}return-1}function w(t,e){var r=k[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((A+=1)-1))}function T(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),M[e]>=0&&w(M[e],g(e)),M[r]>=0&&w(M[r],g(r))}}var k=[],M=new Array(a);for(f=0;f<a;++f){(c[f]=g(f))<1/0?(M[f]=k.length,k.push(f)):M[f]=-1}var A=k.length;for(f=A>>1;f>=0;--f)x(f);for(;;){var S=_();if(S<0||c[S]>r)break;T(S)}var E=[];for(f=0;f<a;++f)u[f]||(M[f]=E.length,E.push(e[f].slice()));E.length;function C(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var L=[];return t.forEach((function(t){var e=C(s,t[0]),r=C(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=M[e],i=M[r];n!==i&&L.push([n,i])}})),i.unique(i.normalize(L)),{positions:E,edges:L}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":548,\"simplicial-complex\":560}],563:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var f=n(i,r,a);return f||((f=n(i,r,o))||o-i)}},{\"robust-orientation\":548}],564:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],565:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new f(l[0][0],l,c,a),n[2*a+1]=new f(l[1][0],l,!c,a)}n.sort((function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))}));var h=i(o),p=[],d=[],g=[];for(a=0;a<r;){for(var m=n[a].x,v=[];a<r;){var y=n[a];if(y.x!==m)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(v.push(new u(y.segment[0][1],y.index,!0,!0)),v.push(new u(y.segment[1][1],y.index,!1,!1))):(v.push(new u(y.segment[1][1],y.index,!0,!1)),v.push(new u(y.segment[0][1],y.index,!1,!0)))):h=y.create?h.insert(y.segment,y.index):h.remove(y.segment)}p.push(h.root),d.push(m),g.push(v)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function f(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var f=this.horizontal[e];if(f.length>0){var h=n.ge(f,t[1],l);if(h<f.length){var p=f[h];if(t[1]===p.y){if(p.closed)return p.index;for(;h<f.length-1&&f[h+1].y===t[1];)if((p=f[h+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((h+=1)>=f.length)return i;p=f[h]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":563,\"binary-search-bounds\":564,\"functional-red-black-tree\":247,\"robust-orientation\":548}],566:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var f=o(s,u,l,i);r.push(f),n.push(f.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":545,\"robust-sum\":553}],567:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(t){return i(o(t),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}function i(r,n){var i,a,o,s,l,c,u,f,h,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(f=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||f&&!s.sign?h=\"\":(h=f?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(h+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?h+i+l:\"0\"===c?h+l+i:l+h+i)}return g}var a=Object.create(null);function o(e){if(a[e])return a[e];for(var r,n=e,i=[],o=0;n;){if(null!==(r=t.text.exec(n)))i.push(r[0]);else if(null!==(r=t.modulo.exec(n)))i.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");i.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return a[e]=i}\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],568:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map((function(t){return 1===t.length&&(t+=t),t})));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:503}],569:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,f=[],h=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){var m=[],v=[],y=0;for(d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,m.push(x),v.push(s[x]),y+=s[x].length,o[x]=f.length,x===e){l.length=d;break}}f.push(m);var b=new Array(y);for(d=0;d<v.length;d++)for(var _=0;_<v[d].length;_++)b[--y]=v[d][_];h.push(b)}c.pop()}}}for(l=0;l<e;++l)r[l]<0&&p(l);for(l=0;l<h.length;l++){var d=h[l];if(0!==d.length){d.sort((function(t,e){return t-e})),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);h[l]=c}}return{components:f,adjacencyList:h}}},{}],570:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r];e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");var u=[];for(c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var f=[],h=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),h=a):a.push(\"switch(m>>>7){\");for(c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){f.length>0&&h.push(\"}}\");var p=\"vExtra\"+f.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),h=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],f.push(h)}h.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),m=new Array(r),v=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],m[x]=0,v[x]=0;for(x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),m[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),m[b]-=2),y+=1;for(var T=0;T<r;++T)T!==b&&(_&1<<T?v[T]+=1:v[T]-=1)}}var k=[];for(b=0;b<r;++b)if(0===d[b].length)k.push(\"d\"+b+\"-0.5\");else{var M=\"\";m[b]<0?M=m[b]+\"*c\":m[b]>0&&(M=\"+\"+m[b]+\"*c\");var A=d[b].length/y*.5,S=.5+v[b]/y*.5;k.push(\"d\"+b+\"-\"+S+\"-\"+A+\"*(\"+d[b].join(\"+\")+M+\")/(\"+g[b].join(\"+\")+\")\")}h.push(\"a.push([\",k.join(),\"]);\",\"break;\")}a.push(\"}},\"),f.length>0&&h.push(\"}}\");var E=[];for(c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map((function(t){return\"[\"+t.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}else{b.push(\",C.map((function(t){var e=t.slice();return e.reverse(),\"[\"+e.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(c=0;c<f.length;++c)a.push(f[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":487,\"triangulate-hypercube\":580,\"zero-crossings\":624}],571:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")},i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=1.5707963267948966===e?.551915024494:-1.5707963267948966===e?-.551915024494:4/3*Math.tan(e/4),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*r+e*n;return i>1&&(i=1),i<-1&&(i=-1),(t*n-e*r<0?-1:1)*Math.acos(i)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,f=t.ry,h=t.xAxisRotation,p=void 0===h?0:h,d=t.largeArcFlag,g=void 0===d?0:d,m=t.sweepFlag,v=void 0===m?0:m,y=[];if(0===u||0===f)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),f=Math.abs(f);var T=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(f,2);T>1&&(u*=Math.sqrt(T),f*=Math.sqrt(T));var k=function(t,e,r,n,a,o,l,c,u,f,h,p){var d=Math.pow(a,2),g=Math.pow(o,2),m=Math.pow(h,2),v=Math.pow(p,2),y=d*g-d*v-g*m;y<0&&(y=0),y/=d*v+g*m;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*h,_=f*x-u*b+(t+r)/2,w=u*x+f*b+(e+n)/2,T=(h-x)/a,k=(p-b)/o,M=(-h-x)/a,A=(-p-b)/o,S=s(1,0,T,k),E=s(T,k,M,A);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,f,g,v,x,b,_,w),M=n(k,4),A=M[0],S=M[1],E=M[2],C=M[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var I=Math.max(Math.ceil(L),1);C/=I;for(var P=0;P<I;P++)y.push(o(E,C)),E+=C;return y.map((function(t){var e=a(t[0],u,f,b,x,A,S),r=e.x,n=e.y,i=a(t[1],u,f,b,x,A,S),o=i.x,s=i.y,l=a(t[2],u,f,b,x,A,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}}))},e.exports=r.default},{}],572:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":65,assert:73,\"is-svg-path\":471,\"normalize-svg-path\":573,\"parse-svg-path\":505}],573:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,f=null,h=0,p=0,d=0,g=t.length;d<g;d++){var m=t[d],v=m[0];switch(v){case\"M\":l=m[1],c=m[2];break;case\"A\":var y=n({px:h,py:p,cx:m[6],cy:m[7],rx:m[1],ry:m[2],xAxisRotation:m[3],largeArcFlag:m[4],sweepFlag:m[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],m=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(m);break;case\"S\":var _=h,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),m=[\"C\",_,w,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*h-u,f=2*p-f):(u=h,f=p),m=a(h,p,u,f,m[1],m[2]);break;case\"Q\":u=m[1],f=m[2],m=a(h,p,m[1],m[2],m[3],m[4]);break;case\"L\":m=i(h,p,m[1],m[2]);break;case\"H\":m=i(h,p,m[1],p);break;case\"V\":m=i(h,p,h,m[1]);break;case\"Z\":m=i(h,p,l,c)}e=v,h=m[m.length-2],p=m[m.length-1],m.length>4?(o=m[m.length-4],s=m[m.length-3]):(o=h,s=p),r.push(m)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":571}],574:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,f;e.shape?(r=e.shape[0],f=e.shape[1]):(r=c.width=e.w||e.width||200,f=c.height=e.h||e.height||200);var h=Math.min(r,f),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),f/(d[3]-d[1])],m=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,f),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*f),u.scale(m,m),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var v=new Path2D(t);u.fill(v),p&&u.stroke(v)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*h})}},{\"bitmap-sdf\":98,\"draw-svg-path\":174,\"is-svg-path\":471,\"parse-svg-path\":505,\"svg-path-bounds\":572}],575:[function(t,e,r){(function(r){(function(){\"use strict\";e.exports=function t(e,r,i){i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,f=0,h=0;h<l.length;++h)c[h]=t(e,l[h]),u+=c[h].data.length,f+=c[h].shape,h>0&&(f+=.02);var p=new Float32Array(u),d=0,g=-.5*f;for(h=0;h<c.length;++h){for(var m=c[h].data,v=0;v<m.length;v+=2)p[d++]=m[v]+g,p[d++]=m[v+1];g+=c[h].shape+.02}s=o[r]={data:p,shape:f}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this)}).call(this,t(\"_process\"))},{_process:526,\"vectorize-text\":600}],576:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,f=!1,h=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:P(e[1]),g:P(e[2]),b:P(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:P(e[1]),g:P(e[2]),b:P(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:P(e[1]+\"\"+e[1]),g:P(e[2]+\"\"+e[2]),b:P(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:P(e[1]+\"\"+e[1]),g:P(e[2]+\"\"+e[2]),b:P(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},f=!0,h=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=O(e.s),c=O(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),f=!0,h=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=O(e.s),u=O(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),f=!0,h=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:f,format:e.format||h,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function f(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function h(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=I(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=I(r.s),c(r)}function m(t){return c(t).desaturate(100)}function v(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=I(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=I(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function M(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function A(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=f(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=f(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return h(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[h(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(v,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(m,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(M,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(A,arguments)},splitcomplement:function(){return this._applyCombination(k,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(T,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:O(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function I(t){return o(1,s(0,t))}function P(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function O(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return P(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],577:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],578:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=a;function i(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*a(r[1],t)}function a(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=i(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return i(e,\"font-size\");case\"rem\":return i(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return 96;case\"cm\":return 96/2.54;case\"mm\":return 96/25.4;case\"pt\":return 96/72;case\"pc\":return 16}return 1}},{\"parse-unit\":506}],579:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).topojson=t.topojson||{})}(this,(function(t){\"use strict\";function e(t){return t}function r(t){if(null==t)return e;var r,n,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c);for(u[0]=(r+=t[0])*i+o,u[1]=(n+=t[1])*a+s;l<c;)u[l]=t[l],++l;return u}}function n(t){var e,n=r(t.transform),i=1/0,a=i,o=-i,s=-i;function l(t){(t=n(t))[0]<i&&(i=t[0]),t[0]>o&&(o=t[0]),t[1]<a&&(a=t[1]),t[1]>s&&(s=t[1])}function c(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(c);break;case\"Point\":l(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(l)}}for(e in t.arcs.forEach((function(t){for(var e,r=-1,l=t.length;++r<l;)(e=n(t[r],r))[0]<i&&(i=e[0]),e[0]>o&&(o=e[0]),e[1]<a&&(a=e[1]),e[1]>s&&(s=e[1])})),t.objects)c(t.objects[e]);return[i,a,o,s]}function i(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,o=a(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:o}:null==n?{type:\"Feature\",id:r,properties:i,geometry:o}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:o}}function a(t,e){var n=r(t.transform),i=t.arcs;function a(t,e){e.length&&e.pop();for(var r=i[t<0?~t:t],a=0,o=r.length;a<o;++a)e.push(n(r[a],a));t<0&&function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r}(e,o)}function o(t){return n(t)}function s(t){for(var e=[],r=0,n=t.length;r<n;++r)a(t[r],e);return e.length<2&&e.push(e[0]),e}function l(t){for(var e=s(t);e.length<4;)e.push(e[0]);return e}function c(t){return t.map(l)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=o(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(o);break;case\"LineString\":r=s(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(s);break;case\"Polygon\":r=c(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(c);break;default:return null}return{type:n,coordinates:r}}(e)}function o(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach((function(t){r[t<0?~t:t]=1})),a.push(i)}}return e.forEach((function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)})),e.forEach((function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach((function(t){r[0]+=t[0],r[1]+=t[1]}))):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r})),s(i,n),s(n,i),e.forEach((function(t){r[t<0?~t:t]||a.push([t])})),a}function s(t,e,r){var n,i,a;if(arguments.length>1)n=l(t,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:o(t,n)}}function l(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":!function(t){t.forEach(l)}(e.arcs)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}function c(t,e){var r={},n=[],i=[];function s(t){t.forEach((function(e){e.forEach((function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)}))})),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(a(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach((function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":s(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(s)}})),n.forEach((function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].forEach((function(t){t._||(t._=1,n.push(t))}))}))}))}})),n.forEach((function(t){delete t._})),{type:\"MultiPolygon\",arcs:i.map((function(e){var n,i=[];if(e.forEach((function(t){t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].length<2&&i.push(t)}))}))})),(n=(i=o(t,i)).length)>1)for(var a,s,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(s=i[0],i[0]=i[c],i[c]=s,u=a);return i})).filter((function(t){return t.length>0}))}}function u(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r}function f(t){if(null==t)return e;var r,n,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c),f=Math.round((t[0]-o)/i),h=Math.round((t[1]-s)/a);for(u[0]=f-r,r=f,u[1]=h-n,n=h;l<c;)u[l]=t[l],++l;return u}}t.bbox=n,t.feature=function(t,e){return\"string\"==typeof e&&(e=t.objects[e]),\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map((function(e){return i(t,e)}))}:i(t,e)},t.merge=function(t){return a(t,c.apply(this,arguments))},t.mergeArcs=c,t.mesh=function(t){return a(t,s.apply(this,arguments))},t.meshArcs=s,t.neighbors=function(t){var e={},r=t.map((function(){return[]}));function n(t,r){t.forEach((function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]}))}function i(t,e){t.forEach((function(t){n(t,e)}))}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach((function(t){i(t,e)}))}};for(var o in t.forEach((function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach((function(e){t(e,r)})):e.type in a&&a[e.type](e.arcs,r)})),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var f=c+1;f<l;++f){var h,p=s[c],d=s[f];(h=r[p])[o=u(h,d)]!==d&&h.splice(o,0,d),(h=r[d])[o=u(h,p)]!==p&&h.splice(o,0,p)}return r},t.quantize=function(t,e){if(t.transform)throw new Error(\"already quantized\");if(e&&e.scale)l=t.bbox;else{if(!((r=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");var r,i=(l=t.bbox||n(t))[0],a=l[1],o=l[2],s=l[3];e={scale:[o-i?(o-i)/(r-1):1,s-a?(s-a)/(r-1):1],translate:[i,a]}}var l,c,u=f(e),h=t.objects,p={};function d(t){return u(t)}function g(t){var e;switch(t.type){case\"GeometryCollection\":e={type:\"GeometryCollection\",geometries:t.geometries.map(g)};break;case\"Point\":e={type:\"Point\",coordinates:d(t.coordinates)};break;case\"MultiPoint\":e={type:\"MultiPoint\",coordinates:t.coordinates.map(d)};break;default:return t}return null!=t.id&&(e.id=t.id),null!=t.bbox&&(e.bbox=t.bbox),null!=t.properties&&(e.properties=t.properties),e}for(c in h)p[c]=g(h[c]);return{type:\"Topology\",bbox:l,transform:e,objects:p,arcs:t.arcs.map((function(t){var e,r=0,n=1,i=t.length,a=new Array(i);for(a[0]=u(t[0],0);++r<i;)((e=u(t[r],r))[0]||e[1])&&(a[n++]=e);return 1===n&&(a[n++]=[0,0]),a.length=n,a}))}},t.transform=r,t.untransform=f,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],580:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:248,\"permutation-parity\":509,\"permutation-rank\":510}],581:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||f(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=f(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,m=l(n,d)/i;u=Math.acos(g),a=Math.acos(m)}return i=Math.log(i),new h(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function f(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function h(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=h.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var f=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=f;var h=this.computedToward;o(h,e,r),s(h,h);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],m=Math.cos(d),v=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=m*y,w=v*y,T=x,k=-m*x,M=-v*x,A=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*h[a]+T*e[a];E[4*a+1]=k*r[a]+M*h[a]+A*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],I=E[5],P=E[9],z=E[2],O=E[6],D=E[10],R=I*D-P*O,F=P*z-L*D,B=L*O-I*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=c(u-=a*p,f-=o*p,h-=s*p),g=(u/=d)*e+a*r,m=(f/=d)*e+o*r,v=(h/=d)*e+s*r;this.center.move(t,g,m,v);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],f=e[a+8];if(n){var h=Math.abs(s),p=Math.abs(l),d=Math.abs(f),g=Math.max(h,p,d);h===g?(s=s<0?-1:1,l=f=0):d===g?(f=f<0?-1:1,s=l=0):(l=l<0?-1:1,s=f=0)}else{var m=c(s,l,f);s/=m,l/=m,f/=m}var v,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*f,T=c(x-=s*w,b-=l*w,_-=f*w),k=l*(_/=T)-f*(b/=T),M=f*(x/=T)-s*_,A=s*b-l*x,S=c(k,M,A);if(k/=S,M/=S,A/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,f),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],I=E*x+C*b+L*_,P=E*k+C*M+L*A;v=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(P,I)}else{var z=e[2],O=e[6],D=e[10],R=z*s+O*l+D*f,F=z*x+O*b+D*_,B=z*k+O*M+D*A;v=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,v),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],f=e[1]-r[1],h=e[2]-r[2],p=c(l,f,h);if(!(p<1e-6)){l/=p,f/=p,h/=p;var d=this.computedRight,g=d[0],m=d[1],v=d[2],y=i*g+a*m+o*v,x=c(g-=y*i,m-=y*a,v-=y*o);if(!(x<.01&&(x=c(g=a*h-o*f,m=o*l-i*h,v=i*f-a*l))<1e-6)){g/=x,m/=x,v/=x,this.up.set(t,i,a,o),this.right.set(t,g,m,v),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*v-o*m,_=o*g-i*v,w=i*m-a*g,T=c(b,_,w),k=i*l+a*f+o*h,M=g*l+m*f+v*h,A=(b/=T)*l+(_/=T)*f+(w/=T)*h,S=Math.asin(u(k)),E=Math.atan2(A,M),C=this.angle._state,L=C[C.length-1],I=C[C.length-2];L%=2*Math.PI;var P=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),O=Math.abs(L-2*Math.PI-E);P<z&&(L+=2*Math.PI),O<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,I),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":242,\"gl-mat4/invert\":293,\"gl-mat4/rotate\":299,\"gl-vec3/cross\":365,\"gl-vec3/dot\":370,\"gl-vec3/normalize\":387}],582:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,f=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=f,r[1]=i,r;return[f,i]};var n=+(Math.pow(2,27)+1)},{}],583:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],584:[function(t,e,r){\"use strict\";var n=t(\"../prototype/is\");e.exports=function(t){if(\"function\"!=typeof t)return!1;if(!hasOwnProperty.call(t,\"length\"))return!1;try{if(\"number\"!=typeof t.length)return!1;if(\"function\"!=typeof t.call)return!1;if(\"function\"!=typeof t.apply)return!1}catch(t){return!1}return!n(t)}},{\"../prototype/is\":591}],585:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i=t(\"../object/is\"),a=t(\"../string/coerce\"),o=t(\"./to-short-string\"),s=function(t,e){return t.replace(\"%v\",o(e))};e.exports=function(t,e,r){if(!i(r))throw new TypeError(s(e,t));if(!n(t)){if(\"default\"in r)return r.default;if(r.isOptional)return null}var o=a(r.errorMessage);throw n(o)||(o=e),new TypeError(s(o,t))}},{\"../object/is\":588,\"../string/coerce\":592,\"../value/is\":594,\"./to-short-string\":587}],586:[function(t,e,r){\"use strict\";e.exports=function(t){try{return t.toString()}catch(e){try{return String(t)}catch(t){return null}}}},{}],587:[function(t,e,r){\"use strict\";var n=t(\"./safe-to-string\"),i=/[\\n\\r\\u2028\\u2029]/g;e.exports=function(t){var e=n(t);return null===e?\"<Non-coercible to string value>\":(e.length>100&&(e=e.slice(0,99)+\"\\u2026\"),e=e.replace(i,(function(t){switch(t){case\"\\n\":return\"\\\\n\";case\"\\r\":return\"\\\\r\";case\"\\u2028\":return\"\\\\u2028\";case\"\\u2029\":return\"\\\\u2029\";default:throw new Error(\"Unexpected character\")}})))}},{\"./safe-to-string\":586}],588:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i={object:!0,function:!0,undefined:!0};e.exports=function(t){return!!n(t)&&hasOwnProperty.call(i,typeof t)}},{\"../value/is\":594}],589:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),i=t(\"./is\");e.exports=function(t){return i(t)?t:n(t,\"%v is not a plain function\",arguments[1])}},{\"../lib/resolve-exception\":585,\"./is\":590}],590:[function(t,e,r){\"use strict\";var n=t(\"../function/is\"),i=/^\\s*class[\\s{/}]/,a=Function.prototype.toString;e.exports=function(t){return!!n(t)&&!i.test(a.call(t))}},{\"../function/is\":584}],591:[function(t,e,r){\"use strict\";var n=t(\"../object/is\");e.exports=function(t){if(!n(t))return!1;try{return!!t.constructor&&t.constructor.prototype===t}catch(t){return!1}}},{\"../object/is\":588}],592:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i=t(\"../object/is\"),a=Object.prototype.toString;e.exports=function(t){if(!n(t))return null;if(i(t)){var e=t.toString;if(\"function\"!=typeof e)return null;if(e===a)return null}try{return\"\"+t}catch(t){return null}}},{\"../object/is\":588,\"../value/is\":594}],593:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),i=t(\"./is\");e.exports=function(t){return i(t)?t:n(t,\"Cannot use %v\",arguments[1])}},{\"../lib/resolve-exception\":585,\"./is\":594}],594:[function(t,e,r){\"use strict\";e.exports=function(t){return null!=t}},{}],595:[function(t,e,r){(function(e){(function(){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"dup\"),a=t(\"buffer\").Buffer;e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:i([32,0]),UINT16:i([32,0]),UINT32:i([32,0]),BIGUINT64:i([32,0]),INT8:i([32,0]),INT16:i([32,0]),INT32:i([32,0]),BIGINT64:i([32,0]),FLOAT:i([32,0]),DOUBLE:i([32,0]),DATA:i([32,0]),UINT8C:i([32,0]),BUFFER:i([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=\"undefined\"!=typeof BigUint64Array,l=\"undefined\"!=typeof BigInt64Array,c=e.__TYPEDARRAY_POOL;c.UINT8C||(c.UINT8C=i([32,0])),c.BIGUINT64||(c.BIGUINT64=i([32,0])),c.BIGINT64||(c.BIGINT64=i([32,0])),c.BUFFER||(c.BUFFER=i([32,0]));var u=c.DATA,f=c.BUFFER;function h(t){if(t){var e=t.length||t.byteLength,r=n.log2(e);u[r].push(t)}}function p(t){t=n.nextPow2(t);var e=n.log2(t),r=u[e];return r.length>0?r.pop():new ArrayBuffer(t)}function d(t){return new Uint8Array(p(t),0,t)}function g(t){return new Uint16Array(p(2*t),0,t)}function m(t){return new Uint32Array(p(4*t),0,t)}function v(t){return new Int8Array(p(t),0,t)}function y(t){return new Int16Array(p(2*t),0,t)}function x(t){return new Int32Array(p(4*t),0,t)}function b(t){return new Float32Array(p(4*t),0,t)}function _(t){return new Float64Array(p(8*t),0,t)}function w(t){return o?new Uint8ClampedArray(p(t),0,t):d(t)}function T(t){return s?new BigUint64Array(p(8*t),0,t):null}function k(t){return l?new BigInt64Array(p(8*t),0,t):null}function M(t){return new DataView(p(t),0,t)}function A(t){t=n.nextPow2(t);var e=n.log2(t),r=f[e];return r.length>0?r.pop():new a(t)}r.free=function(t){if(a.isBuffer(t))f[n.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|n.log2(e);u[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeBigUint64=r.freeInt8=r.freeInt16=r.freeInt32=r.freeBigInt64=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){h(t.buffer)},r.freeArrayBuffer=h,r.freeBuffer=function(t){f[n.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return p(t);switch(e){case\"uint8\":return d(t);case\"uint16\":return g(t);case\"uint32\":return m(t);case\"int8\":return v(t);case\"int16\":return y(t);case\"int32\":return x(t);case\"float\":case\"float32\":return b(t);case\"double\":case\"float64\":return _(t);case\"uint8_clamped\":return w(t);case\"bigint64\":return k(t);case\"biguint64\":return T(t);case\"buffer\":return A(t);case\"data\":case\"dataview\":return M(t);default:return null}return null},r.mallocArrayBuffer=p,r.mallocUint8=d,r.mallocUint16=g,r.mallocUint32=m,r.mallocInt8=v,r.mallocInt16=y,r.mallocInt32=x,r.mallocFloat32=r.mallocFloat=b,r.mallocFloat64=r.mallocDouble=_,r.mallocUint8Clamped=w,r.mallocBigUint64=T,r.mallocBigInt64=k,r.mallocDataView=M,r.mallocBuffer=A,r.clearCache=function(){for(var t=0;t<32;++t)c.UINT8[t].length=0,c.UINT16[t].length=0,c.UINT32[t].length=0,c.INT8[t].length=0,c.INT16[t].length=0,c.INT32[t].length=0,c.FLOAT[t].length=0,c.DOUBLE[t].length=0,c.BIGUINT64[t].length=0,c.BIGINT64[t].length=0,c.UINT8C[t].length=0,u[t].length=0,f[t].length=0}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"bit-twiddle\":97,buffer:111,dup:176}],596:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],597:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],598:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],599:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],600:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":601}],601:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter((function(t){return t})).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",h(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(p=0;p<r.length;++p)l[p]=s;!0===o.bolds&&(l=c(\"b\",\"b|\",r,l));!0===o.italics&&(l=c(\"i\",\"i|\",r,l));!0===o.superscripts&&(l=c(\"sup\",\"+1\",r,l));!0===o.subscripts&&(l=c(\"sub\",\"-1\",r,l));var u=[],f=\"\";for(p=0;p<r.length;++p)null!==l[p]&&(f+=r[p],u.push(l[p]));var h,p,d,g,m,v=f.split(\"\\n\"),y=v.length,x=Math.round(a*n),b=n,_=2*n,w=0,T=y*x+_;t.height<T&&(t.height=T);e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var k=0,M=\"\";function A(){if(\"\"!==M){var t=e.measureText(M).width;e.fillText(M,b+d,_+g),d+=t}}function S(){return Math.round(m)+\"px \"}function E(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(\"-\"),a=r.indexOf(\"-\"),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(S(),\"?px \"),m*=Math.pow(.75,l-s),n=n.replace(\"?px \",S())),g+=.25*x*(l-s)}if(!0===o.superscripts){var c=t.indexOf(\"+\"),u=r.indexOf(\"+\"),f=c>-1?parseInt(t[1+c]):0,h=u>-1?parseInt(r[1+u]):0;f!==h&&(n=n.replace(S(),\"?px \"),m*=Math.pow(.75,h-f),n=n.replace(\"?px \",S())),g-=.25*x*(h-f)}if(!0===o.bolds){var p=t.indexOf(\"b|\")>-1,d=r.indexOf(\"b|\")>-1;!p&&d&&(n=v?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),p&&!d&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var v=t.indexOf(\"i|\")>-1,y=r.indexOf(\"i|\")>-1;!v&&y&&(n=\"italic \"+n),v&&!y&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(h=0;h<y;++h){var C=v[h]+\"\\n\";for(d=0,g=h*x,m=n,M=\"\",p=0;p<C.length;++p){var L=p+k<u.length?u[p+k]:u[u.length-1];s===L?M+=C[p]:(A(),M=C[p],void 0!==L&&(E(s,L),s=L))}A(),k+=C.length;var I=0|Math.round(d+2*b);w<I&&(w=I)}var P=w,z=_+x*y;return i(e.getImageData(0,0,P,z).data,[z,P,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=h;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\");function c(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=\"+\"===e[0]||\"-\"===e[0],c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var f=c;f<u+s;++f)if(f<c+o||f>=u)n[f]=null,r=r.substr(0,f)+\" \"+r.substr(f+1);else if(null!==n[f]){var h=n[f].indexOf(e[0]);-1===h?n[f]+=e:l&&(n[f]=n[f].substr(0,h+1)+(1+parseInt(n[f][h+1]))+n[f].substr(h+2))}var p=c+o,d=r.substr(p,u-p).indexOf(i);c=-1!==d?d:u+s}return n}function u(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function f(t,e,r,n){var i=u(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var f=0;switch(n){case\"center\":f=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":f=-o[0];break;case\"left\":case\"start\":f=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var h=0;switch(i){case\"hanging\":case\"top\":h=-a[1];break;case\"middle\":h=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":h=-3*r;break;case\"bottom\":h=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map((function(t){return[p*(t[0]+f),p*(t[1]+h)]}))}(i.positions,e,r),c=i.edges,f=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),p=new Array(h.length),d=0;d<h.length;++d){for(var g=h[d],m=new Array(g.length),v=0;v<g.length;++v){for(var y=g[v],x=new Array(y.length),b=0;b<y.length;++b)x[b]=a[y[b]].slice();f&&x.reverse(),m[v]=x}p[d]=m}return p}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function h(t,e,r){try{return f(t,e,r,!0)}catch(t){}try{return f(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:112,\"clean-pslg\":121,ndarray:495,\"planar-graph-to-polyline\":514,\"simplify-planar-graph\":562,\"surface-nets\":570}],602:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=g);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var c=new ArrayBuffer(25),u=new Uint8Array(c);crypto.getRandomValues(u),l=\"weakmap:rand:\"+Array.prototype.map.call(u,(function(t){return(t%36).toString(36)})).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return v(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return v(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return v(t),r(t)}})}();var h=!1,p=0,d=function(){this instanceof d||x();var t=[],e=[],r=p++;return Object.create(d.prototype,{get___:{value:y((function(n,i){var a,o=v(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i}))},has___:{value:y((function(e){var n=v(e);return n?r in n:t.indexOf(e)>=0}))},set___:{value:y((function(n,i){var a,o=v(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this}))},delete___:{value:y((function(n){var i,a,o=v(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0)&&(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,!0)}))}})};d.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof d||x();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new d),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new d),i.set___(t,e)}else n.set(t,e);return this},Object.create(d.prototype,{get___:{value:y((function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)}))},has___:{value:y((function(t){return n.has(t)||!!i&&i.has___(t)}))},set___:{value:y(e)},delete___:{value:y((function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e}))},permitHostObjects___:{value:y((function(t){if(t!==g)throw new Error(\"bogus call to permitHostObjects___\");a=!0}))}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=d.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=d)}function g(t){t.permitHostObjects___&&t.permitHostObjects___(g)}function m(t){return!(\"weakmap:\"==t.substr(0,\"weakmap:\".length)&&\"___\"===t.substr(t.length-3))}function v(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[l];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,l,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function y(t){return t.prototype=null,Object.freeze(t)}function x(){h||\"undefined\"==typeof console||(h=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],603:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":604}],604:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],605:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":603}],606:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":249}],607:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),f[t-f[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=h[o-h[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var f=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(f/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=f[t-f[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l;if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Lunar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Lunar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=30))throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(l=!1,a=n):(l=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:l}}s=o.day-1;var c,u=f[o.year-f[0]],p=u>>13;c=p&&(o.month>p||o.isIntercalary)?o.month:o.month-1;for(var d=0;d<c;d++){s+=u&1<<12-d?30:29}var g=h[o.year-h[0]],m=new Date(g>>9&4095,(g>>5&15)-1,(31&g)+s);return a.year=m.getFullYear(),a.month=1+m.getMonth(),a.day=m.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Solar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Solar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=31))throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var o=h[i.year-h[0]],s=i.year<<9|i.month<<5|i.day;a.year=s>=o?i.year:i.year-1,o=h[a.year-h[0]];var l,c=new Date(o>>9&4095,(o>>5&15)-1,31&o),u=new Date(i.year,i.month-1,i.day);l=Math.round((u-c)/864e5);var p,d=f[a.year-f[0]];for(p=0;p<13;p++){var g=d&1<<12-p?30:29;if(l<g)break;l-=g}var m=d>>13;!m||p<m?(a.isIntercalary=!1,a.month=1+p):p===m?(a.isIntercalary=!0,a.month=p):(a.isIntercalary=!1,a.month=p);return a.day=1+l,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),f=this.isIntercalaryMonth(c,s),h=a&&f?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);h!==u&&l.month(h)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-/](\\d?\\d)([iI]?)[-/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var f=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],h=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":621,\"object-assign\":499}],608:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":621,\"object-assign\":499}],609:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":621,\"object-assign\":499}],610:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":621,\"object-assign\":499}],611:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)||8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":621,\"object-assign\":499}],612:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":621,\"object-assign\":499}],613:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":621,\"object-assign\":499}],614:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":621,\"object-assign\":499}],615:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":621,\"object-assign\":499}],616:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2e3:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":621,\"object-assign\":499}],617:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),f=t-this.toJD(l,u,1)+1;return this.newDate(l,u,f)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":621,\"object-assign\":499}],618:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":621,\"object-assign\":499}],619:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":621,\"object-assign\":499}],620:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":621,\"object-assign\":499}],621:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,(function(e){return t[e]}))}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":499}],622:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,f=r.monthNamesShort||this.local.monthNamesShort,h=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,m=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},v=function(t,e){return e?\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]:\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=m(e);break;case\"M\":b+=v(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,f=-1,h=-1,p=-1,d=-1,g=-1,m=!1,v=!1,y=function(e,r){for(var n=1;A+n<t.length&&t.charAt(A+n)===e;)n++;return A+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(M).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,M);return M+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(M));return M+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(M,o[s].length).toLowerCase()===o[s].toLowerCase())return M+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,M)},T=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(M)):c.call(b,e.substring(M));return M+=t.length,t}return w(\"M\",c,u)},k=function(){if(e.charAt(M)!==t.charAt(A))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,M);M++},M=0,A=0;A<t.length;A++)if(v)\"'\"!==t.charAt(A)||y(\"'\")?k():v=!1;else switch(t.charAt(A)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=T();break;case\"y\":var S=A;m=!y(\"y\",2),A=S,h=x(\"y\",2);break;case\"Y\":h=x(\"Y\",2);break;case\"J\":f=x(\"J\")+.5,\".\"===e.charAt(M)&&(M++,x(\"J\"));break;case\"@\":f=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":f=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":M=e.length;break;case\"'\":y(\"'\")?k():v=!0;break;default:k()}if(M<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===h?h=this.today().year():h<100&&m&&(h+=-1===n?1900:this.today().year()-this.today().year()%100-(h<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,h,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(h,p);d>E;E=this.daysInMonth(h,p))p++,d-=E}return f>-1?this.fromJD(f):this.newDate(h,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":621,\"object-assign\":499}],623:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":151}],624:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":623}],625:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],626:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../constants/axis_placeable_objects\":746,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/font_attributes\":856,\"./arrow_paths\":625}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach((function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref),a=i.getRefType(e.xref),o=i.getRefType(e.yref);e._extremes={},\"range\"===a&&s(e,r),\"range\"===o&&s(e,n)}))}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],f=t[\"_\"+a+\"padminus\"],h={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+h,g=p-h,m=3*t.startarrowsize*t.arrowwidth||0,v=m+h,y=m-h;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,v),ppadminus:Math.max(f,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else v=s?v+s:v,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,v),ppadminus:Math.max(f,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./draw\":632}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,f=[],h=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?h:p:f).push(r);break}n===d&&i.visible&&\"onout\"===a&&h.push(r)}return{on:f,off:h,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),f={},h=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",h[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(f,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",h[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(f,s.getUpdateObj());return i.call(\"update\",t,{},f)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911}],629:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var f,h,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(f=a(\"arrowhead\"),h=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",f),a(\"startarrowsize\",h)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var m=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),v=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(m));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||v})}a(\"captureevents\",!!d)}},{\"../../lib\":778,\"../color\":643}],630:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,f=e._id.charAt(0),h=0;h<u.length;h++)l=u[h],c=\"annotations[\"+h+\"].\",l[f+\"ref\"]===e._id&&p(f),l[\"a\"+f+\"ref\"]===e._id&&p(\"a\"+f);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":805,\"fast-isnumeric\":241}],631:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,f=[\"x\",\"y\"],h=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=f[d],m=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==m)i.getFromId(p,m)._annIndices.push(e._index);if(i.coercePosition(e,p,a,m,g,.5),u){var v=\"a\"+g,y=i.coerceRef(t,e,p,v,\"pixel\",[\"pixel\",\"paper\"]);\"pixel\"!==y&&y!==m&&(y=e[v]=\"pixel\");var x=\"pixel\"===y?h[d]:.4;i.coercePosition(e,p,a,y,v,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":626,\"./common_defaults\":629}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../../plots/cartesian/axes\"),c=t(\"../color\"),u=t(\"../drawing\"),f=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),p=t(\"../../lib/setcursor\"),d=t(\"../dragelement\"),g=t(\"../../plot_api/plot_template\").arrayEditor,m=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=l.getFromId(t,r.xref),i=l.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),x(t,r,e,!1,n,i)}function y(t,e,r,n,i){var a=i[r],o=i[r+\"ref\"],s=-1!==r.indexOf(\"y\"),c=\"domain\"===l.getRefType(o),u=s?n.h:n.w;return t?c?a+(s?-e:e)/t._length:t.p2r(t.r2p(a)+e):a+(s?-e:e)/u}function x(t,e,r,a,v,x){var b,_,w=t._fullLayout,T=t._fullLayout._size,k=t._context.edits;a?(b=\"annotation-\"+a,_=a+\".annotations\"):(b=\"annotation\",_=\"annotations\");var M=g(t.layout,_,e),A=M.modifyBase,S=M.modifyItem,E=M.getUpdateObj;w._infolayer.selectAll(\".\"+b+'[data-index=\"'+r+'\"]').remove();var C=\"clip\"+w._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var L={x:{},y:{}},I=+e.textangle||0,P=w._infolayer.append(\"g\").classed(b,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),z=P.append(\"g\").classed(\"annotation-text-g\",!0),O=k[e.showarrow?\"annotationTail\":\"annotationPosition\"],D=e.captureevents||k.annotationText||O,R=z.append(\"g\").style(\"pointer-events\",D?\"all\":null).call(p,\"pointer\").on(\"click\",(function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",Y(n.event))}));e.hovertext&&R.on(\"mouseover\",(function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();f.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:w._hoverlayer.node(),outerContainer:w._paper.node(),gd:t})})).on(\"mouseout\",(function(){f.loneUnhover(w._hoverlayer.node())}));var F=e.borderwidth,B=e.borderpad,N=F+B,j=R.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",F+\"px\").call(c.stroke,e.bordercolor).call(c.fill,e.bgcolor),U=e.width||e.height,V=w._topclips.selectAll(\"#\"+C).data(U?[0]:[]);V.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",C).append(\"rect\"),V.exit().remove();var q=e.font,H=w._meta?o.templateString(e.text,w._meta):e.text,G=R.append(\"text\").classed(\"annotation-text\",!0).text(H);k.annotationText?G.call(h.makeEditable,{delegate:R,gd:t}).call(W).on(\"edit\",(function(r){e.text=r,this.call(W),S(\"text\",r),v&&v.autorange&&A(v._name+\".autorange\",!0),x&&x.autorange&&A(x._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,E())})):G.call(W)}else n.selectAll(\"#\"+C).remove();function Y(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function W(r){return r.call(u.font,q).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,X),r}function X(){var r=G.selectAll(\"a\");1===r.size()&&r.text()===G.text()&&R.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(j.node());var n=R.select(\".annotation-text-math-group\"),f=!n.empty(),g=u.bBox((f?n:G).node()),b=g.width,_=g.height,M=e.width||b,D=e.height||_,B=Math.round(M+2*N),q=Math.round(D+2*N);function H(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var W=!1,X=[\"x\",\"y\"],Z=0;Z<X.length;Z++){var J,K,Q,$,tt,et=X[Z],rt=e[et+\"ref\"]||et,nt=e[\"a\"+et+\"ref\"],it={x:v,y:x}[et],at=(I+(\"x\"===et?0:-90))*Math.PI/180,ot=B*Math.cos(at),st=q*Math.sin(at),lt=Math.abs(ot)+Math.abs(st),ct=e[et+\"anchor\"],ut=e[et+\"shift\"]*(\"x\"===et?1:-1),ft=L[et],ht=l.getRefType(rt);if(it&&\"domain\"!==ht){var pt=it.r2fraction(e[et]);(pt<0||pt>1)&&(nt===rt?((pt=it.r2fraction(e[\"a\"+et]))<0||pt>1)&&(W=!0):W=!0),J=it._offset+it.r2p(e[et]),$=.5}else{var dt=\"domain\"===ht;\"x\"===et?(Q=e[et],J=dt?it._offset+it._length*Q:J=T.l+T.w*Q):(Q=1-e[et],J=dt?it._offset+it._length*Q:J=T.t+T.h*Q),$=e.showarrow?.5:Q}if(e.showarrow){ft.head=J;var gt=e[\"a\"+et];if(tt=ot*H(.5,e.xanchor)-st*H(.5,e.yanchor),nt===rt){var mt=l.getRefType(nt);\"domain\"===mt?(\"y\"===et&&(gt=1-gt),ft.tail=it._offset+it._length*gt):\"paper\"===mt?\"y\"===et?(gt=1-gt,ft.tail=T.t+T.h*gt):ft.tail=T.l+T.w*gt:ft.tail=it._offset+it.r2p(gt),K=tt}else ft.tail=J+gt,K=tt+gt;ft.text=ft.tail+tt;var vt=w[\"x\"===et?\"width\":\"height\"];if(\"paper\"===rt&&(ft.head=o.constrain(ft.head,1,vt-1)),\"pixel\"===nt){var yt=-Math.max(ft.tail-3,ft.text),xt=Math.min(ft.tail+3,ft.text)-vt;yt>0?(ft.tail+=yt,ft.text+=yt):xt>0&&(ft.tail-=xt,ft.text-=xt)}ft.tail+=ut,ft.head+=ut}else K=tt=lt*H($,ct),ft.text=J+tt;ft.text+=ut,tt+=ut,K+=ut,e[\"_\"+et+\"padplus\"]=lt/2+K,e[\"_\"+et+\"padminus\"]=lt/2-K,e[\"_\"+et+\"size\"]=lt,e[\"_\"+et+\"shift\"]=tt}if(W)R.remove();else{var bt=0,_t=0;if(\"left\"!==e.align&&(bt=(M-b)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(_t=(D-_)*(\"middle\"===e.valign?.5:1)),f)n.select(\"svg\").attr({x:N+bt-1,y:N+_t}).call(u.setClipUrl,U?C:null,t);else{var wt=N+_t-g.top,Tt=N+bt-g.left;G.call(h.positionText,Tt,wt).call(u.setClipUrl,U?C:null,t)}V.select(\"rect\").call(u.setRect,N,N,M,D),j.call(u.setRect,F/2,F/2,B-F,q-F),R.call(u.setTranslate,Math.round(L.x.text-B/2),Math.round(L.y.text-q/2)),z.attr({transform:\"rotate(\"+I+\",\"+L.x.text+\",\"+L.y.text+\")\"});var kt,Mt=function(r,n){P.selectAll(\".annotation-arrow-g\").remove();var l=L.x.head,f=L.y.head,h=L.x.tail+r,p=L.y.tail+n,g=L.x.text+r,b=L.y.text+n,_=o.rotationXYMatrix(I,g,b),w=o.apply2DTransform(_),M=o.apply2DTransform2(_),C=+j.attr(\"width\"),O=+j.attr(\"height\"),D=g-.5*C,F=D+C,B=b-.5*O,N=B+O,U=[[D,B,D,N],[D,N,F,N],[F,N,F,B],[F,B,D,B]].map(M);if(!U.reduce((function(t,e){return t^!!o.segmentsIntersect(l,f,l+1e6,f+1e6,e[0],e[1],e[2],e[3])}),!1)){U.forEach((function(t){var e=o.segmentsIntersect(h,p,l,f,t[0],t[1],t[2],t[3]);e&&(h=e.x,p=e.y)}));var V=e.arrowwidth,q=e.arrowcolor,H=e.arrowside,G=P.append(\"g\").style({opacity:c.opacity(q)}).classed(\"annotation-arrow-g\",!0),Y=G.append(\"path\").attr(\"d\",\"M\"+h+\",\"+p+\"L\"+l+\",\"+f).style(\"stroke-width\",V+\"px\").call(c.stroke,c.rgb(q));if(m(Y,H,e),k.annotationPosition&&Y.node().parentNode&&!a){var W=l,X=f;if(e.standoff){var Z=Math.sqrt(Math.pow(l-h,2)+Math.pow(f-p,2));W+=e.standoff*(h-l)/Z,X+=e.standoff*(p-f)/Z}var J,K,Q=G.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(h-W)+\",\"+(p-X),transform:s(W,X)}).style(\"stroke-width\",V+6+\"px\").call(c.stroke,\"rgba(0,0,0,0)\").call(c.fill,\"rgba(0,0,0,0)\");d.init({element:Q.node(),gd:t,prepFn:function(){var t=u.getTranslate(R);J=t.x,K=t.y,v&&v.autorange&&A(v._name+\".autorange\",!0),x&&x.autorange&&A(x._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(J,K),i=n[0]+t,a=n[1]+r;R.call(u.setTranslate,i,a),S(\"x\",y(v,t,\"x\",T,e)),S(\"y\",y(x,r,\"y\",T,e)),e.axref===e.xref&&S(\"ax\",y(v,t,\"ax\",T,e)),e.ayref===e.yref&&S(\"ay\",y(x,r,\"ay\",T,e)),G.attr(\"transform\",s(t,r)),z.attr({transform:\"rotate(\"+I+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&Mt(0,0),O)d.init({element:R.node(),gd:t,prepFn:function(){kt=z.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?S(\"ax\",y(v,t,\"ax\",T,e)):S(\"ax\",e.ax+t),e.ayref===e.yref?S(\"ay\",y(x,r,\"ay\",T.w,e)):S(\"ay\",e.ay+r),Mt(t,r);else{if(a)return;var i,o;if(v)i=y(v,t,\"x\",T,e);else{var l=e._xsize/T.w,c=e.x+(e._xshift-e.xshift)/T.w-l/2;i=d.align(c+t/T.w,l,0,1,e.xanchor)}if(x)o=y(x,r,\"y\",T,e);else{var u=e._ysize/T.h,f=e.y-(e._yshift+e.yshift)/T.h-u/2;o=d.align(f-r/T.h,u,0,1,e.yanchor)}S(\"x\",i),S(\"y\",o),v&&x||(n=d.getCursor(v?.5:i,x?.5:o,e.xanchor,e.yanchor))}z.attr({transform:s(t,r)+kt}),p(R,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",Y(n))},doneFn:function(){p(R),i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:x}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axes\":828,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../fx\":683,\"./draw_arrow_head\":633,d3:169}],633:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\"),o=t(\"../../lib\"),s=o.strScale,l=o.strRotate,c=o.strTranslate;e.exports=function(t,e,r){var o,u,f,h,p=t.node(),d=a[r.arrowhead||0],g=a[r.startarrowhead||0],m=(r.arrowwidth||1)*(r.arrowsize||1),v=(r.arrowwidth||1)*(r.startarrowsize||1),y=e.indexOf(\"start\")>=0,x=e.indexOf(\"end\")>=0,b=d.backoff*m+r.standoff,_=g.backoff*v+r.startstandoff;if(\"line\"===p.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},u={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var w=o.x-u.x,T=o.y-u.y;if(h=(f=Math.atan2(T,w))+Math.PI,b&&_&&b+_>Math.sqrt(w*w+T*T))return void O();if(b){if(b*b>w*w+T*T)return void O();var k=b*Math.cos(f),M=b*Math.sin(f);u.x+=k,u.y+=M,t.attr({x2:u.x,y2:u.y})}if(_){if(_*_>w*w+T*T)return void O();var A=_*Math.cos(f),S=_*Math.sin(f);o.x-=A,o.y-=S,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===p.nodeName){var E=p.getTotalLength(),C=\"\";if(E<b+_)return void O();var L=p.getPointAtLength(0),I=p.getPointAtLength(.1);f=Math.atan2(L.y-I.y,L.x-I.x),o=p.getPointAtLength(Math.min(_,E)),C=\"0px,\"+_+\"px,\";var P=p.getPointAtLength(E),z=p.getPointAtLength(E-.1);h=Math.atan2(P.y-z.y,P.x-z.x),u=p.getPointAtLength(Math.max(0,E-b)),C+=E-(C?_+b:b)+\"px,\"+E+\"px\",t.style(\"stroke-dasharray\",C)}function O(){t.style(\"stroke-dasharray\",\"0px,100px\")}function D(e,a,o,u){e.path&&(e.noRotate&&(o=0),n.select(p.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:c(a.x,a.y)+l(180*o/Math.PI)+s(u)}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}y&&D(g,o,f,v),x&&D(d,u,h,m)}},{\"../../lib\":778,\"../color\":643,\"./arrow_paths\":625,d3:169}],634:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":626,\"./calc_autorange\":627,\"./click\":628,\"./convert_coords\":630,\"./defaults\":631,\"./draw\":632}],635:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../annotations/attributes\":626}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],637:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"../annotations/common_defaults\":629,\"./attributes\":635}],638:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var f=a[u],h=l[f],p=e[f+\"axis\"].r2fraction(h);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":879,\"../annotations/draw\":632}],639:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":778,\"../../registry\":911,\"./attributes\":635,\"./convert\":636,\"./defaults\":637,\"./draw\":638}],640:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":607,\"world-calendars/dist/calendars/coptic\":608,\"world-calendars/dist/calendars/discworld\":609,\"world-calendars/dist/calendars/ethiopian\":610,\"world-calendars/dist/calendars/hebrew\":611,\"world-calendars/dist/calendars/islamic\":612,\"world-calendars/dist/calendars/julian\":613,\"world-calendars/dist/calendars/mayan\":614,\"world-calendars/dist/calendars/nanakshahi\":615,\"world-calendars/dist/calendars/nepali\":616,\"world-calendars/dist/calendars/persian\":617,\"world-calendars/dist/calendars/taiwan\":618,\"world-calendars/dist/calendars/thai\":619,\"world-calendars/dist/calendars/ummalqura\":620,\"world-calendars/dist/main\":621,\"world-calendars/dist/plus\":622}],641:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:\"##\",w:\"##\",c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function h(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function p(t){return i.extendFlat({},l,{description:t})}function d(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var g={xcalendar:p(d(\"x\"))},m=i.extendFlat({},g,{ycalendar:p(d(\"y\"))}),v=i.extendFlat({},m,{zcalendar:p(d(\"z\"))}),y=p([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:v,surface:v,mesh3d:v,scattergl:m,ohlc:g,candlestick:g},layout:{calendar:p([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:y},yaxis:{calendar:y},scene:{xaxis:{calendar:y},yaxis:{calendar:y},zaxis:{calendar:y}},polar:{radialaxis:{calendar:y}}},transforms:{filter:{valuecalendar:p([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:p([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:h,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,p=h(r).fromJD(f),d=0;-1!==(d=t.indexOf(\"%\",d));)\"0\"===(n=t.charAt(d+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(d+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=u[i])?(c=\"##\"===l?\"##\":p.formatDate(l[n]),t=t.substr(0,d)+c+t.substr(d+a),d+=c.length):d+=a;return t}}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./calendars\":640}],642:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],643:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":642,\"fast-isnumeric\":241,tinycolor2:576}],644:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\"},ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,minexponent:n.minexponent,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/font_attributes\":856}],645:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],646:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function f(t,e){return n.coerce(u,c,l,t,e)}var h=f(\"thicknessmode\");f(\"thickness\",\"fraction\"===h?30/(r.width-r.margin.l-r.margin.r):30);var p=f(\"lenmode\");f(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),f(\"x\"),f(\"xanchor\"),f(\"xpad\"),f(\"y\"),f(\"yanchor\"),f(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),f(\"outlinecolor\"),f(\"outlinewidth\"),f(\"bordercolor\"),f(\"borderwidth\"),f(\"bgcolor\");var d=f(\"ticklabelposition\");a(u,c,f,\"linear\");var g={outerTicks:!1,font:r.font};-1!==d.indexOf(\"inside\")&&(g.bgColor=\"black\"),s(u,c,f,\"linear\",g),o(u,c,f,\"linear\",g),f(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(f,\"title.font\",r.font),f(\"title.side\")}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_mark_defaults\":850,\"../../plots/cartesian/tick_value_defaults\":851,\"./attributes\":644}],647:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=c.strTranslate,f=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),p=t(\"../drawing\"),d=t(\"../color\"),g=t(\"../titles\"),m=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,y=t(\"../../plots/cartesian/axis_defaults\"),x=t(\"../../plots/cartesian/position_defaults\"),b=t(\"../../plots/cartesian/layout_attributes\"),_=t(\"../../constants/alignment\"),w=_.LINE_SPACING,T=_.FROM_TL,k=_.FROM_BR,M=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+M.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return f(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var u=0;u<o.length;u++){var h=o[u],p=(n=h[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),(function(t){return t._id}));e.enter().append(\"g\").attr(\"class\",(function(t){return t._id})).classed(M.colorbar,!0),e.each((function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",M.cbbg),c.ensureSingle(r,\"g\",M.cbfills),c.ensureSingle(r,\"g\",M.cblines),c.ensureSingle(r,\"g\",M.cbaxis,(function(t){t.classed(M.crisp,!0)})),c.ensureSingle(r,\"g\",M.cbtitleunshift,(function(t){t.append(\"g\").classed(M.cbtitle,!0)})),c.ensureSingle(r,\"rect\",M.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,_=e.title,A=_.side,S=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),E=\"function\"==typeof v.color?v.color:function(){return v.color},C=\"function\"==typeof h?h:function(){return h},L=e._levels,I=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],f=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<f&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var h=e._filllevels;if(h)for(l=h.end+h.size/100,c=h.size,i=0;i<1e5&&(n=h.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map((function(t){return t-a.size/2}))).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);a.size<0&&(o.reverse(),s.reverse());return{line:o,fill:s}}(0,e,S),P=I.fill,z=I.line,O=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),D=O/l.w,R=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),F=R/l.h,B=e.xpad/l.w,N=(e.borderwidth+e.outlinewidth)/2,j=e.ypad/l.h,U=Math.round(e.x*l.w+e.xpad),V=e.x-D*({middle:.5,right:1}[e.xanchor]||0),q=e.y+F*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),H=Math.round(l.h*(1-q)),G=H-R;e._lenFrac=F,e._thickFrac=D,e._xLeftFrac=V,e._yBottomFrac=q;var Y=e._axis=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,ticklabelposition:e.ticklabelposition,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,minexponent:e.minexponent,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,noTicklabelmode:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,b,t,e)}return y(i,a,s,o,n),x(i,a,s,o),a}(r,e,S);Y.position=e.x+B+D,-1!==[\"top\",\"bottom\"].indexOf(A)&&(Y.title.side=A,Y.titlex=e.x+B,Y.titley=q+(\"top\"===_.side?F-j:j));if(v.color&&\"auto\"===e.tickmode){Y.tickmode=\"linear\",Y.tick0=L.start;var W=L.size,X=c.constrain((H-G)/50,4,15)+1,Z=(S[1]-S[0])/((e.nticks||X)*W);if(Z>1){var J=Math.pow(10,Math.floor(Math.log(Z)/Math.LN10));W*=J*c.roundUp(Z/J,[2,5,10]),(Math.abs(L.start)/L.size+1e-6)%1<2e-6&&(Y.tick0=0)}Y.dtick=W}Y.domain=[q+j,q+F-j],Y.setScale(),t.attr(\"transform\",u(Math.round(l.l),Math.round(l.t)));var K,Q=t.select(\".\"+M.cbtitleunshift).attr(\"transform\",u(-Math.round(l.l),-Math.round(l.t))),$=t.select(\".\"+M.cbaxis),tt=0;function et(n,i){var a={propContainer:Y,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+M.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),g.draw(r,n,f(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+B)*l.w,n=Y.title.font.size;t=\"top\"===A?(1-(q+F-j))*l.h+l.t+3+.75*n:(1-(q+j))*l.h+l.t-3-.25*n,et(Y._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+M.cbtitle),o=a.select(\"text\"),f=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+Y._id+\"title-math-group\").node(),d=15.6;if(o.node()&&(d=parseInt(o.node().style.fontSize,10)*w),h?(tt=p.bBox(h).height)>d&&(f[1]-=(tt-d)/2):o.node()&&!o.classed(M.jsPlaceholder)&&(tt=p.bBox(o.node()).height),tt){if(tt+=5,\"top\"===A)Y.domain[1]-=tt/l.h,f[1]*=-1;else{Y.domain[0]+=tt/l.h;var g=m.lineCount(o);f[1]+=(1-g)*d}a.attr(\"transform\",u(f[0],f[1])),Y.setScale()}}t.selectAll(\".\"+M.cbfills+\",.\"+M.cblines).attr(\"transform\",u(0,Math.round(l.h*(1-Y.domain[1])))),$.attr(\"transform\",u(0,Math.round(-l.t)));var y=t.select(\".\"+M.cbfills).selectAll(\"rect.\"+M.cbfill).attr(\"style\",\"\").data(P);y.enter().append(\"rect\").classed(M.cbfill,!0).style(\"stroke\",\"none\"),y.exit().remove();var x=S.map(Y.c2p).map(Math.round).sort((function(t,e){return t-e}));y.each((function(t,a){var o=[0===a?S[0]:(P[a]+P[a-1])/2,a===P.length-1?S[1]:(P[a]+P[a+1])/2].map(Y.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,x[0],x[1]);var s=n.select(this).attr({x:U,width:Math.max(O,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)p.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=C(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}}));var b=t.select(\".\"+M.cblines).selectAll(\"path.\"+M.cbline).data(v.color&&v.width?z:[]);b.enter().append(\"path\").classed(M.cbline,!0),b.exit().remove(),b.each((function(t){n.select(this).attr(\"d\",\"M\"+U+\",\"+(Math.round(Y.c2p(t))+v.width/2%1)+\"h\"+O).call(p.lineGroupStyle,v.width,E(t),v.dash)})),$.selectAll(\"g.\"+Y._id+\"tick,path\").remove();var _=U+O+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),T=s.calcTicks(Y),k=s.getTickSigns(Y)[2];return s.drawTicks(r,Y,{vals:\"inside\"===Y.ticks?s.clipEnds(Y,T):T,layer:$,path:s.makeTickPath(Y,_,k),transFn:s.makeTransTickFn(Y)}),s.drawLabels(r,Y,{vals:T,layer:$,transFn:s.makeTransTickLabelFn(Y),labelFns:s.makeLabelFns(Y,_)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=Y.title.font.size,e=Y._offset+Y._length/2,i=l.l+(Y.position||0)*l.w+(\"right\"===Y.side?10+t*(Y.showticklabels?1:.5):-10-t*(Y.showticklabels?.5:0));et(\"h\"+Y._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+Y._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=O+e.outlinewidth/2;if(-1===Y.ticklabelposition.indexOf(\"inside\")&&(n+=p.bBox($.node()).width),(K=Q.select(\"text\")).node()&&!K.classed(M.jsPlaceholder)){var i,o=Q.select(\".h\"+Y._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?p.bBox(o).width:p.bBox(Q.node()).right-U-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=H-G;t.select(\".\"+M.cbbg).attr({x:U-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:G-N,width:Math.max(s,2),height:Math.max(c+2*N,2)}).call(d.fill,e.bgcolor).call(d.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+M.cboutline).attr({x:U,y:G+e.ypad+(\"top\"===A?tt:0),width:Math.max(O,2),height:Math.max(c-2*e.ypad-tt,2)}).call(d.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var f=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",u(l.l-f,l.t));var h={},g=T[e.yanchor],m=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*g,h.b=c*m):(h.t=h.b=0,h.yt=e.y+e.len*g,h.yb=e.y-e.len*m);var v=T[e.xanchor],y=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*y;else{var x=s-O;h.l=x*v,h.r=x*y,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*y}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+u(r,o)),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)})),e.exit().each((function(e){a.autoMargin(t,e._id)})).remove(),e.order()}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/extend\":768,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_defaults\":830,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/cartesian/position_defaults\":845,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../colorscale/helpers\":654,\"../dragelement\":662,\"../drawing\":665,\"../titles\":738,\"./constants\":645,d3:169,tinycolor2:576}],648:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":778}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":644,\"./defaults\":646,\"./draw\":647,\"./has_colorbar\":648}],650:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,f=e.editTypeOverride||\"\",h=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(h+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",m=s+\"mid\",v=(o(h+p),o(h+d),o(h+g),{});v[d]=v[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:f||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:v},x[d]={valType:\"number\",dflt:null,editType:f||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:f||\"plot\",impliedEdits:y},x[m]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:v},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":795,\"../colorbar/attributes\":644,\"./scales.js\":658}],651:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,f=a(u),h=!1!==f.auto,p=f.min,d=f.max,g=f.mid,m=function(){return i.aggNums(Math.min,null,l)},v=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=m():h&&(p=u._colorAx&&n(p)?Math.min(p,m()):m()),void 0===d?d=v():h&&(d=u._colorAx&&n(d)?Math.max(d,v()):v()),h&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),f._sync(\"min\",p),f._sync(\"max\",d),f.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,f._sync(\"colorscale\",o))}},{\"../../lib\":778,\"./helpers\":654,\"fast-isnumeric\":241}],652:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var f in e._colorAxes)o(e[f],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":778,\"./helpers\":654}],653:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,f,h){var p=h.prefix,d=h.cLetter,g=\"_module\"in r,m=c(e,p),v=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,f,h)};if(g){var b=u._colorAxes||{},_=f(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",T=b[_];return void(T?(T[2].push(x),T[0]!==w&&(T[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var k=m[d+\"min\"],M=m[d+\"max\"],A=n(k)&&n(M)&&k<M;f(p+d+\"auto\",!A)?f(p+d+\"mid\"):(f(p+d+\"min\"),f(p+d+\"max\"));var S,E,C=m.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),f(p+\"autocolorscale\",S),f(p+\"colorscale\"),f(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(m)),f(p+\"showscale\",E)&&(p&&y&&(v._template=y),o(m,v,u)))}},{\"../../lib\":778,\"../../registry\":911,\"../colorbar/defaults\":646,\"../colorbar/has_colorbar\":648,\"./scales\":658,\"fast-isnumeric\":241}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function f(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)((s=\"c\"+(n=u[r]))in a||(s=\"z\"+n)in a)&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function h(t){for(var e=f(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var f=i(o[u]).toRgb();c[u]=[f.r,f.g,f.b,f.a]}var h,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,m=e.returnArray;return(h=d&&m?p:d?function(t){return g(p(t))}:m?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,h.range=function(){return o},h}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e,r){var n=e?o.nestedProperty(t,e).get()||{}:t,i=n[r||\"color\"],s=!1;if(o.isArrayOrTypedArray(i))for(var c=0;c<i.length;c++)if(a(i[c])){s=!0;break}return o.isPlainObject(n)&&(s||!0===n.showscale||a(n.cmin)&&a(n.cmax)||l(n.colorscale)||o.isPlainObject(n.colorbar))},extractOpts:f,extractScale:h,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(h(t),e)}}},{\"../../lib\":778,\"../color\":643,\"./scales\":658,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],655:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":650,\"./calc\":651,\"./cross_trace_defaults\":652,\"./defaults\":653,\"./helpers\":654,\"./layout_attributes\":656,\"./layout_defaults\":657,\"./scales\":658}],656:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":768,\"./attributes\":650,\"./scales\":658}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var f in c){var h=c[f];if(h[0])s=t[f]||{},(l=i.newContainer(e,f,\"coloraxis\"))._name=f,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<h[2].length;p++)h[2][p]();delete e._colorAxes[f]}}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"./defaults\":653,\"./layout_attributes\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:576}],659:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],660:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":778}],661:[function(t,e,r){\"use strict\";r.selectMode=function(t){return\"lasso\"===t||\"select\"===t},r.drawMode=function(t){return\"drawclosedpath\"===t||\"drawopenpath\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.openMode=function(t){return\"drawline\"===t||\"drawopenpath\"===t},r.rectMode=function(t){return\"select\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.freeMode=function(t){return\"lasso\"===t||\"drawclosedpath\"===t||\"drawopenpath\"===t},r.selectingOrDrawing=function(t){return r.freeMode(t)||r.rectMode(t)}},{}],662:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function f(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,h,p,d,g,m=t.gd,v=1,y=m._context.doubleClickDelay,x=t.element;m._mouseDownTime||(m._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){m._dragged=!1,m._dragging=!0;var o=f(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-m._mouseDownTime<y?v+=1:(v=1,m._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(h=u()).style.cursor=window.getComputedStyle(x).cursor:i||(h=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",T),document.addEventListener(\"touchend\",T),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w,{passive:!1}))}function w(n){n.preventDefault();var i=f(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(m._dragged=!0,l.unhover(m)),m._dragged&&t.moveFn&&!g&&(m._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function T(e){if(delete m._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",T),document.removeEventListener(\"touchend\",T),i?o(h):c&&(h.documentElement.style.cursor=c,c=null),m._dragging){if(m._dragging=!1,(new Date).getTime()-m._mouseDownTime>y&&(v=Math.max(v-1,1)),m._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(v,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=f(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}m._dragging=!1,m._dragged=!1}else m._dragged=!1}},l.coverSlip=u},{\"../../lib\":778,\"../../plots/cartesian/constants\":834,\"./align\":659,\"./cursor\":660,\"./unhover\":663,\"has-hover\":440,\"has-passive-events\":441,\"mouse-event-offset\":484}],663:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":766,\"../../lib/events\":767,\"../../lib/throttle\":804,\"../fx/constants\":677}],664:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=c.strTranslate,f=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),p=t(\"../../constants/alignment\").LINE_SPACING,d=t(\"../../constants/interactions\").DESELECTDIM,g=t(\"../../traces/scatter/subtypes\"),m=t(\"../../traces/scatter/make_bubble_size_func\"),v=t(\"../../components/fx/helpers\").appendArrayPointValue,y=e.exports={};y.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},y.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},y.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},y.setRect=function(t,e,r,n,i){t.call(y.setPosition,e,r).call(y.setSize,n,i)},y.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",u(a,o)),!0)},y.translatePoints=function(t,e,r){t.each((function(t){var i=n.select(this);y.translatePoint(t,i,e,r)}))},y.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},y.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each((function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each((function(t){y.hideOutsideRangePoint(t,n.select(this),r,i,s,l)}))}))}},y.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},y.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),y.dashLine(e,l,o)},y.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each((function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(y.dashLine,l,o)}))},y.dashLine=function(t,e,r){r=+r||0,e=y.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},y.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},y.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},y.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each((function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)}))};var x=t(\"./symbol_defs\");y.symbolNames=[],y.symbolFuncs=[],y.symbolNeedLines={},y.symbolNoDot={},y.symbolNoFill={},y.symbolList=[],Object.keys(x).forEach((function(t){var e=x[t],r=e.n;y.symbolList.push(r,String(r),t,r+100,String(r+100),t+\"-open\"),y.symbolNames[r]=t,y.symbolFuncs[r]=e.f,e.needLine&&(y.symbolNeedLines[r]=!0),e.noDot?y.symbolNoDot[r]=!0:y.symbolList.push(r+200,String(r+200),t+\"-dot\",r+300,String(r+300),t+\"-open-dot\"),e.noFill&&(y.symbolNoFill[r]=!0)}));var b=y.symbolNames.length;function _(t,e){var r=t%100;return y.symbolFuncs[r](e)+(t>=200?\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\":\"\")}y.symbolNumber=function(t){if(i(t))t=+t;else if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=y.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=b||t>=400?0:Math.floor(Math.max(t,0))};var w={x1:1,x2:0,y1:0,y2:0},T={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),M={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:w},horizontalreversed:{node:\"linearGradient\",attrs:w,reversed:!0},vertical:{node:\"linearGradient\",attrs:T},verticalreversed:{node:\"linearGradient\",attrs:T,reversed:!0}};y.gradient=function(t,e,r,i,o,l){for(var u=o.length,f=M[i],h=new Array(u),p=0;p<u;p++)f.reversed?h[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:h[p]=[k(100*o[p][0]),o[p][1]];var d=e._fullLayout,g=\"g\"+d._uid+\"-\"+r,m=d._defs.select(\".gradients\").selectAll(\"#\"+g).data([i+h.join(\";\")],c.identity);m.exit().remove(),m.enter().append(f.node).each((function(){var t=n.select(this);f.attrs&&t.attr(f.attrs),t.attr(\"id\",g);var e=t.selectAll(\"stop\").data(h);e.exit().remove(),e.enter().append(\"stop\"),e.each((function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})}))})),t.style(l,O(g,e)).style(l+\"-opacity\",null);var v=function(t){return\".\"+t.attr(\"class\").replace(/\\s/g,\".\")},y=v(n.select(t.node().parentNode))+\">\"+v(t);d._gradientUrlQueryParts[y]=1},y.initGradients=function(t){var e=t._fullLayout;c.ensureSingle(e._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove(),e._gradientUrlQueryParts={}},y.pointStyle=function(t,e,r){if(t.size()){var i=y.makePointStyleFns(e);t.each((function(t){y.singlePointStyle(t,n.select(this),e,i,r)}))}},y.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=y.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",_(u,l))}var f,h,p,d=!1;if(t.so)p=o.outlierwidth,h=o.outliercolor,f=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,h=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(f=s.defaultLine,d=!0),f=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(f=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,f).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",(t.isBlank?0:p)+\"px\");var m=a.gradient,v=t.mgt;if(v?d=!0:v=m&&m.type,Array.isArray(v)&&(v=v[0],M[v]||(v=0)),v&&\"none\"!==v){var x=t.mgc;x?d=!0:x=m.color;var b=r.uid;d&&(b+=\"-\"+t.i),y.gradient(e,i,b,v,[[0,x],[1,f]],\"fill\")}else s.fill(e,f);p&&s.stroke(e,h)}},y.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=y.tryColorscale(r,\"\"),e.lineScale=y.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=g.isBubble(t)?m(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,y.makeSelectedPointStyleFns(t)),e},y.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,f=s.opacity,h=void 0!==u,p=void 0!==f;(c.isArrayOrTypedArray(l)||h||p)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?h?u:e:p?f:d*e});var g=i.color,m=a.color,v=s.color;(m||v)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?m||e:v||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},y.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,d))},e},y.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=y.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push((function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))})),r.selectedColorFn&&a.push((function(t,e){s.fill(t,r.selectedColorFn(e))})),r.selectedSizeFn&&a.push((function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",_(y.symbolNumber(n),a)),e.mrc2=a})),a.length&&t.each((function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)}))}},y.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function S(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(f.lineCount(t)-1)*p+1,h=A[s]*l,d=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",u(h,d))}function E(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}y.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=y.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}var o=e.texttemplate,s=r._fullLayout;t.each((function(t){var a=n.select(this),l=o?c.extractOption(t,e,\"txt\",\"texttemplate\"):c.extractOption(t,e,\"tx\",\"text\");if(l||0===l){if(o){var u=e._module.formatLabels?e._module.formatLabels(t,e,s):{},h={};v(h,e,t.i);var p=e._meta||{};l=c.texttemplateString(l,u,s._d3locale,h,t,p)}var d=t.tp||e.textposition,g=E(t,e),m=i?i(t):t.tc||e.textfont.color;a.call(y.font,t.tf||e.textfont.family,g,m).text(l).call(f.convertToTspans,r).call(S,d,g,t.mrc)}else a.remove()}))}},y.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=y.makeSelectedTextStyleFns(e);t.each((function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=E(t,e);s.fill(i,a),S(i,o,l,t.mrc2||t.mrc)}))}};function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,.25),u=Math.pow(s*s+l*l,.25),f=(u*u*a-c*c*s)*i,h=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&f/p),2),n.round(e[1]+(p&&h/p),2)],[n.round(e[0]-(d&&f/d),2),n.round(e[1]-(d&&h/d),2)]]}y.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},y.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},I=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};y.steps=function(t){var e=L[t]||I;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},y.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",(function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})})),e=c.ensureSingle(t,\"path\",\"js-reference-point\",(function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})}));y.tester=t,y.testref=e},y.savedBBoxes={};var P=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function O(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}y.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=y.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,u=+s.getAttribute(\"y\")||0,h=s.getAttribute(\"transform\");if(!h){var p=y.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),u&&(p.top+=u,p.bottom+=u),p}if(r+=\"~\"+l+\"~\"+u+\"~\"+h,i=y.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=y.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(f.positionText,0,0);var d=a.getBoundingClientRect(),g=y.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return P>=1e4&&(y.savedBBoxes={},P=0),r&&(y.savedBBoxes[r]=m),P++,c.extendFlat({},m)},y.setClipUrl=function(t,e,r){t.attr(\"clip-path\",O(e,r))},y.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},y.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=u(e,r)).trim(),t[i](\"transform\",a),a},y.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},y.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\"scale(\"+e+\",\"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;y.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\"scale(\"+e+\",\"+r+\")\";t.each((function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)}))}};var R=/translate\\([^)]*\\)\\s*$/;y.setTextPointsScale=function(t,e,r){t&&t.each((function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[u(o,s),\"scale(\"+e+\",\"+r+\")\",u(-o,-s)],l&&t.push(l),i.attr(\"transform\",t.join(\"\"))}}))}},{\"../../components/fx/helpers\":679,\"../../constants/alignment\":745,\"../../constants/interactions\":752,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../registry\":911,\"../../traces/scatter/make_bubble_size_func\":1204,\"../../traces/scatter/subtypes\":1212,\"../color\":643,\"../colorscale\":655,\"./symbol_defs\":666,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],666:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0},\"arrow-up\":{n:45,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-down\":{n:46,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-left\":{n:47,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-right\":{n:48,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-bar-up\":{n:49,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-down\":{n:50,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-left\":{n:51,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-right\":{n:52,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0}}},{d3:169}],667:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],668:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),f=0;f<t.length;f++){var h=t[f],p=h.i;if(void 0===p)p=f;else if(null===p)continue;var d=h[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var m=h[i+\"s\"]=d-g[0],v=h[i+\"h\"]=d+g[1];c.push(m,v)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./compute_error\":669,\"fast-isnumeric\":241}],669:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],670:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),f=t[c]||{};function h(t,e){return a.coerce(f,u,s,t,e)}if(!1!==h(\"visible\",void 0!==f.array||void 0!==f.value||\"sqrt\"===f.type)){var p=h(\"type\",\"array\"in f?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=h(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in f))),\"data\"===p?(h(\"array\"),h(\"traceref\"),d||(h(\"arrayminus\"),h(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(h(\"value\"),d||h(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&h(g,!(f.color||n(f.thickness)||n(f.width)));l.inherit&&u[g]||(h(\"color\",r),h(\"thickness\"),h(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911,\"./attributes\":667,\"fast-isnumeric\":241}],671:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":778,\"../../plot_api/edit_types\":810,\"./attributes\":667,\"./calc\":668,\"./compute_error\":669,\"./defaults\":670,\"./plot\":672,\"./style\":673}],672:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each((function(e){var f,h=e[0].trace,p=h.error_x||{},d=h.error_y||{};h.ids&&(f=function(t){return t.id});var g=o.hasMarkers(h)&&h.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var m=n.select(this).selectAll(\"g.errorbar\").data(e,f);if(m.exit().remove(),e.length){p.visible||m.selectAll(\"path.xerror\").remove(),d.visible||m.selectAll(\"path.yerror\").remove(),m.style(\"opacity\",1);var v=m.enter().append(\"g\").classed(\"errorbar\",!0);u&&v.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(m,r.layerClipId,t),m.each((function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var f=d.width;a=\"M\"+(r.x-f)+\",\"+r.yh+\"h\"+2*f+\"m-\"+f+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+f+\",0h\"+2*f),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var h=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var m=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-m)+\"v\"+2*m+\"m0,-\"+m+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+m+\"v\"+2*m),!h.size()?h=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(h=h.transition().duration(s.duration).ease(s.easing)),h.attr(\"d\",a)}else h.remove()}}))}}))}},{\"../../traces/scatter/subtypes\":1212,\"../drawing\":665,d3:169,\"fast-isnumeric\":241}],673:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each((function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)}))}},{\"../color\":643,d3:169}],674:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"./layout_attributes\":684}],675:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":778,\"../../registry\":911}],676:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":911,\"./hover\":680}],677:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,(function(r,a){return n.coerce(t,e,i,r,a)}),s)}},{\"../../lib\":778,\"./attributes\":674,\"./hoverlabel_defaults\":681}],679:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t.charAt(0)?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),f=new Array(r.length),h=0;h<r.length;h++)f[h]=o(u,r[h]);t[c]=f}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}var s={x:!0,y:!0},l={\"x unified\":!0,\"y unified\":!0};r.isUnifiedHover=function(t){return\"string\"==typeof t&&!!l[t]},r.isXYhover=function(t){return\"string\"==typeof t&&!!s[t]}},{\"../../lib\":778}],680:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=o.strTranslate,l=o.strRotate,c=t(\"../../lib/events\"),u=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/override_cursor\"),h=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../dragelement\"),g=t(\"../../plots/cartesian/axes\"),m=t(\"../../registry\"),v=t(\"./helpers\"),y=t(\"./constants\"),x=t(\"../legend/defaults\"),b=t(\"../legend/draw\"),_=y.YANGLE,w=Math.PI*_/180,T=1/Math.sin(w),k=Math.cos(w),M=Math.sin(w),A=y.HOVERARROWSIZE,S=y.HOVERTEXTPAD;function E(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")}r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+y.HOVERID,y.HOVERMINTIME,(function(){!function(t,e,r,a){r||(r=\"xy\");var s=Array.isArray(r)?r:[r],l=t._fullLayout,u=l._plots||[],h=u[r],g=l._has(\"cartesian\");if(h){var y=h.overlays.map((function(t){return t.id}));s=s.concat(y)}for(var x=s.length,b=new Array(x),_=new Array(x),w=!1,k=0;k<x;k++){var M=s[k];if(u[M])w=!0,b[k]=u[M].xaxis,_[k]=u[M].yaxis;else{if(!l[M]||!l[M]._subplot)return void o.warn(\"Unrecognized subplot: \"+M);var A=l[M]._subplot;b[k]=A.xaxis,_[k]=A.yaxis}}var S=e.hovermode||l.hovermode;S&&!w&&(S=\"closest\");if(-1===[\"x\",\"y\",\"closest\",\"x unified\",\"y unified\"].indexOf(S)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return d.unhoverRaw(t,e);var C,I,R,F,B,N,j,U,V,q,H,G,Y,W=-1===l.hoverdistance?1/0:l.hoverdistance,X=-1===l.spikedistance?1/0:l.spikedistance,Z=[],J=[],K={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(S=\"array\",R=0;R<e.length;R++)(B=t.calcdata[e[R].curveNumber||0])&&(N=B[0].trace,\"skip\"!==B[0].trace.hoverinfo&&(J.push(B),\"h\"===N.orientation&&(Q=!0)));else{for(F=0;F<t.calcdata.length;F++)B=t.calcdata[F],\"skip\"!==(N=B[0].trace).hoverinfo&&v.isTraceInSubplots(N,s)&&(J.push(B),\"h\"===N.orientation&&(Q=!0));var $,tt;if(!e.target)$=\"xpx\"in e?e.xpx:b[0]._length/2,tt=\"ypx\"in e?e.ypx:_[0]._length/2;else{if(!1===c.triggerHandler(t,\"plotly_beforehover\",e))return;var et=e.target.getBoundingClientRect();$=e.clientX-et.left,tt=e.clientY-et.top,l._calcInverseTransform(t);var rt=o.apply3DTransform(l._invTransform)($,tt);if($=rt[0],tt=rt[1],$<0||$>b[0]._length||tt<0||tt>_[0]._length)return d.unhoverRaw(t,e)}if(e.pointerX=$+b[0]._offset,e.pointerY=tt+_[0]._offset,C=\"xval\"in e?v.flat(s,e.xval):v.p2c(b,$),I=\"yval\"in e?v.flat(s,e.yval):v.p2c(_,tt),!i(C[0])||!i(I[0]))return o.warn(\"Fx.hover failed\",e,t),d.unhoverRaw(t,e)}var nt=1/0;function it(t,r){for(F=0;F<J.length;F++)if((B=J[F])&&B[0]&&B[0].trace&&!0===(N=B[0].trace).visible&&0!==N._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(N._module.name)){if(\"splom\"===N.type?j=s[U=0]:(j=v.getSubplot(N),U=s.indexOf(j)),V=S,v.isUnifiedHover(V)&&(V=V.charAt(0)),G={cd:B,trace:N,xa:b[U],ya:_[U],maxHoverDistance:W,maxSpikeDistance:X,index:!1,distance:Math.min(nt,W),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:p.defaultLine,name:N.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},l[j]&&(G.subplot=l[j]._subplot),l._splomScenes&&l._splomScenes[N.uid]&&(G.scene=l._splomScenes[N.uid]),Y=Z.length,\"array\"===V){var n=e[F];\"pointNumber\"in n?(G.index=n.pointNumber,V=\"closest\"):(V=\"\",\"xval\"in n&&(q=n.xval,V=\"x\"),\"yval\"in n&&(H=n.yval,V=V?\"closest\":\"y\"))}else void 0!==t&&void 0!==r?(q=t,H=r):(q=C[U],H=I[U]);if(0!==W)if(N._module&&N._module.hoverPoints){var a=N._module.hoverPoints(G,q,H,V,l._hoverlayer);if(a)for(var c,u=0;u<a.length;u++)c=a[u],i(c.x0)&&i(c.y0)&&Z.push(z(c,S))}else o.log(\"Unrecognized trace type in hover:\",N);if(\"closest\"===S&&Z.length>Y&&(Z.splice(0,Y),nt=Z[0].distance),g&&0!==X&&0===Z.length){G.distance=X,G.index=!1;var f=N._module.hoverPoints(G,q,H,\"closest\",l._hoverlayer);if(f&&(f=f.filter((function(t){return t.spikeDistance<=X}))),f&&f.length){var h,d=f.filter((function(t){return t.xa.showspikes&&\"hovered data\"!==t.xa.spikesnap}));if(d.length){var m=d[0];i(m.x0)&&i(m.y0)&&(h=ot(m),(!K.vLinePoint||K.vLinePoint.spikeDistance>h.spikeDistance)&&(K.vLinePoint=h))}var y=f.filter((function(t){return t.ya.showspikes&&\"hovered data\"!==t.ya.spikesnap}));if(y.length){var x=y[0];i(x.x0)&&i(x.y0)&&(h=ot(x),(!K.hLinePoint||K.hLinePoint.spikeDistance>h.spikeDistance)&&(K.hLinePoint=h))}}}}}function at(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<=i&&r<=e&&(n=t[a],i=r);return n}function ot(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}it();var st={fullLayout:l,container:l._hoverlayer,outerContainer:l._paperdiv,event:e},lt=t._spikepoints,ct={vLinePoint:K.vLinePoint,hLinePoint:K.hLinePoint};if(t._spikepoints=ct,g&&0!==X&&0!==Z.length){var ut=at(Z.filter((function(t){return t.ya.showspikes})),X);K.hLinePoint=ot(ut);var ft=at(Z.filter((function(t){return t.xa.showspikes})),X);K.vLinePoint=ot(ft)}if(0===Z.length){var ht=d.unhoverRaw(t,e);return!g||null===K.hLinePoint&&null===K.vLinePoint||D(lt)&&O(t,K,st),ht}g&&D(lt)&&O(t,K,st);if(Z.sort((function(t,e){return t.distance-e.distance})),v.isXYhover(V)&&0!==Z[0].length&&\"splom\"!==Z[0].trace.type){var pt=Z[0],dt=pt.cd[pt.index],gt=\"group\"===l.boxmode||\"group\"===l.violinmode,mt=pt.xVal,vt=pt.xa;\"category\"===vt.type&&(mt=vt._categoriesMap[mt]),\"date\"===vt.type&&(mt=vt.d2c(mt)),dt&&dt.t&&dt.t.posLetter===vt._id&&gt&&(mt+=dt.t.dPos);var yt=pt.yVal;\"category\"===(vt=pt.ya).type&&(yt=vt._categoriesMap[yt]),\"date\"===vt.type&&(yt=vt.d2c(yt)),dt&&dt.t&&dt.t.posLetter===vt._id&&gt&&(yt+=dt.t.dPos),it(mt,yt);var xt={};Z=Z.filter((function(t){var e=E(t);if(!xt[e])return xt[e]=!0,xt[e]}))}var bt=t._hoverdata,_t=[];for(R=0;R<Z.length;R++){var wt=Z[R],Tt=v.makeEventData(wt,wt.trace,wt.cd);if(!1!==wt.hovertemplate){var kt=!1;wt.cd[wt.index]&&wt.cd[wt.index].ht&&(kt=wt.cd[wt.index].ht),wt.hovertemplate=kt||wt.trace.hovertemplate||!1}wt.eventData=[Tt],_t.push(Tt)}t._hoverdata=_t;var Mt=\"y\"===S&&(J.length>1||Z.length>1)||\"closest\"===S&&Q&&Z.length>1,At=p.combine(l.plot_bgcolor||p.background,l.paper_bgcolor),St={hovermode:S,rotateLabels:Mt,bgColor:At,container:l._hoverlayer,outerContainer:l._paperdiv,commonLabelOpts:l.hoverlabel,hoverdistance:l.hoverdistance},Et=L(Z,St,t);v.isUnifiedHover(S)||(!function(t,e,r){var n,i,a,o,s,l,c,u=0,f=1,h=t.size(),p=new Array(h),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}t.each((function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(f=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?T:1)/2,pmin:0,pmax:i?r.width:r.height}]})),p.sort((function(t,e){return t[0].posref-e[0].posref||f*(e[0].traceIndex-t[0].traceIndex)}));for(;!n&&u<=h;){for(u++,n=!0,o=0;o<p.length-1;){var m=p[o],v=p[o+1],y=m[m.length-1],x=v[0];if((i=y.pos+y.dp+y.size-x.pos-x.dp+x.size)>.01&&y.pmin===x.pmin&&y.pmax===x.pmax){for(s=v.length-1;s>=0;s--)v[s].dp+=i;for(m.push.apply(m,v),p.splice(o+1,1),c=0,s=m.length-1;s>=0;s--)c+=m[s].dp;for(a=c/m.length,s=m.length-1;s>=0;s--)m[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var b=p[o];for(s=b.length-1;s>=0;s--){var _=b[s],w=_.datum;w.offset=_.dp,w.del=_.del}}}(Et,Mt?\"xa\":\"ya\",l),P(Et,Mt,l._invScaleX,l._invScaleY));if(e.target&&e.target.tagName){var Ct=m.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,_t);f(n.select(e.target),Ct?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,bt))return;bt&&t.emit(\"plotly_unhover\",{event:e,points:bt});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:b,yaxes:_,xvals:C,yvals:I})}(t,e,r,a)}))},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map((function(t){return{color:t.color||p.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}})),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||p.background,container:a,outerContainer:o},l=L(i,s,e.gd),c=0,u=0;l.sort((function(t,e){return t.y0-e.y0})).each((function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)})).each((function(t){t.offset-=u}));var f=e.gd._fullLayout._invScaleX,h=e.gd._fullLayout._invScaleY;return P(l,s.rotateLabels,f,h),r?l:l.node()};var C=/<extra>([\\s\\S]*)<\\/extra>/;function L(t,e,r){var i=r._fullLayout,a=e.hovermode,c=e.rotateLabels,f=e.bgColor,d=e.container,g=e.outerContainer,m=e.commonLabelOpts||{},w=e.fontFamily||y.HOVERFONT,T=e.fontSize||y.HOVERFONTSIZE,k=t[0],M=k.xa,C=k.ya,L=\"y\"===a.charAt(0)?\"yLabel\":\"xLabel\",P=k[L],z=(String(P)||\"\").split(\" \")[0],O=g.node().getBoundingClientRect(),D=O.top,R=O.width,F=O.height,B=void 0!==P&&k.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(B){var N,j,U=!0;for(N=0;N<t.length;N++)if(U&&void 0===t[N].zLabel&&(U=!1),j=t[N].hoverinfo||t[N].trace.hoverinfo){var V=Array.isArray(j)?j:j.split(\"+\");if(-1===V.indexOf(\"all\")&&-1===V.indexOf(a)){B=!1;break}}U&&(B=!1)}var q=d.selectAll(\"g.axistext\").data(B?[0]:[]);function H(t){return t.filter((function(t){return void 0!==t.zLabelVal||(t[L]||\"\").split(\" \")[0]===z}))}if(q.enter().append(\"g\").classed(\"axistext\",!0),q.exit().remove(),q.each((function(){var e=n.select(this),l=o.ensureSingle(e,\"path\",\"\",(function(t){t.style({\"stroke-width\":\"1px\"})})),c=o.ensureSingle(e,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),f=m.bgcolor||p.defaultLine,d=m.bordercolor||p.contrast(f),g=p.contrast(f),v={family:m.font.family||w,size:m.font.size||T,color:m.font.color||g};l.style({fill:f,stroke:d}),c.text(P).call(h.font,v).call(u.positionText,0,0).call(u.convertToTspans,r),e.attr(\"transform\",\"\");var y,x,b=c.node().getBoundingClientRect();if(\"x\"===a){var _=\"top\"===M.side?\"-\":\"\";c.attr(\"text-anchor\",\"middle\").call(u.positionText,0,\"top\"===M.side?D-b.bottom-A-S:D-b.top+A+S),y=M._offset+(k.x0+k.x1)/2,x=C._offset+(\"top\"===M.side?0:C._length);var E=b.width/2+S;y<E?(y=E,l.attr(\"d\",\"M-\"+(E-A)+\",0L-\"+(E-2*A)+\",\"+_+A+\"H\"+(S+b.width/2)+\"v\"+_+(2*S+b.height)+\"H-\"+E+\"V\"+_+A+\"Z\")):y>i.width-E?(y=i.width-E,l.attr(\"d\",\"M\"+(E-A)+\",0L\"+E+\",\"+_+A+\"v\"+_+(2*S+b.height)+\"H-\"+E+\"V\"+_+A+\"H\"+(E-2*A)+\"Z\")):l.attr(\"d\",\"M0,0L\"+A+\",\"+_+A+\"H\"+(S+b.width/2)+\"v\"+_+(2*S+b.height)+\"H-\"+(S+b.width/2)+\"V\"+_+A+\"H-\"+A+\"Z\")}else{var L,I,z;\"right\"===C.side?(L=\"start\",I=1,z=\"\",y=M._offset+M._length):(L=\"end\",I=-1,z=\"-\",y=M._offset),x=C._offset+(k.y0+k.y1)/2,c.attr(\"text-anchor\",L),l.attr(\"d\",\"M0,0L\"+z+A+\",\"+A+\"V\"+(S+b.height/2)+\"h\"+z+(2*S+b.width)+\"V-\"+(S+b.height/2)+\"H\"+z+A+\"V-\"+A+\"Z\");var O,R=b.height/2,F=D-b.top-R,B=\"clip\"+i._uid+\"commonlabel\"+C._id;if(y<b.width+2*S+A){O=\"M-\"+(A+S)+\"-\"+R+\"h-\"+(b.width-S)+\"V\"+R+\"h\"+(b.width-S)+\"Z\";var N=b.width-y+S;u.positionText(c,N,F),\"end\"===L&&c.selectAll(\"tspan\").each((function(){var t=n.select(this),e=h.tester.append(\"text\").text(t.text()).call(h.font,v),r=e.node().getBoundingClientRect();Math.round(r.width)<Math.round(b.width)&&t.attr(\"x\",N-r.width),e.remove()}))}else u.positionText(c,I*(S+A),F),O=null;var j=i._topclips.selectAll(\"#\"+B).data(O?[0]:[]);j.enter().append(\"clipPath\").attr(\"id\",B).append(\"path\"),j.exit().remove(),j.select(\"path\").attr(\"d\",O),h.setClipUrl(c,O?B:null,r)}e.attr(\"transform\",s(y,x)),t=H(t)})),v.isUnifiedHover(a)){if(d.selectAll(\"g.hovertext\").remove(),void 0!==P&&k.distance<=e.hoverdistance&&(t=H(t)),0===t.length)return;var G={showlegend:!0,legend:{title:{text:P,font:i.hoverlabel.font},font:i.hoverlabel.font,bgcolor:i.hoverlabel.bgcolor,bordercolor:i.hoverlabel.bordercolor,borderwidth:1,tracegroupgap:7,traceorder:i.legend?i.legend.traceorder:void 0,orientation:\"v\"}},Y={};x(G,Y,r._fullData);var W=Y.legend;W.entries=[];for(var X=0;X<t.length;X++){var Z=I(t[X],!0,a,i,P),J=Z[0],K=Z[1],Q=t[X];Q.name=K,Q.text=\"\"!==K?K+\" : \"+J:J;var $=Q.cd[Q.index];$&&($.mc&&(Q.mc=$.mc),$.mcc&&(Q.mc=$.mcc),$.mlc&&(Q.mlc=$.mlc),$.mlcc&&(Q.mlc=$.mlcc),$.mlw&&(Q.mlw=$.mlw),$.mrc&&(Q.mrc=$.mrc),$.dir&&(Q.dir=$.dir)),Q._distinct=!0,W.entries.push([Q])}W.entries.sort((function(t,e){return t[0].trace.index-e[0].trace.index})),W.layer=d,b(r,W);var tt=o.mean(t.map((function(t){return(t.y0+t.y1)/2}))),et=o.mean(t.map((function(t){return(t.x0+t.x1)/2}))),rt=d.select(\"g.legend\"),nt=rt.node().getBoundingClientRect();et+=M._offset,tt+=C._offset-nt.height/2;var it=nt.width+2*S;!(et+it<=R)&&et-it>=0?et-=it:et+=2*S;var at=nt.height+2*S,ot=tt+at>=F;return at<=F&&(tt<=D?tt=C._offset+2*S:ot&&(tt=F-at)),rt.attr(\"transform\",s(et,tt)),rt}var st=d.selectAll(\"g.hovertext\").data(t,(function(t){return E(t)}));return st.enter().append(\"g\").classed(\"hovertext\",!0).each((function(){var t=n.select(this);t.append(\"rect\").call(p.fill,p.addOpacity(f,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(h.font,w,T)})),st.exit().remove(),st.each((function(t){var e=n.select(this).attr(\"transform\",\"\"),o=t.color;Array.isArray(o)&&(o=o[t.eventData[0].pointNumber]);var d=t.bgcolor||o,g=p.combine(p.opacity(d)?d:p.defaultLine,f),m=p.combine(p.opacity(o)?o:p.defaultLine,f),v=t.borderColor||p.contrast(g),y=I(t,B,a,i,P,e),x=y[0],b=y[1],k=e.select(\"text.nums\").call(h.font,t.fontFamily||w,t.fontSize||T,t.fontColor||v).text(x).attr(\"data-notex\",1).call(u.positionText,0,0).call(u.convertToTspans,r),M=e.select(\"text.name\"),E=0,C=0;if(b&&b!==x){M.call(h.font,t.fontFamily||w,t.fontSize||T,m).text(b).attr(\"data-notex\",1).call(u.positionText,0,0).call(u.convertToTspans,r);var L=M.node().getBoundingClientRect();E=L.width+2*S,C=L.height+2*S}else M.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:g,stroke:v});var z,O,N=k.node().getBoundingClientRect(),j=t.xa._offset+(t.x0+t.x1)/2,U=t.ya._offset+(t.y0+t.y1)/2,V=Math.abs(t.x1-t.x0),q=Math.abs(t.y1-t.y0),H=N.width+A+S+E;if(t.ty0=D-N.top,t.bx=N.width+2*S,t.by=Math.max(N.height+2*S,C),t.anchor=\"start\",t.txwidth=N.width,t.tx2width=E,t.offset=0,c)t.pos=j,z=U+q/2+H<=F,O=U-q/2-H>=0,\"top\"!==t.idealAlign&&z||!O?z?(U+=q/2,t.anchor=\"start\"):t.anchor=\"middle\":(U-=q/2,t.anchor=\"end\");else if(t.pos=U,z=j+V/2+H<=R,O=j-V/2-H>=0,\"left\"!==t.idealAlign&&z||!O)if(z)j+=V/2,t.anchor=\"start\";else{t.anchor=\"middle\";var G=H/2,Y=j+G-R,W=j-G;Y>0&&(j-=Y),W<0&&(j+=-W)}else j-=V/2,t.anchor=\"end\";k.attr(\"text-anchor\",t.anchor),E&&M.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",s(j,U)+(c?l(_):\"\"))})),st}function I(t,e,r,n,i,a){var s=\"\",l=\"\";void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),s=R(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(l+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(l+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(l+=(l?\"z: \":\"\")+t.zLabel)):e&&t[r.charAt(0)+\"Label\"]===i?l=t[(\"x\"===r.charAt(0)?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(l=t.yLabel):l=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(l+=(l?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(l+=(l?\"<br>\":\"\")+t.extraText),a&&\"\"===l&&!t.hovertemplate&&(\"\"===s&&a.remove(),l=s);var c=n._d3locale,u=t.hovertemplate||!1,f=t.hovertemplateLabels||t,h=t.eventData[0]||{};return u&&(l=(l=o.hovertemplateString(u,f,c,h,t.trace._meta)).replace(C,(function(e,r){return s=R(r,t.nameLength),\"\"}))),[l,s]}function P(t,e,r,i){var a=function(t){return t*r},o=function(t){return t*i};t.each((function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),s=t.anchor,l=\"end\"===s?-1:1,c={start:1,end:-1,middle:0}[s],f=c*(A+S),p=f+c*(t.txwidth+S),d=0,g=t.offset,m=\"middle\"===s;m&&(f-=t.tx2width/2,p+=t.txwidth/2+S),e&&(g*=-M,d=t.offset*k),r.select(\"path\").attr(\"d\",m?\"M-\"+a(t.bx/2+t.tx2width/2)+\",\"+o(g-t.by/2)+\"h\"+a(t.bx)+\"v\"+o(t.by)+\"h-\"+a(t.bx)+\"Z\":\"M0,0L\"+a(l*A+d)+\",\"+o(A+g)+\"v\"+o(t.by/2-A)+\"h\"+a(l*t.bx)+\"v-\"+o(t.by)+\"H\"+a(l*A+d)+\"V\"+o(g-A)+\"Z\");var v=d+f,y=g+t.ty0-t.by/2+S,x=t.textAlign||\"auto\";\"auto\"!==x&&(\"left\"===x&&\"start\"!==s?(i.attr(\"text-anchor\",\"start\"),v=m?-t.bx/2-t.tx2width/2+S:-t.bx-S):\"right\"===x&&\"end\"!==s&&(i.attr(\"text-anchor\",\"end\"),v=m?t.bx/2-t.tx2width/2-S:t.bx+S)),i.call(u.positionText,a(v),o(y)),t.tx2width&&(r.select(\"text.name\").call(u.positionText,a(p+c*S+d),o(g+t.ty0-t.by/2+S)),r.select(\"rect\").call(h.setRect,a(p+(c-1)*t.tx2width/2+d),o(g-t.by/2-1),a(t.tx2width),o(t.by+2)))}))}function z(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:g.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:g.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var f=g.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+f+\" / -\"+g.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+f,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var h=g.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+h+\" / -\"+g.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+h,\"y\"===e&&(t.distance+=1)}var p=t.hoverinfo||t.trace.hoverinfo;return p&&\"all\"!==p&&(-1===(p=Array.isArray(p)?p:p.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===p.indexOf(\"y\")&&(t.yLabel=void 0),-1===p.indexOf(\"z\")&&(t.zLabel=void 0),-1===p.indexOf(\"text\")&&(t.text=void 0),-1===p.indexOf(\"name\")&&(t.name=void 0)),t}function O(t,e,r){var n,i,o=r.container,s=r.fullLayout,l=s._size,c=r.event,u=!!e.hLinePoint,f=!!e.vLinePoint;if(o.selectAll(\".spikeline\").remove(),f||u){var d=p.combine(s.plot_bgcolor,s.paper_bgcolor);if(u){var m,v,y=e.hLinePoint;n=y&&y.xa,\"cursor\"===(i=y&&y.ya).spikesnap?(m=c.pointerX,v=c.pointerY):(m=n._offset+y.x,v=i._offset+y.y);var x,b,_=a.readability(y.color,d)<1.5?p.contrast(d):y.color,w=i.spikemode,T=i.spikethickness,k=i.spikecolor||_,M=g.getPxPosition(t,i);if(-1!==w.indexOf(\"toaxis\")||-1!==w.indexOf(\"across\")){if(-1!==w.indexOf(\"toaxis\")&&(x=M,b=m),-1!==w.indexOf(\"across\")){var A=i._counterDomainMin,S=i._counterDomainMax;\"free\"===i.anchor&&(A=Math.min(A,i.position),S=Math.max(S,i.position)),x=l.l+A*l.w,b=l.l+S*l.w}o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T,stroke:k,\"stroke-dasharray\":h.dashStyle(i.spikedash,T)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T+2,stroke:d}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==w.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:M+(\"right\"!==i.side?T:-T),cy:v,r:T,fill:k}).classed(\"spikeline\",!0)}if(f){var E,C,L=e.vLinePoint;n=L&&L.xa,i=L&&L.ya,\"cursor\"===n.spikesnap?(E=c.pointerX,C=c.pointerY):(E=n._offset+L.x,C=i._offset+L.y);var I,P,z=a.readability(L.color,d)<1.5?p.contrast(d):L.color,O=n.spikemode,D=n.spikethickness,R=n.spikecolor||z,F=g.getPxPosition(t,n);if(-1!==O.indexOf(\"toaxis\")||-1!==O.indexOf(\"across\")){if(-1!==O.indexOf(\"toaxis\")&&(I=F,P=C),-1!==O.indexOf(\"across\")){var B=n._counterDomainMin,N=n._counterDomainMax;\"free\"===n.anchor&&(B=Math.min(B,n.position),N=Math.max(N,n.position)),I=l.t+(1-N)*l.h,P=l.t+(1-B)*l.h}o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:I,y2:P,\"stroke-width\":D,stroke:R,\"stroke-dasharray\":h.dashStyle(n.spikedash,D)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:I,y2:P,\"stroke-width\":D+2,stroke:d}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==O.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:E,cy:F-(\"top\"!==n.side?D:-D),r:D,fill:R}).classed(\"spikeline\",!0)}}}function D(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function R(t,e){return u.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":778,\"../../lib/events\":767,\"../../lib/override_cursor\":789,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../legend/defaults\":695,\"../legend/draw\":696,\"./constants\":677,\"./helpers\":679,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],681:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"./helpers\").isUnifiedHover;e.exports=function(t,e,r,o){function s(t){o.font[t]||(o.font[t]=e.legend?e.legend.font[t]:e.font[t])}o=o||{},e&&a(e.hovermode)&&(o.font||(o.font={}),s(\"size\"),s(\"family\"),s(\"color\"),e.legend?(o.bgcolor||(o.bgcolor=i.combine(e.legend.bgcolor,e.paper_bgcolor)),o.bordercolor||(o.bordercolor=e.legend.bordercolor)):o.bgcolor||(o.bgcolor=e.paper_bgcolor)),r(\"hoverlabel.bgcolor\",o.bgcolor),r(\"hoverlabel.bordercolor\",o.bordercolor),r(\"hoverlabel.namelength\",o.namelength),n.coerceFont(r,\"hoverlabel.font\",o.font),r(\"hoverlabel.align\",o.align)}},{\"../../lib\":778,\"../color\":643,\"./helpers\":679}],682:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return void 0!==e[r]?e[r]:n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");return e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=(r[a]||{})[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==o.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)}},{\"../../lib\":778,\"./layout_attributes\":684}],683:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",(function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)}))},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":778,\"../dragelement\":662,\"./attributes\":674,\"./calc\":675,\"./click\":676,\"./constants\":677,\"./defaults\":678,\"./helpers\":679,\"./hover\":680,\"./layout_attributes\":684,\"./layout_defaults\":685,\"./layout_global_defaults\":686,d3:169}],684:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"drawclosedpath\",\"drawopenpath\",\"drawline\",\"drawrect\",\"drawcircle\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1,\"x unified\",\"y unified\"],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":856,\"./constants\":677}],685:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").isUnifiedHover,a=t(\"./layout_attributes\"),o=t(\"./hovermode_defaults\"),s=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r){function l(r,i){return n.coerce(t,e,a,r,i)}var c=o(t,e,r);c&&(l(\"hoverdistance\"),l(\"spikedistance\",i(c)?-1:void 0)),\"select\"===l(\"dragmode\")&&l(\"selectdirection\");var u=e._has(\"mapbox\"),f=e._has(\"geo\"),h=e._basePlotModules.length;\"zoom\"===e.dragmode&&((u||f)&&1===h||u&&f&&2===h)&&(e.dragmode=\"pan\"),s(t,e,l)}},{\"../../lib\":778,\"./helpers\":679,\"./hoverlabel_defaults\":681,\"./hovermode_defaults\":682,\"./layout_attributes\":684}],686:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,(function(r,i){return n.coerce(t,e,a,r,i)}))}},{\"../../lib\":778,\"./hoverlabel_defaults\":681,\"./layout_attributes\":684}],687:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),f=u*(1-o),h=0;h<i;h++){var p=c+u*h;l[a?i-1-h:h]=[p,p+f]}return l}function f(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,f,h=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;h?(o=r.subplots.length,f=r.subplots[0].length):(d&&(o=a.length),p&&(f=i.length));var m=s.newContainer(e,\"grid\"),v=k(\"rows\",o),y=k(\"columns\",f);if(v*y>1){if(!h&&!p&&!d)\"independent\"===k(\"pattern\")&&(h=!0);m._hasSubplotGrid=h;var x,b,_=\"top to bottom\"===k(\"roworder\"),w=h?.2:.1,T=h?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),m._domains={x:u(\"x\",k,w,x,y),y:u(\"y\",k,T,b,v,_)}}else delete e.grid}function k(t,e){return n.coerce(r,m,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,h=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,m=r.columns,v=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=h.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(m),w=x[n]||[];for(i=0;i<m;i++)if(v?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var T=c(e,h,\"x\"),k=c(e,h,\"y\");r.xaxes=f(T,p.xaxis,m,y,\"x\"),r.yaxes=f(k,p.yaxis,g,y,\"y\")}var M=r._anchors={},A=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,I=S.charAt(0),P=r[I+\"side\"];if(P.length<8)M[S]=\"free\";else if(\"x\"===I){if(\"t\"===P.charAt(0)===A?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){M[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){M[S]=o;break}}else if(\"l\"===P.charAt(0)?(E=0,C=1,L=m):(E=m-1,C=-1,L=-1),d){var O=y[S];for(n=E;n!==L;n+=C)if((s=l[O][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){M[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){M[S]=a;break}}}}}},{\"../../lib\":778,\"../../lib/regex\":795,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/domain\":855}],688:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../constants/axis_placeable_objects\":746,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834}],689:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,f=e._id.charAt(0),h=0;h<u.length;h++)if(c=\"images[\"+h+\"].\",(l=u[h])[f+\"ref\"]===e._id){var p=l[f],d=l[\"size\"+f],g=null,m=null;if(o){g=i(p,e.range);var v=d/Math.pow(10,g)/2;m=2*Math.log(v+Math.sqrt(1+v*v))/Math.LN10}else m=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(m)||(m=null):(g=null,m=null),a(c+f,g),a(c+\"size\"+f,m)}}},{\"../../lib/to_log_range\":805,\"fast-isnumeric\":241}],690:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var f=c[u],h=i.coerceRef(t,e,l,f,\"paper\",void 0);if(\"paper\"!==h)i.getFromId(l,h)._imgIndices.push(e._index);i.coercePosition(e,l,a,h,f,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":688}],691:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/axis_ids\"),s=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,l=t._fullLayout,c=[],u={},f=[];for(r=0;r<l.images.length;r++){var h=l.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=o.ref2id(h.xref)+o.ref2id(h.yref);var p=l._plots[e];if(!p){f.push(h);continue}p.mainplot&&(e=p.mainplot.id),u[e]||(u[e]=[]),u[e].push(h)}else\"above\"===h.layer?c.push(h):f.push(h)}var d={left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},g={top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}};function m(e){var r=n.select(this);if(this._imgSrc!==e.source)if(r.attr(\"xmlns\",s.svg),e.source&&\"data:\"===e.source.slice(0,5))r.attr(\"xlink:href\",e.source),this._imgSrc=e.source;else{var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source,this._imgSrc=e.source}.bind(this));t._promises.push(i)}}function v(e){var r,o,s=n.select(this),c=a.getFromId(t,e.xref),u=a.getFromId(t,e.yref),f=\"domain\"===a.getRefType(e.xref),h=\"domain\"===a.getRefType(e.yref),p=l._size;r=void 0!==c?\"string\"==typeof e.xref&&f?c._length*e.sizex:Math.abs(c.l2p(e.sizex)-c.l2p(0)):e.sizex*p.w,o=void 0!==u?\"string\"==typeof e.yref&&h?u._length*e.sizey:Math.abs(u.l2p(e.sizey)-u.l2p(0)):e.sizey*p.h;var m,v,y=r*d[e.xanchor].offset,x=o*g[e.yanchor].offset,b=d[e.xanchor].sizing+g[e.yanchor].sizing;switch(m=void 0!==c?\"string\"==typeof e.xref&&f?c._length*e.x+c._offset:c.r2p(e.x)+c._offset:e.x*p.w+p.l,m+=y,v=void 0!==u?\"string\"==typeof e.yref&&h?u._length*(1-e.y)+u._offset:u.r2p(e.y)+u._offset:p.h-e.y*p.h+p.t,v+=x,e.sizing){case\"fill\":b+=\" slice\";break;case\"stretch\":b=\"none\"}s.attr({x:m,y:v,width:r,height:o,preserveAspectRatio:b,opacity:e.opacity});var _=(c&&\"domain\"!==a.getRefType(e.xref)?c._id:\"\")+(u&&\"domain\"!==a.getRefType(e.yref)?u._id:\"\");i.setClipUrl(s,_?\"clip\"+l._uid+_:null,t)}var y=l._imageLowerLayer.selectAll(\"image\").data(f),x=l._imageUpperLayer.selectAll(\"image\").data(c);y.enter().append(\"image\"),x.enter().append(\"image\"),y.exit().remove(),x.exit().remove(),y.each((function(t){m.bind(this)(t),v.bind(this)(t)})),x.each((function(t){m.bind(this)(t),v.bind(this)(t)}));var b=Object.keys(l._plots);for(r=0;r<b.length;r++){e=b[r];var _=l._plots[e];if(_.imagelayer){var w=_.imagelayer.selectAll(\"image\").data(u[e]||[]);w.enter().append(\"image\"),w.exit().remove(),w.each((function(t){m.bind(this)(t),v.bind(this)(t)}))}}}},{\"../../constants/xmlns_namespaces\":754,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_ids\":831,\"../drawing\":665,d3:169}],692:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":688,\"./convert_coords\":689,\"./defaults\":690,\"./draw\":691}],693:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemwidth:{valType:\"number\",min:30,dflt:30,editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"legend\"},font:n({editType:\"legend\"}),side:{valType:\"enumerated\",values:[\"top\",\"left\",\"top left\"],editType:\"legend\"},editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":856,\"../color/attributes\":642}],694:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,scrollBarEnterAttrs:{rx:20,ry:3,width:0,height:0},titlePad:2,itemGap:5}},{}],695:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c=t.legend||{},u=0,f=!1,h=\"normal\",p=0;p<r.length;p++){var d=r[p];d.visible&&((d.showlegend||d._dfltShowLegend&&!(d._module&&d._module.attributes&&d._module.attributes.showlegend&&!1===d._module.attributes.showlegend.dflt))&&(u++,d.showlegend&&(f=!0,(n.traceIs(d,\"pie-like\")||!0===d._input.showlegend)&&u++)),(n.traceIs(d,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(d.fill))&&(h=l.isGrouped({traceorder:h})?\"grouped+reversed\":\"reversed\"),void 0!==d.legendgroup&&\"\"!==d.legendgroup&&(h=l.isReversed({traceorder:h})?\"reversed+grouped\":\"grouped\"))}var g=i.coerce(t,e,s,\"showlegend\",f&&u>1);if(!1!==g||c.uirevision){var m=a.newContainer(e,\"legend\");if(_(\"uirevision\",e.uirevision),!1!==g){_(\"bgcolor\",e.paper_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),i.coerceFont(_,\"font\",e.font);var v,y,x,b=_(\"orientation\");\"h\"===b?(v=0,n.getComponentMethod(\"rangeslider\",\"isVisible\")(t.xaxis)?(y=1.1,x=\"bottom\"):(y=-.1,x=\"top\")):(v=1.02,y=1,x=\"auto\"),_(\"traceorder\",h),l.isGrouped(e.legend)&&_(\"tracegroupgap\"),_(\"itemsizing\"),_(\"itemwidth\"),_(\"itemclick\"),_(\"itemdoubleclick\"),_(\"x\",v),_(\"xanchor\"),_(\"y\",y),_(\"yanchor\",x),_(\"valign\"),i.noneOrAll(c,m,[\"x\",\"y\"]),_(\"title.text\")&&(_(\"title.side\",\"h\"===b?\"left\":\"top\"),i.coerceFont(_,\"title.font\",e.font))}}function _(t,e){return i.coerce(c,m,o,t,e)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/layout_attributes\":882,\"../../registry\":911,\"./attributes\":693,\"./helpers\":699}],696:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,m=d.FROM_TL,v=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout((function(){h(r,t,n)}),t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&h(r,t,n)}}function w(t,e,r){var n,a=t.data()[0][0],s=a.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,h=r._main&&e._context.edits.legendText&&!l,d=r._maxNameLength;r.entries?n=a.text:(n=l?a.label:s.name,s._meta&&(n=i.templateString(n,s._meta)));var g=i.ensureSingle(t,\"text\",\"legendtext\");g.attr(\"text-anchor\",\"start\").call(c.font,r.font).text(h?T(n,d):n);var m=r.itemwidth+2*p.itemGap;f.positionText(g,m,0),h?g.call(f.makeEditable,{gd:e,text:n}).call(M,t,e,r).on(\"edit\",(function(n){this.text(T(n,d)).call(M,t,e,r);var s=a.trace._fullInput||{},l={};if(o.hasTransform(s,\"groupby\")){var c=o.getTransformIndices(s,\"groupby\"),f=c[c.length-1],h=i.keyedContainer(s,\"transforms[\"+f+\"].styles\",\"target\",\"value.name\");h.set(a.trace._group,n),l=h.constructUpdate()}else l.name=n;return o.call(\"_guiRestyle\",e,l,u)})):M(g,t,e,r)}function T(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function k(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",(function(t){e._context.staticPlot||t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\"),t.call(u.fill,\"rgba(0,0,0,0)\")}));e._context.staticPlot||(s.on(\"mousedown\",(function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)})),s.on(\"mouseup\",(function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})))}function M(t,e,r,n){n._main||t.attr(\"data-notex\",!0),f.convertToTspans(t,r,(function(){!function(t,e,r){var n=t.data()[0][0];if(r._main&&n&&!n.trace.showlegend)return void t.remove();var i=t.select(\"g[class*=math-group]\"),a=i.node();r||(r=e._fullLayout.legend);var o,s,l=r.borderwidth,u=(n?r:r.title).font.size*g;if(a){var h=c.bBox(a);o=h.height,s=h.width,n?c.setTranslate(i,0,.25*o):c.setTranslate(i,l,.75*o+l)}else{var d=t.select(n?\".legendtext\":\".legendtitletext\"),m=f.lineCount(d),v=d.node();o=u*m,s=v?c.bBox(v).width:0;var y=u*((m-1)/2-.3);if(n){var x=r.itemwidth+2*p.itemGap;f.positionText(d,x,-y)}else f.positionText(d,p.titlePad+l,u+l)}n?(n.lineHeight=u,n.height=Math.max(o,16)+3,n.width=s):(r._titleWidth=s,r._titleHeight=o)}(e,r,n)}))}function A(t){return i.isRightAnchor(t)?\"right\":i.isCenterAnchor(t)?\"center\":\"left\"}function S(t){return i.isBottomAnchor(t)?\"bottom\":i.isMiddleAnchor(t)?\"middle\":\"top\"}e.exports=function(t,e){var r,s=t._fullLayout,f=\"legend\"+s._uid;if(e?(r=e.layer,f+=\"-hover\"):((e=s.legend||{})._main=!0,r=s._infolayer),r){var h;if(t._legendMouseDownTime||(t._legendMouseDownTime=0),e._main){if(!t.calcdata)return;h=s.showlegend&&y(t.calcdata,e)}else{if(!e.entries)return;h=y(e.entries,e)}var d=s.hiddenlabels||[];if(e._main&&(!s.showlegend||!h.length))return r.selectAll(\".legend\").remove(),s._topdefs.select(\"#\"+f).remove(),a.autoMargin(t,\"legend\");var g=i.ensureSingle(r,\"g\",\"legend\",(function(t){e._main&&t.attr(\"pointer-events\",\"all\")})),T=i.ensureSingleById(s._topdefs,\"clipPath\",f,(function(t){t.append(\"rect\")})),E=i.ensureSingle(g,\"rect\",\"bg\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));E.call(u.stroke,e.bordercolor).call(u.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\");var C=i.ensureSingle(g,\"g\",\"scrollbox\"),L=e.title;if(e._titleWidth=0,e._titleHeight=0,L.text){var I=i.ensureSingle(C,\"text\",\"legendtitletext\");I.attr(\"text-anchor\",\"start\").call(c.font,L.font).text(L.text),M(I,C,t,e)}else C.selectAll(\".legendtitletext\").remove();var P=i.ensureSingle(g,\"rect\",\"scrollbar\",(function(t){t.attr(p.scrollBarEnterAttrs).call(u.fill,p.scrollBarColor)})),z=C.selectAll(\"g.groups\").data(h);z.enter().append(\"g\").attr(\"class\",\"groups\"),z.exit().remove();var O=z.selectAll(\"g.traces\").data(i.identity);O.enter().append(\"g\").attr(\"class\",\"traces\"),O.exit().remove(),O.style(\"opacity\",(function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==d.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1})).each((function(){n.select(this).call(w,t,e)})).call(x,t,e).each((function(){e._main&&n.select(this).call(k,t)})),i.syncOrAsync([a.previousPromises,function(){return function(t,e,r,i){var a=t._fullLayout;i||(i=a.legend);var o=a._size,s=b.isVertical(i),l=b.isGrouped(i),u=i.borderwidth,f=2*u,h=p.itemGap,d=i.itemwidth+2*h,g=2*(u+h),m=S(i),v=i.y<0||0===i.y&&\"top\"===m,y=i.y>1||1===i.y&&\"bottom\"===m;i._maxHeight=Math.max(v||y?a.height/2:o.h,30);var x=0;i._width=0,i._height=0;var _=function(t){var e=0,r=0,n=t.title.side;n&&(-1!==n.indexOf(\"left\")&&(e=t._titleWidth),-1!==n.indexOf(\"top\")&&(r=t._titleHeight));return[e,r]}(i);if(s)r.each((function(t){var e=t[0].height;c.setTranslate(this,u+_[0],u+_[1]+i._height+e/2+h),i._height+=e,i._width=Math.max(i._width,t[0].width)})),x=d+i._width,i._width+=h+d+f,i._height+=g,l&&(e.each((function(t,e){c.setTranslate(this,0,e*i.tracegroupgap)})),i._height+=(i._lgroupsLength-1)*i.tracegroupgap);else{var w=A(i),T=i.x<0||0===i.x&&\"right\"===w,k=i.x>1||1===i.x&&\"left\"===w,M=y||v,E=a.width/2;i._maxWidth=Math.max(T?M&&\"left\"===w?o.l+o.w:E:k?M&&\"right\"===w?o.r+o.w:E:o.w,2*d);var C=0,L=0;r.each((function(t){var e=t[0].width+d;C=Math.max(C,e),L+=e})),x=null;var I=0;if(l){var P=0,z=0,O=0;e.each((function(){var t=0,e=0;n.select(this).selectAll(\"g.traces\").each((function(r){var n=r[0].height;c.setTranslate(this,_[0],_[1]+u+h+n/2+e),e+=n,t=Math.max(t,d+r[0].width)})),P=Math.max(P,e);var r=t+h;r+u+z>i._maxWidth&&(I=Math.max(I,z),z=0,O+=P+i.tracegroupgap,P=e),c.setTranslate(this,z,O),z+=r})),i._width=Math.max(I,z)+u,i._height=O+P+g}else{var D=r.size(),R=L+f+(D-1)*h<i._maxWidth,F=0,B=0,N=0,j=0;r.each((function(t){var e=t[0].height,r=d+t[0].width,n=(R?r:C)+h;n+u+B-h>=i._maxWidth&&(I=Math.max(I,j),B=0,N+=F,i._height+=F,F=0),c.setTranslate(this,_[0]+u+B,_[1]+u+N+e/2+h),j=B+r+h,B+=n,F=Math.max(F,e)})),R?(i._width=B+f,i._height=F+g):(i._width=Math.max(I,j)+f,i._height+=F+g)}}i._width=Math.ceil(Math.max(i._width+_[0],i._titleWidth+2*(u+p.titlePad))),i._height=Math.ceil(Math.max(i._height+_[1],i._titleHeight+2*(u+p.itemGap))),i._effHeight=Math.min(i._height,i._maxHeight);var U=t._context.edits,V=U.legendText||U.legendPosition;r.each((function(t){var e=n.select(this).select(\".legendtoggle\"),r=t[0].height,i=V?d:x||d+t[0].width;s||(i+=h/2),c.setRect(e,0,-r/2,i,r)}))}(t,z,O,e)},function(){if(!e._main||!function(t){var e=t._fullLayout.legend,r=A(e),n=S(e);return a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*m[r],r:e._width*v[r],b:e._effHeight*v[n],t:e._effHeight*m[n]})}(t)){var u,h,d,y,x=s._size,b=e.borderwidth,w=x.l+x.w*e.x-m[A(e)]*e._width,k=x.t+x.h*(1-e.y)-m[S(e)]*e._effHeight;if(e._main&&s.margin.autoexpand){var M=w,L=k;w=i.constrain(w,0,s.width-e._width),k=i.constrain(k,0,s.height-e._effHeight),w!==M&&i.log(\"Constrain legend.x to make legend fit inside graph\"),k!==L&&i.log(\"Constrain legend.y to make legend fit inside graph\")}if(e._main&&c.setTranslate(g,w,k),P.on(\".drag\",null),g.on(\"wheel\",null),!e._main||e._height<=e._maxHeight||t._context.staticPlot){var I=e._effHeight;e._main||(I=e._height),E.attr({width:e._width-b,height:I-b,x:b/2,y:b/2}),c.setTranslate(C,0,0),T.select(\"rect\").attr({width:e._width-2*b,height:I-2*b,x:b,y:b}),c.setClipUrl(C,f,t),c.setRect(P,0,0,0,0),delete e._scrollY}else{var z,O,D,R=Math.max(p.scrollBarMinHeight,e._effHeight*e._effHeight/e._height),F=e._effHeight-R-2*p.scrollBarMargin,B=e._height-e._effHeight,N=F/B,j=Math.min(e._scrollY||0,B);E.attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-b,x:b/2,y:b/2}),T.select(\"rect\").attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-2*b,x:b,y:b+j}),c.setClipUrl(C,f,t),q(j,R,N),g.on(\"wheel\",(function(){q(j=i.constrain(e._scrollY+n.event.deltaY/F*B,0,B),R,N),0!==j&&j!==B&&n.event.preventDefault()}));var U=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;z=\"touchstart\"===t.type?t.changedTouches[0].clientY:t.clientY,D=j})).on(\"drag\",(function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||(O=\"touchmove\"===t.type?t.changedTouches[0].clientY:t.clientY,q(j=function(t,e,r){var n=(r-e)/N+t;return i.constrain(n,0,B)}(D,z,O),R,N))}));P.call(U);var V=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;\"touchstart\"===t.type&&(z=t.changedTouches[0].clientY,D=j)})).on(\"drag\",(function(){var t=n.event.sourceEvent;\"touchmove\"===t.type&&(O=t.changedTouches[0].clientY,q(j=function(t,e,r){var n=(e-r)/N+t;return i.constrain(n,0,B)}(D,z,O),R,N))}));C.call(V)}if(t._context.edits.legendPosition)g.classed(\"cursor-move\",!0),l.init({element:g.node(),gd:t,prepFn:function(){var t=c.getTranslate(g);d=t.x,y=t.y},moveFn:function(t,r){var n=d+t,i=y+r;c.setTranslate(g,n,i),u=l.align(n,0,x.l,x.l+x.w,e.xanchor),h=l.align(i,0,x.t+x.h,x.t,e.yanchor)},doneFn:function(){void 0!==u&&void 0!==h&&o.call(\"_guiRelayout\",t,{\"legend.x\":u,\"legend.y\":h})},clickFn:function(e,n){var i=r.selectAll(\"g.traces\").filter((function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom}));i.size()>0&&_(t,g,i,e,n)}})}function q(r,n,i){e._scrollY=t._fullLayout.legend._scrollY=r,c.setTranslate(C,0,-r),c.setRect(P,e._width,p.scrollBarMargin+r*i,p.scrollBarWidth,n),T.select(\"rect\").attr(\"y\",b+r)}}],t)}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/events\":767,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"./constants\":694,\"./get_legend_data\":697,\"./handle_click\":698,\"./helpers\":699,\"./style\":701,d3:169}],697:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0,f=0,h=e._main;function p(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var d=t[r],g=d[0],m=g.trace,v=m.legendgroup;if(!h||m.visible&&m.showlegend)if(n.traceIs(m,\"pie-like\"))for(c[v]||(c[v]={}),a=0;a<d.length;a++){var y=d[a].label;c[v][y]||(p(v,{label:y,color:d[a].color,i:d[a].i,trace:m,pts:d[a].pts}),c[v][y]=!0,f=Math.max(f,(y||\"\").length))}else p(v,g),f=Math.max(f,(m.name||\"\").length)}if(!s.length)return[];var x,b,_=s.length;if(l&&i.isGrouped(e))for(b=new Array(_),r=0;r<_;r++)x=o[s[r]],b[r]=i.isReversed(e)?x.reverse():x;else{for(b=[new Array(_)],r=0;r<_;r++)x=o[s[r]][0],b[0][i.isReversed(e)?_-r-1:r]=x;_=1}return e._lgroupsLength=_,e._maxNameLength=f,b}},{\"../../registry\":911,\"./helpers\":699}],698:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,f,h,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],m=t.data()[0][0],v=e._fullData,y=m.trace,x=y.legendgroup,b={},_=[],w=[],T=[];if(i.traceIs(y,\"pie-like\")){var k=m.label,M=g.indexOf(k);\"toggle\"===s?-1===M?g.push(k):g.splice(M,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach((function(t){k!==t.label&&g.push(t.label)})),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===M&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var A,S=x&&x.length,E=[];if(S)for(u=0;u<v.length;u++)(A=v[u]).visible&&A.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<v.length;u++)!1!==v[u].visible&&v[u].legendgroup===x&&B(v[u],C);else B(y,C)}else if(\"toggleothers\"===s){var L,I,P,z,O=!0;for(u=0;u<v.length;u++)if(L=v[u]===y,P=!0!==v[u].showlegend,!(L||P||(I=S&&v[u].legendgroup===x)||!0!==v[u].visible||i.traceIs(v[u],\"notLegendIsolatable\"))){O=!1;break}for(u=0;u<v.length;u++)if(!1!==v[u].visible&&!i.traceIs(v[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":B(v[u],!0);break;case!0:z=!!O||\"legendonly\",L=v[u]===y,P=!0!==v[u].showlegend&&!v[u].legendgroup,I=L||S&&v[u].legendgroup===x,B(v[u],!(!I&&!P)||z)}}for(u=0;u<w.length;u++)if(h=w[u]){var D=h.constructUpdate(),R=Object.keys(D);for(f=0;f<R.length;f++)p=R[f],(b[p]=b[p]||[])[T[u]]=D[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],f=0;f<_.length;f++)b[p].hasOwnProperty(f)||(b[p][f]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function F(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function B(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),T[r.index]=F(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;F(r.index,\"visible\",c)}}}},{\"../../lib\":778,\"../../registry\":911}],699:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],700:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":693,\"./defaults\":695,\"./draw\":696,\"./style\":701}],701:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.strTranslate,s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../colorscale/helpers\").extractOpts,u=t(\"../../traces/scatter/subtypes\"),f=t(\"../../traces/pie/style_one\"),h=t(\"../../traces/pie/helpers\").castOption,p=t(\"./constants\");function d(t,e){return(e?\"radial\":\"horizontal\")+(t?\"\":\"reversed\")}e.exports=function(t,e,r){var g=e._fullLayout;r||(r=g.legend);var m=\"constant\"===r.itemsizing,v=r.itemwidth,y=(v+2*p.itemGap)/2,x=o(y,0),b=function(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return m?n:Math.min(i,r)};function _(t,e,r){var a=t[0].trace,o=a.marker||{},s=o.line||{},c=r?a.visible&&a.type===r:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),u.exit().remove(),u.each((function(t){var e=n.select(this),r=t[0],i=b(r.mlw,o.line,5,2);e.style(\"stroke-width\",i+\"px\").call(l.fill,r.mc||o.color),i&&l.stroke(e,r.mlc||s.color)}))}function w(t,e,r){var o=t[0],s=o.trace,l=r?s.visible&&s.type===r:i.traceIs(s,r),c=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(c.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),c.exit().remove(),c.size()){var u=(s.marker||{}).line,p=b(h(u.width,o.pts),u,5,2),d=a.minExtend(s,{marker:{line:{width:p}}});d.marker.line.color=u.color;var g=a.minExtend(o,{trace:d});f(c,g,d)}}t.each((function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var s=r.valign,l=t[0].lineHeight,c=t[0].height;if(\"middle\"!==s&&l&&c){var u={top:1,bottom:-1}[s]*(.5*(l-c+3));i.attr(\"transform\",o(0,u))}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var f=i.selectAll(\"g.legendsymbols\").data([t]);f.enter().append(\"g\").classed(\"legendsymbols\",!0),f.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)})).each((function(t){var r,i=t[0].trace,o=[];if(i.visible)switch(i.type){case\"histogram2d\":case\"heatmap\":o=[[\"M-15,-2V4H15V-2Z\"]],r=!0;break;case\"choropleth\":case\"choroplethmapbox\":o=[[\"M-6,-6V6H6V-6Z\"]],r=!0;break;case\"densitymapbox\":o=[[\"M-6,0 a6,6 0 1,0 12,0 a 6,6 0 1,0 -12,0\"]],r=\"radial\";break;case\"cone\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 V6L6,4Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 L6,-4Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 L6,0Z\"]],r=!1;break;case\"streamtube\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 H6 A2,2 0 0,1 6,2 Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 H6 A2,2 0 0,1 6,-6 Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 H6 A2,2 0 0,1 6,-2 Z\"]],r=!1;break;case\"surface\":o=[[\"M-6,-6 A2,3 0 0,0 -6,0 H6 A2,3 0 0,1 6,-6 Z\"],[\"M-6,1 A2,3 0 0,1 -6,6 H6 A2,3 0 0,0 6,0 Z\"]],r=!0;break;case\"mesh3d\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!1;break;case\"volume\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!0;break;case\"isosurface\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6 A12,24 0 0,0 6,-6 L0,6Z\"]],r=!1}var u=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legend3dandfriends\").data(o);u.enter().append(\"path\").classed(\"legend3dandfriends\",!0).attr(\"transform\",x).style(\"stroke-miterlimit\",1),u.exit().remove(),u.each((function(t,o){var u,f=n.select(this),h=c(i),p=h.colorscale,g=h.reversescale;if(p){if(!r){var m=p.length;u=0===o?p[g?m-1:0][1]:1===o?p[g?0:m-1][1]:p[Math.floor((m-1)/2)][1]}}else{var v=i.vertexcolor||i.facecolor||i.color;u=a.isArrayOrTypedArray(v)?v[o]||v[0]:v}f.attr(\"d\",t[0]),u?f.call(l.fill,u):f.call((function(t){if(t.size()){var n=\"legendfill-\"+i.uid;s.gradient(t,e,n,d(g,\"radial\"===r),p,\"fill\")}}))}))})).each((function(t){var e=t[0].trace,r=\"waterfall\"===e.type;if(t[0]._distinct&&r){var i=t[0].trace[t[0].dir].marker;return t[0].mc=i.color,t[0].mlw=i.line.width,t[0].mlc=i.line.color,_(t,this,\"waterfall\")}var a=[];e.visible&&r&&(a=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(a);o.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",x).style(\"stroke-miterlimit\",1),o.exit().remove(),o.each((function(t){var r=n.select(this),i=e[t[0]].marker,a=b(void 0,i.line,5,2);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(l.fill,i.color),a&&r.call(l.stroke,i.line.color)}))})).each((function(t){_(t,this,\"funnel\")})).each((function(t){_(t,this)})).each((function(t){var r=t[0].trace,o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(r.visible&&i.traceIs(r,\"box-violin\")?[t]:[]);o.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),o.exit().remove(),o.each((function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==l.opacity(r.fillcolor)||0!==l.opacity((r.line||{}).color)){var i=b(void 0,r.line,5,2);t.style(\"stroke-width\",i+\"px\").call(l.fill,r.fillcolor),i&&l.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:m?12:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});o.call(s.pointStyle,c,e)}}))})).each((function(t){w(t,this,\"funnelarea\")})).each((function(t){w(t,this,\"pie\")})).each((function(t){var r,i,o=t[0],l=o.trace,f=l.visible&&l.fill&&\"none\"!==l.fill,h=u.hasLines(l),p=l.contours,g=!1,m=!1,y=c(l),x=y.colorscale,_=y.reversescale;if(p){var w=p.coloring;\"lines\"===w?g=!0:h=\"none\"===w||\"heatmap\"===w||p.showlines,\"constraint\"===p.type?f=\"=\"!==p._operation:\"fill\"!==w&&\"heatmap\"!==w||(m=!0)}var T=u.hasMarkers(l)||u.hasText(l),k=f||m,M=h||g,A=T||!k?\"M5,0\":M?\"M5,-2\":\"M5,-3\",S=n.select(this),E=S.select(\".legendfill\").selectAll(\"path\").data(f||m?[t]:[]);if(E.enter().append(\"path\").classed(\"js-fill\",!0),E.exit().remove(),E.attr(\"d\",A+\"h\"+v+\"v6h-\"+v+\"z\").call(f?s.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+l.uid;s.gradient(t,e,r,d(_),x,\"fill\")}}),h||g){var C=b(void 0,l.line,10,5);i=a.minExtend(l,{line:{width:C}}),r=[a.minExtend(o,{trace:i})]}var L=S.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);L.enter().append(\"path\").classed(\"js-line\",!0),L.exit().remove(),L.attr(\"d\",A+(g?\"l\"+v+\",0.0001\":\"h\"+v)).call(h?s.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+l.uid;s.lineGroupStyle(t),s.gradient(t,e,r,d(_),x,\"stroke\")}})})).each((function(t){var r,i,o=t[0],l=o.trace,c=u.hasMarkers(l),f=u.hasText(l),h=u.hasLines(l);function p(t,e,r,n){var i=a.nestedProperty(l,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(m&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function d(t){return o._distinct&&o.index&&t[o.index]?t[o.index]:t[0]}if(c||f||h){var g={},v={};if(c){g.mc=p(\"marker.color\",d),g.mx=p(\"marker.symbol\",d),g.mo=p(\"marker.opacity\",a.mean,[.2,1]),g.mlc=p(\"marker.line.color\",d),g.mlw=p(\"marker.line.width\",a.mean,[0,5],2),v.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var y=p(\"marker.size\",a.mean,[2,16],12);g.ms=y,v.marker.size=y}h&&(v.line={width:p(\"line.width\",d,[0,10],5)}),f&&(g.tx=\"Aa\",g.tp=p(\"textposition\",d),g.ts=10,g.tc=p(\"textfont.color\",d),g.tf=p(\"textfont.family\",d)),r=[a.minExtend(o,g)],(i=a.minExtend(l,v)).selectedpoints=null,i.texttemplate=null}var b=n.select(this).select(\"g.legendpoints\"),_=b.selectAll(\"path.scatterpts\").data(c?r:[]);_.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",x),_.exit().remove(),_.call(s.pointStyle,i,e),c&&(r[0].mrc=3);var w=b.selectAll(\"g.pointtext\").data(f?r:[]);w.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",x),w.exit().remove(),w.selectAll(\"text\").call(s.textPointStyle,i,e)})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(e.visible&&\"candlestick\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"})).attr(\"transform\",x).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=b(void 0,a.line,5,2);i.style(\"stroke-width\",o+\"px\").call(l.fill,a.fillcolor),o&&l.stroke(i,a.line.color)}))})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(e.visible&&\"ohlc\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"})).attr(\"transform\",x).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=b(void 0,a.line,5,2);i.style(\"fill\",\"none\").call(s.dashLine,a.line.dash,o),o&&l.stroke(i,a.line.color)}))}))}},{\"../../lib\":778,\"../../registry\":911,\"../../traces/pie/helpers\":1166,\"../../traces/pie/style_one\":1172,\"../../traces/scatter/subtypes\":1212,\"../color\":643,\"../colorscale/helpers\":654,\"../drawing\":665,\"./constants\":694,d3:169}],702:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../fonts/ploticon\"),s=t(\"../shapes/draw\").eraseActiveShape,l=t(\"../../lib\"),c=l._,u=e.exports={};function f(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},f=a.list(t,null,!0),h=c._cartesianSpikesEnabled;if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,m=(1-d)/2;for(i=0;i<f.length;i++)if(!(r=f[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var v=r._rangeInitial.slice();u[p+\".range[0]\"]=v[0],u[p+\".range[1]\"]=v[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==h||r._showSpikeInitial||(h=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+m*y[1],g*y[1]+m*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}}else\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l||(l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l)),u[s]=l;c._cartesianSpikesEnabled=h,n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d||[],s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function p(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=\"resetLastSave\"===r,a=\"resetDefault\"===r,o=t._fullLayout,s=o._subplots.gl3d||[],l={},c=0;c<s.length;c++){var u,f=s[c],h=f+\".camera\",p=f+\".aspectratio\",d=f+\".aspectmode\",g=o[f]._scene;i?(l[h+\".up\"]=g.viewInitial.up,l[h+\".eye\"]=g.viewInitial.eye,l[h+\".center\"]=g.viewInitial.center,u=!0):a&&(l[h+\".up\"]=null,l[h+\".eye\"]=null,l[h+\".center\"]=null,u=!0),u&&(l[p+\".x\"]=g.viewInitial.aspectratio.x,l[p+\".y\"]=g.viewInitial.aspectratio.y,l[p+\".z\"]=g.viewInitial.aspectratio.z,l[d]=g.viewInitial.aspectmode)}n.call(\"_guiRelayout\",t,l)}function d(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d||[],o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],f=i[u],h=u+\".hovermode\";s[h]=f.hovermode,l[h]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=f[d].showspikes}}r._previousVal=s}return l}function g(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo||[],l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var f=u.projection.scale,h=\"in\"===a?2*f:.5*f;n.call(\"_guiRelayout\",t,c+\".projection.scale\",h)}}\"reset\"===i&&x(t,\"geo\")}function m(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=m(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function y(t,e){for(var r=e.currentTarget.getAttribute(\"data-val\"),i=t._fullLayout,a=i._subplots.mapbox||[],o={},s=0;s<a.length;s++){var l=a[s],c=i[l].zoom,u=\"in\"===r?1.05*c:c/1.05;o[l+\".zoom\"]=u}n.call(\"_guiRelayout\",t,o)}function x(t,e){for(var r=t._fullLayout,i=r._subplots[e]||[],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var f=c[u];a[s+\".\"+f]=l[f]}n.call(\"_guiRelayout\",t,a)}u.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return c(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:o.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};l.notifier(c(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&l.isIE()&&(l.notifier(c(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach((function(t){t in e&&(r[t]=e[t])})),n.call(\"downloadImage\",t,r).then((function(e){l.notifier(c(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")})).catch((function(){l.notifier(c(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")}))}},u.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.disk,click:function(t){i.sendDataToCloud(t)}},u.editInChartStudio={name:\"editInChartStudio\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.pencil,click:function(t){i.sendDataToCloud(t)}},u.zoom2d={name:\"zoom2d\",title:function(t){return c(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:o.zoombox,click:f},u.pan2d={name:\"pan2d\",title:function(t){return c(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:o.pan,click:f},u.select2d={name:\"select2d\",title:function(t){return c(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:o.selectbox,click:f},u.lasso2d={name:\"lasso2d\",title:function(t){return c(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:o.lasso,click:f},u.drawclosedpath={name:\"drawclosedpath\",title:function(t){return c(t,\"Draw closed freeform\")},attr:\"dragmode\",val:\"drawclosedpath\",icon:o.drawclosedpath,click:f},u.drawopenpath={name:\"drawopenpath\",title:function(t){return c(t,\"Draw open freeform\")},attr:\"dragmode\",val:\"drawopenpath\",icon:o.drawopenpath,click:f},u.drawline={name:\"drawline\",title:function(t){return c(t,\"Draw line\")},attr:\"dragmode\",val:\"drawline\",icon:o.drawline,click:f},u.drawrect={name:\"drawrect\",title:function(t){return c(t,\"Draw rectangle\")},attr:\"dragmode\",val:\"drawrect\",icon:o.drawrect,click:f},u.drawcircle={name:\"drawcircle\",title:function(t){return c(t,\"Draw circle\")},attr:\"dragmode\",val:\"drawcircle\",icon:o.drawcircle,click:f},u.eraseshape={name:\"eraseshape\",title:function(t){return c(t,\"Erase active shape\")},icon:o.eraseshape,click:s},u.zoomIn2d={name:\"zoomIn2d\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:f},u.zoomOut2d={name:\"zoomOut2d\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:f},u.autoScale2d={name:\"autoScale2d\",title:function(t){return c(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:o.autoscale,click:f},u.resetScale2d={name:\"resetScale2d\",title:function(t){return c(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:o.home,click:f},u.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return c(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:f},u.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return c(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:o.tooltip_compare,gravity:\"ne\",click:f},u.zoom3d={name:\"zoom3d\",title:function(t){return c(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:o.zoombox,click:h},u.pan3d={name:\"pan3d\",title:function(t){return c(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:o.pan,click:h},u.orbitRotation={name:\"orbitRotation\",title:function(t){return c(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:o[\"3d_rotate\"],click:h},u.tableRotation={name:\"tableRotation\",title:function(t){return c(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:o[\"z-axis\"],click:h},u.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return c(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:o.home,click:p},u.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return c(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:o.movie,click:p},u.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);n.call(\"_guiRelayout\",t,r)}},u.zoomInGeo={name:\"zoomInGeo\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:g},u.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:g},u.resetGeo={name:\"resetGeo\",title:function(t){return c(t,\"Reset\")},attr:\"reset\",val:null,icon:o.autoscale,click:g},u.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:v},u.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return c(t,\"Reset view\")},icon:o.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},u.toggleHover={name:\"toggleHover\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);r.hovermode=m(t),n.call(\"_guiRelayout\",t,r)}},u.resetViews={name:\"resetViews\",title:function(t){return c(t,\"Reset views\")},icon:o.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),f(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),p(t,e),x(t,\"geo\"),x(t,\"mapbox\")}},u.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return c(t,\"Toggle Spike Lines\")},icon:o.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout,r=e._cartesianSpikesEnabled;e._cartesianSpikesEnabled=\"on\"===r?\"off\":\"on\",n.call(\"_guiRelayout\",t,function(t){for(var e=\"on\"===t._fullLayout._cartesianSpikesEnabled,r=a.list(t,null,!0),n={},i=0;i<r.length;i++){var o=r[i];n[o._name+\".showspikes\"]=!!e||o._showSpikeInitial}return n}(t))}},u.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return c(t,\"Reset view\")},attr:\"reset\",icon:o.home,click:function(t){x(t,\"mapbox\")}},u.zoomInMapbox={name:\"zoomInMapbox\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:y},u.zoomOutMapbox={name:\"zoomOutMapbox\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:y}},{\"../../fonts/ploticon\":757,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../shapes/draw\":724}],703:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":704}],704:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"../fx/helpers\").isUnifiedHover,s=t(\"./modebar\"),l=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,u=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var f,h=r.modeBarButtons;f=Array.isArray(h)&&h.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===l[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=l[i]}}return t}(h):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,s=t._context,u=s.modeBarButtonsToRemove,f=s.modeBarButtonsToAdd,h=e._has(\"cartesian\"),p=e._has(\"gl3d\"),d=e._has(\"geo\"),g=e._has(\"pie\"),m=e._has(\"funnelarea\"),v=e._has(\"gl2d\"),y=e._has(\"ternary\"),x=e._has(\"mapbox\"),b=e._has(\"polar\"),_=e._has(\"sankey\"),w=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),T=o(e.hovermode),k=[];function M(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===u.indexOf(n)&&e.push(l[n])}k.push(e)}}var A=[\"toImage\"];s.showEditInChartStudio?A.push(\"editInChartStudio\"):s.showSendToCloud&&A.push(\"sendDataToCloud\");M(A);var S=[],E=[],C=[],L=[];(h||v||g||m||y)+d+p+x+b>1?(E=[\"toggleHover\"],C=[\"resetViews\"]):d?(S=[\"zoomInGeo\",\"zoomOutGeo\"],E=[\"hoverClosestGeo\"],C=[\"resetGeo\"]):p?(E=[\"hoverClosest3d\"],C=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):x?(S=[\"zoomInMapbox\",\"zoomOutMapbox\"],E=[\"toggleHover\"],C=[\"resetViewMapbox\"]):v?E=[\"hoverClosestGl2d\"]:g?E=[\"hoverClosestPie\"]:_?(E=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],C=[\"resetViewSankey\"]):E=[\"toggleHover\"];h&&(E=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0}(r)||T)&&(E=[]);!h&&!v||w||(S=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==C[0]&&(C=[\"resetScale2d\"]));p?L=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(h||v)&&!w||y?L=[\"zoom2d\",\"pan2d\"]:x||d?L=[\"pan2d\"]:b&&(L=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&L.push(\"select2d\",\"lasso2d\");if(Array.isArray(f)){for(var I=[],P=0;P<f.length;P++){var z=f[P];\"string\"==typeof z?-1!==c.indexOf(z)&&(e._has(\"mapbox\")||e._has(\"cartesian\"))&&L.push(z):I.push(z)}f=I}return M(L),M(S.concat(C)),M(E),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(k,f)}(t),u?u.update(t,f):e._modeBar=s(t,f)}else u&&(u.destroy(),delete e._modeBar)};var c=[\"drawline\",\"drawopenpath\",\"drawclosedpath\",\"drawcircle\",\"drawrect\",\"eraseshape\"]},{\"../../plots/cartesian/axis_ids\":831,\"../../registry\":911,\"../../traces/scatter/subtypes\":1212,\"../fx/helpers\":679,\"./buttons\":702,\"./modebar\":705}],705:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var f=this.getLogo();r.watermark&&(f.className=f.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(f,this.element.childNodes[0]):this.element.appendChild(f),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach((function(t){var r=e.createGroup();t.forEach((function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)})),e.element.appendChild(r)}))},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",(function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)})),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach((function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}}))},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plotly.com/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":757,\"../../lib\":778,d3:169,\"fast-isnumeric\":241}],706:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":817,\"../../plots/font_attributes\":856,\"../color/attributes\":642}],707:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],708:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,f){var h=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(h,p,s,t,e)}if(d(\"visible\",o(h,p,{name:\"buttons\",handleItemDefaults:c,calendar:f}).length>0)){var g=function(t,e,r){for(var n=r.filter((function(r){return e[r].anchor===t._id})),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var m=d(\"bgcolor\");d(\"activecolor\",i.contrast(m,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../color\":643,\"./attributes\":706,\"./constants\":707}],709:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=l.strTranslate,u=t(\"../../lib/svg_text_utils\"),f=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),p=h.LINE_SPACING,d=h.FROM_TL,g=h.FROM_BR,m=t(\"./constants\"),v=t(\"./get_update_object\");function y(t){return t._id}function x(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));n.attr({rx:m.rx,ry:m.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",(function(t){t.attr(\"text-anchor\",\"middle\")})).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call((function(t){u.convertToTspans(t,n)}))}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=f.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),y);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each((function(e){var r=n.select(this),o=e,f=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(f.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each((function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(x,f,e),r.call(b,f,e,t),r.on(\"click\",(function(){t._dragged||i.call(\"_guiRelayout\",t,a)})),r.on(\"mouseover\",(function(){e._isHovered=!0,r.call(x,f,e)})),r.on(\"mouseout\",(function(){e._isHovered=!1,r.call(x,f,e)}))})),function(t,e,r,i,o){var f=0,h=0,v=r.borderwidth;e.each((function(){var t=n.select(this).select(\".selector-text\"),e=r.font.size*p,i=Math.max(e*u.lineCount(t),16)+3;h=Math.max(h,i)})),e.each((function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*p,l=u.lineCount(i),d=Math.max(a+10,m.minButtonWidth);t.attr(\"transform\",c(v+f,v)),e.attr({x:0,y:0,width:d,height:h}),u.positionText(i,d/2,h/2-(l-1)*o/2+3),f+=d+5}));var y=t._fullLayout._size,x=y.l+y.w*r.x,b=y.t+y.h*(1-r.y),_=\"left\";l.isRightAnchor(r)&&(x-=f,_=\"right\");l.isCenterAnchor(r)&&(x-=f/2,_=\"center\");var w=\"top\";l.isBottomAnchor(r)&&(b-=h,w=\"bottom\");l.isMiddleAnchor(r)&&(b-=h/2,w=\"middle\");f=Math.ceil(f),h=Math.ceil(h),x=Math.round(x),b=Math.round(b),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:f*d[_],r:f*g[_],b:h*g[w],t:h*d[w]}),o.attr(\"transform\",c(x,b))}(t,h,f,o._name,r)}))}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../drawing\":665,\"./constants\":707,\"./get_update_object\":710,d3:169}],710:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:169}],711:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":706,\"./defaults\":708,\"./draw\":709}],712:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":642}],713:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":827,\"../../plots/cartesian/axis_ids\":831,\"./constants\":714}],714:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],715:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,f,h=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(h.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter((function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)})).map((function(t){return t.substr(t.indexOf(\"y\"),t.length)})),m=n.simpleMap(g,a.id2name),v=0;v<m.length;v++){var y=m[v];u=h[y]||{},f=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=h}}function _(t,e){return n.coerce(h,p,o,t,e)}function w(t,e){return n.coerce(u,f,s,t,e)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axis_ids\":831,\"./attributes\":712,\"./oppaxis_attributes\":719}],716:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../titles\"),f=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),p=t(\"../dragelement\"),d=t(\"../../lib/setcursor\"),g=t(\"./constants\");function m(t,e,r,n){var i=o.ensureSingle(t,\"rect\",g.bgClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,c=-n._offsetShift,u=l.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:s(c,c),fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":u})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,(function(t){t.append(\"rect\").attr({x:0,y:0})})).select(\"rect\").attr({width:n._width,height:n._height})}function y(t,e,r,i){var s,c=e.calcdata,u=t.selectAll(\"g.\"+g.rangePlotClassName).data(r._subplotsWith,o.identity);u.enter().append(\"g\").attr(\"class\",(function(t){return g.rangePlotClassName+\" \"+t})).call(l.setClipUrl,i._clipId,e),u.order(),u.exit().remove(),u.each((function(t,o){var l=n.select(this),u=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],m={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};r.rangebreaks&&(m.layout.xaxis.rangebreaks=r.rangebreaks),m.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},p.rangebreaks&&(m.layout[d].rangebreaks=p.rangebreaks),a.supplyDefaults(m);var v=m._fullLayout.xaxis,y=m._fullLayout[d];v.clearCalc(),v.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:l,xaxis:v,yaxis:y,isRangePlot:!0};u?s=x:(x.mainplot=\"xy\",x.mainplotinfo=s),f.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))}))}function x(t,e,r,n,i){(o.ensureSingle(t,\"rect\",g.maskMinClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,g.maskColor),o.ensureSingle(t,\"rect\",g.maskMaxClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,g.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",g.maskMinOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).call(c.fill,g.maskOppAxisColor),o.ensureSingle(t,\"rect\",g.maskMaxOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).style(\"border-top\",g.maskOppBorder).call(c.fill,g.maskOppAxisColor))}function b(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",g.slideBoxClassName,(function(t){t.attr({y:0,cursor:g.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})})).attr({height:n._height,fill:g.slideBoxFill})}function _(t,e,r,n){var i=o.ensureSingle(t,\"g\",g.grabberMinClassName),a=o.ensureSingle(t,\"g\",g.grabberMaxClassName),s={x:0,width:g.handleWidth,rx:g.handleRadius,fill:c.background,stroke:c.defaultLine,\"stroke-width\":g.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},l={y:Math.round(n._height/4),height:Math.round(n._height/2)};o.ensureSingle(i,\"rect\",g.handleMinClassName,(function(t){t.attr(s)})).attr(l),o.ensureSingle(a,\"rect\",g.handleMaxClassName,(function(t){t.attr(s)})).attr(l);var u={width:g.grabAreaWidth,x:0,y:0,fill:g.grabAreaFill,cursor:e._context.staticPlot?void 0:g.grabAreaCursor};o.ensureSingle(i,\"rect\",g.grabAreaMinClassName,(function(t){t.attr(u)})).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",g.grabAreaMaxClassName,(function(t){t.attr(u)})).attr(\"height\",n._height)}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var l=r[a][g.name];l._clipId=l._id+\"-\"+e._uid}var c=e._infolayer.selectAll(\"g.\"+g.containerClassName).data(r,(function(t){return t._name}));c.exit().each((function(t){var r=t[g.name];e._topdefs.select(\"#\"+r._clipId).remove()})).remove(),0!==r.length&&(c.enter().append(\"g\").classed(g.containerClassName,!0).attr(\"pointer-events\",\"all\"),c.each((function(r){var a=n.select(this),l=r[g.name],c=e[h.id2name(r.anchor)],f=l[h.id2name(r.anchor)];if(l.range){var w,T=o.simpleMap(l.range,r.r2l),k=o.simpleMap(r.range,r.r2l);w=k[0]<k[1]?[Math.min(T[0],k[0]),Math.max(T[1],k[1])]:[Math.max(T[0],k[0]),Math.min(T[1],k[1])],l.range=l._input.range=o.simpleMap(w,r.l2r)}r.cleanRange(\"rangeslider.range\");var M=e._size,A=r.domain;l._width=M.w*(A[1]-A[0]);var S=Math.round(M.l+M.w*A[0]),E=Math.round(M.t+M.h*(1-r._counterDomainMin)+(\"bottom\"===r.side?r._depth:0)+l._offsetShift+g.extraPad);a.attr(\"transform\",s(S,E)),l._rl=o.simpleMap(l.range,r.r2l);var C=l._rl[0],L=l._rl[1],I=L-C;if(l.p2d=function(t){return t/l._width*I+C},l.d2p=function(t){return(t-C)/I*l._width},r.rangebreaks){var P=r.locateBreaks(C,L);if(P.length){var z,O,D=0;for(z=0;z<P.length;z++)D+=(O=P[z]).max-O.min;var R=l._width/(L-C-D),F=[-R*C];for(z=0;z<P.length;z++)O=P[z],F.push(F[F.length-1]-R*(O.max-O.min));for(l.d2p=function(t){for(var e=F[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.max)e=F[r+1];else if(t<n.min)break}return e+R*t},z=0;z<P.length;z++)(O=P[z]).pmin=l.d2p(O.min),O.pmax=l.d2p(O.max);l.p2d=function(t){for(var e=F[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.pmax)e=F[r+1];else if(t<n.pmin)break}return(t-e)/R}}}if(\"match\"!==f.rangemode){var B=c.r2l(f.range[0]),N=c.r2l(f.range[1])-B;l.d2pOppAxis=function(t){return(t-B)/N*l._height}}a.call(m,t,r,l).call(v,t,r,l).call(y,t,r,l).call(x,t,r,l,f).call(b,t,r,l).call(_,t,r,l),function(t,e,r,a){if(e._context.staticPlot)return;var s=t.select(\"rect.\"+g.slideBoxClassName).node(),l=t.select(\"rect.\"+g.grabAreaMinClassName).node(),c=t.select(\"rect.\"+g.grabAreaMaxClassName).node();function u(){var u=n.event,f=u.target,h=u.clientX||u.touches[0].clientX,g=h-t.node().getBoundingClientRect().left,m=a.d2p(r._rl[0]),v=a.d2p(r._rl[1]),y=p.coverSlip();function x(t){var u,p,x,b=+(t.clientX||t.touches[0].clientX)-h;switch(f){case s:x=\"ew-resize\",u=m+b,p=v+b;break;case l:x=\"col-resize\",u=m+b,p=v;break;case c:x=\"col-resize\",u=m,p=v+b;break;default:x=\"ew-resize\",u=g,p=g+b}if(p<u){var _=p;p=u,u=_}a._pixelMin=u,a._pixelMax=p,d(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame((function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])}))}(0,e,r,a)}function b(){y.removeEventListener(\"mousemove\",x),y.removeEventListener(\"mouseup\",b),this.removeEventListener(\"touchmove\",x),this.removeEventListener(\"touchend\",b),o.removeElement(y)}this.addEventListener(\"touchmove\",x),this.addEventListener(\"touchend\",b),y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",b)}t.on(\"mousedown\",u),t.on(\"touchstart\",u)}(a,t,r,l),function(t,e,r,n,i,a){var l=g.handleWidth/2;function c(t){return o.constrain(t,0,n._width)}function u(t){return o.constrain(t,0,n._height)}function f(t){return o.constrain(t,-l,n._width+l)}var h=c(n.d2p(r._rl[0])),p=c(n.d2p(r._rl[1]));if(t.select(\"rect.\"+g.slideBoxClassName).attr(\"x\",h).attr(\"width\",p-h),t.select(\"rect.\"+g.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+g.maskMaxClassName).attr(\"x\",p).attr(\"width\",n._width-p),\"match\"!==a.rangemode){var d=n._height-u(n.d2pOppAxis(i._rl[1])),m=n._height-u(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+g.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",d).attr(\"width\",p-h),t.select(\"rect.\"+g.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",m).attr(\"height\",n._height-m).attr(\"width\",p-h),t.select(\"rect.\"+g.slideBoxClassName).attr(\"y\",d).attr(\"height\",m-d)}var v=Math.round(f(h-l))-.5,y=Math.round(f(p-l))+.5;t.select(\"g.\"+g.grabberMinClassName).attr(\"transform\",s(v,.5)),t.select(\"g.\"+g.grabberMaxClassName).attr(\"transform\",s(y,.5))}(a,0,r,l,c,f),\"bottom\"===r.side&&u.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:E+l._height+l._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})})))}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plots/cartesian\":841,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../titles\":738,\"./constants\":714,d3:169}],717:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../lib/svg_text_utils\"),a=t(\"./constants\"),o=t(\"../../constants/alignment\").LINE_SPACING,s=a.name;function l(t){var e=t&&t[s];return e&&e.visible}r.isVisible=l,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var a=0;a<e.length;a++){var o=e[a];if(l(o)){i.push(o);var c=o[s];c._id=s+o._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){var r=t._fullLayout,n=e[s],l=e._id.charAt(0),c=0,u=0;\"bottom\"===e.side&&(c=e._depth,e.title.text!==r._dfltTitle[l]&&(u=1.5*e.title.font.size+10+n._offsetShift,u+=(e.title.text.match(i.BR_TAG_ALL)||[]).length*e.title.font.size*o));return{x:0,y:e._counterDomainMin,l:0,r:0,t:0,b:n._height+c+Math.max(r.margin.b,u),pad:a.extraPad+2*n._offsetShift}}},{\"../../constants/alignment\":745,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axis_ids\":831,\"./constants\":714}],718:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":778,\"./attributes\":712,\"./calc_autorange\":713,\"./defaults\":715,\"./draw\":716,\"./helpers\":717,\"./oppaxis_attributes\":719}],719:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],720:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"arraydraw\"},editable:{valType:\"boolean\",dflt:!1,editType:\"calc+arraydraw\"},editType:\"arraydraw\"})},{\"../../constants/axis_placeable_objects\":746,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../traces/scatter/attributes\":1187,\"../annotations/attributes\":626,\"../drawing/attributes\":664}],721:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var f=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],h=n.aggNums(Math.max,null,f),p=n.aggNums(Math.min,null,f),d=p<0?Math.abs(p)+c:c,g=h>0?h+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,f,h=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((f=s(u[c]))<h&&(h=f),f>p&&(p=f)));return p>=h?[h,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,f,h=r[o];h._extremes={};var p=i.getRefType(h.xref),d=i.getRefType(h.yref);if(\"paper\"!==h.xref&&\"domain\"!==p){var g=\"pixel\"===h.xsizemode?h.xanchor:h.x0,m=\"pixel\"===h.xsizemode?h.xanchor:h.x1;(f=u(c=i.getFromId(t,h.xref),g,m,h.path,a.paramIsX))&&(h._extremes[c._id]=i.findExtremes(c,f,s(h)))}if(\"paper\"!==h.yref&&\"domain\"!==d){var v=\"pixel\"===h.ysizemode?h.yanchor:h.y0,y=\"pixel\"===h.ysizemode?h.yanchor:h.y1;(f=u(c=i.getFromId(t,h.yref),v,y,h.path,a.paramIsY))&&(h._extremes[c._id]=i.findExtremes(c,f,l(h)))}}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./constants\":722,\"./helpers\":731}],722:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],723:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){var l=a(\"path\"),c=a(\"type\",l?\"path\":\"rect\");\"path\"!==e.type&&delete e.path,a(\"editable\"),a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"fillrule\"),a(\"line.width\")&&(a(\"line.color\"),a(\"line.dash\"));for(var u=a(\"xsizemode\"),f=a(\"ysizemode\"),h=[\"x\",\"y\"],p=0;p<2;p++){var d,g,m,v=h[p],y=v+\"anchor\",x=\"x\"===v?u:f,b={_fullLayout:r},_=i.coerceRef(t,e,b,v,void 0,\"paper\");if(\"range\"===i.getRefType(_)?((d=i.getFromId(b,_))._shapeIndices.push(e._index),m=s.rangeToShapePosition(d),g=s.shapePositionToRange(d)):g=m=n.identity,\"path\"!==c){var w=v+\"0\",T=v+\"1\",k=t[w],M=t[T];t[w]=g(t[w],!0),t[T]=g(t[T],!0),\"pixel\"===x?(a(w,0),a(T,10)):(i.coercePosition(e,b,a,_,w,.25),i.coercePosition(e,b,a,_,T,.75)),e[w]=m(e[w]),e[T]=m(e[T]),t[w]=k,t[T]=M}if(\"pixel\"===x){var A=t[y];t[y]=g(t[y],!0),i.coercePosition(e,b,a,_,y,.25),e[y]=m(e[y]),t[y]=A}}\"path\"===c?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":720,\"./helpers\":731}],724:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"./draw_newshape/helpers\").readPaths,s=t(\"./draw_newshape/display_outlines\"),l=t(\"../../plots/cartesian/handle_outline\").clearOutlineControllers,c=t(\"../color\"),u=t(\"../drawing\"),f=t(\"../../plot_api/plot_template\").arrayEditor,h=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\"),g=t(\"./helpers\");function m(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&x(t,i)}function v(t){return!!t._fullLayout._drawing}function y(t){return!t._context.edits.shapePosition}function x(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=g.makeOptionsAndPlotinfo(t,e),l=r.options,x=r.plotinfo;if(l._input&&!1!==l.visible)if(\"below\"!==l.layer)k(t._fullLayout._shapeUpperLayer);else if(\"paper\"===l.xref||\"paper\"===l.yref)k(t._fullLayout._shapeLowerLayer);else{if(x._hadPlotinfo)k((x.mainplotinfo||x).shapelayer);else k(t._fullLayout._shapeLowerLayer)}function k(r){var k=_(t,l),M={\"data-index\":e,\"fill-rule\":l.fillrule,d:k},A=l.opacity,S=l.fillcolor,E=l.line.width?l.line.color:\"rgba(0,0,0,0)\",C=l.line.width,L=l.line.dash;C||!0!==l.editable||(C=5,L=\"solid\");var I=\"Z\"!==k[k.length-1],P=y(t)&&l.editable&&t._fullLayout._activeShapeIndex===e;P&&(S=I?\"rgba(0,0,0,0)\":t._fullLayout.activeshape.fillcolor,A=t._fullLayout.activeshape.opacity);var z,O=r.append(\"path\").attr(M).style(\"opacity\",A).call(c.stroke,E).call(c.fill,S).call(u.dashLine,L,C);if(b(O,t,l),(P||t._context.edits.shapePosition)&&(z=f(t.layout,\"shapes\",l)),P){O.style({cursor:\"move\"});var D={element:O.node(),plotinfo:x,gd:t,editHelpers:z,isActiveShape:!0},R=o(k,t);s(R,O,D)}else t._context.edits.shapePosition?function(t,e,r,o,s,l){var c,f,m,y,x,T,k,M,A,S,E,C,L,I,P,z,O=\"pixel\"===r.xsizemode,D=\"pixel\"===r.ysizemode,R=\"line\"===r.type,F=\"path\"===r.type,B=l.modifyItem,N=a.getFromId(t,r.xref),j=a.getRefType(r.xref),U=a.getFromId(t,r.yref),V=a.getRefType(r.yref),q=g.getDataToPixel(t,N,!1,j),H=g.getDataToPixel(t,U,!0,V),G=g.getPixelToData(t,N,!1,j),Y=g.getPixelToData(t,U,!0,V),W=R?function(){var t=Math.max(r.line.width,10),n=s.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=Math.max(t/2,10);return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:O?q(r.xanchor)+r.x0:q(r.x0),cy:D?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:O?q(r.xanchor)+r.x1:q(r.x1),cy:D?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){if(v(t))return;O&&(x=q(r.xanchor));D&&(T=H(r.yanchor));\"path\"===r.type?P=r.path:(c=O?r.x0:q(r.x0),f=D?r.y0:H(r.y0),m=O?r.x1:q(r.x1),y=D?r.y1:H(r.y1));c<m?(A=c,L=\"x0\",S=m,I=\"x1\"):(A=m,L=\"x1\",S=c,I=\"x0\");!D&&f<y||D&&f>y?(k=f,E=\"y0\",M=y,C=\"y1\"):(k=y,E=\"y1\",M=f,C=\"y0\");Z(n),Q(s,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),s=a.getFromId(r,i),l=\"\";\"paper\"===n||o.autorange||(l+=n);\"paper\"===i||s.autorange||(l+=i);u.setClipUrl(t,l?\"clip\"+r._fullLayout._uid+l:null,r)}(e,r,t),X.moveFn=\"move\"===z?J:K,X.altKey=n.altKey},doneFn:function(){if(v(t))return;p(e),$(s),b(e,t,r),n.call(\"_guiRelayout\",t,l.getUpdateObj())},clickFn:function(){if(v(t))return;$(s)}};function Z(r){if(v(t))z=null;else if(R)z=\"path\"===r.target.tagName?\"move\":\"start-point\"===r.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var n=X.element.getBoundingClientRect(),i=n.right-n.left,a=n.bottom-n.top,o=r.clientX-n.left,s=r.clientY-n.top,l=!F&&i>10&&a>10&&!r.shiftKey?h.getCursor(o/i,1-s/a):\"move\";p(e,l),z=l.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,l=a;O?B(\"xanchor\",r.xanchor=G(x+n)):(o=function(t){return G(q(t)+n)},N&&\"date\"===N.type&&(o=g.encodeDate(o))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(l=function(t){return Y(H(t)+i)},U&&\"date\"===U.type&&(l=g.encodeDate(l))),B(\"path\",r.path=w(P,o,l))}else O?B(\"xanchor\",r.xanchor=G(x+n)):(B(\"x0\",r.x0=G(c+n)),B(\"x1\",r.x1=G(m+n))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(B(\"y0\",r.y0=Y(f+i)),B(\"y1\",r.y1=Y(y+i)));e.attr(\"d\",_(t,r)),Q(s,r)}function K(n,i){if(F){var a=function(t){return t},o=a,l=a;O?B(\"xanchor\",r.xanchor=G(x+n)):(o=function(t){return G(q(t)+n)},N&&\"date\"===N.type&&(o=g.encodeDate(o))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(l=function(t){return Y(H(t)+i)},U&&\"date\"===U.type&&(l=g.encodeDate(l))),B(\"path\",r.path=w(P,o,l))}else if(R){if(\"resize-over-start-point\"===z){var u=c+n,h=D?f-i:f+i;B(\"x0\",r.x0=O?u:G(u)),B(\"y0\",r.y0=D?h:Y(h))}else if(\"resize-over-end-point\"===z){var p=m+n,d=D?y-i:y+i;B(\"x1\",r.x1=O?p:G(p)),B(\"y1\",r.y1=D?d:Y(d))}}else{var v=function(t){return-1!==z.indexOf(t)},b=v(\"n\"),j=v(\"s\"),V=v(\"w\"),W=v(\"e\"),X=b?k+i:k,Z=j?M+i:M,J=V?A+n:A,K=W?S+n:S;D&&(b&&(X=k-i),j&&(Z=M-i)),(!D&&Z-X>10||D&&X-Z>10)&&(B(E,r[E]=D?X:Y(X)),B(C,r[C]=D?Z:Y(Z))),K-J>10&&(B(L,r[L]=O?J:G(J)),B(I,r[I]=O?K:G(K)))}e.attr(\"d\",_(t,r)),Q(s,r)}function Q(t,e){(O||D)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(O?e.xanchor:i.midRange(r?[e.x0,e.x1]:g.extractPathCoords(e.path,d.paramIsX))),o=H(D?e.yanchor:i.midRange(r?[e.y0,e.y1]:g.extractPathCoords(e.path,d.paramIsY)));if(a=g.roundPositionForSharpStrokeRendering(a,1),o=g.roundPositionForSharpStrokeRendering(o,1),O&&D){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(O){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function $(t){t.selectAll(\".visual-cue\").remove()}h.init(X),W.node().onmousemove=Z}(t,O,l,e,r,z):!0===l.editable&&O.style(\"pointer-events\",I||c.opacity(S)*A<=.5?\"stroke\":\"all\");O.node().addEventListener(\"click\",(function(){return function(t,e){if(!y(t))return;var r=+e.node().getAttribute(\"data-index\");if(r>=0){if(r===t._fullLayout._activeShapeIndex)return void T(t);t._fullLayout._activeShapeIndex=r,t._fullLayout._deactivateShape=T,m(t)}}(t,O)}))}}function b(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\").replace(/[xyz][1-9]* *domain/g,\"\");u.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function _(t,e){var r,n,o,s,l,c,u,f,h=e.type,p=a.getRefType(e.xref),m=a.getRefType(e.yref),v=a.getFromId(t,e.xref),y=a.getFromId(t,e.yref),x=t._fullLayout._size;if(v?\"domain\"===p?n=function(t){return v._offset+v._length*t}:(r=g.shapePositionToRange(v),n=function(t){return v._offset+v.r2p(r(t,!0))}):n=function(t){return x.l+x.w*t},y?\"domain\"===m?s=function(t){return y._offset+y._length*(1-t)}:(o=g.shapePositionToRange(y),s=function(t){return y._offset+y.r2p(o(t,!0))}):s=function(t){return x.t+x.h*(1-t)},\"path\"===h)return v&&\"date\"===v.type&&(n=g.decodeDate(n)),y&&\"date\"===y.type&&(s=g.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(d.segmentRE,(function(t){var n=0,c=t.charAt(0),u=d.paramIsX[c],f=d.paramIsY[c],h=d.numParams[c],p=t.substr(1).replace(d.paramRE,(function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>h&&(t=\"X\"),t}));return n>h&&(p=p.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+p}))}(e,n,s);if(\"pixel\"===e.xsizemode){var b=n(e.xanchor);l=b+e.x0,c=b+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var _=s(e.yanchor);u=_-e.y0,f=_-e.y1}else u=s(e.y0),f=s(e.y1);if(\"line\"===h)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+f;if(\"rect\"===h)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+f+\"H\"+l+\"Z\";var w=(l+c)/2,T=(u+f)/2,k=Math.abs(w-l),M=Math.abs(T-u),A=\"A\"+k+\",\"+M,S=w+k+\",\"+T;return\"M\"+S+A+\" 0 1,1 \"+(w+\",\"+(T-M))+A+\" 0 0,1 \"+S+\"Z\"}function w(t,e,r){return t.replace(d.segmentRE,(function(t){var n=0,i=t.charAt(0),a=d.paramIsX[i],o=d.paramIsY[i],s=d.numParams[i];return i+t.substr(1).replace(d.paramRE,(function(t){return n>=s||(a[n]?t=e(t):o[n]&&(t=r(t)),n++),t}))}))}function T(t){y(t)&&(t._fullLayout._activeShapeIndex>=0&&(l(t),delete t._fullLayout._activeShapeIndex,m(t)))}e.exports={draw:m,drawOne:x,eraseActiveShape:function(t){if(!y(t))return;l(t);var e=t._fullLayout._activeShapeIndex,r=(t.layout||{}).shapes||[];if(e<r.length){for(var i=[],a=0;a<r.length;a++)a!==e&&i.push(r[a]);delete t._fullLayout._activeShapeIndex,n.call(\"_guiRelayout\",t,{shapes:i})}}}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/handle_outline\":838,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"./constants\":722,\"./draw_newshape/display_outlines\":728,\"./draw_newshape/helpers\":729,\"./helpers\":731}],725:[function(t,e,r){\"use strict\";var n=t(\"../../drawing/attributes\").dash,i=t(\"../../../lib/extend\").extendFlat;e.exports={newshape:{line:{color:{valType:\"color\",editType:\"none\"},width:{valType:\"number\",min:0,dflt:4,editType:\"none\"},dash:i({},n,{dflt:\"solid\",editType:\"none\"}),editType:\"none\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"none\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"none\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"none\"},drawdirection:{valType:\"enumerated\",values:[\"ortho\",\"horizontal\",\"vertical\",\"diagonal\"],dflt:\"diagonal\",editType:\"none\"},editType:\"none\"},activeshape:{fillcolor:{valType:\"color\",dflt:\"rgb(255,0,255)\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"none\"},editType:\"none\"}}},{\"../../../lib/extend\":768,\"../../drawing/attributes\":664}],726:[function(t,e,r){\"use strict\";e.exports={CIRCLE_SIDES:32,i000:0,i090:8,i180:16,i270:24,cos45:Math.cos(Math.PI/4),sin45:Math.sin(Math.PI/4),SQRT2:Math.sqrt(2)}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"../../color\");e.exports=function(t,e,r){if(r(\"newshape.drawdirection\"),r(\"newshape.layer\"),r(\"newshape.fillcolor\"),r(\"newshape.fillrule\"),r(\"newshape.opacity\"),r(\"newshape.line.width\")){var i=(t||{}).plot_bgcolor||\"#FFF\";r(\"newshape.line.color\",n.contrast(i)),r(\"newshape.line.dash\")}r(\"activeshape.fillcolor\"),r(\"activeshape.opacity\")}},{\"../../color\":643}],728:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement\"),i=t(\"../../dragelement/helpers\").drawMode,a=t(\"../../../registry\"),o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,f=t(\"../../../plots/cartesian/handle_outline\").clearOutlineControllers,h=t(\"./helpers\"),p=h.pointsShapeRectangle,d=h.pointsShapeEllipse,g=h.writePaths,m=t(\"./newshapes\");e.exports=function t(e,r,o,h){h||(h=0);var v=o.gd;function y(){t(e,r,o,h++),d(e[0])&&x({redrawing:!0})}function x(t){o.isActiveShape=!1;var e=m(r,o);Object.keys(e).length&&a.call((t||{}).redrawing?\"relayout\":\"_guiRelayout\",v,e)}var b,_,w,T,k,M=o.isActiveShape,A=v._fullLayout._zoomlayer,S=o.dragmode;(i(S)?v._fullLayout._drawing=!0:v._fullLayout._activeShapeIndex>=0&&f(v),r.attr(\"d\",g(e)),M&&!h)&&(k=function(t,e){for(var r=0;r<e.length;r++){var n=e[r];t[r]=[];for(var i=0;i<n.length;i++){t[r][i]=[];for(var a=0;a<n[i].length;a++)t[r][i][a]=n[i][a]}}return t}([],e),function(t){b=[];for(var r=0;r<e.length;r++){var i=e[r],a=!p(i)&&d(i);b[r]=[];for(var o=0;o<i.length;o++)if(\"Z\"!==i[o][0]&&(!a||o===s||o===l||o===c||o===u)){var f=i[o][1],h=i[o][2],g=t.append(\"circle\").classed(\"cursor-grab\",!0).attr(\"data-i\",r).attr(\"data-j\",o).attr(\"cx\",f).attr(\"cy\",h).attr(\"r\",4).style({\"mix-blend-mode\":\"luminosity\",fill:\"black\",stroke:\"white\",\"stroke-width\":1});b[r][o]={element:g.node(),gd:v,prepFn:E,doneFn:L,clickFn:I},n.init(b[r][o])}}}(A.append(\"g\").attr(\"class\",\"outline-controllers\")),function(){if(_=[],!e.length)return;_[0]={element:r[0][0],gd:v,prepFn:z,doneFn:O},n.init(_[0])}());function E(t){w=+t.srcElement.getAttribute(\"data-i\"),T=+t.srcElement.getAttribute(\"data-j\"),b[w][T].moveFn=C}function C(t,r){if(e.length){var n=k[w][T][1],i=k[w][T][2],a=e[w],o=a.length;if(p(a)){for(var s=0;s<o;s++)if(s!==T){var l=a[s];l[1]===a[T][1]&&(l[1]=n+t),l[2]===a[T][2]&&(l[2]=i+r)}if(a[T][1]=n+t,a[T][2]=i+r,!p(a))for(var c=0;c<o;c++)for(var u=0;u<a[c].length;u++)a[c][u]=k[w][c][u]}else a[T][1]=n+t,a[T][2]=i+r;y()}}function L(){x()}function I(t,r){if(2===t){w=+r.srcElement.getAttribute(\"data-i\"),T=+r.srcElement.getAttribute(\"data-j\");var n=e[w];p(n)||d(n)||function(){if(e.length&&e[w]&&e[w].length){for(var t=[],r=0;r<e[w].length;r++)r!==T&&t.push(e[w][r]);t.length>1&&(2!==t.length||\"Z\"!==t[1][0])&&(0===T&&(t[0][0]=\"M\"),e[w]=t,y(),x())}}()}}function P(t,r){!function(t,r){if(e.length)for(var n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)for(var a=0;a+2<e[n][i].length;a+=2)e[n][i][a+1]=k[n][i][a+1]+t,e[n][i][a+2]=k[n][i][a+2]+r}(t,r),y()}function z(t){(w=+t.srcElement.getAttribute(\"data-i\"))||(w=0),_[w].moveFn=P}function O(){x()}}},{\"../../../plots/cartesian/handle_outline\":838,\"../../../registry\":911,\"../../dragelement\":662,\"../../dragelement/helpers\":661,\"./constants\":726,\"./helpers\":729,\"./newshapes\":730}],729:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"./constants\"),a=i.CIRCLE_SIDES,o=i.SQRT2,s=t(\"../../../plots/cartesian/helpers\"),l=s.p2r,c=s.r2p,u=[0,3,4,5,6,1,2],f=[0,3,4,1,2];function h(t,e){return Math.abs(t-e)<=1e-6}function p(t,e){var r=e[1]-t[1],n=e[2]-t[2];return Math.sqrt(r*r+n*n)}r.writePaths=function(t){var e=t.length;if(!e)return\"M0,0Z\";for(var r=\"\",n=0;n<e;n++)for(var i=t[n].length,a=0;a<i;a++){var o=t[n][a][0];if(\"Z\"===o)r+=\"Z\";else for(var s=t[n][a].length,l=0;l<s;l++){var c=l;\"Q\"===o||\"S\"===o?c=f[l]:\"C\"===o&&(c=u[l]),r+=t[n][a][c],l>0&&l<s-1&&(r+=\",\")}}return r},r.readPaths=function(t,e,r,i){var o,s,u,f=n(t),h=[],p=-1,d=0,g=0,m=function(){s=d,u=g};m();for(var v=0;v<f.length;v++){var y,x,b,_,w=[],T=f[v][0],k=T;switch(T){case\"M\":p++,h[p]=[],d=+f[v][1],g=+f[v][2],w.push([k,d,g]),m();break;case\"Q\":case\"S\":y=+f[v][1],b=+f[v][2],d=+f[v][3],g=+f[v][4],w.push([k,d,g,y,b]);break;case\"C\":y=+f[v][1],b=+f[v][2],x=+f[v][3],_=+f[v][4],d=+f[v][5],g=+f[v][6],w.push([k,d,g,y,b,x,_]);break;case\"T\":case\"L\":d=+f[v][1],g=+f[v][2],w.push([k,d,g]);break;case\"H\":k=\"L\",d=+f[v][1],w.push([k,d,g]);break;case\"V\":k=\"L\",g=+f[v][1],w.push([k,d,g]);break;case\"A\":k=\"L\";var M=+f[v][1],A=+f[v][2];+f[v][4]||(M=-M,A=-A);var S=d-M,E=g;for(o=1;o<=a/2;o++){var C=2*Math.PI*o/a;w.push([k,S+M*Math.cos(C),E+A*Math.sin(C)])}break;case\"Z\":d===s&&g===u||(d=s,g=u,w.push([k,d,g]))}for(var L=(r||{}).domain,I=e._fullLayout._size,P=r&&\"pixel\"===r.xsizemode,z=r&&\"pixel\"===r.ysizemode,O=!1===i,D=0;D<w.length;D++){for(o=0;o+2<7;o+=2){var R=w[D][o+1],F=w[D][o+2];void 0!==R&&void 0!==F&&(d=R,g=F,r&&(r.xaxis&&r.xaxis.p2r?(O&&(R-=r.xaxis._offset),R=P?c(r.xaxis,r.xanchor)+R:l(r.xaxis,R)):(O&&(R-=I.l),L?R=L.x[0]+R/I.w:R/=I.w),r.yaxis&&r.yaxis.p2r?(O&&(F-=r.yaxis._offset),F=z?c(r.yaxis,r.yanchor)-F:l(r.yaxis,F)):(O&&(F-=I.t),F=L?L.y[1]-F/I.h:1-F/I.h)),w[D][o+1]=R,w[D][o+2]=F)}h[p].push(w[D].slice())}}return h},r.pointsShapeRectangle=function(t){if(5!==t.length)return!1;for(var e=1;e<3;e++){if(!h(t[0][e]-t[1][e],t[3][e]-t[2][e]))return!1;if(!h(t[0][e]-t[3][e],t[1][e]-t[2][e]))return!1}return!(!h(t[0][1],t[1][1])&&!h(t[0][1],t[3][1]))&&!!(p(t[0],t[1])*p(t[0],t[3]))},r.pointsShapeEllipse=function(t){var e=t.length;if(e!==a+1)return!1;e=a;for(var r=0;r<e;r++){var n=(2*e-r)%e,i=(e/2+n)%e,o=(e/2+r)%e;if(!h(p(t[r],t[o]),p(t[n],t[i])))return!1}return!0},r.handleEllipse=function(t,e,n){if(!t)return[e,n];var i=r.ellipseOver({x0:e[0],y0:e[1],x1:n[0],y1:n[1]}),s=(i.x1+i.x0)/2,l=(i.y1+i.y0)/2,c=(i.x1-i.x0)/2,u=(i.y1-i.y0)/2;c||(c=u/=o),u||(u=c/=o);for(var f=[],h=0;h<a;h++){var p=2*h*Math.PI/a;f.push([s+c*Math.cos(p),l+u*Math.sin(p)])}return f},r.ellipseOver=function(t){var e=t.x0,r=t.y0,n=t.x1,i=t.y1,a=n-e,s=i-r,l=((e-=a)+n)/2,c=((r-=s)+i)/2;return{x0:l-(a*=o),y0:c-(s*=o),x1:l+a,y1:c+s}}},{\"../../../plots/cartesian/helpers\":839,\"./constants\":726,\"parse-svg-path\":505}],730:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement/helpers\"),i=n.drawMode,a=n.openMode,o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,f=o.cos45,h=o.sin45,p=t(\"../../../plots/cartesian/helpers\"),d=p.p2r,g=p.r2p,m=t(\"../../../plots/cartesian/handle_outline\").clearSelect,v=t(\"./helpers\"),y=v.readPaths,x=v.writePaths,b=v.ellipseOver;e.exports=function(t,e){if(t.length){var r=t[0][0];if(r){var n=r.getAttribute(\"d\"),o=e.gd,p=o._fullLayout.newshape,v=e.plotinfo,_=v.xaxis,w=v.yaxis,T=!!v.domain||!v.xaxis,k=!!v.domain||!v.yaxis,M=e.isActiveShape,A=e.dragmode,S=(o.layout||{}).shapes||[];if(!i(A)&&void 0!==M){var E=o._fullLayout._activeShapeIndex;if(E<S.length)switch(o._fullLayout.shapes[E].type){case\"rect\":A=\"drawrect\";break;case\"circle\":A=\"drawcircle\";break;case\"line\":A=\"drawline\";break;case\"path\":var C=S[E].path||\"\";A=\"Z\"===C[C.length-1]?\"drawclosedpath\":\"drawopenpath\"}}var L,I=a(A),P=y(n,o,v,M),z={editable:!0,xref:T?\"paper\":_._id,yref:k?\"paper\":w._id,layer:p.layer,opacity:p.opacity,line:{color:p.line.color,width:p.line.width,dash:p.line.dash}};if(I||(z.fillcolor=p.fillcolor,z.fillrule=p.fillrule),1===P.length&&(L=P[0]),L&&\"drawrect\"===A)z.type=\"rect\",z.x0=L[0][1],z.y0=L[0][2],z.x1=L[2][1],z.y1=L[2][2];else if(L&&\"drawline\"===A)z.type=\"line\",z.x0=L[0][1],z.y0=L[0][2],z.x1=L[1][1],z.y1=L[1][2];else if(L&&\"drawcircle\"===A){z.type=\"circle\";var O=L[s][1],D=L[l][1],R=L[c][1],F=L[u][1],B=L[s][2],N=L[l][2],j=L[c][2],U=L[u][2],V=v.xaxis&&(\"date\"===v.xaxis.type||\"log\"===v.xaxis.type),q=v.yaxis&&(\"date\"===v.yaxis.type||\"log\"===v.yaxis.type);V&&(O=g(v.xaxis,O),D=g(v.xaxis,D),R=g(v.xaxis,R),F=g(v.xaxis,F)),q&&(B=g(v.yaxis,B),N=g(v.yaxis,N),j=g(v.yaxis,j),U=g(v.yaxis,U));var H=(D+F)/2,G=(B+j)/2,Y=b({x0:H,y0:G,x1:H+(F-D+R-O)/2*f,y1:G+(U-N+j-B)/2*h});V&&(Y.x0=d(v.xaxis,Y.x0),Y.x1=d(v.xaxis,Y.x1)),q&&(Y.y0=d(v.yaxis,Y.y0),Y.y1=d(v.yaxis,Y.y1)),z.x0=Y.x0,z.y0=Y.y0,z.x1=Y.x1,z.y1=Y.y1}else z.type=\"path\",_&&w&&function(t,e,r){var n=\"date\"===e.type,i=\"date\"===r.type;if(!n&&!i)return t;for(var a=0;a<t.length;a++)for(var o=0;o<t[a].length;o++)for(var s=0;s+2<t[a][o].length;s+=2)n&&(t[a][o][s+1]=t[a][o][s+1].replace(\" \",\"_\")),i&&(t[a][o][s+2]=t[a][o][s+2].replace(\" \",\"_\"))}(P,_,w),z.path=x(P),L=null;m(o);for(var W=e.editHelpers,X=(W||{}).modifyItem,Z=[],J=0;J<S.length;J++){var K=o._fullLayout.shapes[J];if(Z[J]=K._input,void 0!==M&&J===o._fullLayout._activeShapeIndex){var Q=z;switch(K.type){case\"line\":case\"rect\":case\"circle\":X(\"x0\",Q.x0),X(\"x1\",Q.x1),X(\"y0\",Q.y0),X(\"y1\",Q.y1);break;case\"path\":X(\"path\",Q.path)}}}return void 0===M?(Z.push(z),Z):W?W.getUpdateObj():{}}}}},{\"../../../plots/cartesian/handle_outline\":838,\"../../../plots/cartesian/helpers\":839,\"../../dragelement/helpers\":661,\"./constants\":726,\"./helpers\":729}],731:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach((function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}})),r},r.getDataToPixel=function(t,e,n,i){var a,o=t._fullLayout._size;if(e)if(\"domain\"===i)a=function(t){return e._length*(n?1-t:t)+e._offset};else{var s=r.shapePositionToRange(e);a=function(t){return e._offset+e.r2p(s(t,!0))},\"date\"===e.type&&(a=r.decodeDate(a))}else a=n?function(t){return o.t+o.h*(1-t)}:function(t){return o.l+o.w*t};return a},r.getPixelToData=function(t,e,n,i){var a,o=t._fullLayout._size;if(e)if(\"domain\"===i)a=function(t){var r=(t-e._offset)/e._length;return n?1-r:r};else{var s=r.rangeToShapePosition(e);a=function(t){return s(e.p2r(t-e._offset))}}else a=n?function(t){return 1-(t-o.t)/o.h}:function(t){return(t-o.l)/o.w};return a},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n},r.makeOptionsAndPlotinfo=function(t,e){var r=t._fullLayout.shapes[e]||{},n=t._fullLayout._plots[r.xref+r.yref];return!!n?n._hadPlotinfo=!0:(n={},r.xref&&\"paper\"!==r.xref&&(n.xaxis=t._fullLayout[r.xref+\"axis\"]),r.yref&&\"paper\"!==r.yref&&(n.yaxis=t._fullLayout[r.yref+\"axis\"])),n.xsizemode=r.xsizemode,n.ysizemode=r.ysizemode,n.xanchor=r.xanchor,n.yanchor=r.yanchor,{options:r,plotinfo:n}}},{\"../../lib\":778,\"./constants\":722}],732:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),supplyDrawNewShapeDefaults:t(\"./draw_newshape/defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":720,\"./calc_autorange\":721,\"./defaults\":723,\"./draw\":724,\"./draw_newshape/defaults\":727}],733:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/animation_attributes\":822,\"../../plots/font_attributes\":856,\"../../plots/pad_attributes\":890,\"./constants\":734}],734:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],735:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var f=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=f[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"./attributes\":733,\"./constants\":734}],736:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plot_api/plot_template\").arrayEditor,f=t(\"./constants\"),h=t(\"../../constants/alignment\"),p=h.LINE_SPACING,d=h.FROM_TL,g=h.FROM_BR;function m(t){return f.autoMarginIdRoot+t._index}function v(t){return t._index}function y(t,e){var r=o.tester.selectAll(\"g.\"+f.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(f.labelGroupClass,!0);var a=0,l=0;r.each((function(t){var r=_(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);l=Math.max(l,i.height),a=Math.max(a,i.width)}})),r.remove();var u=e._dims={};u.inputAreaWidth=Math.max(f.railWidth,f.gripHeight);var h=t._fullLayout._size;u.lx=h.l+h.w*e.x,u.ly=h.t+h.h*(1-e.y),\"fraction\"===e.lenmode?u.outerLength=Math.round(h.w*e.len):u.outerLength=e.len,u.inputAreaStart=0,u.inputAreaLength=Math.round(u.outerLength-e.pad.l-e.pad.r);var p=(u.inputAreaLength-2*f.stepInset)/(e._stepCount-1),v=a+f.labelPadding;if(u.labelStride=Math.max(1,Math.ceil(v/p)),u.labelHeight=l,u.currentValueMaxWidth=0,u.currentValueHeight=0,u.currentValueTotalHeight=0,u.currentValueMaxLines=1,e.currentvalue.visible){var y=o.tester.append(\"g\");r.each((function(t){var r=x(y,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=c.lineCount(r);u.currentValueMaxWidth=Math.max(u.currentValueMaxWidth,Math.ceil(n.width)),u.currentValueHeight=Math.max(u.currentValueHeight,Math.ceil(n.height)),u.currentValueMaxLines=Math.max(u.currentValueMaxLines,i)})),u.currentValueTotalHeight=u.currentValueHeight+e.currentvalue.offset,y.remove()}u.height=u.currentValueTotalHeight+f.tickOffset+e.ticklen+f.labelOffset+u.labelHeight+e.pad.t+e.pad.b;var b=\"left\";s.isRightAnchor(e)&&(u.lx-=u.outerLength,b=\"right\"),s.isCenterAnchor(e)&&(u.lx-=u.outerLength/2,b=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(u.ly-=u.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(u.ly-=u.height/2,w=\"middle\"),u.outerLength=Math.ceil(u.outerLength),u.height=Math.ceil(u.height),u.lx=Math.round(u.lx),u.ly=Math.round(u.ly);var T={y:e.y,b:u.height*g[w],t:u.height*d[w]};\"fraction\"===e.lenmode?(T.l=0,T.xl=e.x-e.len*d[b],T.r=0,T.xr=e.x+e.len*g[b]):(T.x=e.x,T.l=u.outerLength*d[b],T.r=u.outerLength*g[b]),i.autoMargin(t,m(e),T)}function x(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-f.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=f.currentValueInset,i=\"left\"}var l=s.ensureSingle(t,\"text\",f.labelClass,(function(t){t.attr({\"text-anchor\":i,\"data-notex\":1})})),u=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)u+=r;else{var h=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(h=s.templateString(h,d)),u+=h}e.currentvalue.suffix&&(u+=e.currentvalue.suffix),l.call(o.font,e.currentvalue.font).text(u).call(c.convertToTspans,e._gd);var g=c.lineCount(l),m=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*p;return c.positionText(l,n,m),l}}function b(t,e,r){s.ensureSingle(t,\"rect\",f.gripRectClass,(function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")})).attr({width:f.gripWidth,height:f.gripHeight,rx:f.gripRadius,ry:f.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function _(t,e,r){var n=s.ensureSingle(t,\"text\",f.labelClass,(function(t){t.attr({\"text-anchor\":\"middle\",\"data-notex\":1})})),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(c.convertToTspans,r._gd),n}function w(t,e){var r=s.ensureSingle(t,\"g\",f.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+f.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(f.labelGroupClass,!0),a.exit().remove(),a.each((function(t){var r=n.select(this);r.call(_,t,e),o.setTranslate(r,E(e,t.fraction),f.tickOffset+e.ticklen+e.font.size*p+f.labelOffset+i.currentValueTotalHeight)}))}function T(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,u(t.layout,f.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(S,r,o),e.call(x,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame((function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)}))))}function M(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",(function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+f.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=C(t,n.mouse(i)[0]);T(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",(function(){var t=s(),a=C(t,n.mouse(i)[0]);T(e,r,t,a,!1)})),o.on(\"mouseup\",(function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})}))}))}function A(t,e){var r=t.selectAll(\"rect.\"+f.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(f.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each((function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,E(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?f.tickOffset:f.minorTickOffset)+i.currentValueTotalHeight)}))}function S(t,e,r){for(var n=t.select(\"rect.\"+f.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=E(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",l(o-.5*f.gripWidth,e._dims.currentValueTotalHeight))}}function E(t,e){var r=t._dims;return r.inputAreaStart+f.stepInset+(r.inputAreaLength-2*f.stepInset)*Math.min(1,Math.max(0,e))}function C(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-f.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*f.stepInset-2*r.inputAreaStart)))}function L(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",f.railTouchRectClass,(function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")}));i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,f.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function I(t,e){var r=e._dims,n=r.inputAreaLength-2*f.railInset,i=s.ensureSingle(t,\"rect\",f.railRectClass);i.attr({width:n,height:f.railWidth,rx:f.railRadius,ry:f.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,f.railInset,.5*(r.inputAreaWidth-f.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[f.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,m(e))}if(a.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each((function(){n.select(this).selectAll(\"g.\"+f.groupClassName).each(s)})).remove(),0!==r.length){var l=a.selectAll(\"g.\"+f.groupClassName).data(r,v);l.enter().append(\"g\").classed(f.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var u=r[c];y(t,u)}l.each((function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,(function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))})),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(x,r).call(I,r).call(w,r).call(A,r).call(L,t,r).call(b,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(S,r,!1),e.call(x,r)}(t,n.select(this),e)}))}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/plots\":891,\"../color\":643,\"../drawing\":665,\"./constants\":734,d3:169}],737:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":733,\"./constants\":734,\"./defaults\":735,\"./draw\":736}],738:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\"),p=t(\"../../constants/alignment\").OPPOSITE_SIDE,d=/ [XY][0-9]* /;e.exports={draw:function(t,e,r){var g,m=r.propContainer,v=r.propName,y=r.placeholder,x=r.traceIndex,b=r.avoid||{},_=r.attributes,w=r.transform,T=r.containerGroup,k=t._fullLayout,M=1,A=!1,S=m.title,E=(S&&S.text?S.text:\"\").trim(),C=S&&S.font?S.font:{},L=C.family,I=C.size,P=C.color;\"title.text\"===v?g=\"titleText\":-1!==v.indexOf(\"axis\")?g=\"axisTitleText\":v.indexOf(!0)&&(g=\"colorbarTitleText\");var z=t._context.edits[g];\"\"===E?M=0:E.replace(d,\" % \")===y.replace(d,\" % \")&&(M=.2,A=!0,z||(E=\"\")),r._meta?E=s.templateString(E,r._meta):k._meta&&(E=s.templateString(E,k._meta));var O=E||z;T||(T=s.ensureSingle(k._infolayer,\"g\",\"g-\"+e));var D=T.selectAll(\"text\").data(O?[0]:[]);if(D.enter().append(\"text\"),D.text(E).attr(\"class\",e),D.exit().remove(),!O)return T;function R(t){s.syncOrAsync([F,B],t)}function F(e){var r;return w?(r=\"\",w.rotate&&(r+=\"rotate(\"+[w.rotate,_.x,_.y]+\")\"),w.offset&&(r+=l(0,w.offset))):r=null,e.attr(\"transform\",r),e.style({\"font-family\":L,\"font-size\":n.round(I,2)+\"px\",fill:u.rgb(P),opacity:M*u.opacity(P),\"font-weight\":a.fontWeight}).attr(_).call(f.convertToTspans,t),a.previousPromises(t)}function B(t){var e=n.select(t.node().parentNode);if(b&&b.selection&&b.side&&E){e.attr(\"transform\",null);var r=p[b.side],a=\"left\"===b.side||\"top\"===b.side?-1:1,o=i(b.pad)?b.pad:2,u=c.bBox(e.node()),f={left:0,top:0,right:k.width,bottom:k.height},h=b.maxShift||a*(f[b.side]-u[b.side]),d=0;if(h<0)d=h;else{var g=b.offsetLeft||0,m=b.offsetTop||0;u.left-=g,u.right-=g,u.top-=m,u.bottom-=m,b.selection.each((function(){var t=c.bBox(this);s.bBoxIntersect(u,t,o)&&(d=Math.max(d,a*(t[b.side]-u[r])+o))})),d=Math.min(h,d)}if(d>0||h<0){var v={left:[-d,0],right:[d,0],top:[0,-d],bottom:[0,d]}[b.side];e.attr(\"transform\",l(v[0],v[1]))}}}return D.call(R),z&&(E?D.on(\".opacity\",null):(M=0,A=!0,D.text(y).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)}))),D.call(f.makeEditable,{gd:t}).on(\"edit\",(function(e){void 0!==x?o.call(\"_guiRestyle\",t,v,e,x):o.call(\"_guiRelayout\",t,v,e)})).on(\"cancel\",(function(){this.text(this.attr(\"data-unformatted\")).call(R)})).on(\"input\",(function(t){this.text(t||\" \").call(f.positionText,_.x,_.y)}))),D.classed(\"js-placeholder\",A),T}}},{\"../../constants/alignment\":745,\"../../constants/interactions\":752,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../drawing\":665,d3:169,\"fast-isnumeric\":241}],739:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},args2:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/font_attributes\":856,\"../../plots/pad_attributes\":890,\"../color/attributes\":642}],740:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],741:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"args2\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"./attributes\":739,\"./constants\":740}],742:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,f=t(\"./constants\"),h=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(f.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,f.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?v(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(f.menuIndexAttrName,\"-1\"),m(t,n,i,a,e),s||v(t,n,i,a,e))}function m(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",f.headerClassName,(function(t){t.style(\"pointer-events\",\"all\")})),l=i._dims,c=i.active,u=i.buttons[c]||f.blankHeaderOpts,h={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(A,i,h,p),s.ensureSingle(e,\"text\",f.headerArrowClassName,(function(t){t.attr(\"text-anchor\",\"end\").call(o.font,i.font).text(f.arrowSymbol[i.direction])})).attr({x:l.headerWidth-f.arrowOffsetX+i.pad.l,y:l.headerHeight/2+f.textOffsetY+i.pad.t}),a.on(\"click\",(function(){r.call(S,String(d(r,i)?-1:i._index)),v(t,e,r,n,i)})),a.on(\"mouseover\",(function(){a.call(w)})),a.on(\"mouseout\",(function(){a.call(T,i)})),o.setTranslate(e,l.lx,l.ly)}function v(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(f.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?f.dropdownButtonClassName:f.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),h=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(h.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,m=0,v=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?m=v.headerHeight+f.gapButtonHeader:d=v.headerWidth+f.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(m=-f.gapButtonHeader+f.gapButton-v.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-f.gapButtonHeader+f.gapButton-v.openWidth);var b={x:v.lx+d+o.pad.l,y:v.ly+m+o.pad.t,yPad:f.gapButton,xPad:f.gapButton,index:0},k={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each((function(s,l){var c=n.select(this);c.call(y,o,s,t).call(A,o,b),c.on(\"click\",(function(){n.event.defaultPrevented||(s.execute&&(s.args2&&o.active===l?(g(t,o,0,e,r,a,-1),i.executeAPICommand(t,s.method,s.args2)):(g(t,o,0,e,r,a,l),i.executeAPICommand(t,s.method,s.args))),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))})),c.on(\"mouseover\",(function(){c.call(w)})),c.on(\"mouseout\",(function(){c.call(T,o),u.call(_,o)}))})),u.call(_,o),x?(k.w=Math.max(v.openWidth,v.headerWidth),k.h=b.y-k.t):(k.w=b.x-k.l,k.h=Math.max(v.openHeight,v.headerHeight)),k.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,h=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=h.heights[l]+f.gapButton;else for(o=0,l=0;l<p;l++)o+=h.widths[l]+f.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,k):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){e=!1,r||t.disable()}));r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){r=!1,e||t.disable()}))}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",f.itemRectClassName,(function(t){t.attr({rx:f.rx,ry:f.ry,\"shape-rendering\":\"crispEdges\"})})).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",f.itemTextClassName,(function(t){t.attr({\"text-anchor\":\"start\",\"data-notex\":1})})),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each((function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.activeColor)}))}function w(t){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.hoverColor)}function T(t,e){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,e.bgcolor)}function k(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+f.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(f.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each((function(i,a){var s=n.select(this);s.call(y,e,i,t);var h=s.select(\".\"+f.itemTextClassName),p=h.node()&&o.bBox(h.node()).width,d=Math.max(p+f.textPadX,f.minWidth),g=e.font.size*u,m=l.lineCount(h),v=Math.max(g*m,f.minHeight)+f.textOffsetY;v=Math.ceil(v),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=v,r.height1=Math.max(r.height1,v),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=v+f.gapButton,r.openHeight+=v+f.gapButton):(r.totalWidth+=d+f.gapButton,r.openWidth+=d+f.gapButton,r.totalHeight=Math.max(r.totalHeight,v),r.openHeight=r.totalHeight)})),c?r.totalHeight-=f.gapButton:r.totalWidth-=f.gapButton,r.headerWidth=r.width1+f.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=f.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=f.arrowPadX),a.remove();var h=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=h,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=h/2,g=\"center\");var m=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,m=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,m=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,M(e),{x:e.x,y:e.y,l:h*({right:1,center:.5}[g]||0),r:h*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[m]||0),t:p*({bottom:1,middle:.5}[m]||0)})}function M(t){return f.autoMarginIdRoot+t._index}function A(t,e,r,n){n=n||{};var i=t.select(\".\"+f.itemRectClassName),a=t.select(\".\"+f.itemTextClassName),s=e.borderwidth,c=r.index,h=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?h.heights[c]:h.height1);i.attr({x:0,y:0,width:n.width||(p?h.width1:h.widths[c]),height:d});var g=e.font.size*u,m=(l.lineCount(a)-1)*g/2;l.positionText(a,f.textOffsetX,d/2-m+f.textOffsetY),p?r.y+=h.heights[c]+r.yPad:r.x+=h.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(f.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+f.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[f.name]);function a(e){i.autoMargin(t,M(e))}var o=e._menulayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each((function(){n.select(this).selectAll(\"g.\"+f.headerGroupClassName).each(a)})).remove(),0!==r.length){var l=o.selectAll(\"g.\"+f.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(f.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",f.dropdownButtonGroupClassName,(function(t){t.style(\"pointer-events\",\"all\")})),u=0;u<r.length;u++){var y=r[u];k(t,y)}var x=\"updatemenus\"+e._uid,b=new h(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each((function(t){c.call(S),a(t)})).remove(),l.each((function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,(function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)})),\"dropdown\"===e.type?(m(t,r,c,b,e),d(c,e)&&v(t,r,c,b,e)):v(t,r,null,null,e)}))}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/plots\":891,\"../color\":643,\"../drawing\":665,\"./constants\":740,\"./scrollbox\":744,d3:169}],743:[function(t,e,r){arguments[4][737][0].apply(r,arguments)},{\"./attributes\":739,\"./constants\":740,\"./defaults\":741,\"./draw\":742,dup:737}],744:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,f,h,p,d=this.position.l,g=this.position.w,m=this.position.t,v=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,T=v;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(f=(u=d)+w,x?(h=m,T=(p=Math.min(h+T,c))-h):T=(p=m+T)-(h=Math.max(p-T,0))):(p=(h=m)+T,b?w=(f=d+w)-(u=Math.max(f-w,0)):(u=d,w=(f=Math.min(u+w,l))-u)),this._box={l:u,t:h,w:w,h:T};var k=g>w,M=s.barLength+2*s.barPad,A=s.barWidth+2*s.barPad,S=d,E=m+v;E+A>c&&(E=c-A);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(k?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),k?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:M,height:A}),this._hbarXMin=S+M/2,this._hbarTranslateMax=w-M):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=v>T,I=s.barWidth+2*s.barPad,P=s.barLength+2*s.barPad,z=d+g,O=m;z+I>l&&(z=l-I);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:O,width:I,height:P}),this._vbarYMin=O+P/2,this._vbarTranslateMax=T-P):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?f+I+.5:f+.5,N=h-.5,j=k?p+A+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(k||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),k||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:m,width:g,height:v})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),k||L){var V=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault()})).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()})).on(\"drag\",this._onBarDrag.bind(this));k&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":778,\"../color\":643,\"../drawing\":665,d3:169}],745:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],746:[function(t,e,r){\"use strict\";e.exports={axisRefDescription:function(t,e,r){return[\"If set to a\",t,\"axis id (e.g. *\"+t+\"* or\",\"*\"+t+\"2*), the `\"+t+\"` position refers to a\",t,\"coordinate. If set to *paper*, the `\"+t+\"`\",\"position refers to the distance from the\",e,\"of the plotting\",\"area in normalized coordinates where *0* (*1*) corresponds to the\",e,\"(\"+r+\"). If set to a\",t,\"axis ID followed by\",\"*domain* (separated by a space), the position behaves like for\",\"*paper*, but refers to the distance in fractions of the domain\",\"length from the\",e,\"of the domain of that axis: e.g.,\",\"*\"+t+\"2 domain* refers to the domain of the second\",t,\" axis and a\",t,\"position of 0.5 refers to the\",\"point between the\",e,\"and the\",r,\"of the domain of the\",\"second\",t,\"axis.\"].join(\" \")}}},{}],747:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-time-format#locale_format\"}},{}],749:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],750:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],751:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],752:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],753:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEMAXYEAR:316224e5,ONEAVGYEAR:315576e5,ONEMINYEAR:31536e6,ONEMAXQUARTER:79488e5,ONEAVGQUARTER:78894e5,ONEMINQUARTER:76896e5,ONEMAXMONTH:26784e5,ONEAVGMONTH:26298e5,ONEMINMONTH:24192e5,ONEWEEK:6048e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:.999999,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],754:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],755:[function(t,e,r){\"use strict\";r.version=t(\"./version\").version,t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/legend\"),t(\"./components/fx\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),window.PlotlyLocales&&Array.isArray(window.PlotlyLocales)&&(i(window.PlotlyLocales),delete window.PlotlyLocales),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":634,\"./components/annotations3d\":639,\"./components/colorbar\":649,\"./components/colorscale\":655,\"./components/errorbars\":671,\"./components/fx\":683,\"./components/grid\":687,\"./components/images\":692,\"./components/legend\":700,\"./components/rangeselector\":711,\"./components/rangeslider\":718,\"./components/shapes\":732,\"./components/sliders\":737,\"./components/updatemenus\":743,\"./fonts/mathjax_config\":756,\"./fonts/ploticon\":757,\"./lib/queue\":794,\"./locale-en\":808,\"./locale-en-us\":807,\"./plot_api\":812,\"./plot_api/plot_schema\":816,\"./plots/plots\":891,\"./registry\":911,\"./snapshot\":916,\"./traces/scatter\":1199,\"./version\":1370,d3:169,\"es6-promise\":224}],756:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],757:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawopenpath:{width:70,height:70,path:\"M33.21,85.65a7.31,7.31,0,0,1-2.59-.48c-8.16-3.11-9.27-19.8-9.88-41.3-.1-3.58-.19-6.68-.35-9-.15-2.1-.67-3.48-1.43-3.79-2.13-.88-7.91,2.32-12,5.86L3,32.38c1.87-1.64,11.55-9.66,18.27-6.9,2.13.87,4.75,3.14,5.17,9,.17,2.43.26,5.59.36,9.25a224.17,224.17,0,0,0,1.5,23.4c1.54,10.76,4,12.22,4.48,12.4.84.32,2.79-.46,5.76-3.59L43,80.07C41.53,81.57,37.68,85.64,33.21,85.65ZM74.81,69a11.34,11.34,0,0,0,6.09-6.72L87.26,44.5,74.72,32,56.9,38.35c-2.37.86-5.57,3.42-6.61,6L38.65,72.14l8.42,8.43ZM55,46.27a7.91,7.91,0,0,1,3.64-3.17l14.8-5.3,8,8L76.11,60.6l-.06.19a6.37,6.37,0,0,1-3,3.43L48.25,74.59,44.62,71Zm16.57,7.82A6.9,6.9,0,1,0,64.64,61,6.91,6.91,0,0,0,71.54,54.09Zm-4.05,0a2.85,2.85,0,1,1-2.85-2.85A2.86,2.86,0,0,1,67.49,54.09Zm-4.13,5.22L60.5,56.45,44.26,72.7l2.86,2.86ZM97.83,35.67,84.14,22l-8.57,8.57L89.26,44.24Zm-13.69-8,8,8-2.85,2.85-8-8Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawclosedpath:{width:90,height:90,path:\"M88.41,21.12a26.56,26.56,0,0,0-36.18,0l-2.07,2-2.07-2a26.57,26.57,0,0,0-36.18,0,23.74,23.74,0,0,0,0,34.8L48,90.12a3.22,3.22,0,0,0,4.42,0l36-34.21a23.73,23.73,0,0,0,0-34.79ZM84,51.24,50.16,83.35,16.35,51.25a17.28,17.28,0,0,1,0-25.47,20,20,0,0,1,27.3,0l4.29,4.07a3.23,3.23,0,0,0,4.44,0l4.29-4.07a20,20,0,0,1,27.3,0,17.27,17.27,0,0,1,0,25.46ZM66.76,47.68h-33v6.91h33ZM53.35,35H46.44V68h6.91Z\",transform:\"matrix(1 0 0 1 -5 -5)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawline:{width:70,height:70,path:\"M60.64,62.3a11.29,11.29,0,0,0,6.09-6.72l6.35-17.72L60.54,25.31l-17.82,6.4c-2.36.86-5.57,3.41-6.6,6L24.48,65.5l8.42,8.42ZM40.79,39.63a7.89,7.89,0,0,1,3.65-3.17l14.79-5.31,8,8L61.94,54l-.06.19a6.44,6.44,0,0,1-3,3.43L34.07,68l-3.62-3.63Zm16.57,7.81a6.9,6.9,0,1,0-6.89,6.9A6.9,6.9,0,0,0,57.36,47.44Zm-4,0a2.86,2.86,0,1,1-2.85-2.85A2.86,2.86,0,0,1,53.32,47.44Zm-4.13,5.22L46.33,49.8,30.08,66.05l2.86,2.86ZM83.65,29,70,15.34,61.4,23.9,75.09,37.59ZM70,21.06l8,8-2.84,2.85-8-8ZM87,80.49H10.67V87H87Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawrect:{width:80,height:80,path:\"M78,22V79H21V22H78m9-9H12V88H87V13ZM68,46.22H31V54H68ZM53,32H45.22V69H53Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},drawcircle:{width:80,height:80,path:\"M50,84.72C26.84,84.72,8,69.28,8,50.3S26.84,15.87,50,15.87,92,31.31,92,50.3,73.16,84.72,50,84.72Zm0-60.59c-18.6,0-33.74,11.74-33.74,26.17S31.4,76.46,50,76.46,83.74,64.72,83.74,50.3,68.6,24.13,50,24.13Zm17.15,22h-34v7.11h34Zm-13.8-13H46.24v34h7.11Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},eraseshape:{width:80,height:80,path:\"M82.77,78H31.85L6,49.57,31.85,21.14H82.77a8.72,8.72,0,0,1,8.65,8.77V69.24A8.72,8.72,0,0,1,82.77,78ZM35.46,69.84H82.77a.57.57,0,0,0,.49-.6V29.91a.57.57,0,0,0-.49-.61H35.46L17,49.57Zm32.68-34.7-24,24,5,5,24-24Zm-19,.53-5,5,24,24,5-5Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #3f4f75;} .cls-2 {fill: #80cfbe;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],758:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],759:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function f(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,f,h,p,d,g=l([r,n]);function m(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,f=o,h=s):r<n?(u=r,h=n):(u=n,h=r),t<e?(p=t,d=e):(p=e,d=t);var v,y=Math.abs(h-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+m(t,e)}return g?v=null===p?\"M\"+m(d,u)+x(d,f,0)+x(d,h,0)+\"Z\":\"M\"+m(p,u)+x(p,f,0)+x(p,h,0)+\"ZM\"+m(d,u)+x(d,f,1)+x(d,h,1)+\"Z\":null===p?(v=\"M\"+m(d,u)+x(d,h,0),c&&(v+=\"L0,0Z\")):v=\"M\"+m(p,u)+\"L\"+m(d,u)+x(d,h,0)+\"L\"+m(p,h)+x(p,u,1)+\"Z\",v}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return f(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return f(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return f(t,e,r,n,i,a,1)}}},{\"./mod\":785}],760:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,f=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,f?t!==i.constructor&&(t=!1):t=i.constructor),f+=o);if(!f)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(f)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(f),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],761:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":753,\"fast-isnumeric\":241}],762:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each((function(t){t.regl&&t.regl.clear({color:!0,depth:!0})}))}},{}],763:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],764:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,f=t(\"./array\").isArrayOrTypedArray;function h(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&f(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){f(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every((function(t){return i(t).isValid()}))?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,f,h,p=i.items,d=[],g=Array.isArray(p),m=g&&o&&Array.isArray(p[0]),v=o&&g&&!m,y=g&&!v?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],f=v?p.length:g?p[s].length:c.length,l=0;l<f;l++)u=v?p[l]:g?p[s][l]:p,void 0!==(h=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=h);else for(s=0;s<y;s++)void 0!==(h=a(t[s],g?p[s]:p,n[s]))&&(d[s]=h);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!h(t[a][o],n?r[a][o]:r))return!1}else if(!h(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&f(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!h(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)f(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=h},{\"../components/colorscale/scales\":658,\"../constants/interactions\":752,\"../plots/attributes\":824,\"./array\":760,\"./mod\":785,\"./nested_property\":786,\"./regex\":795,\"fast-isnumeric\":241,tinycolor2:576}],765:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3-time-format\").timeFormat,o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,f=c.ONEDAY,h=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,m=t(\"../registry\"),v=t(\"d3-time-format\").utcFormat,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&m.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){var n=function(t,e){return _(t)?e?m.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:m.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"}(t,!!e);if(e<2)return n;var i=r.dateTime2ms(n,t);return i+=f*(e-1),r.ms2DateTime(i,0,t)},r.dfltRange=function(t){return _(t)?m.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),v=t.charAt(0);!c||\"G\"!==v&&\"g\"!==v||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),T=t.match(w?x:y);if(!T)return u;var k=T[1],M=T[3]||\"1\",A=Number(T[5]||1),S=Number(T[7]||0),E=Number(T[9]||0),C=Number(T[11]||0);if(c){if(2===k.length)return u;var L;k=Number(k);try{var I=m.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var P=\"i\"===M.charAt(M.length-1);M=parseInt(M,10),L=I.newDate(k,I.toMonthIndex(k,M,P),A)}else L=I.newDate(k,Number(M),A)}catch(t){return u}return L?(L.toJD()-g)*f+S*h+E*p+C*d:u}k=2===k.length?(Number(k)+2e3-b)%100+b:Number(k),M-=1;var z=new Date(Date.UTC(2e3,M,A,S,E));return z.setUTCFullYear(k),z.getUTCMonth()!==M||z.getUTCDate()!==A?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var T=90*f,k=3*h,M=5*p;function A(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/f)+g,E=Math.floor(l(t,f));try{a=m.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=v(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<T?Math.floor(E/h):0,s=e<T?Math.floor(E%h/p):0,c=e<k?Math.floor(E%p/d):0,y=e<M?E%d*10+b:0}else x=new Date(w),a=v(\"%Y-%m-%d\")(x),o=e<T?x.getUTCHours():0,s=e<T?x.getUTCMinutes():0,c=e<k?x.getUTCSeconds():0,y=e<M?10*x.getUTCMilliseconds()+b:0;return A(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+f&&t<=i-f))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return A(a(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,(function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"}));var i=new Date(Math.floor(e+.05));if(_(n))try{t=m.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,f),n=w(Math.floor(r/h),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*f;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,f);if(t=Math.round(t-n),r)try{var i=Math.round(t/f)+g,a=m.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*f+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&m.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%f))if(c)try{1===(r=c.fromJD(n/f+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var h=t.length-l;return{exactYears:i/h,exactMonths:a/h,exactDays:s/h}}},{\"../constants/numerical\":753,\"../registry\":911,\"./loggers\":782,\"./mod\":785,\"d3-time-format\":166,\"fast-isnumeric\":241}],766:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\"),a=t(\"./matrix\"),o=t(\"gl-mat4\");function s(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function l(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}function c(t){var e=window.getComputedStyle(t,null),r=e.getPropertyValue(\"-webkit-transform\")||e.getPropertyValue(\"-moz-transform\")||e.getPropertyValue(\"-ms-transform\")||e.getPropertyValue(\"-o-transform\")||e.getPropertyValue(\"transform\");return\"none\"===r?null:r.replace(\"matrix\",\"\").replace(\"3d\",\"\").slice(1,-1).split(\",\").map((function(t){return+t}))}function u(t){for(var e=[];f(t);)e.push(t),t=t.parentNode;return e}function f(t){return t&&(t instanceof Element||t instanceof HTMLElement)}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:s,addStyleRule:function(t,e){l(\"global\",t,e)},addRelatedStyleRule:l,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&s(r)},getFullTransformMatrix:function(t){var e=u(t),r=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];return e.forEach((function(t){var e=c(t);if(e){var n=a.convertCssMatrix(e);r=o.multiply(r,r,n)}})),r},getElementTransformMatrix:c,getElementAndAncestors:u,equalDomRects:function(t,e){return t&&e&&t.x===e.x&&t.y===e.y&&t.top===e.top&&t.left===e.left&&t.right===e.right&&t.bottom===e.bottom}}},{\"./loggers\":782,\"./matrix\":784,d3:169,\"gl-mat4\":292}],767:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:110}],768:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,f,h,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(f=i(u)))?(f?(f=!1,h=c&&i(c)?c:[]):h=c&&n(c)?c:{},p[l]=a([h,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":779}],769:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],770:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],771:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"country-regex\"),a=t(\"@turf/area\"),o=t(\"@turf/centroid\"),s=t(\"@turf/bbox\"),l=t(\"./identity\"),c=t(\"./loggers\"),u=t(\"./is_plain_object\"),f=t(\"./nested_property\"),h=t(\"./polygon\"),p=Object.keys(i),d={\"ISO-3\":l,\"USA-states\":l,\"country names\":function(t){for(var e=0;e<p.length;e++){var r=p[e];if(new RegExp(i[r]).test(t.trim().toLowerCase()))return r}return c.log(\"Unrecognized country name: \"+t+\".\"),!1}};function g(t){var e=t.geojson,r=window.PlotlyGeoAssets||{},n=\"string\"==typeof e?r[e]:e;return u(n)?n:(c.error(\"Oops ... something went wrong when fetching \"+e),!1)}e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,i,a,o=d[t](e);if(o){if(\"USA-states\"===t)for(n=[],a=0;a<r.length;a++)(i=r[a]).properties&&i.properties.gu&&\"USA\"===i.properties.gu&&n.push(i);else n=r;for(a=0;a<n.length;a++)if((i=n[a]).id===o)return i;c.log([\"Location with id\",o,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1},feature2polygons:function(t){var e,r,n,i,a=t.geometry,o=a.coordinates,s=t.id,l=[];function c(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===s||\"FJI\"===s?function(t){var e;if(null===c(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];l.push(h.tester(e))}:\"ATA\"===s?function(t){var e=c(t);if(null===e)return l.push(h.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var a=h.tester(r);a.pts.pop(),l.push(a)}:function(t){l.push(h.tester(t))},a.type){case\"MultiPolygon\":for(r=0;r<o.length;r++)for(n=0;n<o[r].length;n++)e(o[r][n]);break;case\"Polygon\":for(r=0;r<o.length;r++)e(o[r])}return l},getTraceGeojson:g,extractTraceFeature:function(t){var e=t[0].trace,r=g(e);if(!r)return!1;var n,i={},s=[];for(n=0;n<e._length;n++){var l=t[n];(l.loc||0===l.loc)&&(i[l.loc]=l)}function u(t){var r=f(t,e.featureidkey||\"id\").get(),n=i[r];if(n){var l=t.geometry;if(\"Polygon\"===l.type||\"MultiPolygon\"===l.type){var u={type:\"Feature\",id:r,geometry:l,properties:{}};u.properties.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,i=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=a.default(l);c>i&&(i=c,e=l)}else e=r;return o.default(e).geometry.coordinates}(u),n.fIn=t,n.fOut=u,s.push(u)}else c.log([\"Location\",n.loc,\"does not have a valid GeoJSON geometry.\",\"Traces with locationmode *geojson-id* only support\",\"*Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete i[r]}switch(r.type){case\"FeatureCollection\":var h=r.features;for(n=0;n<h.length;n++)u(h[n]);break;case\"Feature\":u(r);break;default:return c.warn([\"Invalid GeoJSON type\",(r.type||\"none\")+\".\",\"Traces with locationmode *geojson-id* only support\",\"*FeatureCollection* and *Feature* types.\"].join(\" \")),!1}for(var p in i)c.log([\"Location *\"+p+\"*\",\"does not have a matching feature with id-key\",\"*\"+e.featureidkey+\"*.\"].join(\" \"));return s},fetchTraceGeoData:function(t){var e=window.PlotlyGeoAssets||{},r=[];function i(t){return new Promise((function(r,i){n.json(t,(function(n,a){if(n){delete e[t];var o=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return i(new Error(o))}return e[t]=a,r(a)}))}))}function a(t){return new Promise((function(r,n){var i=0,a=setInterval((function(){return e[t]&&\"pending\"!==e[t]?(clearInterval(a),r(e[t])):i>100?(clearInterval(a),n(\"Unexpected error while fetching from \"+t)):void i++}),50)}))}for(var o=0;o<t.length;o++){var s=t[o][0].trace.geojson;\"string\"==typeof s&&(e[s]?\"pending\"===e[s]&&r.push(a(s)):(e[s]=\"pending\",r.push(i(s))))}return r},computeBbox:function(t){return s.default(t)}}},{\"./identity\":776,\"./is_plain_object\":779,\"./loggers\":782,\"./nested_property\":786,\"./polygon\":790,\"@turf/area\":59,\"@turf/bbox\":60,\"@turf/centroid\":61,\"country-regex\":139,d3:169}],772:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":753}],773:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,f=n-e,h=a-e,p=s-a,d=l*p-u*f;if(0===d)return null;var g=(c*p-u*h)/d,m=(c*f-l*h)/d;return m<0||m>1||g<0||g>1?null:{x:t+l*g,y:e+f*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,f=n-e,h=o-i,p=c-a,d=u*u+f*f,g=h*h+p*p,m=Math.min(l(u,f,d,i-t,a-e),l(u,f,d,o-t,c-e),l(h,p,g,t-i,e-a),l(h,p,g,r-i,n-a));return Math.sqrt(m)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),f=t.getPointAtLength(o(r,e)),h={x:(4*f.x+l.x+c.x)/6,y:(4*f.y+l.y+c.y)/6,theta:u};return n[r]=h,h},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),f=u;function h(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,f=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+f*f)}for(var p=h(c);p;){if((c+=p+r)>f)return;p=h(c)}for(p=h(f);p;){if(c>(f-=p+r))return;p=h(f)}return{min:c,max:f,len:f-c,total:u,isClosed:0===c&&f===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,f=0,h=0,p=s;f<c;){if(i=(h+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:h=i,f++}return a}},{\"./mod\":785}],774:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s);function u(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function h(t){return n(t)?t:1}e.exports={formatColor:function(t,e,r){var n,i,s,p,d,g=t.color,m=l(g),v=l(e),y=o.extractOpts(t),x=[];if(n=void 0!==y.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=v?function(t,e){return void 0===t[e]?1:h(t[e])}:h,m||v)for(var b=0;b<r;b++)p=i(g,b),d=s(e,b),x[b]=u(p,d);else x=u(a(g),e);return x},parseColorScale:function(t){var e=o.extractOpts(t),r=e.colorscale;return e.reversescale&&(r=o.flipScale(e.colorscale)),r.map((function(t){var e=t[0],r=i(t[1]).toRgb();return{index:e,rgb:[r.r,r.g,r.b,r.a]}}))}}},{\"../components/color/attributes\":642,\"../components/colorscale\":655,\"./array\":760,\"color-normalize\":125,\"fast-isnumeric\":241,tinycolor2:576}],775:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":776}],776:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],777:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!e)return t;var r=1/Math.abs(e),n=r>1?(r*t+r*e)/r:t+e,i=String(n).length;if(i>16){var a=String(e).length;if(i>=String(t).length+a){var o=parseFloat(n).toPrecision(12);-1===o.indexOf(\"e+\")&&(n=+o)}}return n}},{}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").utcFormat,a=t(\"fast-isnumeric\"),o=t(\"../constants/numerical\"),s=o.FP_SAFE,l=o.BADNUM,c=e.exports={};c.nestedProperty=t(\"./nested_property\"),c.keyedContainer=t(\"./keyed_container\"),c.relativeAttr=t(\"./relative_attr\"),c.isPlainObject=t(\"./is_plain_object\"),c.toLogRange=t(\"./to_log_range\"),c.relinkPrivateKeys=t(\"./relink_private\");var u=t(\"./array\");c.isTypedArray=u.isTypedArray,c.isArrayOrTypedArray=u.isArrayOrTypedArray,c.isArray1D=u.isArray1D,c.ensureArray=u.ensureArray,c.concat=u.concat,c.maxRowLength=u.maxRowLength,c.minRowLength=u.minRowLength;var f=t(\"./mod\");c.mod=f.mod,c.modHalf=f.modHalf;var h=t(\"./coerce\");c.valObjectMeta=h.valObjectMeta,c.coerce=h.coerce,c.coerce2=h.coerce2,c.coerceFont=h.coerceFont,c.coerceHoverinfo=h.coerceHoverinfo,c.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,c.validate=h.validate;var p=t(\"./dates\");c.dateTime2ms=p.dateTime2ms,c.isDateTime=p.isDateTime,c.ms2DateTime=p.ms2DateTime,c.ms2DateTimeLocal=p.ms2DateTimeLocal,c.cleanDate=p.cleanDate,c.isJSDate=p.isJSDate,c.formatDate=p.formatDate,c.incrementMonth=p.incrementMonth,c.dateTick0=p.dateTick0,c.dfltRange=p.dfltRange,c.findExactDates=p.findExactDates,c.MIN_MS=p.MIN_MS,c.MAX_MS=p.MAX_MS;var d=t(\"./search\");c.findBin=d.findBin,c.sorterAsc=d.sorterAsc,c.sorterDes=d.sorterDes,c.distinctVals=d.distinctVals,c.roundUp=d.roundUp,c.sort=d.sort,c.findIndexOfMin=d.findIndexOfMin;var g=t(\"./stats\");c.aggNums=g.aggNums,c.len=g.len,c.mean=g.mean,c.median=g.median,c.midRange=g.midRange,c.variance=g.variance,c.stdev=g.stdev,c.interp=g.interp;var m=t(\"./matrix\");c.init2dArray=m.init2dArray,c.transposeRagged=m.transposeRagged,c.dot=m.dot,c.translationMatrix=m.translationMatrix,c.rotationMatrix=m.rotationMatrix,c.rotationXYMatrix=m.rotationXYMatrix,c.apply3DTransform=m.apply3DTransform,c.apply2DTransform=m.apply2DTransform,c.apply2DTransform2=m.apply2DTransform2,c.convertCssMatrix=m.convertCssMatrix,c.inverseTransformMatrix=m.inverseTransformMatrix;var v=t(\"./angles\");c.deg2rad=v.deg2rad,c.rad2deg=v.rad2deg,c.angleDelta=v.angleDelta,c.angleDist=v.angleDist,c.isFullCircle=v.isFullCircle,c.isAngleInsideSector=v.isAngleInsideSector,c.isPtInsideSector=v.isPtInsideSector,c.pathArc=v.pathArc,c.pathSector=v.pathSector,c.pathAnnulus=v.pathAnnulus;var y=t(\"./anchor_utils\");c.isLeftAnchor=y.isLeftAnchor,c.isCenterAnchor=y.isCenterAnchor,c.isRightAnchor=y.isRightAnchor,c.isTopAnchor=y.isTopAnchor,c.isMiddleAnchor=y.isMiddleAnchor,c.isBottomAnchor=y.isBottomAnchor;var x=t(\"./geometry2d\");c.segmentsIntersect=x.segmentsIntersect,c.segmentDistance=x.segmentDistance,c.getTextLocation=x.getTextLocation,c.clearLocationCache=x.clearLocationCache,c.getVisibleSegment=x.getVisibleSegment,c.findPointOnPath=x.findPointOnPath;var b=t(\"./extend\");c.extendFlat=b.extendFlat,c.extendDeep=b.extendDeep,c.extendDeepAll=b.extendDeepAll,c.extendDeepNoArrays=b.extendDeepNoArrays;var _=t(\"./loggers\");c.log=_.log,c.warn=_.warn,c.error=_.error;var w=t(\"./regex\");c.counterRegex=w.counter;var T=t(\"./throttle\");c.throttle=T.throttle,c.throttleDone=T.done,c.clearThrottle=T.clear;var k=t(\"./dom\");function M(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}c.getGraphDiv=k.getGraphDiv,c.isPlotDiv=k.isPlotDiv,c.removeElement=k.removeElement,c.addStyleRule=k.addStyleRule,c.addRelatedStyleRule=k.addRelatedStyleRule,c.deleteRelatedStyleRule=k.deleteRelatedStyleRule,c.getFullTransformMatrix=k.getFullTransformMatrix,c.getElementTransformMatrix=k.getElementTransformMatrix,c.getElementAndAncestors=k.getElementAndAncestors,c.equalDomRects=k.equalDomRects,c.clearResponsive=t(\"./clear_responsive\"),c.preserveDrawingBuffer=t(\"./preserve_drawing_buffer\"),c.makeTraceGroups=t(\"./make_trace_groups\"),c._=t(\"./localize\"),c.notifier=t(\"./notifier\"),c.filterUnique=t(\"./filter_unique\"),c.filterVisible=t(\"./filter_visible\"),c.pushUnique=t(\"./push_unique\"),c.increment=t(\"./increment\"),c.cleanNumber=t(\"./clean_number\"),c.ensureNumber=function(t){return a(t)?(t=Number(t))<-s||t>s?l:a(t)?Number(t):l:l},c.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(a(t)&&t>=0&&t%1==0)},c.noop=t(\"./noop\"),c.identity=t(\"./identity\"),c.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},c.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=c.nestedProperty(t,a.replace(\"?\",r)),s=c.nestedProperty(t,a.replace(\"?\",n)),l=o.get();o.set(s.get()),s.set(l)}},c.raiseToTop=function(t){t.parentNode.appendChild(t)},c.cancelTransition=function(t){return t.transition().duration(0)},c.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},c.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},c.simpleMap=function(t,e,r,n,i){for(var a=t.length,o=new Array(a),s=0;s<a;s++)o[s]=e(t[s],r,n,i);return o},c.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),l=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)l=Math.floor(Math.random()*n).toString(n)+l;u&&(o=Math.pow(n,u),l=Math.floor(Math.random()*o).toString(n)+l);var f=parseInt(l,n);return e&&e[l]||f!==1/0&&f>=Math.pow(2,r)?i>10?(c.warn(\"randstr failed uniqueness\"),l):t(e,r,n,(i||0)+1):l},c.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},c.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},c.syncOrAsync=function(t,e,r){var n;function i(){return c.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,c.promiseError);return r&&r(e)},c.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},c.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},c.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(c.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},c.mergeArrayCastPositive=function(t,e,r){return c.mergeArray(t,e,r,(function(t){var e=+t;return isFinite(e)&&e>0?e:0}))},c.fillArray=function(t,e,r,n){if(n=n||c.identity,c.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},c.castOption=function(t,e,r,n){n=n||c.identity;var i=c.nestedProperty(t,r).get();return c.isArrayOrTypedArray(i)?Array.isArray(e)&&c.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},c.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=c.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},c.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=M(o));for(var s=0;s<a.length;s++){var l=a[s];if(c.isIndex(l)||c.isArrayOrTypedArray(l)&&c.isIndex(l[0])&&c.isIndex(l[1])){var u=n?n[l]:l,f=r?r[u]:u;void 0!==(i=f)&&i<t.length&&(t[f].selected=1)}}},c.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=M(r),i=[],a=0;a<e.length;a++){var o=e[a];if(c.isIndex(o)){var s=n[o];c.isIndex(s)&&i.push(s)}}return i}return e},c.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=c.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},c.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):c.isTypedArray(a)?r[i]=a.subarray(0,3):r[i]=a&&\"object\"==typeof a?c.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},c.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},c.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},c.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;c.isIE9orBelow=function(){return c.isIE()&&A.test(window.navigator.userAgent)};var S=/Version\\/[\\d\\.]+.*Safari/;c.isSafari=function(){return S.test(window.navigator.userAgent)};var E=/iPad|iPhone|iPod/;c.isIOS=function(){return E.test(window.navigator.userAgent)},c.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},c.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},c.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},c.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var C=/^([^\\[\\.]+)\\.(.+)?/,L=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;c.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(C))?(i=t[r],n=e[1],delete t[r],t[n]=c.extendDeepNoArrays(t[n]||{},c.objectFromPath(r,c.expandObjectPaths(i))[n])):(e=r.match(L))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},c.extendDeepNoArrays(o,c.objectFromPath(s,c.expandObjectPaths(i)))):t[n][a]=c.expandObjectPaths(i)):t[r]=c.expandObjectPaths(t[r]));return t},c.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},c.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)([:|\\|][^}]*)?}/g;var I=/^\\w*$/;c.templateString=function(t,e){var r={};return t.replace(c.TEMPLATE_STRING_REGEX,(function(t,n){var i;return I.test(n)?i=e[n]:(r[n]=r[n]||c.nestedProperty(e,n).get,i=r[n]()),c.isValidTextValue(i)?i:\"\"}))};var P={max:10,count:0,name:\"hovertemplate\"};c.hovertemplateString=function(){return D.apply(P,arguments)};var z={max:10,count:0,name:\"texttemplate\"};c.texttemplateString=function(){return D.apply(z,arguments)};var O=/^[:|\\|]/;function D(t,e,r){var a=this,o=arguments;e||(e={});var s={};return t.replace(c.TEMPLATE_STRING_REGEX,(function(t,l,u){var f,h,p,d;for(p=3;p<o.length;p++)if(f=o[p]){if(f.hasOwnProperty(l)){h=f[l];break}if(I.test(l)||(h=s[l]||c.nestedProperty(f,l).get())&&(s[l]=h),void 0!==h)break}if(void 0===h&&a)return a.count<a.max&&(c.warn(\"Variable '\"+l+\"' in \"+a.name+\" could not be found!\"),h=t),a.count===a.max&&c.warn(\"Too many \"+a.name+\" warnings - additional warnings will be suppressed\"),a.count++,t;if(u){if(\":\"===u[0]&&(h=(d=r?r.numberFormat:n.format)(u.replace(O,\"\"))(h)),\"|\"===u[0]){d=r?r.timeFormat:i;var g=c.dateTime2ms(h);h=c.formatDate(g,u.replace(O,\"\"),!1,d)}}else e.hasOwnProperty(l+\"Label\")&&(h=e[l+\"Label\"]);return h}))}c.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var R=2e9;c.seedPseudoRandom=function(){R=2e9},c.pseudoRandom=function(){var t=R;return R=(69069*R+1)%4294967296,Math.abs(R-t)<429496729?c.pseudoRandom():R/4294967296},c.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=c.extractOption(t,e,\"htx\",\"hovertext\");if(c.isValidTextValue(i))return n(i);var a=c.extractOption(t,e,\"tx\",\"text\");return c.isValidTextValue(a)?n(a):void 0},c.isValidTextValue=function(t){return t||0===t},c.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},c.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e},c.strTranslate=function(t,e){return t||e?\"translate(\"+t+\",\"+e+\")\":\"\"},c.strRotate=function(t){return t?\"rotate(\"+t+\")\":\"\"},c.strScale=function(t){return 1!==t?\"scale(\"+t+\")\":\"\"},c.getTextTransform=function(t){var e=t.noCenter,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.anchorX||0,s=t.anchorY||0,l=t.rotate,u=t.scale;return u?u>1&&(u=1):u=0,c.strTranslate(i-u*(r+o),a-u*(n+s))+c.strScale(u)+(l?\"rotate(\"+l+(e?\"\":\" \"+r+\" \"+n)+\")\":\"\")},c.ensureUniformFontSize=function(t,e){var r=c.extendFlat({},e);return r.size=Math.max(e.size,t._fullLayout.uniformtext.minsize||0),r},c.join2=function(t,e,r){var n=t.length;return n>1?t.slice(0,-1).join(e)+r+t[n-1]:t.join(e)}},{\"../constants/numerical\":753,\"./anchor_utils\":758,\"./angles\":759,\"./array\":760,\"./clean_number\":761,\"./clear_responsive\":763,\"./coerce\":764,\"./dates\":765,\"./dom\":766,\"./extend\":768,\"./filter_unique\":769,\"./filter_visible\":770,\"./geometry2d\":773,\"./identity\":776,\"./increment\":777,\"./is_plain_object\":779,\"./keyed_container\":780,\"./localize\":781,\"./loggers\":782,\"./make_trace_groups\":783,\"./matrix\":784,\"./mod\":785,\"./nested_property\":786,\"./noop\":787,\"./notifier\":788,\"./preserve_drawing_buffer\":792,\"./push_unique\":793,\"./regex\":795,\"./relative_attr\":796,\"./relink_private\":797,\"./search\":798,\"./stats\":801,\"./throttle\":804,\"./to_log_range\":805,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],779:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],780:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var f=i.test(a),h={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(f?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,f?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,h},get:function(t){if(s){var e=u[t];return void 0===e?void 0:f?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n||(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e),h},remove:function(t){var e=u[t];if(void 0===e)return h;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],h.set(t,null);if(f){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return h},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=f?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return h}},{\"./nested_property\":786}],781:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":911}],782:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=t(\"./notifier\"),a=e.exports={};function o(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}a.log=function(){var t;if(n.logging>1){var e=[\"LOG:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>1){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"long\")}},a.warn=function(){var t;if(n.logging>0){var e=[\"WARN:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}},a.error=function(){var t;if(n.logging>0){var e=[\"ERROR:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.error,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}}},{\"../plot_api/plot_config\":815,\"./notifier\":788}],783:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,(function(t){return t[0].trace.uid}));i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each((function(t){t[0][a]=n.select(this)})),i}},{d3:169}],784:[function(t,e,r){\"use strict\";var n=t(\"gl-mat4\");r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply3DTransform=function(t){return function(){var e=arguments,n=1===arguments.length?e[0]:[e[0],e[1],e[2]||0];return r.dot(t,[n[0],n[1],n[2],1]).slice(0,3)}},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}},r.convertCssMatrix=function(t){if(t){var e=t.length;if(16===e)return t;if(6===e)return[t[0],t[1],0,0,t[2],t[3],0,0,0,0,1,0,t[4],t[5],0,1]}return[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]},r.inverseTransformMatrix=function(t){var e=[];return n.invert(e,t),[[e[0],e[1],e[2],e[3]],[e[4],e[5],e[6],e[7]],[e[8],e[9],e[10],e[11]],[e[12],e[13],e[14],e[15]]]}},{\"gl-mat4\":292}],785:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],786:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;function a(t,e){return function(){var r,n,o,s,l,c=t;for(s=0;s<e.length-1;s++){if(-1===(r=e[s])){for(n=!0,o=[],l=0;l<c.length;l++)o[l]=a(c[l],e.slice(s+1))(),o[l]!==o[0]&&(n=!1);return n?o[0]:o}if(\"number\"==typeof r&&!i(c))return;if(\"object\"!=typeof(c=c[r])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[e[s]]))return o}}e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,i,o,s=0,c=e.split(\".\");s<c.length;){if(r=String(c[s]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[s]=r[1];else{if(0!==s)throw\"bad property string\";c.splice(0,1)}for(i=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<i.length;o++)s++,c.splice(s,0,Number(i[o]))}s++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:l(t,c,e),get:a(t,c),astr:e,parts:c,obj:t}};var o=/(^|\\.)args\\[/;function s(t,e){return void 0===t||null===t&&!e.match(o)}function l(t,e,r){return function(n){var a,o,l=t,h=\"\",p=[[t,h]],d=s(n,r);for(o=0;o<e.length-1;o++){if(\"number\"==typeof(a=e[o])&&!i(l))throw\"array index but container is not an array\";if(-1===a){if(d=!u(l,e.slice(o+1),n,r))break;return}if(!f(l,a,e[o+1],d))break;if(\"object\"!=typeof(l=l[a])||null===l)throw\"container is not an object\";h=c(h,a),p.push([l,h])}if(d){if(o===e.length-1&&(delete l[e[o]],Array.isArray(l)&&+e[o]==l.length-1))for(;l.length&&void 0===l[l.length-1];)l.pop()}else l[e[o]]=n}}function c(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function u(t,e,r,n){var a,o=i(r),c=!0,u=r,h=n.replace(\"-1\",0),p=!o&&s(r,h),d=e[0];for(a=0;a<t.length;a++)h=n.replace(\"-1\",a),o&&(p=s(u=r[a%r.length],h)),p&&(c=!1),f(t,a,d,p)&&l(t[a],e,n.replace(\"-1\",a))(u);return c}function f(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":760,\"fast-isnumeric\":241}],787:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],788:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each((function(t){var i=n.select(this);i.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",(function(){i.transition().call(s)}));for(var a=i.append(\"p\"),o=t.split(/<br\\s*\\/?>/g),l=0;l<o.length;l++)l&&a.append(\"br\"),a.append(\"span\").text(o[l]);\"stick\"===e?i.transition().duration(350).style(\"opacity\",1):i.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)}))}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",(function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()}))}}},{d3:169,\"fast-isnumeric\":241}],789:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":799}],790:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,f=r[0];for(e=1;e<r.length;e++)if(f[0]!==r[e][0]||f[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s)&&(!e||!l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,f,h,p,d,g=r.length,m=r[0][0],v=r[0][1],y=0;for(u=1;u<g;u++)if(f=m,h=v,m=r[u][0],v=r[u][1],!(l<(p=Math.min(f,m))||l>Math.max(f,m)||c>Math.max(h,v)))if(c<Math.min(h,v))l!==p&&y++;else{if(c===(d=m===f?c:h+(l-f)*(v-h)/(m-f)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),f=Math.sqrt(u),h=[-c[1]/f,c[0]/f];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,h))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":753,\"./matrix\":784}],791:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each((function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}n.regl||(o=!1),o&&this.addEventListener(\"webglcontextlost\",(function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})}),!1)}})),o||n({container:a._glcontainer.node()}),o}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":800,regl:540}],792:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"is-mobile\");e.exports=function(t){var e;if(\"string\"!=typeof(e=t&&t.hasOwnProperty(\"userAgent\")?t.userAgent:function(){var t;\"undefined\"!=typeof navigator&&(t=navigator.userAgent);t&&t.headers&&\"string\"==typeof t.headers[\"user-agent\"]&&(t=t.headers[\"user-agent\"]);return t}()))return!0;var r=i({ua:{headers:{\"user-agent\":e}},tablet:!0,featureDetect:!1});if(!r)for(var a=e.split(\" \"),o=1;o<a.length;o++){if(-1!==a[o].indexOf(\"Safari\"))for(var s=o-1;s>-1;s--){var l=a[s];if(\"Version/\"===l.substr(0,8)){var c=l.substr(8).split(\".\")[0];if(n(c)&&(c=+c),c>=13)return!0}}}return r}},{\"fast-isnumeric\":241,\"is-mobile\":467}],793:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],794:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":778,\"../plot_api/plot_config\":815}],795:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],796:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],797:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":760,\"./is_plain_object\":779}],798:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\"),o=t(\"../constants/numerical\").BADNUM;function s(t,e){return t<e}function l(t,e){return t<=e}function c(t,e){return t>e}function u(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,o,f=0,h=e.length,p=0,d=h>1?(e[h-1]-e[0])/(h-1):1;for(o=d>=0?r?s:l:r?u:c,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);f<h&&p++<100;)o(e[a=Math.floor((f+h)/2)],t)?f=a+1:h=a;return p>90&&i.log(\"Long binary search...\"),f-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t,e){var n,i=(e||{}).unitMinDiff,a=t.slice();for(a.sort(r.sorterAsc),n=a.length-1;n>-1&&a[n]===o;n--);var s=1;i||(s=a[n]-a[0]||1);for(var l,c=s/(n||1)/1e4,u=[],f=0;f<=n;f++){var h=a[f],p=h-l;void 0===l?(u.push(h),l=h):p>c&&(s=Math.min(s,p),u.push(h),l=h)}return{vals:u,minDiff:s}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"../constants/numerical\":753,\"./identity\":776,\"./loggers\":782,\"fast-isnumeric\":241}],799:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach((function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)})),e&&t.classed(\"cursor-\"+e,!0)}},{}],800:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":643}],801:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums((function(t){return t+1}),0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums((function(t,e){return t+e}),0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums((function(t,e){return t+Math.pow(e-i,2)}),0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":760,\"fast-isnumeric\":241}],802:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":125}],803:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=i.strTranslate,o=t(\"../constants/xmlns_namespaces\"),s=t(\"../constants/alignment\").LINE_SPACING;function l(t,e){return t.node().getBoundingClientRect()[e]}var c=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,A){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(c),L=n.select(t.node().parentNode);if(!L.empty()){var I=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return I+=\"-math\",L.selectAll(\"svg.\"+I).remove(),L.selectAll(\"g.\"+I+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise((function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),o={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue((function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})}),(function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")}),(function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(u,\"\\\\lt \").replace(f,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())}),(function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)}),(function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)}))}(C[2],o,(function(n,i,o){L.selectAll(\"svg.\"+I).remove(),L.selectAll(\"g.\"+I+\"-group\").remove();var s=n&&n.select(\"svg\");if(!s||!s.node())return P(),void e();var c=L.append(\"g\").classed(I+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});c.node().appendChild(s.node()),i&&i.node()&&s.node().insertBefore(i.node().cloneNode(!0),s.node().firstChild),s.attr({class:I,height:o.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var u=t.node().style.fill||\"black\",f=s.select(\"g\");f.attr({fill:u,stroke:u});var h=l(f,\"width\"),p=l(f,\"height\"),d=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],g=-(r||l(t,\"height\"))/4;\"y\"===I[0]?(c.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\")\"+a(-h/2,g-p/2)}),s.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===I[0]?s.attr({x:t.attr(\"x\"),y:g-p/2}):\"a\"===I[0]&&0!==I.indexOf(\"atitle\")?s.attr({x:0,y:g}):s.attr({x:d,y:+t.attr(\"y\")+g-p/2}),A&&A.call(t,c),e(c)}))}))):P(),t}function P(){L.empty()||(I=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+I).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(m,\" \");var r,a=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(o.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*s+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var a=1;a<i.length;a++)f(i[a])}function f(t){var e,i=t.type,a={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(a={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(a.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(a.style=t.style);var f=document.createElementNS(o.svg,e);if(\"sup\"===i||\"sub\"===i){A(r,\"\\u200b\"),r.appendChild(f);var h=document.createElementNS(o.svg,\"tspan\");A(h,\"\\u200b\"),n.select(h).attr(\"dy\",d[i]),a.dy=p[i],r.appendChild(f),r.appendChild(h)}else r.appendChild(f);n.select(f).attr(a),r=t.node=f,l.push(t)}function A(t,e){t.appendChild(document.createTextNode(e))}function S(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var C=e.split(v),L=0;L<C.length;L++){var I=C[L],P=I.match(y),z=P&&P[2].toLowerCase(),O=h[z];if(\"br\"===z)u();else if(void 0===O)A(r,E(I));else if(P[1])S(z);else{var D=P[4],R={type:z},F=k(D,b);if(F?(F=F.replace(M,\"$1 fill:\"),O&&(F+=\";\"+O)):O&&(F=O),F&&(R.style=F),\"a\"===z){a=!0;var B=k(D,_);if(B){var N=document.createElement(\"a\");N.href=B,-1!==g.indexOf(N.protocol)&&(R.href=encodeURI(decodeURI(B)),R.target=k(D,w)||\"_blank\",R.popup=k(D,T))}}f(R)}}return a}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),A&&A.call(t)}};var u=/(<|&lt;|&#60;)/g,f=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},p={sub:\"0.3em\",sup:\"-0.6em\"},d={sub:\"-0.21em\",sup:\"0.42em\"},g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],m=r.NEWLINES=/(\\r\\n?|\\n)/g,v=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i;r.BR_TAG_ALL=/<br(\\s+.*)?>/gi;var b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,T=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function k(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var M=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(v),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],f=u.match(y),h=f&&f[2].toLowerCase();if(h)-1!==n.indexOf(h)&&(o.push(u),s=h);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var A={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,(function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):A[e])||t}))}function C(t,e,r){var n,a,o,s=r.horizontalAlign,l=r.verticalAlign||\"top\",c=t.node().getBoundingClientRect(),u=e.node().getBoundingClientRect();return a=\"bottom\"===l?function(){return c.bottom-n.height}:\"middle\"===l?function(){return c.top+(c.height-n.height)/2}:function(){return c.top},o=\"right\"===s?function(){return c.right-n.width}:\"center\"===s?function(){return c.left+(c.width-n.width)/2}:function(){return c.left},function(){n=this.node().getBoundingClientRect();var t=o()-u.left,e=a()-u.top,s=r.gd||{};if(r.gd){s._fullLayout._calcInverseTransform(s);var l=i.apply3DTransform(s._fullLayout._invTransform)(t,e);t=l[0],e=l[1]}return this.style({top:e+\"px\",left:t+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.sanitizeHTML=function(t){t=t.replace(m,\" \");for(var e=document.createElement(\"p\"),r=e,i=[],a=t.split(v),o=0;o<a.length;o++){var s=a[o],l=s.match(y),c=l&&l[2].toLowerCase();if(c in h)if(l[1])i.length&&(r=i.pop());else{var u=l[4],f=k(u,b),p=f?{style:f}:{};if(\"a\"===c){var d=k(u,_);if(d){var x=document.createElement(\"a\");if(x.href=d,-1!==g.indexOf(x.protocol)){p.href=encodeURI(decodeURI(d));var T=k(u,w);T&&(p.target=T)}}}var M=document.createElement(c);r.appendChild(M),n.select(M).attr(p),r=M,i.push(M)}else r.appendChild(document.createTextNode(E(s)))}return e.innerHTML},r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each((function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})}))},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",(function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)})).on(\"focus\",(function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",(function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()}))})).on(\"keyup\",(function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",(function(){return!1})).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))})).on(\"keydown\",(function(){13===n.event.which&&this.blur()})).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":745,\"../constants/xmlns_namespaces\":754,\"../lib\":778,d3:169}],804:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout((function(){l(),a.timer=null}),e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise((function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}})):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],805:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":241}],806:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":858,\"topojson-client\":579}],807:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],808:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":911}],810:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function f(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=h(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function h(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=h(t.items[o],e,\"from-root\")}return a}return f(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:f}},{\"../lib\":778}],811:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,f=l.getFromTrace,h=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n,!0))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function m(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function v(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,f=(s.subplotsRegistry.ternary||{}).attrRegex,h=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var m=g[e];if(a&&a.test(m)){var v=t[m];v.anchor&&\"free\"!==v.anchor&&(v.anchor=u(v.anchor)),v.overlaying&&(v.overlaying=u(v.overlaying)),v.type||(v.isdate?v.type=\"date\":v.islog?v.type=\"log\":!1===v.isdate&&!1===v.islog&&(v.type=\"linear\")),\"withzero\"!==v.autorange&&\"tozero\"!==v.autorange||(v.autorange=!0,v.rangemode=\"tozero\"),delete v.islog,delete v.isdate,delete v.categories,y(v,\"domain\")&&delete v.domain,void 0!==v.autotick&&(void 0===v.tickmode&&(v.tickmode=v.autotick?\"auto\":\"linear\"),delete v.autotick),d(v)}else if(l&&l.test(m)){d(t[m].radialaxis)}else if(f&&f.test(m)){var x=t[m];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(h&&h.test(m)){var b=t[m],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],T=_[1],k=_[2],M=i([],w),A=[];for(n=0;n<3;++n)A[n]=T[n]+k*M[2+4*n];b.camera={eye:{x:A[0],y:A[1],z:A[2]},center:{x:T[0],y:T[1],z:T[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var I=Array.isArray(t.images)?t.images.length:0;for(e=0;e<I;e++){var P=t.images[e];o.isPlainObject(P)&&(p(P,\"xref\"),p(P,\"yref\"))}var z=t.legend;return z&&(z.x>3?(z.x=1.02,z.xanchor=\"left\"):z.x<-2&&(z.x=-.02,z.xanchor=\"right\"),z.y>3?(z.y=1.02,z.yanchor=\"bottom\"):z.y<-2&&(z.y=-.02,z.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,f=i.error_y.color||(h(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(f),c.opacity(f)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!h(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),h(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!h(i,\"pie-like\")&&!h(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=v(i.textposition[n]);else i.textposition&&(i.textposition=v(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var T=!1!==(i.increasing||{}).showlegend,k=!1!==(i.decreasing||{}).showlegend,M=g(i.increasing),A=g(i.decreasing);if(!1!==M&&!1!==A){var S=m(M,A,T,k);S&&(i.name=S)}else!M&&!A||i.name||(i.name=M||A)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,I=Object.keys(L);C.styles=[];for(var P=0;P<I.length;P++)C.styles.push({target:I[P],value:L[I[P]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map((function(t,e){return e}));if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=f(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":643,\"../lib\":778,\"../plots/cartesian/axis_ids\":831,\"../plots/plots\":891,\"../registry\":911,\"fast-isnumeric\":241,\"gl-mat4/fromQuat\":282}],812:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":913,\"./plot_api\":814,\"./template_api\":819,\"./to_image\":820,\"./validate\":821}],813:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var f=e.astr,h=s.getComponentMethod(f,\"supplyLayoutDefaults\"),p=s.getComponentMethod(f,\"draw\"),d=s.getComponentMethod(f,\"drawOne\"),g=n.replot||n.recalc||h===i||p===i,m=t.layout,v=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",f);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",f,y),!0;e.set(y)}return!g&&(h(m,v),p(t),!0)}var x,b,_,w,T,k,M,A,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(v,f).get(),I=[],P=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],T=Object.keys(w),k=w[\"\"],M=l(k),_<0||_>C.length-(M?0:1))a.warn(\"index out of range\",f,_);else if(void 0!==k)T.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",f,_),c(k)?I.push(_):M?(\"add\"===k&&(k={}),C.splice(_,0,k),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",f,_,k),-1===P&&(P=_);else for(b=0;b<T.length;b++)A=f+\"[\"+_+\"].\",u(C[_],T[b],A).set(w[T[b]]);for(x=I.length-1;x>=0;x--)C.splice(I[x],1),L&&L.splice(I[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(h(m,v),d!==i){var O;if(-1===P)O=S;else{for(z=Math.max(C.length,z),O=[],x=0;x<S.length&&!((_=S[x])>=P);x++)O.push(_);for(x=P;x<z;x++)O.push(x)}for(x=0;x<O.length;x++)d(t,O[x])}else p(t);return!0}},{\"../lib/is_plain_object\":779,\"../lib/loggers\":782,\"../lib/noop\":787,\"../lib/search\":798,\"../registry\":911,\"./container_array_match\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),f=t(\"./plot_schema\"),h=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),m=t(\"../components/color\"),v=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),T=t(\"./helpers\"),k=t(\"./subroutines\"),M=t(\"./edit_types\"),A=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0;function E(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function C(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function L(t,e){C(t,m.combine(e,\"white\"))}function I(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=L:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=C),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var f=c.scrollZoom,h=c._scrollZoom={};if(!0===f)h.cartesian=1,h.gl3d=1,h.geo=1,h.mapbox=1;else if(\"string\"==typeof f){var p=f.split(\"+\");for(i=0;i<p.length;i++)h[p[i]]=1}else!1!==f&&(h.gl3d=1,h.geo=1,h.mapbox=1)}function P(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function z(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function O(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),z(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&z(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function D(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in z(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,f,h=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=P(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);f=h?n[d][g]:n,i(f)||(f=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(f)})}return p}(t,e,r,n),c={},u={},f=0;f<l.length;f++){var h=l[f].prop,p=l[f].maxp,d=a(l[f].target,l[f].insert,p);h.set(d[0]),Array.isArray(c[h.astr])||(c[h.astr]=[]),c[h.astr].push(d[1]),Array.isArray(u[h.astr])||(u[h.astr]=[]),u[h.astr].push(l[f].target.length)}return{update:c,maxPoints:u}}function R(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function F(t,e,n,i){t=o.getGraphDiv(t),T.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=T.coerceTraceIndices(t,i),l=U(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&T.clearAxisTypes(t,s,{});var f=[];u.fullReplot?f.push(r.plot):(f.push(h.previousPromises),h.supplyDefaults(t),u.markerSize&&(h.doCalcdata(t),G(f)),u.style&&f.push(k.doTraceStyle),u.colorbars&&f.push(k.doColorBars),f.push(E)),f.push(h.rehover,h.redrag),c.add(t,F,[t,l.undoit,l.traces],F,[t,l.redoit,l.traces]);var p=o.syncOrAsync(f,t);return p&&p.then||(p=Promise.resolve()),p.then((function(){return t.emit(\"plotly_restyle\",l.eventData),t}))}function B(t){return void 0===t?null:t}function N(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){j((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function j(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)j(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},f=o.extendFlat({},c,u);for(var h in f)j(t+\".\"+h,c[h],u[h],n)}else void 0===n[t]&&(n[t]=B(e))}function U(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=N(i._preGUI,c),g=o.extendDeepAll({},e);V(e);var m,v=M.traceFlags(),y={},x={};function b(){return r.map((function(){}))}function _(t){var e=d.id2name(t);-1===m.indexOf(e)&&m.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function k(t){return\"LAYOUT\"+t+\".range\"}function A(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach((function(t){S(t,a,o)}));else if(!(n in e)&&!T.hasParent(e,n)){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=N(i._tracePreGUI[A(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=B(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(T.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var I,P,z,O,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(I=l[r[n]],P=A(r[n]),O=(z=N(i._tracePreGUI[P._fullInput.uid],c)(I,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var j=z.parts[z.parts.length-1],U=L.substr(0,L.length-j.length-1),q=U?U+\".\":\"\",H=U?s(P,U).get():P;if((R=f.getTraceValObject(P,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==j&&\"lenmode\"!==j||O===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===O)||\"funnelarea\"===D!=(\"funnelarea\"===O))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==O||\"h\"!==I.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(I,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(I,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(I,[\"?\",\"?src\"],\"values\",W),\"pie\"===O||\"funnelarea\"===O?(s(I,\"marker.color\").set(s(I,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(I,\"cartesian\")&&s(I,\"marker.colors\").set(s(I,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===j){var K=J?X.h:X.w;S(q+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var Q=J?X.w:X.h;S(q+\"len\",H.len*(\"fraction\"===D?1/Q:Q),n)}}x[L][n]=B(O);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var $=I.x&&!I.y?\"h\":\"v\";if((z.get()||$)===P.orientation)continue}else\"orientationaxes\"===L&&(I.orientation={v:\"h\",h:\"v\"}[P.orientation]);T.swapXYData(I),v.calc=v.clearAxisTypes=!0}else-1!==h.dataArrayContainers.indexOf(z.parts[0])?(T.manageArrayContainers(z,D,x),v.calc=!0):(R?R.arrayOk&&!u.traceIs(P,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(O))?v.calc=!0:M.update(v,R):v.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\"),et=tt.get();\"x\"===et?tt.set(\"y\"):\"y\"===et?tt.set(\"x\"):\"x unified\"===et?tt.set(\"y unified\"):\"y unified\"===et&&tt.set(\"x unified\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(m=[],n=0;n<r.length;n++){var rt=l[r[n]];u.traceIs(rt,\"cartesian\")&&(_(rt.xaxis||\"x\"),_(rt.yaxis||\"y\"))}S(m.map(w),!0,0),S(m.map(k),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[B(z.get())],z.set(Array.isArray(F)?F[0]:F),v.calc=!0}return(v.calc||v.plot)&&(v.fullReplot=!0),{flags:v,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function V(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function q(t,e,r){if(t=o.getGraphDiv(t),T.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=Z(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[h.previousPromises];a.layoutReplot?s.push(k.layoutReplot):Object.keys(n).length&&(H(t,a,i)||h.supplyDefaults(t),a.legend&&s.push(k.doLegend),a.layoutstyle&&s.push(k.layoutStyles),a.axrange&&G(s,i.rangesAltered),a.ticks&&s.push(k.doTicksRelayout),a.modebar&&s.push(k.doModeBar),a.camera&&s.push(k.doCamera),a.colorbars&&s.push(k.doColorBars),s.push(E)),s.push(h.rehover,h.redrag),c.add(t,q,[t,i.undoit],q,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then((function(){return t.emit(\"plotly_relayout\",i.eventData),t}))}function H(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,s.range&&(l.range=s.range.slice()),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function G(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),-1!==(a.ticklabelposition||\"\").indexOf(\"inside\")&&a._anchorAxis&&r.push(a._anchorAxis._id),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,k.doAutoRangeAndConstraints,r,k.drawData,k.finalDraw)}var Y=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,W=/^[xyz]axis[0-9]*\\.autorange$/,X=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function Z(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,h=N(l._preGUI,c),p=Object.keys(e),g=d.list(t),m=o.extendDeepAll({},e),v={};for(V(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=M.layoutFlags(),k={},S={};function E(t,r){if(Array.isArray(t))t.forEach((function(t){E(t,r)}));else if(!(t in e)&&!T.hasParent(e,t)){var n=h(a,t);t in S||(S[t]=B(n.get())),void 0!==r&&n.set(r)}}var C,L={};function I(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var P in e){if(T.hasParent(e,P))throw new Error(\"cannot set \"+P+\" and a parent attribute simultaneously\");for(var z=h(a,P),O=e[P],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,j=z.parts.slice(0,D).join(\".\"),U=s(t.layout,j).get(),q=s(l,j).get(),H=z.get();if(void 0!==O){k[P]=O,S[P]=\"reverse\"===R?O:B(H);var G=f.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==O)for(var Z in G.impliedEdits)E(o.relativeAttr(P,Z),G.impliedEdits[Z]);if(-1!==[\"width\",\"height\"].indexOf(P))if(O){E(\"autosize\",null);var K=\"height\"===P?\"width\":\"height\";E(K,l[K])}else l[P]=t._initialAutoSize[P];else if(\"autosize\"===P)E(\"width\",O?null:l.width),E(\"height\",O?null:l.height);else if(F.match(Y))I(F),s(l,j+\"._inputRange\").set(null);else if(F.match(W)){I(F),s(l,j+\"._inputRange\").set(null);var Q=s(l,j).get();Q._inputDomain&&(Q._input.domain=Q._inputDomain.slice())}else F.match(X)&&s(l,j+\"._inputDomain\").set(null);if(\"type\"===R){C=U;var $=\"linear\"===q.type&&\"log\"===O,tt=\"log\"===q.type&&\"linear\"===O;if($||tt){if(C&&C.range)if(q.autorange)$&&(C.range=C.range[1]>C.range[0]?[1,2]:[2,1]);else{var et=C.range[0],rt=C.range[1];$?(et<=0&&rt<=0&&E(j+\".autorange\",!0),et<=0?et=rt/1e6:rt<=0&&(rt=et/1e6),E(j+\".range[0]\",Math.log(et)/Math.LN10),E(j+\".range[1]\",Math.log(rt)/Math.LN10)):(E(j+\".range[0]\",Math.pow(10,et)),E(j+\".range[1]\",Math.pow(10,rt)))}else E(j+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,q,O,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,q,O,E)}else E(j+\".autorange\",!0),E(j+\".range\",null);s(l,j+\"._inputRange\").set(null)}else if(R.match(A)){var nt=s(l,P).get(),it=(O||{}).type;it&&\"-\"!==it||(it=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,nt,it,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,nt,it,E)}var at=w.containerArrayMatch(P);if(at){r=at.array,n=at.index;var ot=at.property,st=G||{editType:\"calc\"};\"\"!==n&&\"\"===ot&&(w.isAddVal(O)?S[P]=null:w.isRemoveVal(O)?S[P]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),M.update(_,st),v[r]||(v[r]={});var lt=v[r][n];lt||(lt=v[r][n]={}),lt[ot]=O,delete e[P]}else\"reverse\"===R?(U.range?U.range.reverse():(E(j+\".autorange\",!0),U.range=[1,0]),q.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===P&&(\"lasso\"===O||\"select\"===O)&&\"lasso\"!==H&&\"select\"!==H||l._has(\"gl2d\")?_.plot=!0:G?M.update(_,G):_.calc=!0,z.set(O))}}for(r in v){w.applyContainerArrayChanges(t,h(a,r),v[r],_,h)||(_.plot=!0)}for(var ct in L){var ut=(C=d.getFromId(t,ct))&&C._constraintGroup;if(ut)for(var ft in _.calc=!0,ut)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(J(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:k,eventData:m}}function J(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&h.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function K(t,e,n,i){if(t=o.getGraphDiv(t),T.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=T.coerceTraceIndices(t,i),s=U(t,o.extendFlat({},e),a),l=s.flags,u=Z(t,o.extendFlat({},n)),f=u.flags;(l.calc||f.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&T.clearAxisTypes(t,a,n);var p=[];f.layoutReplot?p.push(k.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(h.previousPromises),H(t,f,u)||h.supplyDefaults(t),l.style&&p.push(k.doTraceStyle),(l.colorbars||f.colorbars)&&p.push(k.doColorBars),f.legend&&p.push(k.doLegend),f.layoutstyle&&p.push(k.layoutStyles),f.axrange&&G(p,u.rangesAltered),f.ticks&&p.push(k.doTicksRelayout),f.modebar&&p.push(k.doModeBar),f.camera&&p.push(k.doCamera),p.push(E)),p.push(h.rehover,h.redrag),c.add(t,K,[t,s.undoit,u.undoit,s.traces],K,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then((function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t}))}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var $=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center|fitbounds)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],tt=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function et(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function rt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function nt(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function it(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function at(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function ot(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,f=n.immutable,h=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;h&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[h],p):(M.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(Y.test(l)||W.test(l))&&(u.rangesAltered[r[0]]=1),X.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var m=t[a],v=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof m&&m!==v){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(m)!==JSON.stringify(v))){var b,_=i.valType,w=g(i),T=Array.isArray(m),k=Array.isArray(v);if(T&&k){var A=\"_input_\"+a,S=t[A],E=e[A];if(Array.isArray(S)&&S===E)continue}if(void 0===v)w&&T?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;h||(u.arrays[a]=C);var I=Math.min(m.length,v.length),P=Math.max(m.length,v.length);if(I!==P){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<I;b++)ot(m[b],v[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=I;b<P;b++)C.push(b)}else!_&&o.isPlainObject(m)?ot(m,v,y,n):w?T&&k?(f&&(u.calc=!0),(f||n.newDataRevision)&&d()):T!==k?u.calc=!0:d():T&&k&&m.length===v.length&&String(m)===String(v)||d()}}}for(a in e)if(!(a in t)&&\"_\"!==a.charAt(0)&&\"function\"!=typeof e[a]){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function st(t){var e=t._fullLayout,r=t.getBoundingClientRect();if(!o.equalDomRects(r,e._lastBBox)){var n=e._invTransform=o.inverseTransformMatrix(o.getFullTransformMatrix(t));e._invScaleX=Math.sqrt(n[0][0]*n[0][0]+n[0][1]*n[0][1]+n[0][2]*n[0][2]),e._invScaleY=Math.sqrt(n[1][0]*n[1][0]+n[1][1]*n[1][1]+n[1][2]*n[1][2]),e._lastBBox=r}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._calcInverseTransform=st,r._calcInverseTransform(t),r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"user-select-none\",!0).classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),delete r._modeBar,r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each((function(){this.id&&(i[this.id.split(\"-\")[1]]=1)})),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._treemaplayer=r._paper.append(\"g\").classed(\"treemaplayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plotly.com/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=h.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise((function(a,u){function f(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,h.transition(t,e.frame.data,e.frame.layout,T.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then((function(){e.onComplete&&e.onComplete()})),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&f()};e()}var d,g,m=0;function v(t){return Array.isArray(i)?m>=i.length?t.transitionOpts=i[m]:t.transitionOpts=i[0]:t.transitionOpts=i,m++,t}var y=[],x=null==e,b=Array.isArray(e);if(!x&&!b&&o.isPlainObject(e))y.push({type:\"object\",data:v(o.extendFlat({},e))});else if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:v({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:v({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:v(o.extendFlat({},_))})}for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var k=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){k=d;break}if(k>0&&k<y.length-1){var M=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>k)&&M.push(g);y=M}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?h.computeFrame(t,e[i].name):e[i].data;var f=l(i),d=s(i);d.duration=Math.min(d.duration,f.duration);var g={frame:o,name:e[i].name,frameOpts:f,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())}))},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plotly.com/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var f=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,m=(u[g]||d[g]||{}).name,v=e[n].name,y=u[m]||d[m];m&&v&&\"number\"==typeof v&&y&&S<5&&(S++,o.warn('addFrames: overwriting frame \"'+(u[m]||d[m]).name+'\" with a frame whose name of type \"number\" also equates to \"'+m+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),5===S&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:h.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:f+n})}p.sort((function(t,e){return t.index>e.index?-1:t.index<e.index?1:0}));var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=h.modifyFrames,T=h.modifyFrames,k=[t,b],M=[t,x];return c&&c.add(t,w,k,T,M),h.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=h.modifyFrames,u=h.modifyFrames,f=[t,s],p=[t,a];return c&&c.add(t,l,f,u,p),h.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,f=t,h=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map((function(t){return o.extendFlat({},t)})),T.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,h,f,p),s;Array.isArray(i)||(i=[i]);try{O(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,h,f,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,f=[e,s,n],h=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),z(e,n,\"indices\"),(n=P(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,f,u,h),p},r.extendTraces=function t(e,n,i,a){function s(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=R(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}var l=D(e=o.getGraphDiv(e),n,i,a,s),u=r.redraw(e),f=[e,l.update,i,l.maxPoints];return c.add(e,r.prependTraces,f,t,arguments),u},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,f=t,h=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(O(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=P(n,e.data.length-1),i=P(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort((function(t,e){return t.newIndex-e.newIndex})),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,h,f,p),d},r.prependTraces=function t(e,n,i,a){function s(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=R(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}var l=D(e=o.getGraphDiv(e),n,i,a,s),u=r.redraw(e),f=[e,l.update,i,l.maxPoints];return c.add(e,r.extendTraces,f,t,arguments),u},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),h.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),h.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),I(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var f=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(T.cleanData(e),f?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!f||(t.layout=T.cleanLayout(i)),h.supplyDefaults(t);var m=t._fullLayout,y=m._has(\"cartesian\");if(!m._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e);r&&(t.layout=r);p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},f=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,f.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(100).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)})));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",(function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)})).on(\"cancel\",(function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)}))};f.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),h.addLinks(t),Promise.resolve()}(t,e,i);m._replotting=!0,(f||m._shouldCreateBgLayer)&&(lt(t),m._shouldCreateBgLayer&&delete m._shouldCreateBgLayer),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),f&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&h.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||h.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},m._size),M=0;function A(){if(h.clearAutoMarginIds(t),k.drawMarginPushers(t),d.allowAutoMargin(t),m._has(\"pie\"))for(var e=t._fullData,r=0;r<e.length;r++){var n=e[r];\"pie\"===n.type&&n.automargin&&h.allowAutoMargin(t,\"pie.\"+n.uid+\".automargin\")}return h.doAutoMargin(t),h.previousPromises(t)}function S(){t._transitioning||(k.doAutoRangeAndConstraints(t),f&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var C=[h.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=m._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!m._glcanvas&&m._has(\"gl\")&&(m._glcanvas=m._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],(function(t){return t.key})),m._glcanvas.enter().append(\"canvas\").attr(\"class\",(function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")})).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),m._glcanvas){m._glcanvas.attr(\"width\",m.width).attr(\"height\",m.height);var i=m._glcanvas.data()[0].regl;if(i&&(Math.floor(m.width)!==i._gl.drawingBufferWidth||Math.floor(m.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!M)return o.log(a+\" Clearing graph and plotting again.\"),h.cleanPlot([],{},t._fullData,m),h.supplyDefaults(t),m=t._fullLayout,h.doCalcdata(t),M++,e();o.error(a)}}return\"h\"===m.modebar.orientation?m._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):m._modebardiv.style(\"width\",null).style(\"height\",m.height+\"px\"),h.previousPromises(t)},A,function(){if(h.didMarginChange(w,m._size))return o.syncOrAsync([A,k.layoutStyles],t)}];y&&C.push((function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()})),C.push(k.layoutStyles),y&&C.push((function(){return d.draw(t,f?\"\":\"redraw\")}),(function(t){t._fullLayout._insideTickLabelsAutorange&&q(t,t._fullLayout._insideTickLabelsAutorange).then((function(){t._fullLayout._insideTickLabelsAutorange=void 0}))})),C.push(k.drawData,k.finalDraw,v,h.addLinks,h.rehover,h.redrag,h.doAutoMargin,(function(t){t._fullLayout._insideTickLabelsAutorange&&f&&d.saveRangeInitial(t,!0)}),h.previousPromises);var L=o.syncOrAsync(C,t);return L&&L.then||(L=Promise.resolve()),L.then((function(){return E(t),t}))},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return h.cleanPlot([],{},r,e),h.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l;t=o.getGraphDiv(t),T.clearPromiseQueue(t);var c=t._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var m=o.extendDeep({},t._context);t._context=void 0,I(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(m,t._context)}t.data=e||[],T.cleanData(t.data),t.layout=n||{},T.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,f,h,p,d=n._preGUI,g=[],m={};for(i in d){if(u=et(i,$)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&rt(a,e))&&c===l&&(null===(f=d[i])&&(f=void 0),at(p=(h=s(e,i)).get(),f))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),h.set(B(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(m[i.substr(0,i.length-9)]=1)}for(var v=0;v<g.length;v++){var y=g[v];if(m[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,T=b[_],k=null;for(i in T){if(!k){var M=nt(_,r);if(M<0){delete b[_];break}var A=it(_,t,(w=r[M]._fullInput).index);if(A<0){delete b[_];break}k=t[A]}if(u=et(i,tt)){if(u.attr?c=(l=s(n,u.attr).get())&&rt(u.attr,e):(l=w.uirevision,void 0===(c=k.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(f=T[i])&&(f=void 0),at(p=(h=s(k,i)).get(),f))){h.set(B(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete T[i]}}}(t.data,t.layout,c,p),h.supplyDefaults(t,{skipUpdateCalc:!0});var v=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=M.layoutFlags();function o(t){return f.getLayoutValObject(r,t)}a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,ot(e,r,[],{getValObject:o,flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0);i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\");return a}(t,p,y,x,b),w=_.newDataRevision,A=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=M.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=f.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,h.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,ot(e[s]._fullInput,l,[],u)}(c.calc||c.plot)&&(c.fullReplot=!0);i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\");return c}(t,c,v,x,b,w);if(J(t)&&(_.layoutReplot=!0),A.calc||_.calc){t.calcdata=void 0;for(var S=Object.getOwnPropertyNames(y),C=0;C<S.length;C++){var L=S[C],P=L.substring(0,5);if(\"xaxis\"===P||\"yaxis\"===P){var z=y[L]._emptyCategories;z&&z()}}}else h.supplyDefaultsUpdateCalc(t.calcdata,v);var O=[];if(a&&(t._transitionData={},h.createTransitionData(t),O.push((function(){return r.addFrames(t,a)}))),y.transition&&!g&&(A.anim||_.anim))_.ticks&&O.push(k.doTicksRelayout),h.doCalcdata(t),k.doAutoRangeAndConstraints(t),O.push((function(){return h.transitionFromReact(t,A,_,p)}));else if(A.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,O.push(r.plot);else{for(var D in _.arrays){var R=_.arrays[D];if(R.length){var F=u.getComponentMethod(D,\"drawOne\");if(F!==o.noop)for(var N=0;N<R.length;N++)F(t,R[N]);else{var j=u.getComponentMethod(D,\"draw\");if(j===o.noop)throw new Error(\"cannot draw components: \"+D);j(t)}}}O.push(h.previousPromises),A.style&&O.push(k.doTraceStyle),(A.colorbars||_.colorbars)&&O.push(k.doColorBars),_.legend&&O.push(k.doLegend),_.layoutstyle&&O.push(k.layoutStyles),_.axrange&&G(O),_.ticks&&O.push(k.doTicksRelayout),_.modebar&&O.push(k.doModeBar),_.camera&&O.push(k.doCamera),O.push(E)}O.push(h.rehover,h.redrag),(l=o.syncOrAsync(O,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then((function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t}))},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return T.cleanData(t.data),T.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then((function(){return t.emit(\"plotly_redraw\"),t}))},r.relayout=q,r.restyle=F,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=K,r._guiRelayout=Q(q),r._guiRestyle=Q(F),r._guiUpdate=Q(K),r._storeDirectGUIEdit=function(t,e,r){for(var n in r){j(n,s(t,n).get(),r[n],e)}}},{\"../components/color\":643,\"../components/drawing\":665,\"../constants/xmlns_namespaces\":754,\"../lib\":778,\"../lib/events\":767,\"../lib/queue\":794,\"../lib/svg_text_utils\":803,\"../plots/cartesian/axes\":828,\"../plots/cartesian/constants\":834,\"../plots/cartesian/graph_interact\":837,\"../plots/cartesian/select\":847,\"../plots/plots\":891,\"../plots/polar/legacy\":899,\"../registry\":911,\"./edit_types\":810,\"./helpers\":811,\"./manage_arrays\":813,\"./plot_config\":815,\"./plot_schema\":816,\"./subroutines\":818,d3:169,\"fast-isnumeric\":241,\"has-hover\":440}],815:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"integer\",min:0,max:2,dflt:1},notifyOnLogging:{valType:\"integer\",min:0,max:2,dflt:0},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],816:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),f=t(\"../plots/polar/legacy/axis_attributes\"),h=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,m=i.isArrayOrTypedArray,v=i.nestedProperty,y=i.valObjectMeta,x=[\"_isSubplotObj\",\"_isLinkedToArray\",\"_arrayAttrRegexps\",\"_deprecated\"];function b(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(_(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!_(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!_(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!_(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function _(t){return t===Math.round(t)&&t>=0}function w(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry){if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)M(r,e,e.attr[i]);else M(r,e,\"subplot\"===e.attr?e.name:e.attr)}for(t in r=function(t){return p(t,{radialaxis:f.radialaxis,angularaxis:f.angularaxis}),p(t,f.layout),t}(r),n.componentsRegistry){var a=(e=n.componentsRegistry[t]).schema;if(a&&(a.subplots||a.layout)){var s=a.subplots;if(s&&s.xaxis&&!s.yaxis)for(var l in s.xaxis)delete r.yaxis[l]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&A(r,e.layoutAttributes,e.name)}return{layoutAttributes:k(r)}}function T(){var t={frames:d({},s)};return k(t),t.frames}function k(t){return function(t){r.crawl(t,(function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")}))}(t),function(t){r.crawl(t,(function(t,e,r){if(t){var n=t._isLinkedToArray;n&&(delete t._isLinkedToArray,r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\")}}))}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function M(t,e,r){var n=v(t,r),i=d({},e.layoutAttributes);i._isSubplotObj=!0,n.set(i)}function A(t,e,r){var n=v(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=\"_isSubplotObj\",r.IS_LINKED_TO_ARRAY=\"_isLinkedToArray\",r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=x,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach((function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,(function(t,e,r,n,i){v(s,i).set(void 0),void 0===t&&v(l,i).set(void 0)})),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:k(o)};if(e.layoutAttributes){var f={};d(f,e.layoutAttributes),c.layoutAttributes=k(f)}e.animatable||r.crawl(c,(function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim}));return c}(e)}));var e={};return Object.keys(n.transformsRegistry).forEach((function(t){e[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach((function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach((function(e){A(r,i.schema.transforms[t][e],e)}))})),{attributes:k(r)}}(t)})),{defs:{valObjects:y,metaKeys:x.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:h.traces,layout:h.layout},impliedEdits:{}},traces:t,layout:w(),transforms:e,frames:T(),animation:k(l),config:k(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach((function(n){var o=t[n];if(-1===x.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}}))},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]],c=a+o[r];if(r===o.length-1)m(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var f=c[u],h=f._module;h&&(n=\"transforms[\"+u+\"].\",e=f,r.crawl(h.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!_(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var f=t._module;if(f||(f=(n.modules[t.type||a.type.dflt]||{})._module),!f)return!1;if(!(i=(r=f.attributes)&&r[o])){var h=f.basePlotModule;h&&h.attributes&&(i=h.attributes[o])}i||(i=a[o])}return b(i,e,s)},r.getLayoutValObject=function(t,e){return b(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var h=t._modules;if(h)for(r=0;r<h.length;r++)if((s=h[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return f[e];return f.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":778,\"../plots/animation_attributes\":822,\"../plots/attributes\":824,\"../plots/frame_attributes\":857,\"../plots/layout_attributes\":882,\"../plots/polar/legacy/area_attributes\":897,\"../plots/polar/legacy/axis_attributes\":898,\"../registry\":911,\"./edit_types\":810,\"./plot_config\":815}],817:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a={name:{valType:\"string\",editType:\"none\"}};function o(t){return t&&\"string\"==typeof t}function s(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}a.templateitemname={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=a.name,e.templateitemname=a.templateitemname,e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[s(e)],a=n&&n[e];Array.isArray(a)&&a.length||(a=[]);var l={};return{newItem:function(t){var e={name:t.name,_input:t},n=e.templateitemname=t.templateitemname;if(!o(n))return e._template=i,e;for(var s=0;s<a.length;s++){var c=a[s];if(c.name===n)return l[n]=1,e._template=c,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<a.length;e++){var r=a[e],n=r.name;if(o(n)&&!l[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i.templateitemname=r.templateitemname,t.push(i),l[n]=1}}return t}}},r.arrayDefaultKey=s,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,a=r._index,o=a>=i&&(r._input||{})._templateitemname;o&&(a=i);var s,l=e+\"[\"+a+\"]\";function c(){s={},o&&(s[l]={},s[l].templateitemname=o)}function u(t,e){o?n.nestedProperty(s[l],t).set(e):s[l+\".\"+t]=e}function f(){var t=s;return c(),t}return c(),{modifyBase:function(t,e){s[t]=e},modifyItem:u,getUpdateObj:f,applyUpdate:function(e,r){e&&u(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":778,\"../plots/attributes\":824}],818:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),f=t(\"../components/modebar\"),h=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,m=d.clean,v=t(\"../plots/cartesian/autorange\").doAutoRange;function y(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function x(t){var e,i,s,u,d,g,m=t._fullLayout,v=m._size,x=v.p,_=h.list(t,\"\",!0);if(m._paperdiv.style({width:t._context.responsive&&m.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":m.width+\"px\",height:t._context.responsive&&m.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":m.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,m.width,m.height),t._context.setBackground(t,m.paper_bgcolor),r.drawMainTitle(t),f.manage(t),!m._has(\"cartesian\"))return a.previousPromises(t);function T(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-x-n:e._offset+e._length+x+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+x+n:e._offset-x-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<_.length;e++){var k=(u=_[e])._anchorAxis;u._linepositions={},u._lw=c.crispRound(t,u.linewidth,1),u._mainLinePosition=T(u,k,u.side),u._mainMirrorPosition=u.mirror&&k?T(u,k,p.OPPOSITE_SIDE[u.side]):null}var M=[],A=[],S=[],E=1===l.opacity(m.paper_bgcolor)&&1===l.opacity(m.plot_bgcolor)&&m.paper_bgcolor===m.plot_bgcolor;for(i in m._plots)if((s=m._plots[i]).mainplot)s.bg&&s.bg.remove(),s.bg=void 0;else{var C=s.xaxis.domain,L=s.yaxis.domain,I=s.plotgroup;if(y(C,L,S)){var P=I.node(),z=s.bg=o.ensureSingle(I,\"rect\",\"bg\");P.insertBefore(z.node(),P.childNodes[0]),A.push(i)}else I.select(\"rect.bg\").remove(),S.push([C,L]),E||(M.push(i),A.push(i))}var O,D,R,F,B,N,j,U,V,q,H,G,Y,W=m._bgLayer.selectAll(\".bg\").data(M);for(W.enter().append(\"rect\").classed(\"bg\",!0),W.exit().remove(),W.each((function(t){m._plots[t].bg=n.select(this)})),e=0;e<A.length;e++)s=m._plots[A[e]],d=s.xaxis,g=s.yaxis,s.bg&&void 0!==d._offset&&void 0!==g._offset&&s.bg.call(c.setRect,d._offset-x,g._offset-x,d._length+2*x,g._length+2*x).call(l.fill,m.plot_bgcolor).style(\"stroke-width\",0);if(!m._hasOnlyLargeSploms)for(i in m._plots){s=m._plots[i],d=s.xaxis,g=s.yaxis;var X,Z,J=s.clipId=\"clip\"+m._uid+i+\"plot\",K=o.ensureSingleById(m._clips,\"clipPath\",J,(function(t){t.classed(\"plotclip\",!0).append(\"rect\")}));s.clipRect=K.select(\"rect\").attr({width:d._length,height:g._length}),c.setTranslate(s.plot,d._offset,g._offset),s._hasClipOnAxisFalse?(X=null,Z=J):(X=J,Z=null),c.setClipUrl(s.plot,X,t),s.layerClipId=Z}function Q(t){return\"M\"+O+\",\"+t+\"H\"+D}function $(t){return\"M\"+d._offset+\",\"+t+\"h\"+d._length}function tt(t){return\"M\"+t+\",\"+U+\"V\"+j}function et(t){return\"M\"+t+\",\"+g._offset+\"v\"+g._length}function rt(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in m._plots){s=m._plots[i],d=s.xaxis,g=s.yaxis;var nt=\"M0,0\";b(d,i)&&(B=w(d,\"left\",g,_),O=d._offset-(B?x+B:0),N=w(d,\"right\",g,_),D=d._offset+d._length+(N?x+N:0),R=T(d,g,\"bottom\"),F=T(d,g,\"top\"),!(Y=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[R,F]),nt=rt(d,Q,$),Y&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(R)+Q(F)),s.xlines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),s.xlines.attr(\"d\",nt);var it=\"M0,0\";b(g,i)&&(H=w(g,\"bottom\",d,_),j=g._offset+g._length+(H?x:0),G=w(g,\"top\",d,_),U=g._offset-(G?x:0),V=T(g,d,\"left\"),q=T(g,d,\"right\"),!(Y=!g._anchorAxis||i!==g._mainSubplot)||\"allticks\"!==g.mirror&&\"all\"!==g.mirror||(g._linepositions[i]=[V,q]),it=rt(g,tt,et),Y&&g.showline&&(\"all\"===g.mirror||\"allticks\"===g.mirror)&&(it+=tt(V)+tt(q)),s.ylines.style(\"stroke-width\",g._lw+\"px\").call(l.stroke,g.showline?g.linecolor:\"rgba(0,0,0,0)\")),s.ylines.attr(\"d\",it)}return h.makeClipPaths(t),a.previousPromises(t)}function b(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function _(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function w(t,e,r,n){if(_(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&_(t,e,a))return a._lw}return 0}function T(t,e){var r=t.title,n=t._size,i=0;switch(\"start\"===e?i=r.pad.l:\"end\"===e&&(i=-r.pad.r),r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}function k(t,e){var r=t.title,n=t._size,i=0;if(\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b,\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,x],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=\"middle\";o.isRightAnchor(e)?r=\"end\":o.isLeftAnchor(e)&&(r=\"start\");return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:T(e,r),y:k(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},f=u._module||{},h=f.arraysToCalcdata;h&&h(l,u);var p=f.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return h.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;f.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]];i._scene.setViewport(i)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r=h.list(t,\"\",!0),n={},i=0;i<r.length;i++)if(!n[(e=r[i])._id]){n[e._id]=1,m(t,e),v(t,e);var a=e._matchGroup;if(a)for(var o in a){var s=h.getFromId(t,o);v(t,s,e.range),n[o]=1}}g(t)},r.finalDraw=function(t){i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":643,\"../components/drawing\":665,\"../components/modebar\":703,\"../components/titles\":738,\"../constants/alignment\":745,\"../lib\":778,\"../lib/clear_gl_canvases\":762,\"../plots/cartesian/autorange\":827,\"../plots/cartesian/axes\":828,\"../plots/cartesian/constraints\":835,\"../plots/plots\":891,\"../registry\":911,d3:169}],819:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var f=o.defaultItems();for(a=0;a<f.length;a++)r.push(f[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],h=t[c];if(c in e?s(h,e[c],c):e[c]=h,f(c)===c)for(var p in e){var d=f(p);p===d||d!==c||p in t||s(h,e[p],c)}}}function f(t){return t.replace(/[0-9]+$/,\"\")}function h(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],p=g(t,c,a),d=g(t,c,o),m=r(d);if(!m){var v=f(c);v!==c&&(m=r(d=g(t,v,o)))}if((!s||s!==m)&&!(!m||m._noTemplating||\"data_array\"===m.valType||m.arrayOk&&Array.isArray(u)))if(!m.valType&&i(u))h(u,e,r,p,d);else if(m._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var T=w.name;if(T)b[T]||(h(w,e,r,g(u,x,p),g(u,x,d)),x++,b[T]=1);else if(!y){var k=g(t,l.arrayDefaultKey(c),a),M=g(u,x,p);h(w,e,r,M,g(u,x,d));var A=n.nestedProperty(e,M);n.nestedProperty(e,k).set(A.get()),A.set(null),y=!0}}}else{n.nestedProperty(e,p).set(u)}}}function p(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}function d(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}function g(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function m(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function v(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var a={data:{},layout:{}};e.forEach((function(t){var e={};h(t,e,d.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=a.data[r];i||(i=a.data[r]=[]),i.push(e)})),h(r,a.layout,p.bind(null,r)),delete a.layout.template;var l=r.template;if(i(l)){var f,g,m,v,y,x,b=l.layout;i(b)&&u(b,a.layout);var _=l.data;if(i(_)){for(g in a.data)if(m=_[g],Array.isArray(m)){for(x=(y=a.data[g]).length,v=m.length,f=0;f<x;f++)u(m[f%v],y[f]);for(f=x;f<v;f++)y.push(n.extendDeep({},m[f]))}for(g in _)g in a.data||(a.data[g]=n.extendDeep([],_[g]))}}return a},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var h=r._fullLayout,p=r._fullData,d={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=f(n),s=[];for(a=0;a<r.length;a++)s.push(g(e,n,r[a])),o!==n&&s.push(g(e,o,r[a]));for(a=0;a<s.length;a++)d[s[a]]=1;t(e[n],s)}}(h,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=g(e,n,r);d[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<p.length;b++){var _=p[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,T=x[y]||0;w>T?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:T}):T>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:T})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=g(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&m(a)&&t(a,o)}}({data:p,layout:h},\"\"),u.length)return u.map(v)}},{\"../lib\":778,\"../plots/attributes\":824,\"../plots/plots\":891,\"./plot_config\":815,\"./plot_schema\":816,\"./plot_template\":817}],820:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../snapshot/helpers\"),l=t(\"../snapshot/tosvg\"),c=t(\"../snapshot/svgtoimg\"),u=t(\"../version\").version,f={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\",\"full-json\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,h,p,d;function g(t){return!(t in e)||o.validate(e[t],f[t])}if(e=e||{},o.isPlainObject(t)?(r=t.data||[],h=t.layout||{},p=t.config||{},d={}):(t=o.getGraphDiv(t),r=o.extendDeep([],t.data),h=o.extendDeep({},t.layout),p=t._context,d=t._fullLayout||{}),!g(\"width\")&&null!==e.width||!g(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!g(\"format\"))throw new Error(\"Export format is not \"+o.join2(f.format.values,\", \",\" or \")+\".\");var m={};function v(t,r){return o.coerce(e,m,f,t,r)}var y=v(\"format\"),x=v(\"width\"),b=v(\"height\"),_=v(\"scale\"),w=v(\"setBackground\"),T=v(\"imageDataOnly\"),k=document.createElement(\"div\");k.style.position=\"absolute\",k.style.left=\"-5000px\",document.body.appendChild(k);var M=o.extendFlat({},h);x?M.width=x:null===e.width&&n(d.width)&&(M.width=d.width),b?M.height=b:null===e.height&&n(d.height)&&(M.height=d.height);var A=o.extendFlat({},p,{_exportedPlot:!0,staticPlot:!0,setBackground:w}),S=s.getRedrawFunc(k);function E(){return new Promise((function(t){setTimeout(t,s.getDelay(k._fullLayout))}))}function C(){return new Promise((function(t,e){var r=l(k,y,_),n=k._fullLayout.width,f=k._fullLayout.height;function h(){i.purge(k),document.body.removeChild(k)}if(\"full-json\"===y){var p=a.graphJson(k,!1,\"keepdata\",\"object\",!0,!0);return p.version=u,p=JSON.stringify(p),h(),t(T?p:s.encodeJSON(p))}if(h(),\"svg\"===y)return t(T?r:s.encodeSVG(r));var d=document.createElement(\"canvas\");d.id=o.randstr(),c({format:y,width:n,height:f,scale:_,canvas:d,svg:r,promise:!0}).then(t).catch(e)}))}return new Promise((function(t,e){i.plot(k,r,M,A).then(S).then(E).then(C).then((function(e){t(function(t){return T?t.replace(s.IMAGE_URL_PREFIX,\"\"):t}(e))})).catch((function(t){e(t)}))}))}},{\"../lib\":778,\"../plots/plots\":891,\"../snapshot/helpers\":915,\"../snapshot/svgtoimg\":917,\"../snapshot/tosvg\":919,\"../version\":1370,\"./plot_api\":814,\"fast-isnumeric\":241}],821:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var f=Object.keys(t),h=0;h<f.length;h++){var p=f[h];if(\"transforms\"!==p){var v=o.slice();v.push(p);var y=t[p],x=e[p],b=m(r,p),_=(b||{}).valType,w=\"info_array\"===_,T=\"colorscale\"===_,k=(b||{}).items;if(g(r,p))if(s(y)&&s(x)&&\"any\"!==_)u(y,x,b,i,a,v);else if(w&&l(y)){y.length>x.length&&i.push(d(\"unused\",a,v.concat(x.length)));var M,A,S,E,C,L=x.length,I=Array.isArray(k);if(I&&(L=Math.min(L,k.length)),2===b.dimensions)for(A=0;A<L;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(d(\"unused\",a,v.concat(A,x[A].length)));var P=x[A].length;for(M=0;M<(I?Math.min(P,k[A].length):P);M++)S=I?k[A][M]:k,E=y[A][M],C=x[A][M],n.validate(E,S)?C!==E&&C!==+E&&i.push(d(\"dynamic\",a,v.concat(A,M),E,C)):i.push(d(\"value\",a,v.concat(A,M),E))}else i.push(d(\"array\",a,v.concat(A),y[A]));else for(A=0;A<L;A++)S=I?k[A]:k,E=y[A],C=x[A],n.validate(E,S)?C!==E&&C!==+E&&i.push(d(\"dynamic\",a,v.concat(A),E,C)):i.push(d(\"value\",a,v.concat(A),E))}else if(b.items&&!w&&l(y)){var z,O,D=k[Object.keys(k)[0]],R=[];for(z=0;z<x.length;z++){var F=x[z]._index||z;if((O=v.slice()).push(F),s(y[F])&&s(x[z])){R.push(F);var B=y[F],N=x[z];s(B)&&!1!==B.visible&&!1===N.visible?i.push(d(\"invisible\",a,O)):u(B,N,D,i,a,O)}}for(z=0;z<y.length;z++)(O=v.slice()).push(z),s(y[z])?-1===R.indexOf(z)&&i.push(d(\"unused\",a,O)):i.push(d(\"object\",a,O,y[z]))}else!s(y)&&s(x)?i.push(d(\"object\",a,v,y)):c(y)||!c(x)||w||T?p in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(d(\"dynamic\",a,v,y,x)):i.push(d(\"value\",a,v,y)):i.push(d(\"unused\",a,v,y)):i.push(d(\"array\",a,v,y));else i.push(d(\"schema\",a,v))}}return i}function f(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}e.exports=function(t,e){void 0===t&&(t=[]),void 0===e&&(e={});var r,c,h=a.get(),p=[],g={_context:n.extendFlat({},o)};l(t)?(g.data=n.extendDeep([],t),r=t):(g.data=[],r=[],p.push(d(\"array\",\"data\"))),s(e)?(g.layout=n.extendDeep({},e),c=e):(g.layout={},c={},arguments.length>1&&p.push(d(\"object\",\"layout\"))),i.supplyDefaults(g);for(var m=g._fullData,v=r.length,y=0;y<v;y++){var x=r[y],b=[\"data\",y];if(s(x)){var _=m[y],w=_.type,T=h.traces[w].attributes;T.type={valType:\"enumerated\",values:[w]},!1===_.visible&&!1!==x.visible&&p.push(d(\"invisible\",b)),u(x,_,T,p,b);var k=x.transforms,M=_.transforms;if(k){l(k)||p.push(d(\"array\",b,[\"transforms\"])),b.push(\"transforms\");for(var A=0;A<k.length;A++){var S=[\"transforms\",A],E=k[A].type;if(s(k[A])){var C=h.transforms[E]?h.transforms[E].attributes:{};C.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],M[A],C,p,b,S)}else p.push(d(\"object\",b,S))}}}else p.push(d(\"object\",b))}var L=g._fullLayout,I=f(h,m);return u(c,L,I,p,\"layout\"),0===p.length?void 0:p};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":p(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":p(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return p(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return p(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[p(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?p(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[p(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function p(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function d(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function g(t,e){var r=y(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function m(t,e){return e in t?t[e]:t[y(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function y(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":778,\"../plots/plots\":891,\"./plot_config\":815,\"./plot_schema\":816}],822:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],823:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],f=e[s]=[],h=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=h.newItem(p):(o=h.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),f.push(o)}var d=h.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=f.length,r.handleItemDefaults({},o,e,r,{}),f.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,f.length);for(a=0;a<g;a++)n.relinkPrivateKeys(f[a],c[a])}return f}},{\"../lib\":778,\"../plot_api/plot_template\":817}],824:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":674}],825:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i.dateTime2ms,o=i.incrementMonth,s=t(\"../../constants/numerical\").ONEAVGMONTH;e.exports=function(t,e,r,i){if(\"date\"!==e.type)return i;var l=t[r+\"periodalignment\"];if(!l)return i;var c,u=t[r+\"period\"];if(n(u)){if((u=+u)<=0)return i}else if(\"string\"==typeof u&&\"M\"===u.charAt(0)){var f=+u.substring(1);if(!(f>0&&Math.round(f)===f))return i;c=f}for(var h=e.calendar,p=\"start\"===l,d=\"end\"===l,g=t[r+\"period0\"],m=a(g,h)||0,v=[],y=i.length,x=0;x<y;x++){var b,_,w,T=i[x];if(c){for(b=Math.round((T-m)/(c*s)),w=o(m,c*b,h);w>T;)w=o(w,-c,h);for(;w<=T;)w=o(w,c,h);_=o(w,-c,h)}else{for(w=m+(b=Math.round((T-m)/u))*u;w>T;)w-=u;for(;w<=T;)w+=u;_=w-u}v[x]=p?_:d?w:(_+w)/2}return v}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],826:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],827:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\"),s=t(\"./axis_ids\"),l=s.getFromId,c=s.isLinked;function u(t,e){var r,n,a=[],o=t._fullLayout,s=h(o,e,0),l=h(o,e,1),c=p(t,e),u=c.min,d=c.max;if(0===u.length||0===d.length)return i.simpleMap(e.range,e.r2l);var g=u[0].val,m=d[0].val;for(r=1;r<u.length&&g===m;r++)g=Math.min(g,u[r].val);for(r=1;r<d.length&&g===m;r++)m=Math.max(m,d[r].val);var v=!1;if(e.range){var y=i.simpleMap(e.range,e.r2l);v=y[1]<y[0]}\"reversed\"===e.autorange&&(v=!0,e.autorange=!0);var x,b,_,w,T,k,M=e.rangemode,A=\"tozero\"===M,S=\"nonnegative\"===M,E=e._length,C=E/10,L=0;for(r=0;r<u.length;r++)for(x=u[r],n=0;n<d.length;n++)(k=(b=d[n]).val-x.val-f(e,x.val,b.val))>0&&((T=E-s(x)-l(b))>C?k/T>L&&(_=x,w=b,L=k/T):k/E>L&&(_={val:x.val,nopad:1},w={val:b.val,nopad:1},L=k/E));if(g===m){var I=g-1,P=g+1;if(A)if(0===g)a=[0,1];else{var z=(g>0?d:u).reduce((function(t,e){return Math.max(t,l(e))}),0),O=g/(1-Math.min(.5,z/E));a=g>0?[0,O]:[O,0]}else a=S?[Math.max(0,I),Math.max(1,P)]:[I,P]}else A?(_.val>=0&&(_={val:0,nopad:1}),w.val<=0&&(w={val:0,nopad:1})):S&&(_.val-L*s(_)<0&&(_={val:0,nopad:1}),w.val<=0&&(w={val:1,nopad:1})),L=(w.val-_.val-f(e,x.val,b.val))/(E-s(_)-l(w)),a=[_.val-L*s(_),w.val+L*l(w)];return v&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function f(t,e,r){var n=0;if(t.rangebreaks)for(var i=t.locateBreaks(e,r),a=0;a<i.length;a++){var o=i[a];n+=o.max-o.min}return n}function h(t,e,r){var n=.05*e._length,a=e._anchorAxis||{};if(-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")||-1!==(a.ticklabelposition||\"\").indexOf(\"inside\")){var o=\"reversed\"===e.autorange;if(!o){var s=i.simpleMap(e.range,e.r2l);o=s[1]<s[0]}o&&(r=!r)}var l=0;return c(t,e._id)||(l=function(t,e){var r=0,n=t._anchorAxis||{};if(-1!==(n.ticklabelposition||\"\").indexOf(\"inside\")&&(!e&&(\"left\"===n.side||\"bottom\"===n.side)||e&&(\"top\"===n.side||\"right\"===n.side))){var a=\"x\"===t._id.charAt(0);if(n._vals){var o=i.deg2rad(n._tickAngles[n._id+\"tick\"]||0),s=Math.abs(Math.cos(o)),l=Math.abs(Math.sin(o));n._vals.forEach((function(t){if(t.bb){var e=6+t.bb.width,n=6+t.bb.height;r=Math.max(r,a?Math.max(e*s,n*l):Math.max(n*s,e*l))}}))}\"inside\"===n.ticks&&\"inside\"===n.ticklabelposition&&(r+=n.ticklen||0)}return r}(e,r)),n=Math.max(l,n),\"domain\"===e.constrain&&e._inputDomain&&(n*=(e._inputDomain[1]-e._inputDomain[0])/(e.domain[1]-e.domain[0])),function(t){return t.nopad?0:t.pad+(t.extrapad?n:l)}}e.exports={getAutoRange:u,makePadFn:h,doAutoRange:function(t,e,r){if(e.setScale(),e.autorange){e.range=r?r.slice():u(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var n=e._input,a={};a[e._attr+\".range\"]=e.range,a[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,a),n.range=e.range.slice(),n.autorange=e.autorange}var s=e._anchorAxis;if(s&&s.rangeslider){var l=s.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=u(t,e)),s._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,u,f,h,p,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,T=!1,k=r.vpadLinearized||!1;function M(t){if(Array.isArray(t))return T=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=M((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),S=M((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),E=M(r.vpadplus||r.vpad),C=M(r.vpadminus||r.vpad);if(!T){if(h=1/0,p=-1/0,w)for(i=0;i<x;i++)(o=e[i])<h&&o>0&&(h=o),o>p&&o<a&&(p=o);else for(i=0;i<x;i++)(o=e[i])<h&&o>-a&&(h=o),o>p&&o<a&&(p=o);e=[h,p],x=2}var L={tozero:_,extrapad:b};function I(r){s=e[r],n(s)&&(u=A(r),f=S(r),k?(l=t.c2l(s)-C(r),c=t.c2l(s)+E(r)):(h=s-C(r),p=s+E(r),w&&h<p/10&&(h=p/10),l=t.c2l(h),c=t.c2l(p)),_&&(l=Math.min(0,l),c=Math.max(0,c)),v(l)&&d(m,l,f,L),v(c)&&g(y,c,u,L))}var P=Math.min(6,x);for(i=0;i<P;i++)I(i);for(i=x-1;i>=P;i--)I(i);return{min:m,max:y,opts:r}},concatExtremes:p};function p(t,e,r){var n,i,a,o=e._id,s=t._fullData,c=t._fullLayout,u=[],f=[];function h(t,e){for(n=0;n<e.length;n++){var r=t[e[n]],s=(r._extremes||{})[o];if(!0===r.visible&&s){for(i=0;i<s.min.length;i++)a=s.min[i],d(u,a.val,a.pad,{extrapad:a.extrapad});for(i=0;i<s.max.length;i++)a=s.max[i],g(f,a.val,a.pad,{extrapad:a.extrapad})}}}if(h(s,e._traceIndices),h(c.annotations||[],e._annIndices||[]),h(c.shapes||[],e._shapeIndices||[]),e._matchGroup&&!r)for(var m in e._matchGroup)if(m!==e._id){var v=l(t,m),y=p(t,v,!0),x=e._length/v._length;for(i=0;i<y.min.length;i++)a=y.min[i],d(u,a.val,a.pad*x,{extrapad:a.extrapad});for(i=0;i<y.max.length;i++)a=y.max[i],g(f,a.val,a.pad*x,{extrapad:a.extrapad})}return{min:u,max:f}}function d(t,e,r,n){m(t,e,r,n,y)}function g(t,e,r,n){m(t,e,r,n,x)}function m(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function v(t){return n(t)&&Math.abs(t)<a}function y(t,e){return t<=e}function x(t,e){return t>=e}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../registry\":911,\"./axis_ids\":831,\"fast-isnumeric\":241}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/titles\"),f=t(\"../../components/color\"),h=t(\"../../components/drawing\"),p=t(\"./layout_attributes\"),d=t(\"./clean_ticks\"),g=t(\"../../constants/numerical\"),m=g.ONEMAXYEAR,v=g.ONEAVGYEAR,y=g.ONEMINYEAR,x=g.ONEMAXQUARTER,b=g.ONEAVGQUARTER,_=g.ONEMINQUARTER,w=g.ONEMAXMONTH,T=g.ONEAVGMONTH,k=g.ONEMINMONTH,M=g.ONEWEEK,A=g.ONEDAY,S=A/2,E=g.ONEHOUR,C=g.ONEMIN,L=g.ONESEC,I=g.MINUS_SIGN,P=g.BADNUM,z=t(\"../../constants/alignment\"),O=z.MID_SHIFT,D=z.CAP_SHIFT,R=z.LINE_SPACING,F=z.OPPOSITE_SIDE,B=e.exports={};B.setConvert=t(\"./set_convert\");var N=t(\"./axis_autotype\"),j=t(\"./axis_ids\"),U=j.idSort,V=j.isLinked;B.id2name=j.id2name,B.name2id=j.name2id,B.cleanId=j.cleanId,B.list=j.list,B.listIds=j.listIds,B.getFromId=j.getFromId,B.getFromTrace=j.getFromTrace;var q=t(\"./autorange\");B.getAutoRange=q.getAutoRange,B.findExtremes=q.findExtremes;function H(t){var e=1e-4*(t[1]-t[0]);return[t[0]-e,t[1]+e]}B.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||(\"string\"==typeof a?a:a[0])),a||(a=i),l=l.concat(l.map((function(t){return t+\" domain\"}))),u[c]={valType:\"enumerated\",values:l.concat(a?\"string\"==typeof a?[a]:a:[]),dflt:i},s.coerce(t,e,u,c)},B.getRefType=function(t){return void 0===t?t:\"paper\"===t?\"paper\":\"pixel\"===t?\"pixel\":/( domain)$/.test(t)?\"domain\":\"range\"},B.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"range\"!==B.getRefType(n))o=s.ensureNumber,l=r(i,a);else{var c=B.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},B.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:B.getFromId(e,r).cleanPos)(t)},B.redrawComponents=function(t,e){e=e||B.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var f=r[B.id2name(e[u])][a],h=0;h<f.length;h++){var p=f[h];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var G=B.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:N(n,void 0,{autotypenumbers:t._fullLayout.autotypenumbers}),_categories:[]},B.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=B.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:W,c2d:W}:{d2c:Y,c2d:Y}};function Y(t){return+t}function W(t){return String(t)}function X(t){return+t.substring(1)}B.getDataToCoordFunc=function(t,e,r,n){return G(t,e,r,n).d2c},B.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},B.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},B.saveRangeInitial=function(t,e){for(var r=B.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},B.saveShowSpikeInitial=function(t,e){for(var r=B.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},B.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},B.setConvert(l),o=o&&d.dtick(o,l.type))l.dtick=o,l.tick0=d.tick0(void 0,l.type,a);else{var f;if(r)f=(u-c)/r;else{var h=s.distinctVals(t),p=Math.pow(10,Math.floor(Math.log(h.minDiff)/Math.LN10)),g=p*s.roundUp(h.minDiff/p,[.9,1.9,4.9,9.9],!0);f=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(f)||(f=1)}B.autoTicks(l,f)}var m,v=l.dtick,y=B.tickIncrement(B.tickFirst(l),v,\"reverse\",a);if(\"number\"==typeof v)m=(y=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var f=0;f<e.length;f++)e[f]%1==0?l++:i(e[f])||c++,u(e[f])&&o++,u(e[f]+r.dtick/2)&&s++;var h=e.length-c;if(l===h&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*h&&(o>.3*h||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(y,t,l,c,u))+(1+Math.floor((u-y)/v))*v;else for(\"M\"===l.dtick.charAt(0)&&(y=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=B.tickIncrement(t,\"M6\",\"reverse\")+1.5*A:a.exactMonths>.8?t=B.tickIncrement(t,\"M1\",\"reverse\")+15.5*A:t-=S;var l=B.tickIncrement(t,r);if(l<=n)return l}return t}(y,t,v,c,a)),m=y,0;m<=u;)m=B.tickIncrement(m,v,!1,a);return{start:e.c2r(y,0,a),end:e.c2r(m,0,a),size:v,_dataSpan:u-c}},B.prepTicks=function(t,e){var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(t._dtickInit=t.dtick,t._tick0Init=t.tick0,\"auto\"===t.tickmode||!t.dtick){var n,a=t.nticks;a||(\"category\"===t.type||\"multicategory\"===t.type?(n=t.tickfont?1.2*(t.tickfont.size||12):15,a=t._length/n):(n=\"y\"===t._id.charAt(0)?40:80,a=s.constrain(t._length/n,4,9)+1),\"radialaxis\"===t._name&&(a*=2)),\"array\"===t.tickmode&&(a*=100),t._roughDTick=Math.abs(r[1]-r[0])/a,B.autoTicks(t,t._roughDTick),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}\"period\"===t.ticklabelmode&&function(t){var e;function r(){return!(i(t.dtick)||\"M\"!==t.dtick.charAt(0))}var n=r(),a=B.getTickFormat(t);if(a){var o=t._dtickInit!==t.dtick;/%[fLQsSMX]/.test(a)||(/%[HI]/.test(a)?(e=E,o&&!n&&t.dtick<E&&(t.dtick=E)):/%p/.test(a)?(e=S,o&&!n&&t.dtick<S&&(t.dtick=S)):/%[Aadejuwx]/.test(a)?(e=A,o&&!n&&t.dtick<A&&(t.dtick=A)):/%[UVW]/.test(a)?(e=M,o&&!n&&t.dtick<M&&(t.dtick=M)):/%[Bbm]/.test(a)?(e=T,o&&(n?X(t.dtick)<1:t.dtick<k)&&(t.dtick=\"M1\")):/%[q]/.test(a)?(e=b,o&&(n?X(t.dtick)<3:t.dtick<_)&&(t.dtick=\"M3\")):/%[Yy]/.test(a)&&(e=v,o&&(n?X(t.dtick)<12:t.dtick<y)&&(t.dtick=\"M12\")))}(n=r())&&t.tick0===t._dowTick0&&(t.tick0=t._rawTick0);t._definedDelta=e}(t),t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),nt(t)},B.calcTicks=function(t,e){B.prepTicks(t,e);var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=H(s.simpleMap(t.range,t.r2l)),a=Math.min(i[0],i[1]),o=Math.max(i[0],i[1]),l=0;Array.isArray(r)||(r=[]);var c=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var u=0;u<e.length;u++){var f=c(e[u]);f>a&&f<o&&(void 0===r[u]?n[l]=B.tickText(t,f):n[l]=it(t,f,String(r[u])),l++)}l<e.length&&n.splice(l,e.length-l);t.rangebreaks&&(n=n.filter((function(e){return t.maskBreaks(e.x)!==P})));return n}(t);var n=H(r),a=n[0],o=n[1],l=r[1]<r[0],c=Math.min(r[0],r[1]),u=Math.max(r[0],r[1]),f=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),h=\"period\"===t.ticklabelmode;if(t._tmin=B.tickFirst(t,e),t._tmin<a!==l)return[];\"category\"!==t.type&&\"multicategory\"!==t.type||(o=l?Math.max(-.5,o):Math.min(t._categories.length-.5,o));var p=t._tmin;t.rangebreaks&&t._tick0Init!==t.tick0&&(p=wt(p,t),l||(p=B.tickIncrement(p,t.dtick,!l,t.calendar))),h&&(p=B.tickIncrement(p,t.dtick,!l,t.calendar));for(var d,g=Math.max(1e3,t._length||0),C=[],L=null;l?p>=o:p<=o;p=B.tickIncrement(p,t.dtick,l,t.calendar)){if(t.rangebreaks&&!l){if(p<a)continue;if(t.maskBreaks(p)===P&&wt(p,t)>=u)break}if(C.length>g||p===L)break;L=p;var I=!1;f&&p!==(0|p)&&(I=!0),C.push({minor:I,value:p})}if(h&&function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n].value,a=n,o=n+1;n<t.length-1?(a=n,o=n+1):n>0?(a=n-1,o=n):(a=n,o=n);var s,l=t[a].value,c=t[o].value,u=Math.abs(c-l),f=r||u,h=0;f>=y?h=u>=y&&u<=m?u:v:r===b&&f>=_?h=u>=_&&u<=x?u:b:f>=k?h=u>=k&&u<=w?u:T:r===M&&f>=M?h=M:f>=A?h=A:r===S&&f>=S?h=S:r===E&&f>=E&&(h=E),h>=u&&(h=u,s=!0);var p=i+h;if(e.rangebreaks&&h>0){for(var d=0,g=0;g<84;g++){var C=(g+.5)/84;e.maskBreaks(i*(1-C)+C*p)!==P&&d++}(h*=d/84)||(t[n].drop=!0),s&&u>M&&(h=u)}(h>0||0===n)&&(t[n].periodX=i+h/2)}}(C,t,t._definedDelta),t.rangebreaks){var z=\"y\"===t._id.charAt(0),O=1;\"auto\"===t.tickmode&&(O=t.tickfont?t.tickfont.size:12);var D=NaN;for(d=C.length-1;d>-1;d--)if(C[d].drop)C.splice(d,1);else{C[d].value=wt(C[d].value,t);var R=t.c2p(C[d].value);(z?D>R-O:D<R+O)?C.splice(l?d+1:d,1):D=R}}_t(t)&&360===Math.abs(r[1]-r[0])&&C.pop(),t._tmax=(C[C.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;var F,N,j=[];for(d=0;d<C.length;d++){var U=C[d].minor,V=C[d].value;F=B.tickText(t,V,!1,U),void 0!==(N=C[d].periodX)&&(F.periodX=N,(N>u||N<c)&&(N>u&&(F.periodX=u),N<c&&(F.periodX=c),F.text=\" \",t._prevDateHead=\"\")),j.push(F)}return t._inCalcTicks=!1,j};var Z=[2,5,10],J=[1,2,3,6,12],K=[1,2,5,10,15,30],Q=[1,2,3,7,14],$=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],tt=[-.301,0,.301,.699,1],et=[15,30,45,90,180];function rt(t,e,r){return e*s.roundUp(t/e,r)}function nt(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=A&&a<=10||e>=15*A)t._tickround=\"d\";else if(e>=C&&a<=16||e>=E)t._tickround=\"M\";else if(e>=L&&a<=19||e>=C)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01),u=void 0===t.minexponent?3:t.minexponent;Math.abs(c)>u&&(ot(t.exponentformat)&&!st(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function it(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}B.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar,0);var a=2*e;if(a>v)e/=v,r=n(10),t.dtick=\"M\"+12*rt(e,r,Z);else if(a>T)e/=T,t.dtick=\"M\"+rt(e,1,J);else if(a>A){t.dtick=rt(e,A,t._hasDayOfWeekBreaks?[1,2,7,14]:Q);var o=B.getTickFormat(t),l=\"period\"===t.ticklabelmode;l&&(t._rawTick0=t.tick0),/%[uVW]/.test(o)?t.tick0=s.dateTick0(t.calendar,2):t.tick0=s.dateTick0(t.calendar,1),l&&(t._dowTick0=t.tick0)}else a>E?t.dtick=rt(e,E,J):a>C?t.dtick=rt(e,C,K):a>L?t.dtick=rt(e,L,K):(r=n(10),t.dtick=rt(e,r,Z))}else if(\"log\"===t.type){t.tick0=0;var c=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(c[1]-c[0])<1){var u=1.5*Math.abs((c[1]-c[0])/e);e=Math.abs(Math.pow(10,c[1])-Math.pow(10,c[0]))/u,r=n(10),t.dtick=\"L\"+rt(e,r,Z)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):_t(t)?(t.tick0=0,r=1,t.dtick=rt(e,r,et)):(t.tick0=0,r=n(10),t.dtick=rt(e,r,Z));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var f=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(f)}},B.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return s.increment(t,o*e);var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?tt:$,f=t+.01*o,h=s.roundUp(s.mod(f,1),u,r);return Math.floor(f)+Math.log(n.round(Math.pow(10,h),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},B.tickFirst=function(t,e){var r=t.r2l||Number,a=s.simpleMap(t.range,r,void 0,void 0,e),o=a[1]<a[0],l=o?Math.floor:Math.ceil,c=H(a)[0],u=t.dtick,f=r(t.tick0);if(i(u)){var h=l((c-f)/u)*u+f;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var p=u.charAt(0),d=Number(u.substr(1));if(\"M\"===p){for(var g,m,v,y=0,x=f;y<10;){if(((g=B.tickIncrement(x,u,o,t.calendar))-c)*(x-c)<=0)return o?Math.min(x,g):Math.max(x,g);m=(c-(x+g)/2)/(g-x),v=p+(Math.abs(Math.round(m))||1)*d,x=B.tickIncrement(x,v,m<0?!o:o,t.calendar),y++}return s.error(\"tickFirst did not converge\",t),x}if(\"L\"===p)return Math.log(l((Math.pow(10,c)-f)/d)*d+f)/Math.LN10;if(\"D\"===p){var b=\"D2\"===u?tt:$,_=s.roundUp(s.mod(c,1),b,o);return Math.floor(c)+Math.log(n.round(Math.pow(10,_),1))/Math.LN10}throw\"unrecognized dtick \"+String(u)},B.tickText=function(t,e,r,n){var a,o=it(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,f=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var h=s.simpleMap(t.range,t.r2l),p=(Math.abs(h[1]-h[0])-(t._lBreaks||0))/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-f(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||B.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));if(l)if(r)\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\");else if(t._inCalcTicks&&t._prevDateHead===l){var f=-1!==(t.ticklabelposition||\"\").indexOf(\"inside\"),h=t._realSide||t.side;(!f&&\"top\"===h||f&&\"bottom\"===h)&&(c+=\"<br> \")}else t._prevDateHead=l,c+=\"<br>\"+l;e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=lt(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var f=Math.round(l),h=Math.abs(f),p=t.exponentformat;\"power\"===p||ot(p)&&st(f)?(e.text=0===f?1:1===f?\"10\":\"10<sup>\"+(f>1?\"\":I)+h+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&h>2?e.text=\"1\"+p+(f>0?\"+\":I)+h:(e.text=lt(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):_t(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=lt(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){for(var r=1;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=lt(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=I+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=lt(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var m=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[m(o.x-.5),m(o.x+t.dtick-.5)]}return o},B.hoverLabelText=function(t,e,r){if(r!==P&&r!==e)return B.hoverLabelText(t,e)+\" - \"+B.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=B.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":I+i:i};var at=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function ot(t){return\"SI\"===t||\"B\"===t}function st(t){return t>14||t<-15}function lt(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=B.getTickFormat(e),f=e.separatethousands;if(n){var h={exponentformat:l,minexponent:e.minexponent,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};nt(h),o=(Number(h._tickround)||0)+4,c=h._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,I);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var m=(t=String(t)).indexOf(\".\")+1;m&&(t=t.substr(0,m+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,f)}c&&\"hide\"!==l&&(ot(l)&&st(c)&&(l=\"power\"),p=c<0?I+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":ot(l)&&(t+=at[c/3+5]));return a?I+t:t}function ct(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(it(t,s.interp(n[o],.5),o));return r}function ut(t){return void 0!==t.periodX?t.periodX:t.x}function ft(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function ht(t){var e=t.title.font.size,r=(t.title.text.match(c.BR_TAG_ALL)||[]).length;return t.title.hasOwnProperty(\"standoff\")?r?e*(D+r*R):e*D:r?e*(r+1)*R:e}function pt(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function dt(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function gt(t){return t._id+\".automargin\"}function mt(t){return gt(t)+\".mirror\"}function vt(t){return t._id+\".rangeslider\"}function yt(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function xt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(B.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(B.getFromId(t,r[n]));var c=Object.keys(p),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],f=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var h=c[n],d=a[0][h],g=o[0][h],m=!0,v=!1,y=!1;if(\"_\"!==h.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(h)){for(i=1;i<a.length&&m;i++){var x=a[i][h];\"type\"===h&&-1!==f.indexOf(d)&&-1!==f.indexOf(x)&&d!==x?v=!0:x!==d&&(m=!1)}for(i=1;i<o.length&&m;i++){var b=o[i][h];\"type\"===h&&-1!==f.indexOf(g)&&-1!==f.indexOf(b)&&g!==b?y=!0:o[i][h]!==g&&(m=!1)}m&&(v&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),bt(l,h,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function bt(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function _t(t){return\"angularaxis\"===t._id}function wt(t,e){for(var r=e._rangebreaks.length,n=0;n<r;n++){var i=e._rangebreaks[n];if(t>=i.min&&t<i.max)return i.max}return t}B.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*T}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function f(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,s=void 0,l=void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&f(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},B.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?B.findSubplotsWithAxis(n,e):n;return i.sort((function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]})),i},B.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},B.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=B.list(t,\"x\",!0),l=B.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,(function(t){return t.x._id+t.y._id}));u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",(function(t){return\"clip\"+e._uid+t.x._id+t.y._id})).append(\"rect\"),u.exit().remove(),u.each((function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})}))}},B.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each((function(t){var e=t[0],r=n._plots[e];if(r){var i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()}}));var i=e&&\"redraw\"!==e?e:B.listIds(t);return s.syncOrAsync(i.map((function(e){return function(){if(e){var n=B.getFromId(t,e),i=B.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}})))},B.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var c=t._fullLayout,p=e._id,d=p.charAt(0),g=B.counterLetter(p),m=c._plots[e._mainSubplot];if(m){var v=m[d+\"axislayer\"],y=e._mainLinePosition,x=e._mainMirrorPosition,b=e._vals=B.calcTicks(e),_=[e.mirror,y,x].join(\"_\");for(n=0;n<b.length;n++)b[n].axInfo=_;e._selections={},e._tickAngles&&(e._prevTickAngles=e._tickAngles),e._tickAngles={},e._depth=null;var w={};if(e.visible){var T,k,M=B.makeTransTickFn(e),A=B.makeTransTickLabelFn(e),S=\"inside\"===e.ticks,E=\"outside\"===e.ticks;if(\"boundaries\"===e.tickson){var C=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,b);k=B.clipEnds(e,C),T=S?k:C}else k=B.clipEnds(e,b),T=S&&\"period\"!==e.ticklabelmode?k:b;var L=e._gridVals=k,I=function(t,e){var r,n,i=[],a=e.length&&e[e.length-1].x<e[0].x,o=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var l=e[r];l.text2!==n&&o(l,a?1:0),n=l.text2}o(e[r-1],a?0:1)}return i}(e,b);if(!c._hasOnlyLargeSploms){var P=e._subplotsWith,z={};for(n=0;n<P.length;n++){i=P[n];var O=(l=c._plots[i])[g+\"axis\"],D=O._mainAxis._id;if(!z[D]){z[D]=1;var N=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;B.drawGrid(t,e,{vals:L,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:N,transFn:M}),B.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:N,transFn:M})}}}var j=B.getTickSigns(e),U=[];if(e.ticks){var V,q,H,G=B.makeTickPath(e,y,j[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(V=B.makeTickPath(e,x,j[3]),q=G+V):(V=\"\",q=G),e.showdividers&&E&&\"boundaries\"===e.tickson){var Y={};for(n=0;n<I.length;n++)Y[I[n].x]=1;H=function(t){return Y[t.x]?V:q}}else H=q;B.drawTicks(t,e,{vals:T,layer:v,path:H,transFn:M}),\"allticks\"===e.mirror&&(U=Object.keys(e._linepositions||{}))}for(n=0;n<U.length;n++){i=U[n],l=c._plots[i];var W=e._linepositions[i]||[],X=B.makeTickPath(e,W[0],j[0])+B.makeTickPath(e,W[1],j[1]);B.drawTicks(t,e,{vals:T,layer:l[d+\"axislayer\"],path:X,transFn:M})}var Z=[];if(Z.push((function(){return B.drawLabels(t,e,{vals:b,layer:v,transFn:A,labelFns:B.makeLabelFns(e,y)})})),\"multicategory\"===e.type){var J={x:2,y:10}[d];Z.push((function(){var r={x:\"height\",y:\"width\"}[d],n=Q()[r]+J+(e._tickAngles[p+\"tick\"]?e.tickfont.size*R:0);return B.drawLabels(t,e,{vals:ct(e,b),layer:v,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:M,labelFns:B.makeLabelFns(e,y+n*j[4])})})),Z.push((function(){return e._depth=j[4]*(Q(\"tick2\")[e.side]-y),function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,ft);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(f.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:I,layer:v,path:B.makeTickPath(e,y,j[4],e._depth),transFn:M})}))}else e.title.hasOwnProperty(\"standoff\")&&Z.push((function(){e._depth=j[4]*(Q()[e.side]-y)}));var K=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return Z.push((function(){var r,n,i,s,l=e.side.charAt(0),u=F[e.side].charAt(0),f=B.getPxPosition(t,e),h=E?e.ticklen:0;if((e.automargin||K)&&(\"multicategory\"===e.type?r=Q(\"tick2\"):(r=Q(),\"x\"===d&&\"b\"===l&&(e._depth=Math.max(r.width>0?r.bottom-f:0,h)))),e.automargin){n={x:0,y:0,r:0,l:0,t:0,b:0};var p=[0,1];if(\"x\"===d){if(\"b\"===l?n[l]=e._depth:(n[l]=e._depth=Math.max(r.width>0?f-r.top:0,h),p.reverse()),r.width>0){var m=r.right-(e._offset+e._length);m>0&&(n.xr=1,n.r=m);var v=e._offset-r.left;v>0&&(n.xl=0,n.l=v)}}else if(\"l\"===l?n[l]=e._depth=Math.max(r.height>0?f-r.left:0,h):(n[l]=e._depth=Math.max(r.height>0?r.right-f:0,h),p.reverse()),r.height>0){var y=r.bottom-(e._offset+e._length);y>0&&(n.yb=0,n.b=y);var x=e._offset-r.top;x>0&&(n.yt=1,n.t=x)}n[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[p[0]],e.title.text!==c._dfltTitle[d]&&(n[l]+=ht(e)+(e.title.standoff||0)),e.mirror&&\"free\"!==e.anchor&&((i={x:0,y:0,r:0,l:0,t:0,b:0})[u]=e.linewidth,e.mirror&&!0!==e.mirror&&(i[u]+=h),!0===e.mirror||\"ticks\"===e.mirror?i[g]=e._anchorAxis.domain[p[1]]:\"all\"!==e.mirror&&\"allticks\"!==e.mirror||(i[g]=[e._counterDomainMin,e._counterDomainMax][p[1]]))}K&&(s=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,gt(e),n),a.autoMargin(t,mt(e),i),a.autoMargin(t,vt(e),s)})),r.skipTitle||K&&\"bottom\"===e.side||Z.push((function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(e.title.hasOwnProperty(\"standoff\"))r=e._depth+e.title.standoff+ht(e);else{var s=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\");if(\"multicategory\"===e.type)r=e._depth;else{var l=1.5*o;s&&(l=.5*o,\"outside\"===e.ticks&&(l+=e.ticklen)),r=10+l+(e.linewidth?e.linewidth-1:0)}s||(r+=\"x\"===a?\"top\"===e.side?o*(e.showticklabels?1:0):o*(e.showticklabels?1.5:.5):\"right\"===e.side?o*(e.showticklabels?1:.5):o*(e.showticklabels?.5:0))}var c,f,p,d,g=B.getPxPosition(t,e);\"x\"===a?(f=e._offset+e._length/2,p=\"top\"===e.side?g-r:g+r):(p=e._offset+e._length/2,f=\"right\"===e.side?g+r:g-r,c={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var m=e._selections[e._id+\"tick\"];if(d={selection:m,side:e.side},m&&m.node()&&m.node().parentNode){var v=h.getTranslate(m.node().parentNode);d.offsetLeft=v.x,d.offsetTop=v.y}e.title.hasOwnProperty(\"standoff\")&&(d.pad=0)}return u.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:d,transform:c,attributes:{x:f,y:p,\"text-anchor\":\"middle\"}})}(t,e)})),s.syncOrAsync(Z)}}function Q(t){var r=p+(t||\"tick\");return w[r]||(w[r]=function(t,e){var r,n,i,a;t._selections[e].size()?(r=1/0,n=-1/0,i=1/0,a=-1/0,t._selections[e].each((function(){var t=dt(this),e=h.bBox(t.node().parentNode);r=Math.min(r,e.top),n=Math.max(n,e.bottom),i=Math.min(i,e.left),a=Math.max(a,e.right)}))):(r=0,n=0,i=0,a=0);return{top:r,bottom:n,left:i,right:a,height:n-r,width:a-i}}(e,r)),w[r]}},B.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map((function(t){return-t}))),t.side&&i.push({l:-1,t:-1,r:1,b:1}[t.side.charAt(0)]),i},B.makeTransTickFn=function(t){return\"x\"===t._id.charAt(0)?function(e){return l(t._offset+t.l2p(e.x),0)}:function(e){return l(0,t._offset+t.l2p(e.x))}},B.makeTransTickLabelFn=function(t){var e=function(t){var e=t.ticklabelposition||\"\",r=function(t){return-1!==e.indexOf(t)},n=r(\"top\"),i=r(\"left\"),a=r(\"right\"),o=r(\"bottom\"),s=r(\"inside\"),l=o||i||n||a;if(!l&&!s)return[0,0];var c=t.side,u=l?(t.tickwidth||0)/2:0,f=3,h=t.tickfont?t.tickfont.size:12;(o||n)&&(u+=h*D,f+=(t.linewidth||0)/2);(i||a)&&(u+=(t.linewidth||0)/2,f+=3);s&&\"top\"===c&&(f-=h*(1-D));(i||n)&&(u=-u);\"bottom\"!==c&&\"right\"!==c||(f=-f);return[l?u:0,s?f:0]}(t),r=e[0],n=e[1];return\"x\"===t._id.charAt(0)?function(e){return l(r+t._offset+t.l2p(ut(e)),n)}:function(e){return l(n,r+t._offset+t.l2p(ut(e)))}},B.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},B.makeLabelFns=function(t,e,r){var n=t.ticklabelposition||\"\",a=function(t){return-1!==n.indexOf(t)},o=a(\"top\"),l=a(\"left\"),c=a(\"right\"),u=a(\"bottom\")||l||o||c,f=a(\"inside\"),h=\"inside\"===n&&\"inside\"===t.ticks||!f&&\"outside\"===t.ticks&&\"boundaries\"!==t.tickson,p=0,d=0,g=h?t.ticklen:0;if(f?g*=-1:u&&(g=0),h&&(p+=g,r)){var m=s.deg2rad(r);p=g*Math.cos(m)+1,d=g*Math.sin(m)}t.showticklabels&&(h||t.showline)&&(p+=.2*t.tickfont.size);var v,y,x,b,_,w={labelStandoff:p+=(t.linewidth||1)/2*(f?-1:1),labelShift:d},T=0,k=t.side,M=t._id.charAt(0),A=t.tickangle;if(\"x\"===M)b=(_=!f&&\"bottom\"===k||f&&\"top\"===k)?1:-1,f&&(b*=-1),v=d*b,y=e+p*b,x=_?1:-.2,90===Math.abs(A)&&(f?x+=O:x=-90===A&&\"bottom\"===k?D:90===A&&\"top\"===k?O:.5,T=O/2*(A/90)),w.xFn=function(t){return t.dx+v+T*t.fontSize},w.yFn=function(t){return t.dy+y+t.fontSize*x},w.anchorFn=function(t,e){if(u){if(l)return\"end\";if(c)return\"start\"}return i(e)&&0!==e&&180!==e?e*b<0!==f?\"end\":\"start\":\"middle\"},w.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side!==f?-n:0};else if(\"y\"===M){if(b=(_=!f&&\"left\"===k||f&&\"right\"===k)?1:-1,f&&(b*=-1),v=p,y=d*b,x=0,f||90!==Math.abs(A)||(x=-90===A&&\"left\"===k||90===A&&\"right\"===k?D:.5),f){var S=i(A)?+A:0;if(0!==S){var E=s.deg2rad(S);T=Math.abs(Math.sin(E))*D*b,x=0}}w.xFn=function(t){return t.dx+e-(v+t.fontSize*x)*b+T*t.fontSize},w.yFn=function(t){return t.dy+y+t.fontSize*O},w.anchorFn=function(t,e){return i(e)&&90===Math.abs(e)?\"middle\":_?\"end\":\"start\"},w.heightFn=function(e,r,n){return\"right\"===t.side&&(r*=-1),r<-30?-n:r<30?-.5*n:0}}return w},B.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.vals;\"period\"===e.ticklabelmode&&(i=i.slice()).shift();var a=r.layer.selectAll(\"path.\"+n).data(e.ticks?i:[],ft);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(f.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),a.attr(\"transform\",r.transFn)},B.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&B.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,ft);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(f.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},B.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=B.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each((function(){r.layer.selectAll(\"path\").sort((function(t,e){return U(t.id,e.id)}))})),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(f.stroke,e.zerolinecolor||f.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},B.drawLabels=function(t,e,r){r=r||{};var a=t._fullLayout,o=e._id,u=o.charAt(0),f=r.cls||o+\"tick\",p=r.vals,d=r.labelFns,g=r.secondary?0:e.tickangle,m=(e._prevTickAngles||{})[f],v=r.layer.selectAll(\"g.\"+f).data(e.showticklabels?p:[],ft),y=[];function x(t,a){var o=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\");t.each((function(t){var s=n.select(this),u=s.select(\".text-math-group\"),f=d.anchorFn(t,a),p=r.transFn.call(s.node(),t)+(i(a)&&0!=+a?\" rotate(\"+a+\",\"+d.xFn(t)+\",\"+(d.yFn(t)-t.fontSize/2)+\")\":\"\"),g=c.lineCount(s),m=R*t.fontSize,v=d.heightFn(t,i(a)?+a:0,(g-1)*m);if(v&&(p+=l(0,v)),u.empty()){var y=s.select(\"text\");y.attr({transform:p,\"text-anchor\":f}),o&&(y.style({opacity:100}),e._hideOutOfRangeInsideTickLabels&&e._hideOutOfRangeInsideTickLabels())}else{var x=h.bBox(u.node()).width*{end:-.5,start:.5}[f];u.attr(\"transform\",p+l(x,0))}}))}v.enter().append(\"g\").classed(f,1).append(\"text\").attr(\"text-anchor\",\"middle\").each((function(e){var r=n.select(this),i=t._promises.length;r.call(c.positionText,d.xFn(e),d.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(c.convertToTspans,t),t._promises[i]?y.push(t._promises.pop().then((function(){x(r,g)}))):x(r,g)})),v.exit().remove(),r.repositionOnUpdate&&v.each((function(t){n.select(this).select(\"text\").call(c.positionText,d.xFn(t),d.yFn(t))})),e._hideOutOfRangeInsideTickLabels=void 0,-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")&&(e._hideOutOfRangeInsideTickLabels=function(){var t=s.simpleMap(e.range,e.r2l),r=e.l2p(t[0]),i=e.l2p(t[1]),a=Math.min(r,i)+e._offset,o=Math.max(r,i)+e._offset,l=\"x\"===e._id.charAt(0);v.each((function(t){var r=n.select(this);if(r.select(\".text-math-group\").empty()){var i=h.bBox(r.node()),s=!1;l?(i.right>o||i.left<a)&&(s=!0):(i.bottom>o||i.top+(e.tickangle?0:t.fontSize/4)<a)&&(s=!0),s&&r.select(\"text\").style({opacity:0})}}))}),x(v,m+1?m:g);var b=null;e._selections&&(e._selections[f]=v);var _=[function(){return y.length&&Promise.all(y)}];e.automargin&&a._redrawFromAutoMarginCount&&90===m?(b=90,_.push((function(){x(v,m)}))):_.push((function(){if(x(v,g),p.length&&\"x\"===u&&!i(g)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){b=0;var t,n=0,a=[];if(v.each((function(t){n=Math.max(n,t.fontSize);var r=e.l2p(t.x),i=dt(this),o=h.bBox(i.node());a.push({top:0,bottom:10,height:10,left:r-o.width/2,right:r+o.width/2+2,width:o.width+2})})),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var o=p.length,l=Math.abs((p[o-1].x-p[0].x)*e._m)/(o-1),c=e.ticklabelposition||\"\",f=function(t){return-1!==c.indexOf(t)},d=f(\"top\"),m=f(\"left\"),y=f(\"right\"),_=f(\"bottom\")||m||d||y?(e.tickwidth||0)+6:0,w=l<2.5*n||\"multicategory\"===e.type;for(t=0;t<a.length-1;t++)if(s.bBoxIntersect(a[t],a[t+1],_)){b=w?90:30;break}}else{var T=2;for(e.ticks&&(T+=e.tickwidth/2),t=0;t<a.length;t++){var k=p[t].xbnd,M=a[t];if(null!==k[0]&&M.left-e.l2p(k[0])<T||null!==k[1]&&e.l2p(k[1])-M.right<T){b=90;break}}}b&&x(v,b)}})),e._tickAngles&&_.push((function(){e._tickAngles[f]=null===b?i(g)?g:0:b}));var w=e._anchorAxis;w&&w.autorange&&-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")&&!V(a,e._id)&&(a._insideTickLabelsAutorange||(a._insideTickLabelsAutorange={}),a._insideTickLabelsAutorange[w._name+\".autorange\"]=w.autorange,_.push((function(){v.each((function(t,r){var n=dt(this);e._vals[r].bb=h.bBox(n.node())}))})));var T=s.syncOrAsync(_);return T&&T.then&&t._promises.push(T),T},B.getPxPosition=function(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=e._anchorAxis:\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0},B.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&!(e.rangebreaks&&e.maskBreaks(0)===P)&&(pt(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=B.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var f=B.list(t,s),h=0;h<f.length;h++){var p=f[h];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},B.clipEnds=function(t,e){return e.filter((function(e){return pt(t,e.x)}))},B.allowAutoMargin=function(t){for(var e=B.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&(a.allowAutoMargin(t,gt(n)),n.mirror&&a.allowAutoMargin(t,mt(n))),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,vt(n))}},B.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],yt(c.x,l.x),yt(c.y,l.y);yt(c.x,[o]),yt(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)xt(t,r[n].x,r[n].y)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/titles\":738,\"../../constants/alignment\":745,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"./autorange\":827,\"./axis_autotype\":829,\"./axis_ids\":831,\"./clean_ticks\":833,\"./layout_attributes\":842,\"./set_convert\":848,d3:169,\"fast-isnumeric\":241}],829:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=i.isArrayOrTypedArray,s=i.isDateTime,l=i.cleanNumber,c=Math.round;function u(t,e){return e?n(t):\"number\"==typeof t}function f(t){return Math.max(1,(t-1)/1e3)}e.exports=function(t,e,r){var i=t,h=r.noMultiCategory;if(o(i)&&!i.length)return\"-\";if(!h&&function(t){return o(t[0])&&o(t[1])}(i))return\"multicategory\";if(h&&Array.isArray(i[0])){for(var p=[],d=0;d<i.length;d++)if(o(i[d]))for(var g=0;g<i[d].length;g++)p.push(i[d][g]);i=p}if(function(t,e){for(var r=t.length,i=f(r),a=0,o=0,l={},u=0;u<r;u+=i){var h=c(u),p=t[h],d=String(p);l[d]||(l[d]=1,s(p,e)&&a++,n(p)&&o++)}return a>2*o}(i,e))return\"date\";var m=\"strict\"!==r.autotypenumbers;return function(t,e){for(var r=t.length,n=f(r),i=0,o=0,s={},u=0;u<r;u+=n){var h=c(u),p=t[h],d=String(p);if(!s[d]){s[d]=1;var g=typeof p;\"boolean\"===g?o++:(e?l(p)!==a:\"number\"===g)?i++:\"string\"===g&&o++}}return o>2*i}(i,m)?\"category\":function(t,e){for(var r=t.length,n=0;n<r;n++)if(u(t[n],e))return!0;return!1}(i,m)?\"linear\":\"-\"}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],830:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../array_container_defaults\"),s=t(\"./layout_attributes\"),l=t(\"./tick_value_defaults\"),c=t(\"./tick_mark_defaults\"),u=t(\"./tick_label_defaults\"),f=t(\"./category_order_defaults\"),h=t(\"./line_grid_defaults\"),p=t(\"./set_convert\"),d=t(\"./constants\").WEEKDAY_PATTERN,g=t(\"./constants\").HOUR_PATTERN;function m(t,e,r){function i(r,n){return a.coerce(t,e,s.rangebreaks,r,n)}if(i(\"enabled\")){var o=i(\"bounds\");if(o&&o.length>=2){var l,c,u=\"\";if(2===o.length)for(l=0;l<2;l++)if(c=y(o[l])){u=d;break}var f=i(\"pattern\",u);if(f===d)for(l=0;l<2;l++)(c=y(o[l]))&&(e.bounds[l]=o[l]=c-1);if(f)for(l=0;l<2;l++)switch(c=o[l],f){case d:if(!n(c))return void(e.enabled=!1);if((c=+c)!==Math.floor(c)||c<0||c>=7)return void(e.enabled=!1);e.bounds[l]=o[l]=c;break;case g:if(!n(c))return void(e.enabled=!1);if((c=+c)<0||c>24)return void(e.enabled=!1);e.bounds[l]=o[l]=c}if(!1===r.autorange){var h=r.range;if(h[0]<h[1]){if(o[0]<h[0]&&o[1]>h[1])return void(e.enabled=!1)}else if(o[0]>h[0]&&o[1]<h[1])return void(e.enabled=!1)}}else{var p=i(\"values\");if(!p||!p.length)return void(e.enabled=!1);i(\"dvalue\")}}}e.exports=function(t,e,r,n,g){var v,y=n.letter,x=n.font||{},b=n.splomStash||{},_=r(\"visible\",!n.visibleDflt),w=e._template||{},T=e.type||w.type||\"-\";\"date\"===T&&(i.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",n.calendar),n.noTicklabelmode||(v=r(\"ticklabelmode\")));n.noTicklabelposition&&\"multicategory\"!==T||a.coerce(t,e,{ticklabelposition:{valType:\"enumerated\",dflt:\"outside\",values:\"period\"===v?[\"outside\",\"inside\"]:\"x\"===y?[\"outside\",\"inside\",\"outside left\",\"inside left\",\"outside right\",\"inside right\"]:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"]}},\"ticklabelposition\"),p(e,g);var k=!e.isValidRange(t.range);k&&n.reverseDflt&&(k=\"reversed\"),!r(\"autorange\",k)||\"linear\"!==T&&\"-\"!==T||r(\"rangemode\"),r(\"range\"),e.cleanRange(),f(t,e,r,n),\"category\"===T||n.noHover||r(\"hoverformat\");var M=r(\"color\"),A=M!==s.color.dflt?M:x.color,S=b.label||g._dfltTitle[y];if(u(t,e,r,T,n,{pass:1}),!_)return e;r(\"title.text\",S),a.coerceFont(r,\"title.font\",{family:x.family,size:Math.round(1.2*x.size),color:A}),l(t,e,r,T),u(t,e,r,T,n,{pass:2}),c(t,e,r,n),h(t,e,r,{dfltColor:M,bgColor:n.bgColor,showGrid:n.showGrid,attributes:s}),(e.showline||e.ticks)&&r(\"mirror\"),n.automargin&&r(\"automargin\");var E,C=\"multicategory\"===T;n.noTickson||\"category\"!==T&&!C||!e.ticks&&!e.showgrid||(C&&(E=\"boundaries\"),\"boundaries\"===r(\"tickson\",E)&&delete e.ticklabelposition);C&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));if(\"date\"===T)if(o(t,e,{name:\"rangebreaks\",inclusionAttr:\"enabled\",handleItemDefaults:m}),e.rangebreaks.length){for(var L=0;L<e.rangebreaks.length;L++)if(e.rangebreaks[L].pattern===d){e._hasDayOfWeekBreaks=!0;break}if(p(e,g),g._has(\"scattergl\")||g._has(\"splom\"))for(var I=0;I<n.data.length;I++){var P=n.data[I];\"scattergl\"!==P.type&&\"splom\"!==P.type||(P.visible=!1,a.warn(P.type+\" traces do not work on axes with rangebreaks. Setting trace \"+P.index+\" to `visible: false`.\"))}}else delete e.rangebreaks;return e};var v={sun:1,mon:2,tue:3,wed:4,thu:5,fri:6,sat:7};function y(t){if(\"string\"==typeof t)return v[t.substr(0,3).toLowerCase()]}},{\"../../lib\":778,\"../../registry\":911,\"../array_container_defaults\":823,\"./category_order_defaults\":832,\"./constants\":834,\"./layout_attributes\":842,\"./line_grid_defaults\":844,\"./set_convert\":848,\"./tick_label_defaults\":849,\"./tick_mark_defaults\":850,\"./tick_value_defaults\":851,\"fast-isnumeric\":241}],831:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");function a(t,e){if(e&&e.length)for(var r=0;r<e.length;r++)if(e[r][t])return!0;return!1}r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.split(\" \")[0].substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e,r){var n=/( domain)$/.test(t);if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)&&(!n||r)){var a=t.split(\" \")[0].substr(1).replace(/^0+/,\"\");return\"1\"===a&&(a=\"\"),t.charAt(0)+a+(n&&r?\" domain\":\"\")}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return e=void 0===e||\"string\"!=typeof e?e:e.replace(\" domain\",\"\"),\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.ref2id=function(t){return!!/^[xyz]/.test(t)&&t.split(\" \")[0]},r.isLinked=function(t,e){return a(e,t._axisMatchGroups)||a(e,t._axisConstraintGroups)}},{\"../../registry\":911,\"./constants\":834}],832:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],833:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.ONEDAY,s=a.ONEWEEK;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,a=\"category\"===e,s=i?o:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:a?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r,a%s==0?1:0)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],834:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\",\"( domain)?\"),y:n(\"y\",\"( domain)?\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*( domain)?$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,HOUR_PATTERN:\"hour\",WEEKDAY_PATTERN:\"day of week\",MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"imagelayer\",\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":795}],835:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./autorange\"),a=t(\"./axis_ids\").id2name,o=t(\"./layout_attributes\"),s=t(\"./scale_zoom\"),l=t(\"./set_convert\"),c=t(\"../../constants/numerical\").ALMOST_EQUAL,u=t(\"../../constants/alignment\").FROM_BL;function f(t,e,r){var i=r.axIds,s=r.layoutOut,l=r.hasImage,c=s._axisConstraintGroups,u=s._axisMatchGroups,f=e._id,g=f.charAt(0),m=((s._splomAxes||{})[g]||{})[f]||{},v=e._id,y=\"x\"===v.charAt(0);function x(r,i){return n.coerce(t,e,o,r,i)}e._matchGroup=null,e._constraintGroup=null,x(\"constrain\",l?\"domain\":\"range\"),n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:y?\"center\":\"middle\"}},\"constraintoward\");var b,_,w=e.type,T=[];for(b=0;b<i.length;b++){if((_=i[b])!==v)s[a(_)].type===w&&T.push(_)}var k=p(c,v);if(k){var M=[];for(b=0;b<T.length;b++)k[_=T[b]]||M.push(_);T=M}var A,S,E=T.length;E&&(t.matches||m.matches)&&(A=n.coerce(t,e,{matches:{valType:\"enumerated\",values:T,dflt:-1!==T.indexOf(m.matches)?m.matches:void 0}},\"matches\"));var C=l&&!y?e.anchor:void 0;if(E&&!A&&(t.scaleanchor||C)&&(S=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:T}},\"scaleanchor\",C)),A){e._matchGroup=d(u,v,A,1);var L=s[a(A)],I=h(s,e)/h(s,L);y!==(\"x\"===A.charAt(0))&&(I=(y?\"x\":\"y\")+I),d(c,v,A,I)}else t.matches&&-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid an infinite loop');if(S){var P=x(\"scaleratio\");P||(P=e.scaleratio=1),d(c,v,S,P)}else t.scaleanchor&&-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because this axis declares a *matches* constraint.')}function h(t,e){var r=e.domain;return r||(r=t[a(e.overlaying)].domain),r[1]-r[0]}function p(t,e){for(var r=0;r<t.length;r++)if(t[r][e])return t[r];return null}function d(t,e,r,n){var i,a,o,s,l,c=p(t,e);null===c?((c={})[e]=1,l=t.length,t.push(c)):l=t.indexOf(c);var u=Object.keys(c);for(i=0;i<t.length;i++)if(o=t[i],i!==l&&o[r]){var f=o[r];for(a=0;a<u.length;a++)o[s=u[a]]=g(f,g(n,c[s]));return void t.splice(l,1)}if(1!==n)for(a=0;a<u.length;a++){var h=u[a];c[h]=g(n,c[h])}c[r]=1}function g(t,e){var r,n,i=\"\",a=\"\";\"string\"==typeof t&&(r=(i=t.match(/^[xy]*/)[0]).length,t=+t.substr(r)),\"string\"==typeof e&&(n=(a=e.match(/^[xy]*/)[0]).length,e=+e.substr(n));var o=t*e;return r||n?r&&n&&i.charAt(0)!==a.charAt(0)?r===n?o:(r>n?i.substr(n):a.substr(r))+o:i+a+t*e:o}function m(t,e){for(var r=e._size,n=r.h/r.w,i={},a=Object.keys(t),o=0;o<a.length;o++){var s=a[o],l=t[s];if(\"string\"==typeof l){var c=l.match(/^[xy]*/)[0],u=c.length;l=+l.substr(u);for(var f=\"y\"===c.charAt(0)?n:1/n,h=0;h<u;h++)l*=f}i[s]=l}return i}function v(t,e){var r=t._inputDomain,n=u[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleDefaults=function(t,e,r){var i,o,s,c,u,h,p,d,g=r.axIds,m=r.axHasImage,v=e._axisConstraintGroups=[],y=e._axisMatchGroups=[];for(i=0;i<g.length;i++)f(u=t[c=a(g[i])],h=e[c],{axIds:g,layoutOut:e,hasImage:m[c]});function x(t,r){for(i=0;i<t.length;i++)for(s in o=t[i])e[a(s)][r]=o}for(x(y,\"_matchGroup\"),i=0;i<v.length;i++)for(s in o=v[i])if((h=e[a(s)]).fixedrange){for(var b in o){var _=a(b);!1===(t[_]||{}).fixedrange&&n.warn(\"fixedrange was specified as false for axis \"+_+\" but was overridden because another axis in its constraint group has fixedrange true\"),e[_].fixedrange=!0}break}for(i=0;i<v.length;){for(s in o=v[i]){(h=e[a(s)])._matchGroup&&Object.keys(h._matchGroup).length===Object.keys(o).length&&(v.splice(i,1),i--);break}i++}x(v,\"_constraintGroup\");var w=[\"constrain\",\"range\",\"autorange\",\"rangemode\",\"rangebreaks\",\"categoryorder\",\"categoryarray\"],T=!1,k=!1;function M(){d=h[p],\"rangebreaks\"===p&&(k=h._hasDayOfWeekBreaks)}for(i=0;i<y.length;i++){o=y[i];for(var A=0;A<w.length;A++){var S;for(s in p=w[A],d=null,o)if(u=t[c=a(s)],h=e[c],p in h){if(!h.matches&&(S=h,p in u)){M();break}null===d&&p in u&&M()}if(\"range\"===p&&d&&(T=!0),\"autorange\"===p&&null===d&&T&&(d=!1),null===d&&p in S&&(d=S[p]),null!==d)for(s in o)(h=e[a(s)])[p]=\"range\"===p?d.slice():d,\"rangebreaks\"===p&&(h._hasDayOfWeekBreaks=k,l(h,e))}}},r.enforce=function(t){var e,r,n,o,l,u,f,h,p=t._fullLayout,d=p._axisConstraintGroups||[];for(e=0;e<d.length;e++){n=m(d[e],p);var g=Object.keys(n),y=1/0,x=0,b=1/0,_={},w={},T=!1;for(r=0;r<g.length;r++)w[o=g[r]]=l=p[a(o)],l._inputDomain?l.domain=l._inputDomain.slice():l._inputDomain=l.domain.slice(),l._inputRange||(l._inputRange=l.range.slice()),l.setScale(),_[o]=u=Math.abs(l._m)/n[o],y=Math.min(y,u),\"domain\"!==l.constrain&&l._constraintShrinkable||(b=Math.min(b,u)),delete l._constraintShrinkable,x=Math.max(x,u),\"domain\"===l.constrain&&(T=!0);if(!(y>c*x)||T)for(r=0;r<g.length;r++)if(u=_[o=g[r]],f=(l=w[o]).constrain,u!==b||\"domain\"===f)if(h=u/b,\"range\"===f)s(l,h);else{var k=l._inputDomain,M=(l.domain[1]-l.domain[0])/(k[1]-k[0]),A=(l.r2l(l.range[1])-l.r2l(l.range[0]))/(l.r2l(l._inputRange[1])-l.r2l(l._inputRange[0]));if((h/=M)*A<1){l.domain=l._input.domain=k.slice(),s(l,h);continue}if(A<1&&(l.range=l._input.range=l._inputRange.slice(),h*=A),l.autorange){var S=l.r2l(l.range[0]),E=l.r2l(l.range[1]),C=(S+E)/2,L=C,I=C,P=Math.abs(E-C),z=C-P*h*1.0001,O=C+P*h*1.0001,D=i.makePadFn(p,l,0),R=i.makePadFn(p,l,1);v(l,h);var F,B,N=Math.abs(l._m),j=i.concatExtremes(t,l),U=j.min,V=j.max;for(B=0;B<U.length;B++)(F=U[B].val-D(U[B])/N)>z&&F<L&&(L=F);for(B=0;B<V.length;B++)(F=V[B].val+R(V[B])/N)<O&&F>I&&(I=F);h/=(I-L)/(2*P),L=l.l2r(L),I=l.l2r(I),l.range=l._input.range=S<E?[L,I]:[I,L]}v(l,h)}}},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":745,\"../../constants/numerical\":753,\"../../lib\":778,\"./autorange\":827,\"./axis_ids\":831,\"./layout_attributes\":842,\"./scale_zoom\":846,\"./set_convert\":848}],836:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/color\"),f=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),p=t(\"./axes\"),d=t(\"../../lib/setcursor\"),g=t(\"../../components/dragelement\"),m=t(\"../../components/dragelement/helpers\"),v=m.selectingOrDrawing,y=m.freeMode,x=t(\"../../constants/alignment\").FROM_TL,b=t(\"../../lib/clear_gl_canvases\"),_=t(\"../../plot_api/subroutines\").redrawReglTraces,w=t(\"../plots\"),T=t(\"./axis_ids\").getFromId,k=t(\"./select\").prepSelect,M=t(\"./select\").clearSelect,A=t(\"./select\").selectOnClick,S=t(\"./scale_zoom\"),E=t(\"./constants\"),C=E.MINDRAG,L=E.MINZOOM,I=!0;function P(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,(function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)}));return i.call(d,n),i.node()}function z(t,e,r,i,a,o,s){var l=P(t,\"rect\",e,r);return n.select(l).call(f.setRect,i,a,o,s),l}function O(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function D(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange)if(o.rangebreaks){var s=\"y\"===o._id.charAt(0),l=s?1-e:e,c=s?1-r:r;n[o._name+\".range[0]\"]=o.l2r(o.p2l(l*o._length)),n[o._name+\".range[1]\"]=o.l2r(o.p2l(c*o._length))}else{var u=o._rl[0],f=o._rl[1]-u;n[o._name+\".range[0]\"]=o.l2r(u+f*e),n[o._name+\".range[1]\"]=o.l2r(u+f*r)}}if(i&&i.length){var h=(e+(1-r))/2;D(i,h,1-h,n,[])}}function R(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(!n.fixedrange)if(n.rangebreaks){var i=n._length,a=(n.p2l(0+e)-n.p2l(0)+(n.p2l(i+e)-n.p2l(i)))/2;n.range=[n.l2r(n._rl[0]-a),n.l2r(n._rl[1]-a)]}else n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)]}}function F(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function B(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",l(r,n)).attr(\"d\",i+\"Z\")}function N(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:u.background,stroke:u.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",l(e,r)).attr(\"d\",\"M0,0Z\")}function j(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),U(t,e,i,a)}function U(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function V(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function q(t){I&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),I=!1)}function H(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,L)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function G(t,e,r,n,i){for(var a,o,l,c,u=!1,f={},h={},p=(i||{}).xaHash,d=(i||{}).yaHash,g=0;g<e.length;g++){var m=e[g];for(a in r)if(m[a]){for(l in m)i&&(p[l]||d[l])||(\"x\"===l.charAt(0)?r:n)[l]||(f[l]=a);for(o in n)i&&(p[o]||d[o])||!m[o]||(u=!0)}for(o in n)if(m[o])for(c in m)i&&(p[c]||d[c])||(\"x\"===c.charAt(0)?r:n)[c]||(h[c]=o)}u&&(s.extendFlat(f,h),h={});var v={},y=[];for(l in f){var x=T(t,l);y.push(x),v[x._id]=x}var b={},_=[];for(c in h){var w=T(t,c);_.push(w),b[w._id]=w}return{xaHash:v,yaHash:b,xaxes:y,yaxes:_,xLinks:f,yLinks:h,isSubplotConstrained:u}}function Y(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel?t.onmousewheel=e:t.isAddedWheelEvent||(t.isAddedWheelEvent=!0,t.addEventListener(\"wheel\",e,{passive:!1}))}function W(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,l,u,d,m){var I,P,U,X,Z,J,K,Q,$,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ft,ht,pt,dt=t._fullLayout._zoomlayer,gt=d+m===\"nsew\",mt=1===(d+m).length;function vt(){if(I=e.xaxis,P=e.yaxis,$=I._length,tt=P._length,K=I._offset,Q=P._offset,(U={})[I._id]=I,(X={})[P._id]=P,d&&m)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;U[i._id]=i;var a=r[n].yaxis;X[a._id]=a}Z=W(U),J=W(X),nt=O(Z,m),it=O(J,d),at=!it&&!nt,rt=G(t,t._fullLayout._axisMatchGroups,U,X);var o=(et=G(t,t._fullLayout._axisConstraintGroups,U,X,rt)).isSubplotConstrained||rt.isSubplotConstrained;ot=m||o,st=d||o;var s=t._fullLayout;lt=s._has(\"scattergl\"),ct=s._has(\"splom\"),ut=s._has(\"svg\")}vt();var yt=function(t,e,r){if(!t)return\"pointer\";if(\"nsew\"===t)return r?\"\":\"pan\"===e?\"move\":\"crosshair\";return t.toLowerCase()+\"-resize\"}(it+nt,t._fullLayout.dragmode,gt),xt=z(e,d+m+\"drag\",yt,r,a,l,u);if(at&&!gt)return xt.onmousedown=null,xt.style.pointerEvents=\"none\",xt;var bt,_t,wt,Tt,kt,Mt,At,St,Et,Ct,Lt={element:xt,gd:t,plotinfo:e};function It(){Lt.plotinfo.selection=!1,M(t)}function Pt(t,r){var i=Lt.gd;if(i._fullLayout._activeShapeIndex>=0)i._fullLayout._deactivateShape(i);else{var a=i._fullLayout.clickmode;if(V(i),2!==t||mt||qt(),gt)a.indexOf(\"select\")>-1&&A(r,i,Z,J,e.id,Lt),a.indexOf(\"event\")>-1&&h.click(i,r,e.id);else if(1===t&&mt){var s=d?P:I,l=\"s\"===d||\"w\"===m?0:1,u=s._name+\".range[\"+l+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,l),p=\"left\",g=\"middle\";if(s.fixedrange)return;d?(g=\"n\"===d?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===m&&(p=\"right\"),i._context.showAxisRangeEntryBoxes&&n.select(xt).call(c.makeEditable,{gd:i,immediate:!0,background:i._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:g}).on(\"edit\",(function(t){var e=s.d2r(t);void 0!==e&&o.call(\"_guiRelayout\",i,u,e)}))}}}function zt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,ht*e+bt)),i=Math.max(0,Math.min(tt,pt*r+_t)),a=Math.abs(n-bt),o=Math.abs(i-_t);function s(){At=\"\",wt.r=wt.l,wt.t=wt.b,Et.attr(\"d\",\"M0,0Z\")}if(wt.l=Math.min(bt,n),wt.r=Math.max(bt,n),wt.t=Math.min(_t,i),wt.b=Math.max(_t,i),et.isSubplotConstrained)a>L||o>L?(At=\"xy\",a/$>o/tt?(o=a*tt/$,_t>i?wt.t=_t-o:wt.b=_t+o):(a=o*$/tt,bt>n?wt.l=bt-a:wt.r=bt+a),Et.attr(\"d\",H(wt))):s();else if(rt.isSubplotConstrained)if(a>L||o>L){At=\"xy\";var l=Math.min(wt.l/$,(tt-wt.b)/tt),c=Math.max(wt.r/$,(tt-wt.t)/tt);wt.l=l*$,wt.r=c*$,wt.b=(1-l)*tt,wt.t=(1-c)*tt,Et.attr(\"d\",H(wt))}else s();else!it||o<Math.min(Math.max(.6*a,C),L)?a<C||!nt?s():(wt.t=0,wt.b=tt,At=\"x\",Et.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-L-.5)+\"h-3v\"+(2*L+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-L-.5)+\"h3v\"+(2*L+1)+\"h-3Z\"}(wt,_t))):!nt||a<Math.min(.6*o,L)?(wt.l=0,wt.r=$,At=\"y\",Et.attr(\"d\",function(t,e){return\"M\"+(e-L-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*L+1)+\"v3ZM\"+(e-L-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*L+1)+\"v-3Z\"}(wt,bt))):(At=\"xy\",Et.attr(\"d\",H(wt)));wt.w=wt.r-wt.l,wt.h=wt.b-wt.t,At&&(Ct=!0),t._dragged=Ct,j(St,Et,wt,kt,Mt,Tt),Ot(),t.emit(\"plotly_relayouting\",ft),Mt=!0}function Ot(){ft={},\"xy\"!==At&&\"x\"!==At||(D(Z,wt.l/$,wt.r/$,ft,et.xaxes),Ut(\"x\",ft)),\"xy\"!==At&&\"y\"!==At||(D(J,(tt-wt.b)/tt,(tt-wt.t)/tt,ft,et.yaxes),Ut(\"y\",ft))}function Dt(){Ot(),V(t),Ht(),q(t)}Lt.prepFn=function(e,r,n){var a=Lt.dragmode,o=t._fullLayout.dragmode;o!==a&&(Lt.dragmode=o),vt(),ht=t._fullLayout._invScaleX,pt=t._fullLayout._invScaleY,at||(gt?e.shiftKey?\"pan\"===o?o=\"zoom\":v(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),y(o)?Lt.minDrag=1:Lt.minDrag=void 0,v(o)?(Lt.xaxes=Z,Lt.yaxes=J,k(e,r,n,Lt,o)):(Lt.clickFn=Pt,v(a)&&It(),at||(\"zoom\"===o?(Lt.moveFn=zt,Lt.doneFn=Dt,Lt.minDrag=1,function(e,r,n){var a=xt.getBoundingClientRect();bt=r-a.left,_t=n-a.top,t._fullLayout._calcInverseTransform(t);var o=s.apply3DTransform(t._fullLayout._invTransform)(bt,_t);bt=o[0],_t=o[1],wt={l:bt,r:bt,w:0,t:_t,b:_t,h:0},Tt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),Mt=!1,At=\"xy\",Ct=!1,St=B(dt,Tt,K,Q,kt=\"M0,0H\"+$+\"V\"+tt+\"H0V0\"),Et=N(dt,K,Q)}(0,r,n)):\"pan\"===o&&(Lt.moveFn=jt,Lt.doneFn=Ht))),t._fullLayout._redrag=function(){var e=t._dragdata;if(e&&e.element===xt){var r=t._fullLayout.dragmode;v(r)||(vt(),Gt([0,0,$,tt]),Lt.moveFn(e.dx,e.dy))}}},g.init(Lt);var Rt=[0,0,$,tt],Ft=null,Bt=E.REDRAWDELAY,Nt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function jt(e,r){if(e*=ht,r*=pt,!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===nt||\"ns\"===it){var n=nt?-e:0,i=it?-r:0;if(rt.isSubplotConstrained){if(nt&&it){var a=(e/$-r/tt)/2;n=-(e=a*$),i=-(r=-a*tt)}it?n=-i*$/tt:i=-n*tt/$}return nt&&(R(Z,e),Ut(\"x\")),it&&(R(J,r),Ut(\"y\")),Gt([n,i,$,tt]),Vt(),void t.emit(\"plotly_relayouting\",ft)}var o,s,l=\"w\"===nt==(\"n\"===it)?1:-1;if(nt&&it&&(et.isSubplotConstrained||rt.isSubplotConstrained)){var c=(e/$+l*r/tt)/2;e=c*$,r=l*c*tt}if(\"w\"===nt?e=p(Z,0,e):\"e\"===nt?e=p(Z,1,-e):nt||(e=0),\"n\"===it?r=p(J,1,r):\"s\"===it?r=p(J,0,-r):it||(r=0),o=\"w\"===nt?e:0,s=\"n\"===it?r:0,et.isSubplotConstrained&&!rt.isSubplotConstrained||rt.isSubplotConstrained&&nt&&it&&l>0){var u;if(rt.isSubplotConstrained||!nt&&1===it.length){for(u=0;u<Z.length;u++)Z[u].range=Z[u]._r.slice(),S(Z[u],1-r/tt);o=(e=r*$/tt)/2}if(rt.isSubplotConstrained||!it&&1===nt.length){for(u=0;u<J.length;u++)J[u].range=J[u]._r.slice(),S(J[u],1-e/$);s=(r=e*tt/$)/2}}rt.isSubplotConstrained&&it||Ut(\"x\"),rt.isSubplotConstrained&&nt||Ut(\"y\");var f=$-e,h=tt-r;!rt.isSubplotConstrained||nt&&it||(nt?(s=o?0:e*tt/$,h=f*tt/$):(o=s?0:r*$/tt,f=h*$/tt)),Gt([o,s,f,h]),Vt(),t.emit(\"plotly_relayouting\",ft)}function p(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/F(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Ut(t,e){for(var r=rt.isSubplotConstrained?{x:J,y:Z}[t]:rt[t+\"axes\"],n=rt.isSubplotConstrained?{x:Z,y:J}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=rt.xLinks[o]||rt.yLinks[o],l=n[0]||U[s]||X[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Vt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(ot&&(n(Z),n(et.xaxes),n(rt.xaxes)),st&&(n(J),n(et.yaxes),n(rt.yaxes)),ft={},e=0;e<r.length;e++){var i=r[e],a=T(t,i);p.drawOne(t,a,{skipTitle:!0}),ft[a._name+\".range[0]\"]=a.range[0],ft[a._name+\".range[1]\"]=a.range[1]}p.redrawComponents(t,r)}function qt(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];nt&&(r=r.concat(Z)),it&&(r=r.concat(J)),rt.xaxes&&(r=r.concat(rt.xaxes)),rt.yaxes&&(r=r.concat(rt.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((nt||et.isSubplotConstrained)&&(r=r.concat(et.xaxes)),it&&!et.isSubplotConstrained&&(r=r.concat(et.yaxes)),et.isSubplotConstrained&&(nt?it||(r=r.concat(J)):r=r.concat(Z)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}function Ht(){Gt([0,0,$,tt]),s.syncOrAsync([w.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ft)}],t)}function Gt(e){var r,n,i,a,l=t._fullLayout,c=l._plots,u=l._subplots.cartesian;if(ct&&o.subplotsRegistry.splom.drag(t),lt)for(r=0;r<u.length;r++)if(i=(n=c[u[r]]).xaxis,a=n.yaxis,n._scene){var h=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[h[0],p[0],h[1],p[1]]})}if((ct||lt)&&(b(t),_(t)),ut){var g=e[2]/I._length,v=e[3]/P._length;for(r=0;r<u.length;r++){i=(n=c[u[r]]).xaxis,a=n.yaxis;var y,x,w,T,k=(ot||rt.isSubplotConstrained)&&!i.fixedrange&&U[i._id],M=(st||rt.isSubplotConstrained)&&!a.fixedrange&&X[a._id];if(k?(y=g,w=m||rt.isSubplotConstrained?e[0]:Xt(i,y)):rt.xaHash[i._id]?(y=g,w=e[0]*i._length/I._length):rt.yaHash[i._id]?(y=v,w=\"ns\"===it?-e[1]*i._length/P._length:Xt(i,y,{n:\"top\",s:\"bottom\"}[it])):w=Wt(i,y=Yt(i,g,v)),M?(x=v,T=d||rt.isSubplotConstrained?e[1]:Xt(a,x)):rt.yaHash[a._id]?(x=v,T=e[1]*a._length/P._length):rt.xaHash[a._id]?(x=g,T=\"ew\"===nt?-e[0]*a._length/I._length:Xt(a,x,{e:\"right\",w:\"left\"}[nt])):T=Wt(a,x=Yt(a,g,v)),y||x){y||(y=1),x||(x=1);var A=i._offset-w/y,S=a._offset-T/x;n.clipRect.call(f.setTranslate,w,T).call(f.setScale,y,x),n.plot.call(f.setTranslate,A,S).call(f.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(f.setPointGroupScale(n.zoomScalePts,y,x),f.setTextPointsScale(n.zoomScaleTxt,y,x)),f.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Yt(t,e,r){return t.fixedrange?0:ot&&et.xaHash[t._id]?e:st&&(et.isSubplotConstrained?et.xaHash:et.yaHash)[t._id]?r:0}function Wt(t,e){return e?(t.range=t._r.slice(),S(t,e),Xt(t,e)):0}function Xt(t,e,r){return t._length*(1-e)*x[r||t.constraintoward||\"middle\"]}return d.length*m.length!=1&&Y(xt,(function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(It(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();vt(),clearTimeout(Ft);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Nt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(ot){for(m||(o=.5),n=0;n<Z.length;n++)c(Z[n],o,i);Ut(\"x\"),Rt[2]*=i,Rt[0]+=Rt[2]*o*(1/i-1)}if(st){for(d||(l=.5),n=0;n<J.length;n++)c(J[n],l,i);Ut(\"y\"),Rt[3]*=i,Rt[1]+=Rt[3]*(1-l)*(1/i-1)}Gt(Rt),Vt(),t.emit(\"plotly_relayouting\",ft),Ft=setTimeout((function(){Rt=[0,0,$,tt],Ht()}),Bt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map((function(e){return t.l2r(i+(e-i)*r)}))}}})),xt},makeDragger:P,makeRectDragger:z,makeZoombox:B,makeCorners:N,updateZoombox:j,xyCorners:H,transitionZoombox:U,removeZoombox:V,showDoubleClickNotifier:q,attachWheelEventHandler:Y}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plot_api/subroutines\":818,\"../../registry\":911,\"../plots\":891,\"./axes\":828,\"./axis_ids\":831,\"./constants\":834,\"./scale_zoom\":846,\"./select\":847,d3:169,\"has-passive-events\":441,tinycolor2:576}],837:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort((function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1})).forEach((function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&t._fullLayout._plots[r]&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var f=o._mainLinePosition;\"top\"===o.side&&(f-=l),s(t,n,o._offset+.1*o._length,f,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,f,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,f,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var h=c._mainLinePosition;\"right\"!==c.side&&(h-=l),s(t,n,h,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,h,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,h,c._offset,l,.1*c._length,\"n\",\"\")}}}));var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":662,\"../../components/fx\":683,\"../../lib/setcursor\":799,\"./constants\":834,\"./dragbox\":836,d3:169}],838:[function(t,e,r){\"use strict\";e.exports={clearOutlineControllers:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".outline-controllers\").remove()},clearSelect:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".select-outline\").remove(),t._fullLayout._drawing=!1}}},{}],839:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").strTranslate;function i(t,e){switch(t.type){case\"log\":return t.p2d(e);case\"date\":return t.p2r(e,0,t.calendar);default:return t.p2r(e)}}e.exports={p2r:i,r2p:function(t,e){switch(t.type){case\"log\":return t.d2p(e);case\"date\":return t.r2p(e,0,t.calendar);default:return t.r2p(e)}},axValue:function(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return i(t,r[e])}},getTransform:function(t){return n(t.xaxis._offset,t.yaxis._offset)}}},{\"../../lib\":778}],840:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./axis_ids\");e.exports=function(t){return function(e,r){var o=e[t];if(Array.isArray(o))for(var s=n.subplotsRegistry.cartesian,l=s.idRegex,c=r._subplots,u=c.xaxis,f=c.yaxis,h=c.cartesian,p=r._has(\"cartesian\")||r._has(\"gl2d\"),d=0;d<o.length;d++){var g=o[d];if(i.isPlainObject(g)){var m=a.cleanId(g.xref,\"x\",!1),v=a.cleanId(g.yref,\"y\",!1),y=l.x.test(m),x=l.y.test(v);if(y||x){p||i.pushUnique(r._basePlotModules,s);var b=!1;y&&-1===u.indexOf(m)&&(u.push(m),b=!0),x&&-1===f.indexOf(v)&&(f.push(v),b=!0),b&&y&&x&&h.push(m+v)}}}}}},{\"../../lib\":778,\"../../registry\":911,\"./axis_ids\":831}],841:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),f=t(\"../../constants/xmlns_namespaces\"),h=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,(function(t){t.datum(r)}))}function d(t,e,r,a,o){for(var c,f,h,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,m=[],v=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;h=(f=l(r,w))[0],r=f[1],h.length&&m.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:h}),b.zoomScale&&v.push(\".\"+_)}}m.sort((function(t,e){return t.i-e.i}));var T=e.plot.selectAll(\"g.mlayer\").data(m,(function(t){return t.className}));if(T.enter().append(\"g\").attr(\"class\",(function(t){return t.className})).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),T.exit().remove(),T.order(),T.each((function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)})),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),h=l(r,c)[0],c.plot(t,e,h)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),v.length)){var k=e.plot.selectAll(v.join(\",\")).selectAll(\".trace\");e.zoomScalePts=k.selectAll(\"path.point\"),e.zoomScaleTxt=k.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,f=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,h(s.overlinesBelow,\"path\",f),h(s.overlinesBelow,\"path\",d),h(s.overaxesBelow,\"g\",f),h(s.overaxesBelow,\"g\",d),e.plot=h(s.overplot,\"g\",n),h(s.overlinesAbove,\"path\",f),h(s.overlinesAbove,\"path\",d),h(s.overaxesAbove,\"g\",f),h(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+f),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+f),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.xaxislayer=h(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=h(r,\"g\",\"yaxislayer-above\");else{var g=h(r,\"g\",\"layer-subplot\");e.shapelayer=h(g,\"g\",\"shapelayer\"),e.imagelayer=h(g,\"g\",\"imagelayer\"),e.gridlayer=h(r,\"g\",\"gridlayer\"),e.zerolinelayer=h(r,\"g\",\"zerolinelayer\"),h(r,\"path\",\"xlines-below\"),h(r,\"path\",\"ylines-below\"),e.overlinesBelow=h(r,\"g\",\"overlines-below\"),h(r,\"g\",\"xaxislayer-below\"),h(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=h(r,\"g\",\"overaxes-below\"),e.plot=h(r,\"g\",\"plot\"),e.overplot=h(r,\"g\",\"overplot\"),e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.overlinesAbove=h(r,\"g\",\"overlines-above\"),h(r,\"g\",\"xaxislayer-above\"),h(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=h(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map((function(t){return t[0]})).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function m(t,e){if(t){var r={};for(var i in t.each((function(t){var i=t[0];n.select(this).remove(),v(i,e),r[i]=!0})),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function v(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,f=o.cartesian,h=f.concat(o.gl2d||[]),p={},d={};for(r=0;r<h.length;r++){var g=h[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),f.push(n+i),h.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),f.push(n+i),h.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!h.length){for(var m in n=\"\",i=\"\",t){if(u.attrRegex.test(m))\"x\"===m.charAt(0)?(!n||+m.substr(5)<+n.substr(5))&&(n=m):(!i||+m.substr(5)<+i.substr(5))&&(i=m)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),f.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],f=[],h=0;h<s.length;h++){var p=s[h],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===f.indexOf(l)&&f.push(l),f.push(p)),l=p)}d(t,u,f,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var f=n._has&&n._has(\"gl\"),h=e._has&&e._has(\"gl\");if(f&&!h)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)m(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups,delete n._axisMatchGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),v(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],f=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var h=a._mainAxis,p=o._mainAxis,d=h._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,f.push(n)):(i.mainplot=void 0,i.mainplotinfo=void 0,u.push(n))}for(e=0;e<f.length;e++)n=f[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var m=u.concat(f),v=new Array(c);for(e=0;e<c;e++){n=m[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);v[e]=y}return v}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",(function(t){return\"subplot \"+t[0]})),i.order(),i.exit().call(m,e),i.each((function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=h(e._draggers,\"g\",i)}))},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:f.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}))},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":665,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../registry\":911,\"../get_data\":865,\"../plots\":891,\"./attributes\":826,\"./axis_ids\":831,\"./constants\":834,\"./graph_interact\":837,\"./layout_attributes\":842,\"./layout_defaults\":843,\"./transition_axes\":852,d3:169}],842:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"../../constants/numerical\").ONEDAY),c=t(\"./constants\"),u=c.HOUR_PATTERN,f=c.WEEKDAY_PATTERN;e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),standoff:{valType:\"number\",min:0,editType:\"ticks\"},editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"calc\"},rangebreaks:s(\"rangebreak\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},bounds:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},pattern:{valType:\"enumerated\",values:[f,u,\"\"],editType:\"calc\"},values:{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"any\",editType:\"calc\"}},dvalue:{valType:\"number\",editType:\"calc\",min:0,dflt:l},editType:\"calc\"}),tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},ticklabelmode:{valType:\"enumerated\",values:[\"instant\",\"period\"],dflt:\"instant\",editType:\"ticks\"},ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside left\",\"inside left\",\"outside right\",\"inside right\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\",editType:\"calc\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\",\"hovered data\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":642,\"../../components/drawing/attributes\":664,\"../../constants/docs\":748,\"../../constants/numerical\":753,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../font_attributes\":856,\"./constants\":834}],843:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../components/fx/helpers\").isUnifiedHover,o=t(\"../../components/fx/hovermode_defaults\"),s=t(\"../../plot_api/plot_template\"),l=t(\"../layout_attributes\"),c=t(\"./layout_attributes\"),u=t(\"./type_defaults\"),f=t(\"./axis_defaults\"),h=t(\"./constraints\"),p=t(\"./position_defaults\"),d=t(\"./axis_ids\"),g=d.id2name,m=d.name2id,v=t(\"./constants\").AX_ID_PATTERN,y=t(\"../../registry\"),x=y.traceIs,b=y.getComponentMethod;function _(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var y,w,T=e.autotypenumbers,k={},M={},A={},S={},E={},C={},L={},I={},P={},z={};for(y=0;y<r.length;y++){var O=r[y];if(x(O,\"cartesian\")||x(O,\"gl2d\")){var D,R;if(O.xaxis)D=g(O.xaxis),_(k,D,O);else if(O.xaxes)for(w=0;w<O.xaxes.length;w++)_(k,g(O.xaxes[w]),O);if(O.yaxis)R=g(O.yaxis),_(k,R,O);else if(O.yaxes)for(w=0;w<O.yaxes.length;w++)_(k,g(O.yaxes[w]),O);if(\"funnel\"===O.type?\"h\"===O.orientation?(D&&(M[D]=!0),R&&(L[R]=!0)):R&&(A[R]=!0):\"image\"===O.type?(R&&(I[R]=!0),D&&(I[D]=!0)):(R&&(E[R]=!0,C[R]=!0),x(O,\"carpet\")&&(\"carpet\"!==O.type||O._cheater)||D&&(S[D]=!0)),\"carpet\"===O.type&&O._cheater&&D&&(M[D]=!0),x(O,\"2dMap\")&&(P[D]=!0,P[R]=!0),x(O,\"oriented\"))z[\"h\"===O.orientation?R:D]=!0}}var F=e._subplots,B=F.xaxis,N=F.yaxis,j=n.simpleMap(B,g),U=n.simpleMap(N,g),V=j.concat(U),q=i.background;B.length&&N.length&&(q=n.coerce(t,e,l,\"plot_bgcolor\"));var H,G,Y,W,X,Z=i.combine(q,e.paper_bgcolor);function J(){var t=k[H]||[];X._traceIndices=t.map((function(t){return t._expandedIndex})),X._annIndices=[],X._shapeIndices=[],X._imgIndices=[],X._subplotsWith=[],X._counterAxes=[],X._name=X._attr=H,X._id=G}function K(t,e){return n.coerce(W,X,c,t,e)}function Q(t,e){return n.coerce2(W,X,c,t,e)}function $(t){return\"x\"===t?N:B}function tt(e,r){for(var n=\"x\"===e?j:U,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(m(o))}return i}var et={x:$(\"x\"),y:$(\"y\")},rt=et.x.concat(et.y),nt={},it=[];function at(){var t=W.matches;v.test(t)&&-1===rt.indexOf(t)&&(nt[t]=W.type,it=Object.keys(nt))}var ot=o(t,e,r),st=a(ot);for(y=0;y<V.length;y++){H=V[y],G=m(H),Y=H.charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],X=s.newContainer(e,H,Y+\"axis\"),J();var lt=\"x\"===Y&&!S[H]&&M[H]||\"y\"===Y&&!E[H]&&A[H],ct=\"y\"===Y&&(!C[H]&&L[H]||I[H]),ut={letter:Y,font:e.font,outerTicks:P[H],showGrid:!z[H],data:k[H]||[],bgColor:Z,calendar:e.calendar,automargin:!0,visibleDflt:lt,reverseDflt:ct,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Y]||{})[G]};K(\"uirevision\",e.uirevision),u(W,X,K,ut),f(W,X,K,ut,e);var ft=st&&Y===ot.charAt(0),ht=Q(\"spikecolor\",st?X.color:void 0),pt=Q(\"spikethickness\",st?1.5:void 0),dt=Q(\"spikedash\",st?\"dot\":void 0),gt=Q(\"spikemode\",st?\"across\":void 0),mt=Q(\"spikesnap\",st?\"hovered data\":void 0);K(\"showspikes\",!!(ft||ht||pt||dt||gt||mt))||(delete X.spikecolor,delete X.spikethickness,delete X.spikedash,delete X.spikemode,delete X.spikesnap),p(W,X,K,{letter:Y,counterAxes:et[Y],overlayableAxes:tt(Y,H),grid:e.grid}),K(\"title.standoff\"),at(),X._input=W}for(y=0;y<it.length;){G=it[y++],Y=(H=g(G)).charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],X=s.newContainer(e,H,Y+\"axis\"),J();var vt={letter:Y,font:e.font,outerTicks:P[H],showGrid:!z[H],data:[],bgColor:Z,calendar:e.calendar,automargin:!0,visibleDflt:!1,reverseDflt:!1,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Y]||{})[G]};K(\"uirevision\",e.uirevision),X.type=nt[G]||\"linear\",f(W,X,K,vt,e),p(W,X,K,{letter:Y,counterAxes:et[Y],overlayableAxes:tt(Y,H),grid:e.grid}),K(\"fixedrange\"),at(),X._input=W}var yt=b(\"rangeslider\",\"handleDefaults\"),xt=b(\"rangeselector\",\"handleDefaults\");for(y=0;y<j.length;y++)H=j[y],W=t[H],X=e[H],yt(t,e,H),\"date\"===X.type&&xt(W,X,e,U,X.calendar),K(\"fixedrange\");for(y=0;y<U.length;y++){H=U[y],W=t[H],X=e[H];var bt=e[g(X.anchor)];K(\"fixedrange\",b(\"rangeslider\",\"isVisible\")(bt))}h.handleDefaults(t,e,{axIds:rt.concat(it).sort(d.idSort),axHasImage:I})}},{\"../../components/color\":643,\"../../components/fx/helpers\":679,\"../../components/fx/hovermode_defaults\":682,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911,\"../layout_attributes\":882,\"./axis_defaults\":830,\"./axis_ids\":831,\"./constants\":834,\"./constraints\":835,\"./layout_attributes\":842,\"./position_defaults\":845,\"./type_defaults\":853}],844:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var f=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),h=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!f||!!h)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":642,\"../../lib\":778,tinycolor2:576}],845:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],f=a.overlayableAxes||[],h=a.letter,p=a.grid;p&&(s=p._domains[h][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[h+\"side\"].split(\" \")[0],c=p.domain[h][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===h?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===h?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(f.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(f),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":778,\"fast-isnumeric\":241}],846:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)],t.setScale()}},{\"../../constants/alignment\":745}],847:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\").dashStyle,o=t(\"../../components/color\"),s=t(\"../../components/fx\"),l=t(\"../../components/fx/helpers\").makeEventData,c=t(\"../../components/dragelement/helpers\"),u=c.freeMode,f=c.rectMode,h=c.drawMode,p=c.openMode,d=c.selectMode,g=t(\"../../components/shapes/draw_newshape/display_outlines\"),m=t(\"../../components/shapes/draw_newshape/helpers\").handleEllipse,v=t(\"../../components/shapes/draw_newshape/newshapes\"),y=t(\"../../lib\"),x=t(\"../../lib/polygon\"),b=t(\"../../lib/throttle\"),_=t(\"./axis_ids\").getFromId,w=t(\"../../lib/clear_gl_canvases\"),T=t(\"../../plot_api/subroutines\").redrawReglTraces,k=t(\"./constants\"),M=k.MINSELECT,A=x.filter,S=x.tester,E=t(\"./handle_outline\").clearSelect,C=t(\"./helpers\"),L=C.p2r,I=C.axValue,P=C.getTransform;function z(t,e,r,n,i,a,o){var s,l,c,u,f,h,d,m,v,y=e._hoverdata,x=e._fullLayout.clickmode.indexOf(\"event\")>-1,b=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(y)){F(t,e,a);var _=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(y,s=N(e,r,n,i));if(_.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,_):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(h=j(_))){for(o&&o.remove(),v=0;v<s.length;v++)(l=s[v])._module.selectPoints(l,!1);U(e,s),B(a),x&&e.emit(\"plotly_deselect\",null)}else{for(d=t.shiftKey&&(void 0!==h?h:j(_)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(_.pointNumber,_.searchInfo,d),u=R(a.selectionDefs.concat([c])),v=0;v<s.length;v++)if(f=V(s[v]._module.selectPoints(s[v],u),s[v]),b.length)for(var w=0;w<f.length;w++)b.push(f[w]);else b=f;if(U(e,s,m={points:b}),c&&a&&a.selectionDefs.push(c),o){var T=a.mergedPolygons,k=p(a.dragmode);g(q(T,k),o,a)}x&&e.emit(\"plotly_selected\",m)}}}function O(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function D(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function R(t){for(var e=[],r=O(t[0])?0:t[0][0][0],n=r,i=O(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(O(t[o]))e.push(D(t[o]));else{var s=x.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function F(t,e,r){e._fullLayout._drawing=!1;var n=e._fullLayout,i=r.plotinfo,a=r.dragmode,o=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,s=(t.shiftKey||t.altKey)&&!(h(a)&&p(a));o&&s&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):s&&i.selection||B(r),o||(E(e),n._lastSelectedSubplot=i.id)}function B(t){var e=t.dragmode,r=t.plotinfo,n=t.gd;if(n._fullLayout._activeShapeIndex>=0&&n._fullLayout._deactivateShape(n),h(e)){var a=n._fullLayout._zoomlayer.selectAll(\".select-outline-\"+r.id);if(a&&n._fullLayout._drawing){var o=v(a,t);o&&i.call(\"_guiRelayout\",n,{shapes:o}),n._fullLayout._drawing=!1}}r.selection={},r.selection.selectionDefs=t.selectionDefs=[],r.selection.mergedPolygons=t.mergedPolygons=[]}function N(t,e,r,n){var i,a,o,s=[],l=e.map((function(t){return t._id})),c=r.map((function(t){return t._id}));for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=h(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=h(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(h(a._module,i,_(t,a.xaxis),_(t,a.yaxis)))}else s.push(h(a._module,i,e[0],r[0]));return s;function h(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function j(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function U(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var f=u[n],h=f.data,p=f.fullData;f.pointIndices?([].push.apply(h.selectedpoints,f.pointIndices),s._fullInput!==s&&[].push.apply(p.selectedpoints,f.pointIndices)):(h.selectedpoints.push(f.pointIndex),s._fullInput!==s&&p.selectedpoints.push(f.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var d=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(d=!0);var g=a._module,m=g.styleOnSelect||g.style;m&&(m(t,o,o[0].node3),o[0].nodeRangePlot3&&m(t,o,o[0].nodeRangePlot3))}d&&(w(t),T(t))}function V(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=l(t[i],n,r);return t}function q(t,e){for(var r=[],n=0;n<t.length;n++){r[n]=[];for(var i=0;i<t[n].length;i++){r[n][i]=[],r[n][i][0]=i?\"L\":\"M\";for(var a=0;a<t[n][i].length;a++)r[n][i].push(t[n][i][a])}e||r[n].push([\"Z\",r[n][0][1],r[n][0][2]])}return r}e.exports={prepSelect:function(t,e,r,i,l){var c=u(l),v=f(l),x=p(l),_=h(l),w=d(l),T=\"drawcircle\"===l,E=\"drawline\"===l||T,C=i.gd,O=C._fullLayout,D=O._zoomlayer,j=i.element.getBoundingClientRect(),H=i.plotinfo,G=P(H),Y=e-j.left,W=r-j.top;O._calcInverseTransform(C);var X=y.apply3DTransform(O._invTransform)(Y,W);Y=X[0],W=X[1];var Z,J,K,Q,$,tt,et,rt=O._invScaleX,nt=O._invScaleY,it=Y,at=W,ot=\"M\"+Y+\",\"+W,st=i.xaxes[0]._length,lt=i.yaxes[0]._length,ct=i.xaxes.concat(i.yaxes),ut=t.altKey&&!(h(l)&&x);F(t,C,i),c&&(Z=A([[Y,W]],k.BENDPX));var ft=D.selectAll(\"path.select-outline-\"+H.id).data(_?[0]:[1,2]),ht=O.newshape;ft.enter().append(\"path\").attr(\"class\",(function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+H.id})).style(_?{opacity:ht.opacity/2,fill:x?void 0:ht.fillcolor,stroke:ht.line.color,\"stroke-dasharray\":a(ht.line.dash,ht.line.width),\"stroke-width\":ht.line.width+\"px\"}:{}).attr(\"fill-rule\",ht.fillrule).classed(\"cursor-move\",!!_).attr(\"transform\",G).attr(\"d\",ot+\"Z\");var pt,dt=D.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:o.background,stroke:o.defaultLine,\"stroke-width\":1}).attr(\"transform\",G).attr(\"d\",\"M0,0Z\"),gt=O._uid+k.SELECTID,mt=[],vt=N(C,i.xaxes,i.yaxes,i.subplot);function yt(t,e){return t-e}pt=H.fillRangeItems?H.fillRangeItems:v?function(t,e){var r=t.range={};for($=0;$<ct.length;$++){var n=ct[$],i=n._id.charAt(0);r[n._id]=[L(n,e[i+\"min\"]),L(n,e[i+\"max\"])].sort(yt)}}:function(t,e,r){var n=t.lassoPoints={};for($=0;$<ct.length;$++){var i=ct[$];n[i._id]=r.filtered.map(I(i))}},i.moveFn=function(t,e){it=Math.max(0,Math.min(st,rt*t+Y)),at=Math.max(0,Math.min(lt,nt*e+W));var r=Math.abs(it-Y),a=Math.abs(at-W);if(v){var o,s,l;if(w){var u=O.selectdirection;switch(o=\"any\"===u?a<Math.min(.6*r,M)?\"h\":r<Math.min(.6*a,M)?\"v\":\"d\":u){case\"h\":s=T?lt/2:0,l=lt;break;case\"v\":s=T?st/2:0,l=st}}if(_)switch(O.newshape.drawdirection){case\"vertical\":o=\"h\",s=T?lt/2:0,l=lt;break;case\"horizontal\":o=\"v\",s=T?st/2:0,l=st;break;case\"ortho\":r<a?(o=\"h\",s=W,l=at):(o=\"v\",s=Y,l=it);break;default:o=\"d\"}\"h\"===o?((Q=E?m(T,[it,s],[it,l]):[[Y,s],[Y,l],[it,l],[it,s]]).xmin=E?it:Math.min(Y,it),Q.xmax=E?it:Math.max(Y,it),Q.ymin=Math.min(s,l),Q.ymax=Math.max(s,l),dt.attr(\"d\",\"M\"+Q.xmin+\",\"+(W-M)+\"h-4v\"+2*M+\"h4ZM\"+(Q.xmax-1)+\",\"+(W-M)+\"h4v\"+2*M+\"h-4Z\")):\"v\"===o?((Q=E?m(T,[s,at],[l,at]):[[s,W],[s,at],[l,at],[l,W]]).xmin=Math.min(s,l),Q.xmax=Math.max(s,l),Q.ymin=E?at:Math.min(W,at),Q.ymax=E?at:Math.max(W,at),dt.attr(\"d\",\"M\"+(Y-M)+\",\"+Q.ymin+\"v-4h\"+2*M+\"v4ZM\"+(Y-M)+\",\"+(Q.ymax-1)+\"v4h\"+2*M+\"v-4Z\")):\"d\"===o&&((Q=E?m(T,[Y,W],[it,at]):[[Y,W],[Y,at],[it,at],[it,W]]).xmin=Math.min(Y,it),Q.xmax=Math.max(Y,it),Q.ymin=Math.min(W,at),Q.ymax=Math.max(W,at),dt.attr(\"d\",\"M0,0Z\"))}else c&&(Z.addPt([it,at]),Q=Z.filtered);i.selectionDefs&&i.selectionDefs.length?(K=function(t,e,r){if(r)return n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions;return n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,Q,ut),Q.subtract=ut,J=R(i.selectionDefs.concat([Q]))):(K=[Q],J=S(Q)),g(q(K,x),ft,i),w&&b.throttle(gt,k.SELECTDELAY,(function(){var t;mt=[];var e,r=[];for($=0;$<vt.length;$++)if(e=(tt=vt[$])._module.selectPoints(tt,J),r.push(e),t=V(e,tt),mt.length)for(var n=0;n<t.length;n++)mt.push(t[n]);else mt=t;U(C,vt,et={points:mt}),pt(et,Q,Z),i.gd.emit(\"plotly_selecting\",et)}))},i.clickFn=function(t,e){if(dt.remove(),C._fullLayout._activeShapeIndex>=0)C._fullLayout._deactivateShape(C);else if(!_){var r=O.clickmode;b.done(gt).then((function(){if(b.clear(gt),2===t){for(ft.remove(),$=0;$<vt.length;$++)(tt=vt[$])._module.selectPoints(tt,!1);U(C,vt),B(i),C.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&z(e,C,i.xaxes,i.yaxes,i.subplot,i,ft),\"event\"===r&&C.emit(\"plotly_selected\",void 0);s.click(C,e)})).catch(y.error)}},i.doneFn=function(){dt.remove(),b.done(gt).then((function(){b.clear(gt),i.gd.emit(\"plotly_selected\",et),Q&&i.selectionDefs&&(Q.subtract=ut,i.selectionDefs.push(Q),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,K)),i.doneFnCompleted&&i.doneFnCompleted(mt)})).catch(y.error),_&&B(i)}},clearSelect:E,clearSelectionsCache:B,selectOnClick:z}},{\"../../components/color\":643,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/fx/helpers\":679,\"../../components/shapes/draw_newshape/display_outlines\":728,\"../../components/shapes/draw_newshape/helpers\":729,\"../../components/shapes/draw_newshape/newshapes\":730,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/polygon\":790,\"../../lib/throttle\":804,\"../../plot_api/subroutines\":818,\"../../registry\":911,\"./axis_ids\":831,\"./constants\":834,\"./handle_outline\":838,\"./helpers\":839,polybooljs:517}],848:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").utcFormat,a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=o.cleanNumber,l=o.ms2DateTime,c=o.dateTime2ms,u=o.ensureNumber,f=o.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),p=h.FP_SAFE,d=h.BADNUM,g=h.LOG_CLIP,m=h.ONEWEEK,v=h.ONEDAY,y=h.ONEHOUR,x=h.ONEMIN,b=h.ONESEC,_=t(\"./axis_ids\"),w=t(\"./constants\"),T=w.HOUR_PATTERN,k=w.WEEKDAY_PATTERN;function M(t){return Math.pow(10,t)}function A(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function S(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*g*Math.abs(n-i))}return d}function E(e,r,n,i){if((i||{}).msUTC&&a(e))return+e;var s=c(e,n||t.calendar);if(s===d){if(!a(e))return d;e=+e;var l=Math.floor(10*o.mod(e+.05,1)),u=Math.round(e-l/10);s=c(new Date(u))+l/10}return s}function C(e,r,n){return l(e,r,n||t.calendar)}function L(e){return t._categories[Math.round(e)]}function I(e){if(A(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return d}function P(e){if(t._categoriesMap)return t._categoriesMap[e]}function z(t){var e=P(t);return void 0!==e?e:a(t)?+t:void 0}function O(t){return a(t)?+t:P(t)}function D(t,e,r){return n.round(r+e*t,2)}function R(t,e,r){return(t-r)/e}var F=function(e){return a(e)?D(e,t._m,t._b):d},B=function(e){return R(e,t._m,t._b)};if(t.rangebreaks){var N=\"y\"===h;F=function(e){if(!a(e))return d;var r=t._rangebreaks.length;if(!r)return D(e,t._m,t._b);var n=N;t.range[0]>t.range[1]&&(n=!n);for(var i=n?-1:1,o=i*e,s=0,l=0;l<r;l++){var c=i*t._rangebreaks[l].min,u=i*t._rangebreaks[l].max;if(o<c)break;if(!(o>u)){s=o<(c+u)/2?l:l+1;break}s=l+1}var f=t._B[s]||0;return isFinite(f)?D(e,t._m2,f):0},B=function(e){var r=t._rangebreaks.length;if(!r)return R(e,t._m,t._b);for(var n=0,i=0;i<r&&!(e<t._rangebreaks[i].pmin);i++)e>t._rangebreaks[i].pmax&&(n=i+1);return R(e,t._m2,t._B[n])}}t.c2l=\"log\"===t.type?S:u,t.l2c=\"log\"===t.type?M:u,t.l2p=F,t.p2l=B,t.c2p=\"log\"===t.type?function(t,e){return F(S(t,e))}:F,t.p2c=\"log\"===t.type?function(t){return M(B(t))}:B,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=s,t.c2d=t.c2r=t.l2d=t.l2r=u,t.d2p=t.r2p=function(e){return t.l2p(s(e))},t.p2d=t.p2r=B,t.cleanPos=u):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return S(s(t),e)},t.r2d=t.r2c=function(t){return M(s(t))},t.d2c=t.r2l=s,t.c2d=t.l2r=u,t.c2r=S,t.l2d=M,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return M(B(t))},t.r2p=function(e){return t.l2p(s(e))},t.p2r=B,t.cleanPos=u):\"date\"===t.type?(t.d2r=t.r2d=o.identity,t.d2c=t.r2c=t.d2l=t.r2l=E,t.c2d=t.c2r=t.l2d=t.l2r=C,t.d2p=t.r2p=function(e,r,n){return t.l2p(E(e,0,n))},t.p2d=t.p2r=function(t,e,r){return C(B(t),e,r)},t.cleanPos=function(e){return o.cleanDate(e,d,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=I,t.r2d=t.c2d=t.l2d=L,t.d2r=t.d2l_noadd=z,t.r2c=function(e){var r=O(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=u,t.r2l=O,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return L(B(t))},t.r2p=t.d2p,t.p2r=B,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:u(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=L,t.d2r=t.d2l_noadd=z,t.r2c=function(e){var r=z(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=P,t.l2r=t.c2r=u,t.r2l=z,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return L(B(t))},t.r2p=t.d2p,t.p2r=B,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:u(t)},t.setupMultiCategory=function(n){var i,a,s=t._traceIndices,l=t._matchGroup;if(l&&0===t._categories.length)for(var c in l)if(c!==r){var u=e[_.id2name(c)];s=s.concat(u._traceIndices)}var p=[[0,{}],[0,{}]],d=[];for(i=0;i<s.length;i++){var g=n[s[i]];if(h in g){var m=g[h],v=g._length||o.minRowLength(m);if(f(m[0])&&f(m[1]))for(a=0;a<v;a++){var y=m[0][a],x=m[1][a];A(y)&&A(x)&&(d.push([y,x]),y in p[0][1]||(p[0][1][y]=p[0][0]++),x in p[1][1]||(p[1][1][x]=p[1][0]++))}}}for(d.sort((function(t,e){var r=p[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=p[1][1];return i[t[1]]-i[e[1]]})),i=0;i<d.length;i++)I(d[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,i,s=o.nestedProperty(t,e).get();if(i=(i=\"date\"===t.type?o.dfltRange(t.calendar):\"y\"===h?w.DFLTRANGEY:r.dfltRange||w.DFLTRANGEX).slice(),\"tozero\"!==t.rangemode&&\"nonnegative\"!==t.rangemode||(i[0]=0),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=o.cleanDate(s[0],d,t.calendar),s[1]=o.cleanDate(s[1],d,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!o.isDateTime(s[n],t.calendar)){t[e]=i;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=o.constrain(t.r2l(s[0]),o.MIN_MS+1e3,o.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!a(s[n])){if(!a(s[1-n])){t[e]=i;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-p?s[n]=-p:s[n]>p&&(s[n]=p),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else o.nestedProperty(t,e).set(i)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=_.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s,l,c=t.r2l(t[a][0],o),u=t.r2l(t[a][1],o),f=\"y\"===h;if((f?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(c-u),t._b=-t._m*u):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(u-c),t._b=-t._m*c),t._rangebreaks=[],t._lBreaks=0,t._m2=0,t._B=[],t.rangebreaks)&&(t._rangebreaks=t.locateBreaks(Math.min(c,u),Math.max(c,u)),t._rangebreaks.length)){for(s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._lBreaks+=Math.abs(l.max-l.min);var p=f;c>u&&(p=!p),p&&t._rangebreaks.reverse();var d=p?-1:1;for(t._m2=d*t._length/(Math.abs(u-c)-t._lBreaks),t._B.push(-t._m2*(f?u:c)),s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._B.push(t._B[t._B.length-1]-d*t._m2*(l.max-l.min));for(s=0;s<t._rangebreaks.length;s++)(l=t._rangebreaks[s]).pmin=F(l.min),l.pmax=F(l.max)}if(!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.maskBreaks=function(e){for(var r,n,i,a,l,c=t.rangebreaks||[],u=0;u<c.length;u++){var f=c[u];if(f.enabled)if(f.bounds){var h=f.pattern;switch(n=(r=o.simpleMap(f.bounds,h?s:t.d2c))[0],i=r[1],h){case k:a=(l=new Date(e)).getUTCDay(),n>i&&(i+=7,a<n&&(a+=7));break;case T:a=(l=new Date(e)).getUTCHours()+(l.getUTCMinutes()/60+l.getUTCSeconds()/3600+l.getUTCMilliseconds()/36e5),n>i&&(i+=24,a<n&&(a+=24));break;case\"\":a=e}if(a>=n&&a<i)return d}else for(var p=o.simpleMap(f.values,t.d2c).sort(o.sorterAsc),g=0;g<p.length;g++)if(i=(n=p[g])+f.dvalue,e>=n&&e<i)return d}return e},t.locateBreaks=function(e,r){var n,i,a,l,c=[];if(!t.rangebreaks)return c;var u=t.rangebreaks.slice().sort((function(t,e){return t.pattern===k&&e.pattern===T?-1:e.pattern===k&&t.pattern===T?1:0})),f=function(t,n){if((t=o.constrain(t,e,r))!==(n=o.constrain(n,e,r))){for(var i=!0,a=0;a<c.length;a++){var s=c[a];t<s.max&&n>=s.min&&(t<s.min&&(s.min=t),n>s.max&&(s.max=n),i=!1)}i&&c.push({min:t,max:n})}};for(n=0;n<u.length;n++){var h=u[n];if(h.enabled)if(h.bounds){var p=e,d=r;h.pattern&&(p=Math.floor(p)),a=(i=o.simpleMap(h.bounds,h.pattern?s:t.r2l))[0],l=i[1];var g,_,w=new Date(p);switch(h.pattern){case k:_=m,g=(l-a+(l<a?7:0))*v,p+=a*v-(w.getUTCDay()*v+w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;case T:_=v,g=(l-a+(l<a?24:0))*y,p+=a*y-(w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;default:p=Math.min(i[0],i[1]),g=_=(d=Math.max(i[0],i[1]))-p}for(var M=p;M<d;M+=_)f(M,M+g)}else for(var A=o.simpleMap(h.values,t.d2c),S=0;S<A.length;S++)f(a=A[S],l=a+h.dvalue)}return c.sort((function(t,e){return t.min-e.min})),c},t.makeCalcdata=function(e,r,n){var i,a,s,l,c=t.type,u=\"date\"===c&&e[r+\"calendar\"];if(r in e){if(i=e[r],l=e._length||o.minRowLength(i),o.isTypedArray(i)&&(\"linear\"===c||\"log\"===c)){if(l===i.length)return i;if(i.subarray)return i.subarray(0,l)}if(\"multicategory\"===c)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=P([i,a])}return r}(i,l);for(a=new Array(l),s=0;s<l;s++)a[s]=t.d2c(i[s],0,u,n)}else{var f=r+\"0\"in e?t.d2c(e[r+\"0\"],0,u):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(i=e[{x:\"y\",y:\"x\"}[r]],l=e._length||i.length,a=new Array(l),s=0;s<l;s++)a[s]=f+s*h}if(t.rangebreaks)for(s=0;s<l;s++)a[s]=t.maskBreaks(a[s]);return a},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&a(t.r2l(e[0]))&&a(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t._emptyCategories=function(){t._categories=[],t._categoriesMap={}},t.clearCalc=function(){var r=t._matchGroup;if(r){var n=null,i=null;for(var a in r){var o=e[_.id2name(a)];if(o._categories){n=o._categories,i=o._categoriesMap;break}}n&&i?(t._categories=n,t._categoriesMap=i):t._emptyCategories()}else t._emptyCategories();if(t._initialCategories)for(var s=0;s<t._initialCategories.length;s++)I(t._initialCategories[s])},t.sortByInitialCategories=function(){var n=[];if(t._emptyCategories(),t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)I(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[_.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var j=e._d3locale;\"date\"===t.type&&(t._dateFormat=j?j.timeFormat:i,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=j?j.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./axis_ids\":831,\"./constants\":834,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],849:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").contrast,a=t(\"./layout_attributes\"),o=t(\"../array_container_defaults\");function s(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter((function(e){return void 0!==t[e]}));if(e.every((function(r){return t[r]===t[e[0]]}))||1===e.length)return t[e[0]]}function l(t,e){function r(r,i){return n.coerce(t,e,a.tickformatstops,r,i)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,c,u,f){f&&1!==f.pass||function(t,e,r,n,i){var a=s(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,u),f&&2!==f.pass||function(t,e,r,c,u){var f=s(t);r(\"tickprefix\")&&r(\"showtickprefix\",f);r(\"ticksuffix\",u.tickSuffixDflt)&&r(\"showticksuffix\",f);if(r(\"showticklabels\")){var h=u.font||{},p=e.color,d=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")?i(u.bgColor):p&&p!==a.color.dflt?p:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:d}),r(\"tickangle\"),\"category\"!==c){var g=r(\"tickformat\");o(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:l}),e.tickformatstops.length||delete e.tickformatstops,g||\"date\"===c||(r(\"showexponent\",f),r(\"exponentformat\"),r(\"minexponent\"),r(\"separatethousands\"))}}}(t,e,r,c,u)}},{\"../../components/color\":643,\"../../lib\":778,\"../array_container_defaults\":823,\"./layout_attributes\":842}],850:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":778,\"./layout_attributes\":842}],851:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){function o(r){var n=t[r];return void 0!==n?n:(e._template||{})[r]}var s=o(\"tick0\"),l=o(\"dtick\"),c=o(\"tickvals\"),u=r(\"tickmode\",i(c)?\"array\":l?\"linear\":\"auto\");if(\"auto\"===u)r(\"nticks\");else if(\"linear\"===u){var f=e.dtick=n.dtick(l,a);e.tick0=n.tick0(s,a,e.calendar,f)}else if(\"multicategory\"!==a){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"../../lib\":778,\"./clean_ticks\":833}],852:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"./axes\");e.exports=function(t,e,r,l){var c=t._fullLayout;if(0!==e.length){var u,f,h,p;l&&(u=l());var d=n.ease(r.easing);return t._transitionData._interruptCallbacks.push((function(){return window.cancelAnimationFrame(p),p=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr0&&(r[o._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[s._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)}))}()})),f=Date.now(),p=window.requestAnimationFrame((function n(){h=Date.now();for(var a=Math.min(1,(h-f)/r.duration),o=d(a),s=0;s<e.length;s++)m(e[s],o);h-f>r.duration?(!function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr1&&(r[o._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[s._name+\".range\"]=a.yr1.slice())}u&&u(),i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)}))}(),p=window.cancelAnimationFrame(n)):p=window.requestAnimationFrame(n)})),Promise.resolve()}function g(t){var e=t.xaxis,r=t.yaxis;c._defs.select(\"#\"+t.clipId+\"> rect\").call(o.setTranslate,0,0).call(o.setScale,1,1),t.plot.call(o.setTranslate,e._offset,r._offset).call(o.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(o.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(o.setTextPointsScale,1,1),n.call(o.hideOutsideRangePoints,t)}function m(e,r){var n=e.plotinfo,i=n.xaxis,l=n.yaxis,c=i._length,u=l._length,f=!!e.xr1,h=!!e.yr1,p=[];if(f){var d=a.simpleMap(e.xr0,i.r2l),g=a.simpleMap(e.xr1,i.r2l),m=d[1]-d[0],v=g[1]-g[0];p[0]=(d[0]*(1-r)+r*g[0]-d[0])/(d[1]-d[0])*c,p[2]=c*(1-r+r*v/m),i.range[0]=i.l2r(d[0]*(1-r)+r*g[0]),i.range[1]=i.l2r(d[1]*(1-r)+r*g[1])}else p[0]=0,p[2]=c;if(h){var y=a.simpleMap(e.yr0,l.r2l),x=a.simpleMap(e.yr1,l.r2l),b=y[1]-y[0],_=x[1]-x[0];p[1]=(y[1]*(1-r)+r*x[1]-y[1])/(y[0]-y[1])*u,p[3]=u*(1-r+r*_/b),l.range[0]=i.l2r(y[0]*(1-r)+r*x[0]),l.range[1]=l.l2r(y[1]*(1-r)+r*x[1])}else p[1]=0,p[3]=u;s.drawOne(t,i,{skipTitle:!0}),s.drawOne(t,l,{skipTitle:!0}),s.redrawComponents(t,[i._id,l._id]);var w=f?c/p[2]:1,T=h?u/p[3]:1,k=f?p[0]:0,M=h?p[1]:0,A=f?p[0]/p[2]*c:0,S=h?p[1]/p[3]*u:0,E=i._offset-A,C=l._offset-S;n.clipRect.call(o.setTranslate,k,M).call(o.setScale,1/w,1/T),n.plot.call(o.setTranslate,E,C).call(o.setScale,w,T),o.setPointGroupScale(n.zoomScalePts,1/w,1/T),o.setTextPointsScale(n.zoomScaleTxt,1/w,1/T)}s.redrawComponents(t)}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../registry\":911,\"./axes\":828,d3:169}],853:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){r(\"autotypenumbers\",s.autotypenumbersDflt),\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r,s=t._id,l=s.charAt(0);-1!==s.indexOf(\"scene\")&&(s=l);var c=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,s,l);if(!c)return;if(\"histogram\"===c.type&&l==={v:\"y\",h:\"x\"}[c.orientation||\"v\"])return void(t.type=\"linear\");var u=l+\"calendar\",f=c[u],h={noMultiCategory:!n(c,\"cartesian\")||n(c,\"noMultiCategory\")};\"box\"===c.type&&c._hasPreCompStats&&l==={h:\"x\",v:\"y\"}[c.orientation||\"v\"]&&(h.noMultiCategory=!0);if(h.autotypenumbers=t.autotypenumbers,o(c,l)){var p=a(c),d=[];for(r=0;r<e.length;r++){var g=e[r];n(g,\"box-violin\")&&(g[l+\"axis\"]||l)===s&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==f&&(f=void 0))}t.type=i(d,f,h)}else if(\"splom\"===c.type){var m=c.dimensions[c._axesDim[s]];m.visible&&(t.type=i(m.values,f,h))}else t.type=i(c[l]||[c[l+\"0\"]],f,h)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":911,\"./axis_autotype\":829}],854:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,(function(t,e,n){r.push({type:\"layout\",prop:t,value:n})}),\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,(function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var f=0;f<a.length;f++)o[f]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})}),\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach((function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}}))}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],f=0;f<u.length;f++)t._internalOn(u[f],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var f=r.computeAPICommandBindings(t,c,u);if(1!==f.length)return!1;if(a){if((s=f[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var h=0;h<a.traces.length;h++)if(a.traces[h]!==s.traces[h])return!1}else if(s.prop!==a.prop)return!1}else a=f[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=f[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch((function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)}))},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":778,\"../registry\":911}],855:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}var c=r(\"domain.x\",i),u=r(\"domain.y\",a);c[0]<c[1]||(t.domain.x=i.slice()),u[0]<u[1]||(t.domain.y=a.slice())}},{\"../lib/extend\":768}],856:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],857:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],858:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],859:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.strTranslate,s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../components/fx\"),u=t(\"../plots\"),f=t(\"../cartesian/axes\"),h=t(\"../cartesian/autorange\").getAutoRange,p=t(\"../../components/dragelement\"),d=t(\"../cartesian/select\").prepSelect,g=t(\"../cartesian/select\").clearSelect,m=t(\"../cartesian/select\").selectOnClick,v=t(\"./zoom\"),y=t(\"./constants\"),x=t(\"../../lib/geo_location_utils\"),b=t(\"../../lib/topojson_utils\"),_=t(\"topojson-client\").feature;function w(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var T=w.prototype;function k(t,e){var r=y.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}e.exports=function(t){return new w(t)},T.plot=function(t,e,r){var n=this,i=e[this.id],a=[],o=!1;for(var s in y.layerNameToAdjective)if(\"frame\"!==s&&i[\"show\"+s]){o=!0;break}for(var l=0;l<t.length;l++)if(t[0][0].trace.locationmode){o=!0;break}if(o){var c=b.getTopojsonName(i);null!==n.topojson&&c===n.topojsonName||(n.topojsonName=c,void 0===PlotlyGeoAssets.topojson[n.topojsonName]&&a.push(n.fetchTopojson()))}a=a.concat(x.fetchTraceGeoData(t)),r.push(new Promise((function(r,i){Promise.all(a).then((function(){n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e),r()})).catch(i)})))},T.fetchTopojson=function(){var t=this,e=b.getTopojsonPath(t.topojsonURL,t.topojsonName);return new Promise((function(r,i){n.json(e,(function(n,a){if(n)return 404===n.status?i(new Error([\"plotly.js could not find topojson file at\",e,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):i(new Error([\"unexpected error while fetching topojson file at\",e].join(\" \")));PlotlyGeoAssets.topojson[t.topojsonName]=a,r()}))}))},T.update=function(t,e){var r=e[this.id];this.hasChoropleth=!1;for(var n=0;n<t.length;n++){var i=t[n],a=i[0].trace;\"choropleth\"===a.type&&(this.hasChoropleth=!0),!0===a.visible&&a._length>0&&a._module.calcGeoJSON(i,e)}if(!this.updateProjection(t,e)){this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),u.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var o=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=o.selectAll(\".point\"),this.dataPoints.text=o.selectAll(\"text\"),this.dataPaths.line=o.selectAll(\".js-line\");var s=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=s.selectAll(\"path\"),this.render()}},T.updateProjection=function(t,e){var r=this.graphDiv,o=e[this.id],s=e._size,l=o.domain,c=o.projection,u=o.lonaxis,f=o.lataxis,p=u._ax,d=f._ax,g=this.projection=function(t){for(var e=t.projection.type,r=n.geo[y.projNames[e]](),i=t._isClipped?y.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(y.precision),i&&r.clipAngle(i-y.clipPad);return r}(o),m=[[s.l+s.w*l.x[0],s.t+s.h*(1-l.y[1])],[s.l+s.w*l.x[1],s.t+s.h*(1-l.y[0])]],v=o.center||{},x=c.rotation||{},b=u.range||[],_=f.range||[];if(o.fitbounds){p._length=m[1][0]-m[0][0],d._length=m[1][1]-m[0][1],p.range=h(r,p),d.range=h(r,d);var w=(p.range[0]+p.range[1])/2,T=(d.range[0]+d.range[1])/2;if(o._isScoped)v={lon:w,lat:T};else if(o._isClipped){v={lon:w,lat:T},x={lon:w,lat:T,roll:x.roll};var M=c.type,A=y.lonaxisSpan[M]/2||180,S=y.lataxisSpan[M]/2||90;b=[w-A,w+A],_=[T-S,T+S]}else v={lon:w,lat:T},x={lon:w,lat:x.lat,roll:x.roll}}g.center([v.lon-x.lon,v.lat-x.lat]).rotate([-x.lon,-x.lat,x.roll]).parallels(c.parallels);var E=k(b,_);g.fitExtent(m,E);var C=this.bounds=g.getBounds(E),L=this.fitScale=g.scale(),I=g.translate();if(!isFinite(C[0][0])||!isFinite(C[0][1])||!isFinite(C[1][0])||!isFinite(C[1][1])||isNaN(I[0])||isNaN(I[0])){for(var P=[\"fitbounds\",\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],z=\"Invalid geo settings, relayout'ing to default view.\",O={},D=0;D<P.length;D++)O[this.id+\".\"+P[D]]=null;return this.viewInitial=null,a.warn(z),r._promises.push(i.call(\"relayout\",r,O)),z}if(o.fitbounds){var R=g.getBounds(k(p.range,d.range)),F=Math.min((C[1][0]-C[0][0])/(R[1][0]-R[0][0]),(C[1][1]-C[0][1])/(R[1][1]-R[0][1]));isFinite(F)?g.scale(F*L):a.warn(\"Something went wrong during\"+this.id+\"fitbounds computations.\")}else g.scale(c.scale*L);var B=this.midPt=[(C[0][0]+C[1][0])/2,(C[0][1]+C[1][1])/2];if(g.translate([I[0]+(B[0]-I[0]),I[1]+(B[1]-I[1])]).clipExtent(C),o._isAlbersUsa){var N=g([v.lon,v.lat]),j=g.translate();g.translate([j[0]-(N[0]-j[0]),j[1]-(N[1]-j[1])])}},T.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,o=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function u(t){return Boolean(y.lineLayers[t])}function h(t){return Boolean(y.fillLayers[t])}var p=(this.hasChoropleth?y.layersForChoropleth:y.layers).filter((function(t){return u(t)||h(t)?e[\"show\"+t]:!c(t)||e[t].showgrid})),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each((function(t){delete a[t],delete o[t],n.select(this).remove()})),d.enter().append(\"g\").attr(\"class\",(function(t){return\"layer \"+t})).each((function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):u(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):h(t)&&(o[t]=e.append(\"path\").style(\"stroke\",\"none\"))})),d.order(),d.each((function(r){var n=o[r],a=y.layerNameToAdjective[r];\"frame\"===r?n.datum(y.sphereSVG):u(r)||h(r)?n.datum(_(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=y.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};f.setConvert(l,r);var c=f.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var u=c.length,h=new Array(u),p=0;p<u;p++)for(var d=c[p].x,g=h[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)g.push(a(d,m));return{type:\"MultiLineString\",coordinates:h}}(r,e,t)).call(s.stroke,e[r].gridcolor).call(l.dashLine,\"\",e[r].gridwidth),u(r)?n.call(s.stroke,e[a+\"color\"]).call(l.dashLine,\"\",e[a+\"width\"]):h(r)&&n.call(s.fill,e[a+\"color\"])}))},T.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,o=r[1][0]-i+n,c=r[1][1]-a+n;l.setRect(this.clipRect,i,a,o,c),this.bgRect.call(l.setRect,i,a,o,c).call(s.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=o,this.yaxis._offset=a,this.yaxis._length=c},T.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,l=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[h([e.xmin,e.ymin]),h([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(h)});var f={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(t){2===t&&g(a)}};\"pan\"===s?(o.node().onmousedown=null,o.call(v(r,e)),o.on(\"dblclick.zoom\",(function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)})),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),f.prepFn=function(t,e,r){d(t,e,r,f,s)},p.init(f)),o.on(\"mousemove\",(function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return p.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},c.hover(a,n.event,r.id)})),o.on(\"mouseout\",(function(){a._dragging||p.unhover(a,n.event)})),o.on(\"click\",(function(){\"select\"!==s&&\"lasso\"!==s&&(l.indexOf(\"select\")>-1&&m(n.event,a,[r.xaxis],[r.yaxis],r.id,f),l.indexOf(\"event\")>-1&&c.click(a,n.event))}))}function h(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},T.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(l.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},f.setConvert(t.mockAxis,r)},T.saveViewInitial=function(t){var e,r=t.center||{},n=t.projection,i=n.rotation||{};this.viewInitial={fitbounds:t.fitbounds,\"projection.scale\":n.scale},e=t._isScoped?{\"center.lon\":r.lon,\"center.lat\":r.lat}:t._isClipped?{\"projection.rotation.lon\":i.lon,\"projection.rotation.lat\":i.lat}:{\"center.lon\":r.lon,\"center.lat\":r.lat,\"projection.rotation.lon\":i.lon},a.extendFlat(this.viewInitial,e)},T.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?o(r[0],r[1]):null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",(function(t){return r(t.geojson)}));for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/topojson_utils\":806,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/axes\":828,\"../cartesian/select\":847,\"../plots\":891,\"./constants\":858,\"./projections\":863,\"./zoom\":864,d3:169,\"topojson-client\":579}],860:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l.geo={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots.geo,s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots.geo,n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots.geo||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.framework.remove(),s.clipDef.remove())}}}},{\"../../lib\":778,\"../../plots/get_data\":865,\"./geo\":859,\"./layout_attributes\":861,\"./layout_defaults\":862}],861:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),fitbounds:{valType:\"enumerated\",values:[!1,\"locations\",\"geojson\"],dflt:!1,editType:\"plot\"},resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},visible:{valType:\"boolean\",dflt:!0},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":642,\"../../plot_api/edit_types\":810,\"../domain\":855,\"./constants\":858}],862:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../get_data\").getSubplotData,o=t(\"./constants\"),s=t(\"./layout_attributes\"),l=o.axesNames;function c(t,e,r,i){var s=a(i.fullData,\"geo\",i.id).map((function(t){return t._expandedIndex})),c=r(\"resolution\"),u=r(\"scope\"),f=o.scopeDefaults[u],h=r(\"projection.type\",f.projType),p=e._isAlbersUsa=\"albers usa\"===h;p&&(u=e.scope=\"usa\");var d=e._isScoped=\"world\"!==u,g=e._isConic=-1!==h.indexOf(\"conic\"),m=e._isClipped=!!o.lonaxisSpan[h];if(!1===t.visible){var v=n.extendDeep({},e._template);v.showcoastlines=!1,v.showcountries=!1,v.showframe=!1,v.showlakes=!1,v.showland=!1,v.showocean=!1,v.showrivers=!1,v.showsubunits=!1,v.lonaxis&&(v.lonaxis.showgrid=!1),v.lataxis&&(v.lataxis.showgrid=!1),e._template=v}for(var y=r(\"visible\"),x=0;x<l.length;x++){var b,_=l[x],w=[30,10][x];if(d)b=f[_+\"Range\"];else{var T=o[_+\"Span\"],k=(T[h]||T[\"*\"])/2,M=r(\"projection.rotation.\"+_.substr(0,3),f.projRotate[x]);b=[M-k,M+k]}var A=r(_+\".range\",b);r(_+\".tick0\"),r(_+\".dtick\",w),r(_+\".showgrid\",!!y&&void 0)&&(r(_+\".gridcolor\"),r(_+\".gridwidth\")),e[_]._ax={type:\"linear\",_id:_.slice(0,3),_traceIndices:s,setScale:n.identity,c2l:n.identity,r2l:n.identity,autorange:!0,range:A.slice(),_m:1,_input:{}}}var S=e.lonaxis.range,E=e.lataxis.range,C=S[0],L=S[1];C>0&&L<0&&(L+=360);var I,P,z,O=(C+L)/2;if(!p){var D=d?f.projRotate:[O,0,0];I=r(\"projection.rotation.lon\",D[0]),r(\"projection.rotation.lat\",D[1]),r(\"projection.rotation.roll\",D[2]),r(\"showcoastlines\",!d&&y)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\",!!y&&void 0)&&r(\"oceancolor\")}(p?(P=-96.6,z=38.7):(P=d?O:I,z=(E[0]+E[1])/2),r(\"center.lon\",P),r(\"center.lat\",z),g)&&r(\"projection.parallels\",f.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\",!!y&&void 0)&&r(\"landcolor\"),r(\"showlakes\",!!y&&void 0)&&r(\"lakecolor\"),r(\"showrivers\",!!y&&void 0)&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",d&&\"usa\"!==u&&y)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===u||\"north america\"===u&&50===c)&&(r(\"showsubunits\",y),r(\"subunitcolor\"),r(\"subunitwidth\")),d||r(\"showframe\",y)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\"),r(\"fitbounds\")&&(delete e.projection.scale,d?(delete e.center.lon,delete e.center.lat):m?(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon,delete e.projection.rotation.lat,delete e.lonaxis.range,delete e.lataxis.range):(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon))}e.exports=function(t,e,r){i(t,e,r,{type:\"geo\",attributes:s,handleDefaults:c,fullData:r,partition:\"y\"})}},{\"../../lib\":778,\"../get_data\":865,\"../subplot_defaults\":905,\"./constants\":858,\"./layout_attributes\":861}],863:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map((function(t){return r(t,n)}))};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map((function(t){return e(t,r)}))}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach((function(r){!function(t){if((e=t.length)<4)return!1;var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];for(;++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])})),e.forEach((function(e){var r=e[0];t.some((function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],f=t[s],h=f[0],p=f[1];u>n^p>n&&r<(h-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0}))||t.push([e])})),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var f=1e-6,h=Math.PI,p=h/2,d=(Math.sqrt(h),h/180),g=180/h;function m(t){return t>1?p:t<-1?-p:Math.asin(t)}function v(t){return t>1?0:t<-1?h:Math.acos(t)}var y=t.geo.projection,x=t.geo.projectionMutator;function b(t,e){var r=(2+p)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>f;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(h*(4+h))*t*(1+Math.cos(e)),2*Math.sqrt(h/(4+h))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-h,0],[0,p],[h,0]]],[[[-h,0],[0,-p],[h,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}function a(){r=n.map((function(t){return t.map((function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]}))}))}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],l=0,u=o.length;l<u;++l){var f=o[l];if(f[0][0]<=t&&t<f[1][0]&&f[0][1]<=a&&a<f[1][1]){var h=e.invert(t-e(s[l][1][0],0)[0],a);return h[0]+=s[l][1][0],c(i(h[0],h[1]),[t,a])?h:null}}});var o=t.geo.projection(i),s=o.stream;function l(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function c(t,e){return Math.abs(t[0]-e[0])<f&&Math.abs(t[1]-e[1])<f}return o.stream=function(e){var r=o.rotate(),i=s(e),a=(o.rotate([0,0]),s(e));return o.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=180*(p=n[0][i])[0][0]/h,s=180*p[0][1]/h,c=180*p[1][1]/h,u=180*p[2][0]/h,f=180*p[2][1]/h;r.push(l([[o+e,s+e],[o+e,c-e],[u-e,c-e],[u-e,f+e]],30))}for(i=n[1].length-1;i>=0;--i){var p;o=180*(p=n[1][i])[0][0]/h,s=180*p[0][1]/h,c=180*p[1][1]/h,u=180*p[2][0]/h,f=180*p[2][1]/h;r.push(l([[u-e,f-e],[u-e,c+e],[o+e,c+e],[o+e,s-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),a)},i},o.lobes=function(t){return arguments.length?(n=t.map((function(t){return t.map((function(t){return[[t[0][0]*h/180,t[0][1]*h/180],[t[1][0]*h/180,t[1][1]*h/180],[t[2][0]*h/180,t[2][1]*h/180]]}))})),a(),o):n.map((function(t){return t.map((function(t){return[[180*t[0][0]/h,180*t[0][1]/h],[180*t[1][0]/h,180*t[1][1]/h],[180*t[2][0]/h,180*t[2][1]/h]]}))}))},o},b.invert=function(t,e){var r=.5*e*Math.sqrt((4+h)/h),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(h*(4+h))*(1+i)),m((n+r*(i+2))/(2+p))]},(t.geo.eckert4=function(){return y(b)}).raw=b;var _=t.geo.azimuthalEqualArea.raw;function w(t,e){if(arguments.length<2&&(e=t),1===e)return _;if(e===1/0)return T;function r(r,n){var i=_(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=_.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function k(t,e){return[3*t/(2*h)*Math.sqrt(h*h/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(h/4+.4*e))]}function A(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>f&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=x(w),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=w,k.invert=function(t,e){return[2/3*h*t/Math.sqrt(h*h/3-e*e),e]},(t.geo.kavrayskiy7=function(){return y(k)}).raw=k,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*h]},(t.geo.miller=function(){return y(M)}).raw=M,A(h);var S=function(t,e,r){var n=A(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/p,Math.SQRT2,h);function E(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return y(S)}).raw=S,E.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>f&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return y(E)}).raw=E;var C=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function L(t,e){var r,n=Math.min(18,36*Math.abs(e)/h),i=Math.floor(n),a=n-i,o=(r=C[i])[0],s=r[1],l=(r=C[++i])[0],c=r[1],u=(r=C[Math.min(19,++i)])[0],f=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?p:-p)*(c+a*(f-s)/2+a*a*(f-2*c+s)/2)]}function I(t,e){return[t*Math.cos(e),e]}function P(t,e){var r,n=Math.cos(e),i=(r=v(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function z(t,e){var r=P(t,e);return[(r[0]+t/p)/2,(r[1]+e)/2]}C.forEach((function(t){t[1]*=1.0144})),L.invert=function(t,e){var r=e/p,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=C[a][1],s=C[a+1][1],l=C[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,f=2*(Math.abs(r)-s)/c,h=u/c,m=f*(1-h*f*(1-2*h*f));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var v,y=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=C[a][1],s=C[a+1][1],l=C[Math.min(19,a+2)][1],n-=(v=(e>=0?p:-p)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*g}while(Math.abs(v)>1e-12&&--y>0);break}}while(--a>=0);var x=C[a][0],b=C[a+1][0],_=C[Math.min(19,a+2)][0];return[t/(b+m*(_-x)/2+m*m*(_-2*b+x)/2),n*d]},(t.geo.robinson=function(){return y(L)}).raw=L,I.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return y(I)}).raw=I,P.invert=function(t,e){if(!(t*t+4*e*e>h*h+f)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),p=Math.sin(2*n),d=c*c,g=u*u,m=s*s,y=1-g*l*l,x=y?v(u*l)*Math.sqrt(a=1/y):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*m+x*u*l*d),T=a*(.5*o*p-2*x*c*s),k=.25*a*(p*s-x*c*g*o),M=a*(d*l+x*m*u),A=T*k-M*w;if(!A)break;var S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>f||Math.abs(E)>f)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return y(P)}).raw=P,z.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,h=Math.sin(r),d=Math.cos(r/2),g=Math.sin(r/2),m=g*g,y=1-u*d*d,x=y?v(o*d)*Math.sqrt(a=1/y):a=0,b=.5*(2*x*o*g+r/p)-t,_=.5*(x*s+n)-e,w=.5*a*(u*m+x*o*d*c)+.5/p,T=a*(h*l/4-x*s*g),k=.125*a*(l*g-x*s*u*h),M=.5*a*(c*d+x*m*o)+.5,A=T*k-M*w,S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>f||Math.abs(E)>f)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return y(z)}).raw=z}},{}],864:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function f(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],f={},h={};function p(t,e){f[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,f);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),h[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),p(\"fitbounds\",!1),o.emit(\"plotly_relayout\",h)}function h(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",(function(){n.select(this).style(l)})).on(\"zoom\",(function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})})).on(\"zoomend\",(function(){n.select(this).style(c),f(t,e,i)})),r}function p(t,e){var r,i,a,o,s,h,p,d,g,m=u(0,e);function v(t){return e.invert(t)}function y(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return m.on(\"zoomstart\",(function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=v(r)})).on(\"zoom\",(function(){if(h=n.mouse(this),function(t){var r=v(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>2||Math.abs(n[1]-t[1])>2}(r))return m.scale(e.scale()),void m.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?v(h)&&(d=v(h),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=v(r=h),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})})).on(\"zoomend\",(function(){n.select(this).style(c),g&&f(t,e,y)})),m}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),o=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),s=0,h=a.on;function p(t){s++||t({type:\"zoomstart\"})}function d(t){t({type:\"zoom\"})}function b(t){--s||t({type:\"zoomend\"})}function _(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",(function(){n.select(this).style(l);var t=n.mouse(this),s=e.rotate(),c=s,u=e.translate(),f=m(s);r=g(e,t),h.call(a,\"zoom\",(function(){var a=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,a)){e.rotate(s).translate(u);var l=g(e,a),h=y(r,l),p=T(v(f,h)),m=i.r=x(p,r,c);isFinite(m[0])&&isFinite(m[1])&&isFinite(m[2])||(m=c),e.rotate(m),c=m}}else r=g(e,t=a);d(o.of(this,arguments))})),p(o.of(this,arguments))})).on(\"zoomend\",(function(){n.select(this).style(c),h.call(a,\"zoom\",null),b(o.of(this,arguments)),f(t,e,_)})).on(\"zoom.redraw\",(function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})})),n.rebind(a,o,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function m(t){var e=.5*t[0]*o,r=.5*t[1]*o,n=.5*t[2]*o,i=Math.sin(e),a=Math.cos(e),s=Math.sin(r),l=Math.cos(r),c=Math.sin(n),u=Math.cos(n);return[a*l*u+i*s*c,i*l*u-a*s*c,a*s*u+i*l*c,a*l*c-i*s*u]}function v(t,e){var r=t[0],n=t[1],i=t[2],a=t[3],o=e[0],s=e[1],l=e[2],c=e[3];return[r*o-n*s-i*l-a*c,r*s+n*o+i*c-a*l,r*l-n*c+i*o+a*s,r*c+n*l-i*s+a*o]}function y(t,e){if(t&&e){var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(k(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,k(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}}function x(t,e,r){var n=w(e,2,t[0]);n=w(n,1,t[1]),n=w(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],f=n[1],h=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(f)>d?(a=(f>0?90:-90)-p,i=0):(a=Math.asin(f/d)*s-p,i=Math.sqrt(d*d-f*f));var g=180-a-2*p,m=(Math.atan2(h,u)-Math.atan2(c,i))*s,v=(Math.atan2(h,u)-Math.atan2(c,-i))*s;return b(r[0],r[1],a,m)<=b(r[0],r[1],g,v)?[a,m,r[2]]:[g,v,r[2]]}function b(t,e,r,n){var i=_(r-t),a=_(n-e);return Math.sqrt(i*i+a*a)}function _(t){return(t%360+540)%360-180}function w(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function T(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}function k(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?h:e._isClipped?d:p)(t,r)}},{\"../../lib\":778,\"../../registry\":911,d3:169}],865:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var f=0;f<t.length;f++)a=t[f],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":911,\"./cartesian/constants\":834}],866:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function f(e,n,i){var a,s,l=t.calcDataBox(),f=r.viewBox,h=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function m(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=f[3]-f[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var v=n/(f[2]-f[0])*(l[2]-l[0])+l[0],y=i/(f[3]-f[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=v,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=v,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(m(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(m(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(h-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,f),e.addEventListener(\"touchstart\",(function(t){var r=a(t.changedTouches[0],e);f(0,r[0],r[1]),f(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchmove\",(function(t){t.preventDefault();var r=a(t.changedTouches[0],e);f(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchend\",(function(t){f(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()}),!!s&&{passive:!1}),c.wheelListener=i(e,(function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),f=o/(a[2]-a[0])*(i[2]-i[0])+i[0],h=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-f)*l+f,i[2]=(i[2]-f)*l+f,i[1]=(i[1]-h)*l+h,i[3]=(i[3]-h)*l+h,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0}),!0),c}},{\"../cartesian/constants\":834,\"has-passive-events\":441,\"mouse-change\":483,\"mouse-event-offset\":484,\"mouse-wheel\":486}],867:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,f,h,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),h=0;h<2;++h){var d=(e=s[h]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[h+p]=!1,this.labels[h+p]=n,this.labelColor[h+p]=i(r.title.font.color),this.labelFont[h+p]=r.title.font.family,this.labelSize[h+p]=r.title.font.size,this.labelPad[h+p]=this.getLabelPad(e,r),this.tickEnable[h+p]=!1,this.tickColor[h+p]=i((r.tickfont||{}).color),this.tickAngle[h+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[h+p]=this.getTickPad(r),this.tickMarkLength[h+p]=0,this.tickMarkWidth[h+p]=r.tickwidth||0,this.tickMarkColor[h+p]=i(r.tickcolor),this.borderLineEnable[h+p]=!1,this.borderLineColor[h+p]=i(r.linecolor),this.borderLineWidth[h+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,f=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[h]=!0:l&&(this.labelEnable[h+2]=!0),o?this.tickEnable[h]=r.showticklabels:l&&(this.tickEnable[h+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[h]=r.showline),(l||u)&&(this.borderLineEnable[h+2]=r.showline),(o||f)&&(this.tickMarkLength[h]=this.getTickMarkLength(r)),(l||f)&&(this.tickMarkLength[h+2]=this.getTickMarkLength(r)),this.gridLineEnable[h]=r.showgrid,this.gridLineColor[h]=i(r.gridcolor),this.gridLineWidth[h]=r.gridwidth,this.zeroLineEnable[h]=r.zeroline,this.zeroLineColor[h]=i(r.zerolinecolor),this.zeroLineWidth[h]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":802,\"../cartesian/axes\":828}],868:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d){var c=u(t,\"gl2d\",o);0===c.length&&(s._scene2d.destroy(),delete n._plots[o])}}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":684,\"../../constants/xmlns_namespaces\":754,\"../../plot_api/edit_types\":810,\"../cartesian\":841,\"../cartesian/attributes\":826,\"../cartesian/constants\":834,\"../get_data\":865,\"../layout_attributes\":882,\"./scene2d\":869}],869:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),f=t(\"webgl-context\"),h=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),m=g.enforce,v=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=t(\"../../components/dragelement/helpers\"),b=x.drawMode,_=x.selectMode,w=[\"xaxis\",\"yaxis\"],T=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function k(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=h(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=k;var M=k.prototype;M.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=f({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=f({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r);var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",(function(){l.isMouseOver=!1,l.unhover()})),o.addEventListener(\"mouseover\",(function(){l.isMouseOver=!0}))},M.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var f=document.createElement(\"canvas\");f.width=r,f.height=i;var h,p=f.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":h=f.toDataURL(\"image/jpeg\");break;case\"webp\":h=f.toDataURL(\"image/webp\");break;default:h=f.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),h},M.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},M.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},M.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(T),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},M.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},M.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},M.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},M.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map((function(e){t[e].dispose(),delete t[e]})),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},M.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};v(s,this.xaxis),v(s,this.yaxis);var l,c,u=r._size,f=this.xaxis.domain,h=this.yaxis.domain;for(o.viewBox=[u.l+f[0]*u.w,u.b+h[0]*u.h,i-u.r-(1-f[1])*u.w,a-u.t-(1-h[1])*u.h],this.mouseContainer.style.width=u.w*(f[1]-f[0])+\"px\",this.mouseContainer.style.height=u.h*(h[1]-h[0])+\"px\",this.mouseContainer.height=u.h*(h[1]-h[0]),this.mouseContainer.style.left=u.l+f[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-h[1])*u.h+\"px\",c=0;c<2;++c)(l=this[w[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();m(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},M.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},M.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},M.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort((function(t,e){return t._trace.index-e._trace.index}))},M.updateFx=function(t){_(t)||b(t)?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},M.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},M.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var f=i._size,h=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+f.l+h[0]*f.w,l/t.pixelRatio-(f.t+(1-p[1])*f.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var m=this.fullData[g.trace.index]||{},v=g.pointIndex,y=s.castHoverinfo(m,i,v);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(m,v,\"bgcolor\")||g.color,borderColor:s.castHoverOption(m,v,\"bordercolor\"),fontFamily:s.castHoverOption(m,v,\"font.family\"),fontSize:s.castHoverOption(m,v,\"font.size\"),fontColor:s.castHoverOption(m,v,\"font.color\"),nameLength:s.castHoverOption(m,v,\"namelength\"),textAlign:s.castHoverOption(m,v,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},M.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},M.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/dragelement/helpers\":661,\"../../components/fx\":683,\"../../lib/show_no_webgl_msg\":800,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/constants\":834,\"../cartesian/constraints\":835,\"./camera\":866,\"./convert\":867,\"gl-plot2d\":317,\"gl-select-box\":333,\"gl-spikes2d\":342,\"webgl-context\":606}],870:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,f=c._scene;f||(f=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=f),f.viewInitial||(f.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),f.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":684,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../get_data\":865,\"./layout/attributes\":871,\"./layout/defaults\":875,\"./layout/layout_attributes\":876,\"./scene\":880}],871:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],872:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:{text:i.title.text,font:i.title.font},type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":643,\"../../../lib/extend\":768,\"../../../plot_api/edit_types\":810,\"../../cartesian/layout_attributes\":842}],873:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,f;function h(t,e){return i.coerce(u,f,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(f=a.newContainer(e,d))._id=d[0]+r.scene,f._name=d,s(u,f,h,r),l(u,f,h,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,noTicklabelmode:!0,noTicklabelposition:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),h(\"gridcolor\",n(f.color,r.bgColor,13600/187).toRgbString()),h(\"title.text\",d[0]),f.setScale=i.noop,h(\"showspikes\")&&(h(\"spikesides\"),h(\"spikethickness\"),h(\"spikecolor\",f.color)),h(\"showaxeslabels\"),h(\"showbackground\")&&h(\"backgroundcolor\")}}},{\"../../../lib\":778,\"../../../plot_api/plot_template\":817,\"../../cartesian/axis_defaults\":830,\"../../cartesian/type_defaults\":853,\"./axis_attributes\":872,tinycolor2:576}],874:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":778,\"../../../lib/str2rgbarray\":802}],875:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData;function u(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),u=[\"up\",\"center\",\"eye\"],f=0;f<u.length;f++)r(\"camera.\"+u[f]+\".x\"),r(\"camera.\"+u[f]+\".y\"),r(\"camera.\"+u[f]+\".z\");r(\"camera.projection.type\");var h=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),p=r(\"aspectmode\",h?\"manual\":\"auto\");h||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===p&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var d=c(n.fullData,\"gl3d\",n.id);s(t,e,{font:n.font,scene:n.id,data:d,bgColor:l,calendar:n.calendar,autotypenumbersDflt:n.autotypenumbersDflt,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var g=n.getDfltFromLayout(\"dragmode\");if(!1!==g&&!g)if(g=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,v=t.camera.up.y,y=t.camera.up.z;0!==y&&(m&&v&&y?y/Math.sqrt(m*m+v*v+y*y)>.999&&(g=\"turntable\"):g=\"turntable\")}else g=\"turntable\";r(\"dragmode\",g),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:\"gl3d\",attributes:l,handleDefaults:u,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":643,\"../../../lib\":778,\"../../../registry\":911,\"../../get_data\":865,\"../../subplot_defaults\":905,\"./axis_defaults\":873,\"./layout_attributes\":876}],876:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":778,\"../../../lib/extend\":768,\"../../domain\":855,\"./axis_attributes\":872}],877:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":802}],878:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var f=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var h=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/h)}for(var p=n.calcTicks(u,{msUTC:!0}),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=f}}e.ticks=l;for(c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":778,\"../../cartesian/axes\":828}],879:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],880:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\"),o=a.createCamera,s=a.createScene,l=t(\"webgl-context\"),c=t(\"has-passive-events\"),u=t(\"../../registry\"),f=t(\"../../lib\"),h=f.preserveDrawingBuffer(),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../components/fx\"),g=t(\"../../lib/str2rgbarray\"),m=t(\"../../lib/show_no_webgl_msg\"),v=t(\"./project\"),y=t(\"./layout/convert\"),x=t(\"./layout/spikes\"),b=t(\"./layout/tick_marks\");function _(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=y(e,e[this.id]),this.spikeOptions=x(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=u.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=u.getComponentMethod(\"annotations3d\",\"draw\"),this.initializeGLPlot()}var w=_.prototype;w.prepareOptions=function(){var t={canvas:this.canvas,gl:this.gl,glOptions:{preserveDrawingBuffer:h,premultipliedAlpha:!0,antialias:!0},container:this.container,axes:this.axesOptions,spikes:this.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:this.camera,pixelRatio:this.pixelRatio};if(this.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=l({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");t.gl=i,t.canvas=n}return t};var T=!0;w.tryCreatePlot=function(){var t=this.prepareOptions(),e=!0;try{this.glplot=s(t)}catch(r){if(this.staticMode||!T||h)e=!1;else{f.warn([\"webgl setup failed possibly due to\",\"false preserveDrawingBuffer config.\",\"The mobile/tablet device may not be detected by is-mobile module.\",\"Enabling preserveDrawingBuffer in second attempt to create webgl scene...\"].join(\" \"));try{h=t.glOptions.preserveDrawingBuffer=!0,this.glplot=s(t)}catch(r){h=t.glOptions.preserveDrawingBuffer=!1,e=!1}}}return T=!1,e},w.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=o(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},w.initializeGLPlot=function(){var t=this;if(t.initializeGLCamera(),!t.tryCreatePlot())return m(t);t.traces={},t.make4thDimension();var e=t.graphDiv,r=e.layout,n=function(){var e={};return t.isCameraChanged(r)&&(e[t.id+\".camera\"]=t.getCamera()),t.isAspectChanged(r)&&(e[t.id+\".aspectratio\"]=t.glplot.getAspectratio(),\"manual\"!==r[t.id].aspectmode&&(t.fullSceneLayout.aspectmode=r[t.id].aspectmode=e[t.id+\".aspectmode\"]=\"manual\")),e},i=function(t){if(!1!==t.fullSceneLayout.dragmode){var e=n();t.saveLayout(r),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas&&(t.glplot.canvas.addEventListener(\"mouseup\",(function(){i(t)})),t.glplot.canvas.addEventListener(\"wheel\",(function(r){if(e._context._scrollZoom.gl3d){if(t.camera._ortho){var n=r.deltaX>r.deltaY?1.1:1/1.1,a=t.glplot.getAspectratio();t.glplot.setAspectratio({x:n*a.x,y:n*a.y,z:n*a.z})}i(t)}}),!!c&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",(function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e=n();t.graphDiv.emit(\"plotly_relayouting\",e)}})),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",(function(r){e&&e.emit&&e.emit(\"plotly_webglcontextlost\",{event:r,layer:t.id})}),!1)),t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(){t.render()},!0},w.render=function(){var t,e=this,r=e.graphDiv,n=e.svgContainer,i=e.container.getBoundingClientRect();r._fullLayout._calcInverseTransform(r);var a=r._fullLayout._invScaleX,o=r._fullLayout._invScaleY,s=i.width*a,l=i.height*o;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+s+\" \"+l),n.setAttributeNS(null,\"width\",s),n.setAttributeNS(null,\"height\",l),b(e),e.glplot.axes.update(e.axesOptions);for(var c,u=Object.keys(e.traces),h=null,g=e.glplot.selection,m=0;m<u.length;++m)\"skip\"!==(t=e.traces[u[m]]).data.hoverinfo&&t.handlePick(g)&&(h=t),t.setContourLevels&&t.setContourLevels();function y(t,r){var n=e.fullSceneLayout[t];return p.tickText(n,n.d2l(r),\"hover\").text}if(null!==h){var x=v(e.glplot.cameraParams,g.dataCoordinate);t=h.data;var _,w=r._fullData[t.index],T=g.index,k={xLabel:y(\"xaxis\",g.traceCoordinate[0]),yLabel:y(\"yaxis\",g.traceCoordinate[1]),zLabel:y(\"zaxis\",g.traceCoordinate[2])},M=d.castHoverinfo(w,e.fullLayout,T),A=(M||\"\").split(\"+\"),S=M&&\"all\"===M;w.hovertemplate||S||(-1===A.indexOf(\"x\")&&(k.xLabel=void 0),-1===A.indexOf(\"y\")&&(k.yLabel=void 0),-1===A.indexOf(\"z\")&&(k.zLabel=void 0),-1===A.indexOf(\"text\")&&(g.textLabel=void 0),-1===A.indexOf(\"name\")&&(h.name=void 0));var E=[];\"cone\"===t.type||\"streamtube\"===t.type?(k.uLabel=y(\"xaxis\",g.traceCoordinate[3]),(S||-1!==A.indexOf(\"u\"))&&E.push(\"u: \"+k.uLabel),k.vLabel=y(\"yaxis\",g.traceCoordinate[4]),(S||-1!==A.indexOf(\"v\"))&&E.push(\"v: \"+k.vLabel),k.wLabel=y(\"zaxis\",g.traceCoordinate[5]),(S||-1!==A.indexOf(\"w\"))&&E.push(\"w: \"+k.wLabel),k.normLabel=g.traceCoordinate[6].toPrecision(3),(S||-1!==A.indexOf(\"norm\"))&&E.push(\"norm: \"+k.normLabel),\"streamtube\"===t.type&&(k.divergenceLabel=g.traceCoordinate[7].toPrecision(3),(S||-1!==A.indexOf(\"divergence\"))&&E.push(\"divergence: \"+k.divergenceLabel)),g.textLabel&&E.push(g.textLabel),_=E.join(\"<br>\")):\"isosurface\"===t.type||\"volume\"===t.type?(k.valueLabel=p.tickText(e._mockAxis,e._mockAxis.d2l(g.traceCoordinate[3]),\"hover\").text,E.push(\"value: \"+k.valueLabel),g.textLabel&&E.push(g.textLabel),_=E.join(\"<br>\")):_=g.textLabel;var C={x:g.traceCoordinate[0],y:g.traceCoordinate[1],z:g.traceCoordinate[2],data:w._input,fullData:w,curveNumber:w.index,pointNumber:T};d.appendArrayPointValue(C,w,T),t._module.eventData&&(C=w._module.eventData(C,g,w,{},T));var L={points:[C]};e.fullSceneLayout.hovermode&&d.loneHover({trace:w,x:(.5+.5*x[0]/x[3])*s,y:(.5-.5*x[1]/x[3])*l,xLabel:k.xLabel,yLabel:k.yLabel,zLabel:k.zLabel,text:_,name:h.name,color:d.castHoverOption(w,T,\"bgcolor\")||h.color,borderColor:d.castHoverOption(w,T,\"bordercolor\"),fontFamily:d.castHoverOption(w,T,\"font.family\"),fontSize:d.castHoverOption(w,T,\"font.size\"),fontColor:d.castHoverOption(w,T,\"font.color\"),nameLength:d.castHoverOption(w,T,\"namelength\"),textAlign:d.castHoverOption(w,T,\"align\"),hovertemplate:f.castOption(w,T,\"hovertemplate\"),hovertemplateLabels:f.extendFlat({},C,k),eventData:[C]},{container:n,gd:r}),g.buttons&&g.distance<5?r.emit(\"plotly_click\",L):r.emit(\"plotly_hover\",L),c=L}else d.loneUnhover(n),r.emit(\"plotly_unhover\",c);e.drawAnnotations(e)},w.recoverContext=function(){var t=this;t.glplot.dispose();var e=function(){t.glplot.gl.isContextLost()?requestAnimationFrame(e):t.initializeGLPlot()?t.plot.apply(t,t.plotArgs):f.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")};requestAnimationFrame(e)};var k=[\"xaxis\",\"yaxis\",\"zaxis\"];function M(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=k[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],u=e[\"_\"+o+\"length\"];if(f.isArrayOrTypedArray(l))for(var h,p=0;p<(u||l.length);p++)if(f.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)h=s.d2l(l[p][d],0,c),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else h=s.d2l(l[p],0,c),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],u-1)}}w.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];this.fullLayout=e,this.fullSceneLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setViewport(c),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.setClearColor(g(c.bgcolor)),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&M(this,n,f);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=k[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,f);var h=[1,1,1];for(o=0;o<3;++o)f[1][o]===f[0][o]?h[o]=1:h[o]=1/(f[1][o]-f[0][o]);for(this.dataScale=h,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var p=Object.keys(this.traces);t:for(a=0;a<p.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===p[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[p[a]]).dispose(),delete this.traces[p[a]]}this.glplot.objects.sort((function(t,e){return t._trace.data.index-e._trace.data.index}));var d,m=[[0,0,0],[0,0,0]],v=[],y={};for(a=0;a<3;++a){if((l=(s=c[k[a]]).type)in y?(y[l].acc*=h[a],y[l].count+=1):y[l]={acc:h[a],count:1},s.autorange){m[0][a]=1/0,m[1][a]=-1/0;var x=this.glplot.objects,b=this.fullSceneLayout.annotations||[],_=s._name.charAt(0);for(o=0;o<x.length;o++){var w=x[o],T=w.bounds,A=w._trace.data._pad||0;\"ErrorBars\"===w.constructor.name&&s._lowerLogErrorBound?m[0][a]=Math.min(m[0][a],s._lowerLogErrorBound):m[0][a]=Math.min(m[0][a],T[0][a]/h[a]-A),m[1][a]=Math.max(m[1][a],T[1][a]/h[a]+A)}for(o=0;o<b.length;o++){var S=b[o];if(S.visible){var E=s.r2l(S[_]);m[0][a]=Math.min(m[0][a],E),m[1][a]=Math.max(m[1][a],E)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(m[0][a]=Math.min(m[0][a],0),m[1][a]=Math.max(m[1][a],0)),m[0][a]>m[1][a])m[0][a]=-1,m[1][a]=1;else{var C=m[1][a]-m[0][a];m[0][a]-=C/32,m[1][a]+=C/32}if(\"reversed\"===s.autorange){var L=m[0][a];m[0][a]=m[1][a],m[1][a]=L}}else{var I=s.range;m[0][a]=s.r2l(I[0]),m[1][a]=s.r2l(I[1])}m[0][a]===m[1][a]&&(m[0][a]-=1,m[1][a]+=1),v[a]=m[1][a]-m[0][a],this.glplot.setBounds(a,{min:m[0][a]*h[a],max:m[1][a]*h[a]})}var P=c.aspectmode;if(\"cube\"===P)d=[1,1,1];else if(\"manual\"===P){var z=c.aspectratio;d=[z.x,z.y,z.z]}else{if(\"auto\"!==P&&\"data\"!==P)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var O=[1,1,1];for(a=0;a<3;++a){var D=y[l=(s=c[k[a]]).type];O[a]=Math.pow(D.acc,1/D.count)/h[a]}d=\"data\"===P||Math.max.apply(null,O)/Math.min.apply(null,O)<=4?O:[1,1,1]}c.aspectratio.x=u.aspectratio.x=d[0],c.aspectratio.y=u.aspectratio.y=d[1],c.aspectratio.z=u.aspectratio.z=d[2],this.glplot.setAspectratio(c.aspectratio),this.viewInitial.aspectratio||(this.viewInitial.aspectratio={x:c.aspectratio.x,y:c.aspectratio.y,z:c.aspectratio.z}),this.viewInitial.aspectmode||(this.viewInitial.aspectmode=c.aspectmode);var R=c.domain||null,F=e._size||null;if(R&&F){var B=this.container.style;B.position=\"absolute\",B.left=F.l+R.x[0]*F.w+\"px\",B.top=F.t+(1-R.y[1])*F.h+\"px\",B.width=F.w*(R.x[1]-R.x[0])+\"px\",B.height=F.h*(R.y[1]-R.y[0])+\"px\"}this.glplot.redraw()}},w.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},w.getCamera=function(){var t;return this.camera.view.recalcMatrix(this.camera.view.lastT()),{up:{x:(t=this.camera).up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}},w.setViewport=function(t){var e,r=t.camera;this.camera.lookAt.apply(this,[[(e=r).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]),this.glplot.setAspectratio(t.aspectratio),\"orthographic\"===r.projection.type!==this.camera._ortho&&(this.glplot.redraw(),this.glplot.clearRGBA(),this.glplot.dispose(),this.initializeGLPlot())},w.isCameraChanged=function(t){var e=this.getCamera(),r=f.nestedProperty(t,this.id+\".camera\").get();function n(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}var i=!1;if(void 0===r)i=!0;else{for(var a=0;a<3;a++)for(var o=0;o<3;o++)if(!n(e,r,a,o)){i=!0;break}(!r.projection||e.projection&&e.projection.type!==r.projection.type)&&(i=!0)}return i},w.isAspectChanged=function(t){var e=this.glplot.getAspectratio(),r=f.nestedProperty(t,this.id+\".aspectratio\").get();return void 0===r||r.x!==e.x||r.y!==e.y||r.z!==e.z},w.saveLayout=function(t){var e,r,n,i,a,o,s=this.fullLayout,l=this.isCameraChanged(t),c=this.isAspectChanged(t),h=l||c;if(h){var p={};if(l&&(e=this.getCamera(),n=(r=f.nestedProperty(t,this.id+\".camera\")).get(),p[this.id+\".camera\"]=n),c&&(i=this.glplot.getAspectratio(),o=(a=f.nestedProperty(t,this.id+\".aspectratio\")).get(),p[this.id+\".aspectratio\"]=o),u.call(\"_storeDirectGUIEdit\",t,s._preGUI,p),l)r.set(e),f.nestedProperty(s,this.id+\".camera\").set(e);if(c)a.set(i),f.nestedProperty(s,this.id+\".aspectratio\").set(i),this.glplot.redraw()}return h},w.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var c=this.id+\".camera.up\",h={x:0,y:0,z:1},p={};p[c]=h;var d=n.layout;u.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=h,f.nestedProperty(d,c).set(h)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},w.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a),function(t,e,r){for(var n=0,i=r-1;n<i;++n,--i)for(var a=0;a<e;++a)for(var o=0;o<4;++o){var s=4*(e*n+a)+o,l=4*(e*i+a)+o,c=t[s];t[s]=t[l],t[l]=c}}(a,r,i),function(t,e,r){for(var n=0;n<r;++n)for(var i=0;i<e;++i){var a=4*(e*n+i),o=t[a+3];if(o>0)for(var s=255/o,l=0;l<3;++l)t[a+l]=Math.min(s*t[a+l],255)}}(a,r,i);var o=document.createElement(\"canvas\");o.width=r,o.height=i;var s,l=o.getContext(\"2d\"),c=l.createImageData(r,i);switch(c.data.set(a),l.putImageData(c,0,0),t){case\"jpeg\":s=o.toDataURL(\"image/jpeg\");break;case\"webp\":s=o.toDataURL(\"image/webp\");break;default:s=o.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),s},w.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[k[t]];p.setConvert(e,this.fullLayout),e.setScale=f.noop}},w.make4thDimension=function(){var t=this.graphDiv._fullLayout;this._mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},p.setConvert(this._mockAxis,t)},e.exports=_},{\"../../components/fx\":683,\"../../lib\":778,\"../../lib/show_no_webgl_msg\":800,\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./layout/convert\":874,\"./layout/spikes\":877,\"./layout/tick_marks\":878,\"./project\":879,\"gl-plot3d\":321,\"has-passive-events\":441,\"webgl-context\":606}],881:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],882:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"../components/shapes/draw_newshape/attributes\"),s=t(\"./pad_attributes\"),l=t(\"../lib/extend\").extendFlat,c=n({editType:\"calc\"});c.family.dflt='\"Open Sans\", verdana, arial, sans-serif',c.size.dflt=12,c.color.dflt=a.defaultLine,e.exports={font:c,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:l(s({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},uniformtext:{mode:{valType:\"enumerated\",values:[!1,\"hide\",\"show\"],dflt:!1,editType:\"plot\"},minsize:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},computed:{valType:\"any\",editType:\"none\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},newshape:o.newshape,activeshape:o.activeshape,meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:l({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":642,\"../components/shapes/draw_newshape/attributes\":725,\"../lib/extend\":768,\"./animation_attributes\":822,\"./font_attributes\":856,\"./pad_attributes\":890}],883:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.10.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.10.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],884:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":778}],885:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=i.strTranslate,o=i.strScale,s=t(\"../../plots/get_data\").getSubplotCalcData,l=t(\"../../constants/xmlns_namespaces\"),c=t(\"d3\"),u=t(\"../../components/drawing\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./mapbox\"),p=r.constants=t(\"./constants\");function d(t){return\"string\"==typeof t&&(-1!==p.styleValuesMapbox.indexOf(t)||0===t.indexOf(\"mapbox://\"))}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,a=e._subplots.mapbox;if(n.version!==p.requiredVersion)throw new Error(p.wrongVersionErrorMsg);var o=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;d(c.style)&&(u?i.pushUnique(n,u):(d(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var f=o?p.noAccessTokenErrorMsg:p.missingStyleErrorMsg;throw i.error(f),new Error(f)}return n.length?(n.length>1&&i.warn(p.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,a);n.accessToken=o;for(var l=0;l<a.length;l++){var c=a[l],u=s(r,\"mapbox\",c),f=e[c],g=f._subplot;g||(g=new h(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},f.center),zoom:f.zoom,bearing:f.bearing,pitch:f.pitch}),g.plot(u,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var s=e[r[i]],h=s.domain,d=s._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":d,x:n.l+n.w*h.x[0],y:n.t+n.h*(1-h.y[1]),width:n.w*(h.x[1]-h.x[0]),height:n.h*(h.y[1]-h.y[0]),preserveAspectRatio:\"none\"});var g=c.select(s._subplot.div);if(!(null===g.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var m=e._glimages.append(\"g\");m.attr(\"transform\",a(n.l+n.w*h.x[0]+10,n.t+n.h*(1-h.y[0])-31)),m.append(\"path\").attr(\"d\",p.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),m.append(\"path\").attr(\"d\",p.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),m.append(\"path\").attr(\"d\",p.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),m.append(\"polygon\").attr(\"points\",p.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var v=g.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),y=e._glimages.append(\"g\"),x=y.append(\"text\");x.text(v).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":v});var b=u.bBox(x.node()),_=n.w*(h.x[1]-h.x[0]);if(b.width>_/2){var w=v.split(\"|\").join(\"<br>\");x.text(w).attr(\"data-unformatted\",w).call(f.convertToTspans,t),b=u.bBox(x.node())}x.attr(\"transform\",a(-3,8-b.height)),y.insert(\"rect\",\".static-attribution\").attr({x:-b.width-6,y:-b.height-3,width:b.width+6,height:b.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var T=1;b.width+6>_&&(T=_/(b.width+6));var k=[n.l+n.w*h.x[1],n.t+n.h*(1-h.y[0])];y.attr(\"transform\",a(k[0],k[1])+o(T))}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":665,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/get_data\":865,\"./constants\":883,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./mapbox\":889,d3:169,\"mapbox-gl\":473}],886:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/svg_text_utils\").sanitizeHTML,a=t(\"./convert_text_opts\"),o=t(\"./constants\");function s(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=o.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var l=s.prototype;function c(t){if(!t.visible)return!1;var e=t.source;if(Array.isArray(e)&&e.length>0){for(var r=0;r<e.length;r++)if(\"string\"!=typeof e[r]||0===e[r].length)return!1;return!0}return n.isPlainObject(e)||\"string\"==typeof e&&e.length>0}function u(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var i=t.symbol,o=a(i.textposition,i.iconsize);n.extendFlat(e,{\"icon-image\":i.icon+\"-15\",\"icon-size\":i.iconsize/10,\"text-field\":i.text,\"text-size\":i.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":i.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":i.textfont.color,\"text-opacity\":t.opacity});break;case\"raster\":n.extendFlat(r,{\"raster-fade-duration\":0,\"raster-opacity\":t.opacity})}return{layout:e,paint:r}}l.update=function(t){this.visible?this.needsNewImage(t)?this.updateImage(t):this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=c(t)},l.needsNewImage=function(t){return this.subplot.map.getSource(this.idSource)&&\"image\"===this.sourceType&&\"image\"===t.sourcetype&&(this.source!==t.source||JSON.stringify(this.coordinates)!==JSON.stringify(t.coordinates))},l.needsNewSource=function(t){return this.sourceType!==t.sourcetype||JSON.stringify(this.source)!==JSON.stringify(t.source)||this.layerType!==t.type},l.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},l.lookupBelow=function(){return this.subplot.belowLookup[\"layout-\"+this.index]},l.updateImage=function(t){this.subplot.map.getSource(this.idSource).updateImage({url:t.source,coordinates:t.coordinates});var e=this.findFollowingMapboxLayerId(this.lookupBelow());null!==e&&this.subplot.map.moveLayer(this.idLayer,e)},l.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,c(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,a={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",a.tileSize=256):\"image\"===r&&(e=\"url\",a.coordinates=t.coordinates);a[e]=n,t.sourceattribution&&(a.attribution=i(t.sourceattribution));return a}(t);e.addSource(this.idSource,r)}},l.findFollowingMapboxLayerId=function(t){if(\"traces\"===t)for(var e=this.subplot.getMapLayers(),r=0;r<e.length;r++){var n=e[r].id;if(\"string\"==typeof n&&0===n.indexOf(o.traceLayerPrefix)){t=n;break}}return t},l.updateLayer=function(t){var e=this.subplot,r=u(t),n=this.lookupBelow(),i=this.findFollowingMapboxLayerId(n);this.removeLayer(),c(t)&&e.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:r.layout,paint:r.paint},i),this.layerType=t.type,this.below=n},l.updateStyle=function(t){if(c(t)){var e=u(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},l.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},l.dispose=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer),t.getSource(this.idSource)&&t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new s(t,e);return n.update(r),n}},{\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"./constants\":883,\"./convert_text_opts\":884}],887:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),f=o({});f.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:f,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../traces/scatter/attributes\":1187,\"../domain\":855,\"../font_attributes\":856,\"./constants\":883}],888:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":778,\"../array_container_defaults\":823,\"../subplot_defaults\":905,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../lib/geo_location_utils\"),o=t(\"../../registry\"),s=t(\"../cartesian/axes\"),l=t(\"../../components/dragelement\"),c=t(\"../../components/fx\"),u=t(\"../../components/dragelement/helpers\"),f=u.rectMode,h=u.drawMode,p=u.selectMode,d=t(\"../cartesian/select\").prepSelect,g=t(\"../cartesian/select\").clearSelect,m=t(\"../cartesian/select\").clearSelectionsCache,v=t(\"../cartesian/select\").selectOnClick,y=t(\"./constants\"),x=t(\"./layers\");function b(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={},this.dragging=!1,this.wheeling=!1}var _=b.prototype;_.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash={},i.layerList=[]),n=i.map?new Promise((function(r,n){i.updateMap(t,e,r,n)})):new Promise((function(r,n){i.createMap(t,e,r,n)})),r.push(n)},_.createMap=function(t,e,r,i){var o=this,s=e[o.id],l=o.styleObj=T(s.style);o.accessToken=s.accesstoken;var c=o.map=new n.Map({container:o.div,style:l.style,center:M(s.center),zoom:s.zoom,bearing:s.bearing,pitch:s.pitch,interactive:!o.isStatic,preserveDrawingBuffer:o.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));c._canvas.style.left=\"0px\",c._canvas.style.top=\"0px\",o.rejectOnError(i),o.isStatic||o.initFx(t,e);var u=[];u.push(new Promise((function(t){c.once(\"load\",t)}))),u=u.concat(a.fetchTraceGeoData(t)),Promise.all(u).then((function(){o.fillBelowLookup(t,e),o.updateData(t),o.updateLayout(e),o.resolveOnRender(r)})).catch(i)},_.updateMap=function(t,e,r,n){var i=this,o=i.map,s=e[this.id];i.rejectOnError(n);var l=[],c=T(s.style);JSON.stringify(i.styleObj)!==JSON.stringify(c)&&(i.styleObj=c,o.setStyle(c.style),i.traceHash={},l.push(new Promise((function(t){o.once(\"styledata\",t)})))),l=l.concat(a.fetchTraceGeoData(t)),Promise.all(l).then((function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)})).catch(n)},_.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,f,h={};for(u in a)h[n=a[u]]?h[n].push(u):h[n]=[u];for(n in h){var p=h[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(f=u.split(\"trace-\")[1],this.traceHash[f]&&(this.traceHash[f].below=null)):0===u.indexOf(\"layout-\")&&(f=u.split(\"layout-\")[1],this.layerList[f]&&(this.layerList[f].below=null))}};var w={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function T(t){var e={};return i.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==y.styleValuesMapbox.indexOf(t)?e.style=k(t):y.stylesNonMapbox[t]?e.style=y.stylesNonMapbox[t]:e.style=t):(e.id=y.styleValueDflt,e.style=k(y.styleValueDflt)),e.transition={duration:0,delay:0},e}function k(t){return y.styleUrlPrefix+t+\"-\"+y.styleUrlSuffix}function M(t){return[t.lon,t.lat]}_.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort((function(t,e){return w[t[0].trace.type]-w[e[0].trace.type]}));for(n=0;n<o.length;n++){var s=o[n],l=!1;(e=a[(r=s[0].trace).uid])&&(e.type===r.type?(e.update(s),l=!0):e.dispose()),!l&&r._module&&(a[r.uid]=r._module.plot(this,s))}var c=Object.keys(a);t:for(n=0;n<c.length;n++){var u=c[n];for(i=0;i<t.length;i++)if(u===(r=t[i][0].trace).uid)continue t;(e=a[u]).dispose(),delete a[u]}},_.updateLayout=function(t){var e=this.map,r=t[this.id];this.dragging||this.wheeling||(e.setCenter(M(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch)),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},_.resolveOnRender=function(t){var e=this.map;e.on(\"render\",(function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,10))}))},_.rejectOnError=function(t){var e=this.map;function r(){t(new Error(y.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},_.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},s.setConvert(e.mockAxis,t)},_.initFx=function(t,e){var r=this,n=r.gd,i=r.map;function a(){c.loneUnhover(e._hoverlayer)}function s(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEditsWithDerived(t))}i.on(\"moveend\",(function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||r.wheeling){var i=e[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))}t.originalEvent&&\"mouseup\"===t.originalEvent.type?r.dragging=!1:r.wheeling&&(r.wheeling=!1),e._rehover&&e._rehover()}})),i.on(\"wheel\",(function(){r.wheeling=!0})),i.on(\"mousemove\",(function(t){var e=r.div.getBoundingClientRect(),a=[t.originalEvent.offsetX,t.originalEvent.offsetY];t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return i.unproject(a).lng},r.yaxis.p2c=function(){return i.unproject(a).lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&n._fullLayout[r.id]&&c.hover(n,t,r.id)},c.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id})),i.on(\"dragstart\",(function(){r.dragging=!0,a()})),i.on(\"zoomstart\",a),i.on(\"mouseout\",(function(){n._fullLayout._hoversubplot=null})),i.on(\"drag\",s),i.on(\"zoom\",s),i.on(\"dblclick\",(function(){var t=n._fullLayout[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(M(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))})),r.clearSelect=function(){m(r.dragOptions),g(r.dragOptions.gd)},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&v(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&c.click(n,e.originalEvent)}}},_.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var a,o=t.dragmode;a=f(o)?function(t,r){(t.range={})[e.id]=[c([r.xmin,r.ymin]),c([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(c)};var s=e.dragOptions;e.dragOptions=i.extendDeep(s||{},{dragmode:t.dragmode,element:e.div,gd:n,plotinfo:{id:e.id,domain:t[e.id].domain,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:a},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),p(o)||h(o)?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){d(t,r,n,e.dragOptions,o)},l.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function c(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},_.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},_.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(x(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},_.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},_.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},_.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},_.getMapLayers=function(){return this.map.getStyle().layers},_.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),a=0;a<n.length;a++)if(e===n[a].id)return void r.addLayer(t,e);i.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},_.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},_.getView=function(){var t=this.map,e=t.getCenter(),r={lon:e.lng,lat:e.lat},n=t.getCanvas(),i=n.width,a=n.height;return{center:r,zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch(),_derived:{coordinates:[t.unproject([0,0]).toArray(),t.unproject([i,0]).toArray(),t.unproject([i,a]).toArray(),t.unproject([0,a]).toArray()]}}},_.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},_.getViewEditsWithDerived=function(t){var e=this.id,r=this.getViewEdits(t);return r[e+\"._derived\"]=t._derived,r},e.exports=b},{\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../registry\":911,\"../cartesian/axes\":828,\"../cartesian/select\":847,\"./constants\":883,\"./layers\":886,\"mapbox-gl\":473}],890:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").timeFormatLocale,a=t(\"fast-isnumeric\"),o=t(\"../registry\"),s=t(\"../plot_api/plot_schema\"),l=t(\"../plot_api/plot_template\"),c=t(\"../lib\"),u=t(\"../components/color\"),f=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),p=t(\"./cartesian/handle_outline\").clearSelect,d=t(\"./animation_attributes\"),g=t(\"./frame_attributes\"),m=t(\"../plots/get_data\").getModuleCalcData,v=c.relinkPrivateKeys,y=c._,x=e.exports={};c.extendFlat(x,o),x.attributes=t(\"./attributes\"),x.attributes.type.values=x.allTypes,x.fontAttrs=t(\"./font_attributes\"),x.layoutAttributes=t(\"./layout_attributes\"),x.fontWeight=\"normal\";var b=x.transformsRegistry,_=t(\"./command\");x.executeAPICommand=_.executeAPICommand,x.computeAPICommandBindings=_.computeAPICommandBindings,x.manageCommandObserver=_.manageCommandObserver,x.hasSimpleAPICommandBindings=_.hasSimpleAPICommandBindings,x.redrawText=function(t){var e=(t=c.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise((function(e){setTimeout((function(){o.getComponentMethod(\"annotations\",\"draw\")(t),o.getComponentMethod(\"legend\",\"draw\")(t),o.getComponentMethod(\"colorbar\",\"draw\")(t),e(x.previousPromises(t))}),300)}))},x.resize=function(t){var e;t=c.getGraphDiv(t);var r=new Promise((function(r,n){t&&!c.isHidden(t)||n(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._resolveResize&&(e=t._resolveResize),t._resolveResize=r,t._redrawTimer=setTimeout((function(){if(!t.layout||t.layout.width&&t.layout.height||c.isHidden(t))r(t);else{delete t.layout.width,delete t.layout.height;var e=t.changed;t.autoplay=!0,o.call(\"relayout\",t,{autosize:!0}).then((function(){t.changed=e,t._resolveResize===r&&(delete t._resolveResize,r(t))}))}}),100)}));return e&&e(r),r},x.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then((function(){t._promises=[]}))},x.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=c.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",(function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:u.defaultLine,\"pointer-events\":\"all\"}).each((function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)}))})),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),l=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",(function(){x.sendDataToCloud(t)}));else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&l.text()?\" - \":\"\")}},x.sendDataToCloud=function(t){var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL;if(e){t.emit(\"plotly_beforeexport\");var r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=x.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1}};var w=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],T=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function k(t,e){var r=t._context.locale;r||(r=\"en-US\");var n=!1,i={};function a(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(a(u),n))break;l=o.localeRegistry}var f=r.split(\"-\")[0];if(n||f===r)break;r=f}return n||a(o.localeRegistry.en.format),i}function M(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function A(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||b[n.type];if(i&&i.makesData)return!0}return!1}function S(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=b[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function E(t){return\"string\"==typeof t&&\"px\"===t.substr(t.length-2)&&parseFloat(t)}function C(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}x.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,a=t._fullLayout||{};if(a._skipDefaults)delete a._skipDefaults;else{var s,l=t._fullLayout={},u=t.layout||{},f=t._fullData||[],h=t._fullData=[],d=t.data||[],g=t.calcdata||[],m=t._context||{};t._transitionData||x.createTransitionData(t),l._dfltTitle={plot:y(t,\"Click to enter Plot title\"),x:y(t,\"Click to enter X axis title\"),y:y(t,\"Click to enter Y axis title\"),colorbar:y(t,\"Click to enter Colorscale title\"),annotation:y(t,\"new text\")},l._traceWord=y(t,\"trace\");var b=k(t,w);if(l._mapboxAccessToken=m.mapboxAccessToken,a._initialAutoSizeIsDone){var _=a.width,M=a.height;x.supplyLayoutGlobalDefaults(u,l,b),u.width||(l.width=_),u.height||(l.height=M),x.sanitizeMargins(l)}else{x.supplyLayoutGlobalDefaults(u,l,b);var A=!u.width||!u.height,S=l.autosize,E=m.autosizable;A&&(S||E)?x.plotAutoSize(t,u,l):A&&x.sanitizeMargins(l),!S&&A&&(u.width=l.width,u.height=l.height)}l._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),{numberFormat:n.locale(t).numberFormat,timeFormat:i(t).utcFormat}}(b,l.separators),l._extraFormat=k(t,T),l._initialAutoSizeIsDone=!0,l._dataLength=d.length,l._modules=[],l._visibleModules=[],l._basePlotModules=[];var L=l._subplots=function(){var t,e,r=o.collectableSubplotTypes,n={};if(!r){r=[];var i=o.subplotsRegistry;for(var a in i){var s=i[a].attr;if(s&&(r.push(a),Array.isArray(s)))for(e=0;e<s.length;e++)c.pushUnique(r,s[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),I=l._splomAxes={x:{},y:{}},P=l._splomSubplots={};l._splomGridDflt={},l._scatterStackOpts={},l._firstScatter={},l._alignmentOpts={},l._colorAxes={},l._requestRangeslider={},l._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,l=new Array(i),u={};function f(t,e){l[e]=t,u[t]=1}function h(t,e){if(t&&\"string\"==typeof t&&!u[t])return f(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),h(p,r)||(r<s&&h(a[r].uid,r)||f(c.randstr(u),r))}return l}(f,d),l._globalTransforms=(t._context||{}).globalTransforms,x.supplyDataDefaults(d,h,u,l);var z=Object.keys(I.x),O=Object.keys(I.y);if(z.length>1&&O.length>1){for(o.getComponentMethod(\"grid\",\"sizeDefaults\")(u,l),s=0;s<z.length;s++)c.pushUnique(L.xaxis,z[s]);for(s=0;s<O.length;s++)c.pushUnique(L.yaxis,O[s]);for(var D in P)c.pushUnique(L.cartesian,D)}if(l._has=x._hasPlotType.bind(l),f.length===h.length)for(s=0;s<h.length;s++)v(h[s],f[s]);x.supplyLayoutModuleDefaults(u,l,h,t._transitionData);var R=l._visibleModules,F=[];for(s=0;s<R.length;s++){var B=R[s].crossTraceDefaults;B&&c.pushUnique(F,B)}for(s=0;s<F.length;s++)F[s](h,l);l._hasOnlyLargeSploms=1===l._basePlotModules.length&&\"splom\"===l._basePlotModules[0].name&&z.length>15&&O.length>15&&0===l.shapes.length&&0===l.images.length,l._hasCartesian=l._has(\"cartesian\"),l._hasGeo=l._has(\"geo\"),l._hasGL3D=l._has(\"gl3d\"),l._hasGL2D=l._has(\"gl2d\"),l._hasTernary=l._has(\"ternary\"),l._hasPie=l._has(\"pie\"),x.linkSubplots(h,l,f,a),x.cleanPlot(h,l,f,a);var N=!(!a._has||!a._has(\"gl2d\")),j=!(!l._has||!l._has(\"gl2d\")),U=!(!a._has||!a._has(\"cartesian\"))||N,V=!(!l._has||!l._has(\"cartesian\"))||j;U&&!V?a._bgLayer.remove():V&&!U&&(l._shouldCreateBgLayer=!0),a._zoomlayer&&!t._dragging&&p({_fullLayout:a}),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,l),v(l,a),o.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,l),l._preGUI||(l._preGUI={}),l._tracePreGUI||(l._tracePreGUI={});var q,H=l._tracePreGUI,G={};for(q in H)G[q]=\"old\";for(s=0;s<h.length;s++)G[q=h[s]._fullInput.uid]||(H[q]={}),G[q]=\"new\";for(q in G)\"old\"===G[q]&&delete H[q];C(l),o.getComponentMethod(\"rangeslider\",\"makeData\")(l),r||g.length!==h.length||x.supplyDefaultsUpdateCalc(g,h)}},x.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,l,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],l=c.nestedProperty(a,s).get().slice(),c.nestedProperty(n,s).set(l)}i.trace=n}}},x.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},x._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var a=o.modules[i];if(a&&a.categories[t])return!0}return!1},x.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var f=r[i].uid;for(a=0;a<t.length;a++){if(f===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+f).remove()}},x.linkSubplots=function(t,e,r,n){var i,a,s=n._plots||{},l=e._plots={},u=e._subplots,f={_fullData:t,_fullLayout:e},p=u.cartesian.concat(u.gl2d||[]);for(i=0;i<p.length;i++){var d,g=p[i],m=s[g],v=h.getFromId(f,g,\"x\"),y=h.getFromId(f,g,\"y\");for(m?d=l[g]=m:(d=l[g]={}).id=g,v._counterAxes.push(y._id),y._counterAxes.push(v._id),v._subplotsWith.push(g),y._subplotsWith.push(g),d.xaxis=v,d.yaxis=y,d._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var x=t[a];if(x.xaxis===d.xaxis._id&&x.yaxis===d.yaxis._id&&!1===x.cliponaxis){d._hasClipOnAxisFalse=!0;break}}}var b,_=h.list(f,null,!0);for(i=0;i<_.length;i++){var w=null;(b=_[i]).overlaying&&(w=h.getFromId(f,b.overlaying))&&w.overlaying&&(b.overlaying=!1,w=null),b._mainAxis=w||b,w&&(b.domain=w.domain.slice()),b._anchorAxis=\"free\"===b.anchor?null:h.getFromId(f,b.anchor)}for(i=0;i<_.length;i++)if((b=_[i])._counterAxes.sort(h.idSort),b._subplotsWith.sort(c.subplotSort),b._mainSubplot=M(b,e),b._counterAxes.length&&(b.spikemode&&-1!==b.spikemode.indexOf(\"across\")||b.automargin&&b.mirror&&\"free\"!==b.anchor||o.getComponentMethod(\"rangeslider\",\"isVisible\")(b))){var T=1,k=0;for(a=0;a<b._counterAxes.length;a++){var A=h.getFromId(f,b._counterAxes[a]);T=Math.min(T,A.domain[0]),k=Math.max(k,A.domain[1])}T<k&&(b._counterDomainMin=T,b._counterDomainMax=k)}},x.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],s.crawl(t._module.attributes,(function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))}))),n=0;n<e.length;n++){c.nestedProperty(t,\"_input.\"+e[n]).get()||c.nestedProperty(t,e[n]).set(null)}},x.supplyDataDefaults=function(t,e,r,n){var i,a,s,u=n._modules,f=n._visibleModules,h=n._basePlotModules,p=0,d=0;function g(t){e.push(t);var r=t._module;r&&(c.pushUnique(u,r),!0===t.visible&&c.pushUnique(f,r),c.pushUnique(h,t._module.basePlotModule),p++,!1!==t._input.visible&&d++)}n._transformModules=[];var m={},y=[],b=(r.template||{}).data||{},_=l.traceTemplater(b);for(i=0;i<t.length;i++){if(s=t[i],(a=_.newTrace(s)).uid=n._traceUids[i],x.supplyTraceDefaults(s,a,d,n,i),a.index=i,a._input=s,a._expandedIndex=p,a.transforms&&a.transforms.length)for(var w=!1!==s.visible&&!1===a.visible,T=S(a,e,r,n),k=0;k<T.length;k++){var M=T[k],A={_template:a._template,type:a.type,uid:a.uid+k};w&&!1===M.visible&&delete M.visible,x.supplyTraceDefaults(M,A,p,n,i),v(A,M),A.index=i,A._input=s,A._fullInput=a,A._expandedIndex=p,A._expandedInput=M,g(A)}else a._fullInput=a,a._expandedInput=a,g(a);o.traceIs(a,\"carpetAxis\")&&(m[a.carpet]=a),o.traceIs(a,\"carpetDependent\")&&y.push(i)}for(i=0;i<y.length;i++)if((a=e[y[i]]).visible){var E=m[a.carpet];a._carpet=E,E&&E.visible?(a.xaxis=E.xaxis,a.yaxis=E.yaxis):a.visible=!1}},x.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return c.coerce(t||{},r,d,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=x.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=x.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=x.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=x.supplyAnimationTransitionDefaults(t.transition||{});return r},x.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},x.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},x.supplyFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t,e,g,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},x.supplyTraceDefaults=function(t,e,r,n,i){var a,s=n.colorway||u.defaults,l=s[r%s.length];function f(r,n){return c.coerce(t,e,x.attributes,r,n)}var h=f(\"visible\");f(\"type\"),f(\"name\",n._traceWord+\" \"+i),f(\"uirevision\",n.uirevision);var p=x.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var v=n._subplots,y=\"\";if(h||\"gl2d\"!==d.name){if(Array.isArray(g))for(a=0;a<g.length;a++){var b=g[a],_=c.coerce(t,e,m,b);v[b]&&c.pushUnique(v[b],_),y+=_}else y=c.coerce(t,e,m,g);v[d.name]&&c.pushUnique(v[d.name],y)}}}return h&&(f(\"customdata\"),f(\"ids\"),f(\"meta\"),o.traceIs(e,\"showLegend\")?(c.coerce(t,e,p.attributes.showlegend?p.attributes:x.attributes,\"showlegend\"),f(\"legendgroup\"),e._dfltShowLegend=!0):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,l,n),o.traceIs(e,\"noOpacity\")||f(\"opacity\"),o.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),o.traceIs(e,\"noHover\")||(e.hovertemplate||c.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&o.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,l,n)),p&&p.selectPoints&&f(\"selectedpoints\"),x.supplyTransformDefaults(t,e,n)),e},x.hasMakesDataTransform=A,x.supplyTransformDefaults=function(t,e,r){if(e._length||A(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],l=0;l<o.length;l++){var u,f=o[l],h=f.type,p=b[h],d=!(f._module&&f._module===p),g=p&&\"function\"==typeof p.transform;p||c.warn(\"Unrecognized transform type \"+h+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(f,e,r,t)).type=h,u._module=p,c.pushUnique(i,p)):u=c.extendFlat({},f),s.push(u)}}},x.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return c.coerce(t,e,x.layoutAttributes,r,n)}var i=t.template;c.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data),n(\"autotypenumbers\");var a=c.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),c.coerceFont(n,\"title.font\",{family:a.family,size:Math.round(1.4*a.size),color:a.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"uniformtext.mode\")&&n(\"uniformtext.minsize\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&x.sanitizeMargins(e),o.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",u.addOpacity(e.paper_bgcolor,.5));var l=u.contrast(u.rgb(e.modebar.bgcolor));n(\"modebar.color\",u.addOpacity(l,.3)),n(\"modebar.activecolor\",u.addOpacity(l,.7)),n(\"modebar.uirevision\",s),o.getComponentMethod(\"shapes\",\"supplyDrawNewShapeDefaults\")(t,e,n),n(\"meta\"),c.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),o.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),o.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},x.plotAutoSize=function(t,e,r){var n,i,o=t._context||{},s=o.frameMargins,l=c.isPlotDiv(t);if(l&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,i=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=l?window.getComputedStyle(t):{};if(n=E(u.width)||E(u.maxWidth)||r.width,i=E(u.height)||E(u.maxHeight)||r.height,a(s)&&s>0){var f=1-2*s;n=Math.round(f*n),i=Math.round(f*i)}}var h=x.layoutAttributes.width.min,p=x.layoutAttributes.height.min;n<h&&(n=h),i<p&&(i=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-i)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=i)),t._initialAutoSize||(t._initialAutoSize={width:n,height:i}),x.sanitizeMargins(r)},x.supplyLayoutModuleDefaults=function(t,e,r,n){var i,a,s,l=o.componentsRegistry,u=e._basePlotModules,f=o.subplotsRegistry.cartesian;for(i in l)(s=l[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var h in u.length||u.push(f),e._has(\"cartesian\")&&(o.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),f.finalizeSubplots(t,e)),e._subplots)e._subplots[h].sort(c.subplotSort);for(a=0;a<u.length;a++)(s=u[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(a=0;a<p.length;a++)(s=p[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(a=0;a<d.length;a++)(s=d[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in l)(s=l[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},x.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),c.clearThrottle(),c.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},x.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&c.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},x.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},x.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},x.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1};x.autoMargin=function(t,e,r){var n=t._fullLayout,i=n.width,a=n.height,o=n.margin,s=c.constrain(i-o.l-o.r,2,64),l=c.constrain(a-o.t-o.b,2,64),u=Math.max(0,i-s),f=Math.max(0,a-l),h=n._pushmargin,p=n._pushmarginIds;if(!1!==o.autoexpand){if(r){var d=r.pad;if(void 0===d&&(d=Math.min(12,o.l,o.r,o.t,o.b)),u){var g=(r.l+r.r)/u;g>1&&(r.l/=g,r.r/=g)}if(f){var m=(r.t+r.b)/f;m>1&&(r.t/=m,r.b/=m)}var v=void 0!==r.xl?r.xl:r.x,y=void 0!==r.xr?r.xr:r.x,b=void 0!==r.yt?r.yt:r.y,_=void 0!==r.yb?r.yb:r.y;h[e]={l:{val:v,size:r.l+d},r:{val:y,size:r.r+d},b:{val:_,size:r.b+d},t:{val:b,size:r.t+d}},p[e]=1}else delete h[e],delete p[e];if(!n._replotting)return x.doAutoMargin(t)}},x.doAutoMargin=function(t){var e=t._fullLayout,r=e.width,n=e.height;e._size||(e._size={}),C(e);var i=e._size,s=e.margin,l=c.extendFlat({},i),u=s.l,f=s.r,p=s.t,d=s.b,g=e._pushmargin,m=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var v in g)m[v]||delete g[v];for(var y in g.base={l:{val:0,size:u},r:{val:1,size:f},t:{val:1,size:p},b:{val:0,size:d}},g){var b=g[y].l||{},_=g[y].b||{},w=b.val,T=b.size,k=_.val,M=_.size;for(var A in g){if(a(T)&&g[A].r){var S=g[A].r.val,E=g[A].r.size;if(S>w){var L=(T*S+(E-r)*w)/(S-w),I=(E*(1-w)+(T-r)*(1-S))/(S-w);L+I>u+f&&(u=L,f=I)}}if(a(M)&&g[A].t){var P=g[A].t.val,z=g[A].t.size;if(P>k){var O=(M*P+(z-n)*k)/(P-k),D=(z*(1-k)+(M-n)*(1-P))/(P-k);O+D>d+p&&(d=O,p=D)}}}}}var R=c.constrain(r-s.l-s.r,2,64),F=c.constrain(n-s.t-s.b,2,64),B=Math.max(0,r-R),N=Math.max(0,n-F);if(B){var j=(u+f)/B;j>1&&(u/=j,f/=j)}if(N){var U=(d+p)/N;U>1&&(d/=U,p/=U)}if(i.l=Math.round(u),i.r=Math.round(f),i.t=Math.round(p),i.b=Math.round(d),i.p=Math.round(s.pad),i.w=Math.round(r)-i.l-i.r,i.h=Math.round(n)-i.t-i.b,!e._replotting&&x.didMarginChange(l,i)){\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1;var V=3*(1+Object.keys(m).length);if(e._redrawFromAutoMarginCount<V)return o.call(\"plot\",t);e._size=l,c.warn(\"Too many auto-margin redraws.\")}!function(t){for(var e=h.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r]._hideOutOfRangeInsideTickLabels;n&&n()}}(t)};var L=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function I(t,e,r){var n=!1;var i=[x.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,x.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise((function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push((function(){n=!0})),r.redraw&&t._transitionData._interruptCallbacks.push((function(){return o.call(\"redraw\",t)})),t._transitionData._interruptCallbacks.push((function(){t.emit(\"plotly_transitioninterrupted\",[])}));var a=0,s=0;function l(){return a++,function(){s++,n||s!==a||function(e){if(!t._transitionData)return;(function(t){if(t)for(;t.length;)t.shift()})(t._transitionData._interruptCallbacks),Promise.resolve().then((function(){if(r.redraw)return o.call(\"redraw\",t)})).then((function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])})).then(e)}(i)}}r.runFn(l),setTimeout(l())}))}],a=c.syncOrAsync(i,t);return a&&a.then||(a=Promise.resolve()),a.then((function(){return t}))}x.didMarginChange=function(t,e){for(var r=0;r<L.length;r++){var n=L[r],i=t[n],o=e[n];if(!a(i)||Math.abs(o-i)>1)return!0}return!1},x.graphJson=function(t,e,r,n,i,a){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&x.supplyDefaults(t);var o=i?t._fullData:t.data,s=i?t._fullLayout:t.layout,l=(t._transitionData||{})._frames;function u(t,e){if(\"function\"==typeof t)return e?\"_function_\":null;if(c.isPlainObject(t)){var n,i={};return Object.keys(t).sort().forEach((function(a){if(-1===[\"_\",\"[\"].indexOf(a.charAt(0)))if(\"function\"!=typeof t[a]){if(\"keepdata\"===r){if(\"src\"===a.substr(a.length-3))return}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0&&!c.isPlainObject(t.stream))return}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0)return;i[a]=u(t[a],e)}else e&&(i[a]=\"_function\")})),i}return Array.isArray(t)?t.map((function(t){return u(t,e)})):c.isTypedArray(t)?c.simpleMap(t,c.identity):c.isJSDate(t)?c.ms2DateTimeLocal(+t):t}var f={data:(o||[]).map((function(t){var r=u(t);return e&&delete r.fit,r}))};if(!e&&(f.layout=u(s),i)){var h=s._size;f.layout.computed={margin:{b:h.b,l:h.l,r:h.r,t:h.t}}}return t.framework&&t.framework.isPolar&&(f=t.framework.getConfig()),l&&(f.frames=u(l)),a&&(f.config=u(t._context,!0)),\"object\"===n?f:JSON.stringify(f)},x.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},x.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=x.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=x.extendTrace(u.data[a],s.data[r]))}return u},x.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},x.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,l,u,f=c.extendDeepNoArrays({},e||{}),h=c.expandObjectPaths(f),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=c.nestedProperty(h,r[a])).get())?c.nestedProperty(p,r[a]).set(null):(n.set(null),c.nestedProperty(p,r[a]).set(i));if(t=c.extendDeepNoArrays(t||{},h),r&&r.length)for(a=0;a<r.length;a++)if(l=c.nestedProperty(p,r[a]).get()){for(u=(s=c.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<l.length;o++){var d=l[o];u[o]=null===d?null:x.extendObjectWithContainers(u[o],d)}s.set(u)}return t},x.dataArrayContainers=[\"transforms\",\"dimensions\"],x.layoutArrayContainers=o.layoutArrayContainers,x.extendTrace=function(t,e){return x.extendObjectWithContainers(t,e,x.dataArrayContainers)},x.extendLayout=function(t,e){return x.extendObjectWithContainers(t,e,x.layoutArrayContainers)},x.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},l=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],f=t._fullData[u]._module;if(f){if(f.animatable){var h=f.basePlotModule.name;s[h]||(s[h]=[]),s[h].push(u)}t.data[a[o]]=x.extendTrace(t.data[a[o]],e[o])}}var p=c.expandObjectPaths(c.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;x.extendLayout(t.layout,p),delete t.calcdata,x.supplyDefaults(t),x.doCalcdata(t);var m=c.expandObjectPaths(r);if(m){var v=t._fullLayout._plots;for(var y in v){var b=v[y],_=b.xaxis,w=b.yaxis,T=_.range.slice(),k=w.range.slice(),M=null,A=null,S=null,E=null;Array.isArray(m[_._name+\".range\"])?M=m[_._name+\".range\"].slice():Array.isArray((m[_._name]||{}).range)&&(M=m[_._name].range.slice()),Array.isArray(m[w._name+\".range\"])?A=m[w._name+\".range\"].slice():Array.isArray((m[w._name]||{}).range)&&(A=m[w._name].range.slice()),T&&M&&(_.r2l(T[0])!==_.r2l(M[0])||_.r2l(T[1])!==_.r2l(M[1]))&&(S={xr0:T,xr1:M}),k&&A&&(w.r2l(k[0])!==w.r2l(A[0])||w.r2l(k[1])!==w.r2l(A[1]))&&(E={yr0:k,yr1:A}),(S||E)&&l.push(c.extendFlat({plotinfo:b},S,E))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=l.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,l,a,e);for(var f in u?((n=c.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var h=s[f];t._fullData[h[0]]._module.basePlotModule.plot(t,h,n,e)}},I(t,a,o)},x.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var l=t[a],u=l.xaxis,f=l.yaxis,h=n[u._name].range.slice(),p=n[f._name].range.slice(),d=u.range.slice(),g=f.range.slice();u.setScale(),f.setScale();var m=null,v=null;u.r2l(h[0])===u.r2l(d[0])&&u.r2l(h[1])===u.r2l(d[1])||(m={xr0:h,xr1:d}),f.r2l(p[0])===f.r2l(g[0])&&f.r2l(p[1])===f.r2l(g[1])||(v={yr0:p,yr1:g}),(m||v)&&s.push(c.extendFlat({plotinfo:l},m,v))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,l=t._fullData,u=t._fullLayout._basePlotModules,f=[],h=0;h<l.length;h++)f.push(h);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=c.extendFlat({},a,{duration:0}),o=f,i=a,setTimeout(p,a.duration),d()):(n=a,o=null,i=c.extendFlat({},a,{duration:0}),setTimeout(d,n.duration),p()):s.length?(n=a,p()):e.anim&&(o=f,i=a,d())},I(t,a,o)},x.doCalcdata=function(t,e){var r,n,i,a,l=h.list(t),u=t._fullData,p=t._fullLayout,d=new Array(u.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._treemapcolormap={},p._funnelareacolormap={},i=0;i<u.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<u.length;i++)(r=u[i])._arrayAttrs=s.findArrayAttributes(r),r._extremes={};var m=p._subplots.polar||[];for(i=0;i<m.length;i++)l.push(p[m[i]].radialaxis,p[m[i]].angularaxis);for(var v in p._colorAxes){var y=p[v];!1!==y.cauto&&(delete y.cmin,delete y.cmax)}var x=!1;function _(e){if(r=u[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(a=0;a<r.transforms.length;a++){var o=r.transforms[a];(n=b[o.type])&&n.calcTransform&&(r._hasCalcTransform=!0,x=!0,n.calcTransform(t,r,o))}}}function w(e,i){if(r=u[e],!!(n=r._module).isContainer===i){var o=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var s=r.transforms||[];for(a=s.length-1;a>=0;a--)if(s[a].enabled){r._indexToPoints=s[a]._indexToPoints;break}n&&n.calc&&(o=n.calc(t,r))}Array.isArray(o)&&o[0]||(o=[{x:f,y:f}]),o[0].t||(o[0].t={}),o[0].trace=r,d[e]=o}}for(z(l,u,p),i=0;i<u.length;i++)w(i,!0);for(i=0;i<u.length;i++)_(i);for(x&&z(l,u,p),i=0;i<u.length;i++)w(i,!0);for(i=0;i<u.length;i++)w(i,!1);O(t);var T=function(t,e){var r,n,i,a,s,l=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e||s&&t===n[e].length-1||l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return c.aggNums(Math.min,null,t)},max:function(t){return c.aggNums(Math.max,null,t)},sum:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},total:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},mean:function(t){return c.mean(t)},median:function(t){return c.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(P);if(d){var g=d[1],m=d[2],v=p._id.charAt(0),y=\"x\"===v,x=[];for(n=0;n<p._categories.length;n++)x.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var b=p._traceIndices[n],_=e._fullData[b];if(!0===_.visible){var w=_.type;o.traceIs(_,\"histogram\")&&(delete _._xautoBinFinished,delete _._yautoBinFinished);var T=\"splom\"===w,k=\"scattergl\"===w,M=e.calcdata[b];for(i=0;i<M.length;i++){var A,S,E=M[i];if(T){var C=_._axesDim[p._id];if(!y){var L=_._diag[C][0];L&&(p=e._fullLayout[h.id2name(L)])}var I=E.trace.dimensions[C].values;for(a=0;a<I.length;a++)for(A=p._categoriesMap[I[a]],s=0;s<E.trace.dimensions.length;s++)if(s!==C){var z=E.trace.dimensions[s];x[A][1].push(z.values[a])}}else if(k){for(a=0;a<E.t.x.length;a++)y?(A=E.t.x[a],S=E.t.y[a]):(A=E.t.y[a],S=E.t.x[a]),x[A][1].push(S);E.t&&E.t._scene&&delete E.t._scene.dirty}else if(E.hasOwnProperty(\"z\")){S=E.z;var O=u(_.type,p,S);for(a=0;a<S.length;a++)for(s=0;s<S[a].length;s++)(A=O(s,a))+1&&x[A][1].push(S[a][s])}else for(void 0===(A=E.p)&&(A=E[v]),void 0===(S=E.s)&&(S=E.v),void 0===S&&(S=y?E.y:E.x),Array.isArray(S)||(S=void 0===S?[]:[S]),a=0;a<S.length;a++)x[A][1].push(S[a])}}}p._categoriesValue=x;var D=[];for(n=0;n<x.length;n++)D.push([x[n][0],f[g](x[n][1])]);D.sort((function(t,e){return t[1]-e[1]})),p._categoriesAggregatedValue=D,p._initialCategories=D.map((function(t){return t[0]})),\"descending\"===m&&p._initialCategories.reverse(),l=l.concat(p.sortByInitialCategories())}}}return l}(l,t);if(T.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<T.length;i++)w(T[i],!0);for(i=0;i<T.length;i++)w(T[i],!1);O(t)}o.getComponentMethod(\"fx\",\"calc\")(t),o.getComponentMethod(\"errorbars\",\"calc\")(t)};var P=/(total|sum|min|max|mean|median) (ascending|descending)/;function z(t,e,r){var n={};function i(t){t.clearCalc(),\"multicategory\"===t.type&&t.setupMultiCategory(e),n[t._id]=1}c.simpleMap(t,i);for(var a=r._axisMatchGroups||[],o=0;o<a.length;o++)for(var s in a[o])n[s]||i(r[h.id2name(s)])}function O(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],l=s.crossTraceCalc;if(l){var u=s.basePlotModule.name;o[u]?c.pushUnique(o[u],l):o[u]=[l]}}for(n in o){var f=o[n],h=i._subplots[n];if(Array.isArray(h))for(e=0;e<h.length;e++){var p=h[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<f.length;r++)f[r](t,d,p)}else for(r=0;r<f.length;r++)f[r](t)}}x.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},x.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},x.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],l=s[0].trace;l.visible&&(o[l.type]=o[l.type]||[],o[l.type].push(s))}for(var u in a)if(!o[u]){var f=a[u][0];f[0].trace.visible=!1,o[u]=[f]}for(var h in o){var p=o[h];p[0][0].trace._module.plot(t,e,c.filterVisible(p),n)}e.traceHash=o},x.plotBasePlot=function(t,e,r,n,i){var a=o.getModule(t),s=m(e.calcdata,a)[0];a.plot(e,s,n,i)},x.cleanBasePlot=function(t,e,r,n,i){var a=i._has&&i._has(t),o=r._has&&r._has(t);a&&!o&&i[\"_\"+t+\"layer\"].selectAll(\"g.trace\").remove()}},{\"../components/color\":643,\"../constants/numerical\":753,\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plot_api/plot_template\":817,\"../plots/get_data\":865,\"../registry\":911,\"./animation_attributes\":822,\"./attributes\":824,\"./cartesian/axis_ids\":831,\"./cartesian/handle_outline\":838,\"./command\":854,\"./font_attributes\":856,\"./frame_attributes\":857,\"./layout_attributes\":882,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],892:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=f(Math.sin(e)-Math.sin(t)),c=f(Math.cos(e)-Math.cos(t)),u=Math.tan(r),h=f(1/u),p=l/c,d=s-p*o;return h?l&&c?a=u*(i=d/(u-p)):c?(i=s*h,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,f=i.length,h=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,f)}function m(t){return o(t,[e,r])}var v=a(i,(function(t){return m(t)?l(t,e):1/0})),y=d(i[v],i[g(v-1)],e);for(h.push(y),s=v,u=0;u<f;s++,u++){var x=i[g(s)];if(!m(x))break;h.push(p(x))}var b=a(i,(function(t){return m(t)?l(t,r):1/0})),_=d(i[b],i[g(b+1)],r);return h.push(_),h.push([0,0]),h.push(h[0].slice()),h}(t,e,r,i)}function f(t){return Math.abs(t)>1e-10?t:0}function h(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),f=i(u(l,n[0],n[1],a)),h=[t*Math.cos(e),t*Math.sin(e)];return f.contains(h)&&!c.contains(h)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,(function(e){var r=s(e,t);return r>0?r:1/0})),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:f,pathPolygon:function(t,e,r,n,i,a){return\"M\"+h(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=h(u(s,r,n,i),a,o);return\"M\"+h(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":778,\"../../lib/polygon\":790}],894:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],f=n[u]._subplot;if(!e[u]&&f)for(var h in f.framework.remove(),f.layers[\"radial-axis-title\"].remove(),f.clipPaths)f.clipPaths[h].remove();s&&f._scene&&(f._scene.destroy(),f._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":778,\"../cartesian\":841,\"../get_data\":865,\"./constants\":892,\"./layout_attributes\":895,\"./layout_defaults\":896,\"./polar\":903}],895:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:{text:o({},i.title.text,{editType:\"plot\",dflt:\"\"}),font:o({},i.title.font,{editType:\"plot\"}),editType:\"plot\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};o(u,l,c);var f={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:i.autotypenumbers,categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(f,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:f,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":642,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../cartesian/layout_attributes\":842,\"../domain\":855}],896:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),f=t(\"../cartesian/category_order_defaults\"),h=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),m=t(\"./constants\"),v=m.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,m.name,o.id),w=o.layoutOut;function T(t,e){return r(b+\".\"+t,e)}for(var k=0;k<v.length;k++){b=v[k],n.isPlainObject(t[b])||(t[b]={});var M=t[b],A=a.newContainer(e,b);A._id=A._name=b,A._attr=o.id+\".\"+b,A._traceIndices=_.map((function(t){return t._expandedIndex}));var S=m.axisName2dataArray[b],E=x(M,A,T,_,S,o);f(M,A,T,{axData:_,dataAttr:S});var C,L,I=T(\"visible\");switch(g(A,e,w),T(\"uirevision\",e.uirevision),I&&(L=(C=T(\"color\"))===M.color?C:o.font.color),A._m=1,b){case\"radialaxis\":var P=T(\"autorange\",!A.isValidRange(M.range));M.autorange=P,!P||\"linear\"!==E&&\"-\"!==E||T(\"rangemode\"),\"reversed\"===P&&(A._m=-1),T(\"range\"),A.cleanRange(\"range\",{dfltRange:[0,1]}),I&&(T(\"side\"),T(\"angle\",y[0]),T(\"title.text\"),n.coerceFont(T,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=M.type=A.type=\"linear\"}T(\"linear\"===E?\"thetaunit\":\"period\");var O=T(\"direction\");T(\"rotation\",{counterclockwise:0,clockwise:90}[O])}if(I)l(M,A,T,A.type),u(M,A,T,A.type,{tickSuffixDflt:\"degrees\"===A.thetaunit?\"\\xb0\":void 0}),c(M,A,T,{outerTicks:!0}),T(\"showticklabels\")&&(n.coerceFont(T,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),T(\"tickangle\"),T(\"tickformat\")),h(M,A,T,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),T(\"layer\");\"category\"!==E&&T(\"hoverformat\"),A._input=M}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i,a){var o=r(\"autotypenumbers\",a.autotypenumbersDflt);if(\"-\"===r(\"type\")){for(var s,l=0;l<n.length;l++)if(n[l].visible){s=n[l];break}s&&s[i]&&(e.type=p(s[i],\"gregorian\",{noMultiCategory:!0,autotypenumbers:o})),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:m.name,attributes:d,handleDefaults:y,font:e.font,autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../cartesian/axis_autotype\":829,\"../cartesian/category_order_defaults\":832,\"../cartesian/line_grid_defaults\":844,\"../cartesian/tick_label_defaults\":849,\"../cartesian/tick_mark_defaults\":850,\"../cartesian/tick_value_defaults\":851,\"../get_data\":865,\"../subplot_defaults\":905,\"./constants\":892,\"./layout_attributes\":895,\"./set_convert\":904}],897:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":768,\"../../../traces/scatter/attributes\":1187}],898:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":768,\"../../../plot_api/edit_types\":810,\"../../cartesian/layout_attributes\":842}],899:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":900,\"./micropolar_manager\":901}],900:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},f=n.dispatch(\"hover\"),h={};return h.render=function(c){return function(c){e=c||e;var f=l.data,h=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(f).each((function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(h)};var f=0;c.forEach((function(t,e){t.color||(t.color=h.defaultColorRange[f],f=(f+1)%h.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize}));var p=c.filter((function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r})),d=!1,g=p.map((function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t}));if(d){var m=n.nest().key((function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"})).entries(g),v=[],y=m.map((function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map((function(t,e){return 0}));return t.values.forEach((function(t,e,n){t.yStack=[r],v.push(r),r=o.util.sumArrays(t.r,r)})),t.values}));p=n.merge(y)}p.forEach((function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]}));var x=Math.min(h.width-h.margin.left-h.margin.right,h.height-h.margin.top-h.margin.bottom)/2;x=Math.max(10,x);var b,_=[h.margin.left+x,h.margin.top+x];d?b=[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(v)))]:b=n.extent(o.util.flattenArray(p.map((function(t,e){return t.r}))));h.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(h.radialAxis.domain!=o.DATAEXTENT&&h.radialAxis.domain?h.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,T=o.util.flattenArray(p.map((function(t,e){return t.t}))),k=\"string\"==typeof T[0];k&&(T=o.util.deduplicate(T),w=T.slice(),T=n.range(T.length),p=p.map((function(t,e){var r=t;return t.t=[T],d&&(r.yStack=t.yStack),r})));var M=p.filter((function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry})).length===p.length,A=null===h.needsEndSpacing?k||!M:h.needsEndSpacing,S=h.angularAxis.domain&&h.angularAxis.domain!=o.DATAEXTENT&&!k&&h.angularAxis.domain[0]>=0?h.angularAxis.domain:n.extent(T),E=Math.abs(T[1]-T[0]);M&&!k&&(E=0);var C=S.slice();A&&k&&(C[1]+=E);var L=h.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),h.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var I=h.angularAxis.ticksStep||(C[1]-C[0])/(L*(h.minorTicks+1));w&&(I=Math.max(Math.round(I),1)),C[2]||(C[2]=I);var P=n.range.apply(this,C);if(P=P.map((function(t,e){return parseFloat(t.toPrecision(12))})),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===h.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=A?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),O=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(O)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:h.tickColor},B={\"font-size\":h.font.size,\"font-family\":h.font.family,fill:h.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map((function(t,e){return\" \"+t+\" 0 \"+h.font.outlineColor})).join(\",\")};if(h.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,h.margin.top]+\")\"}).style({display:\"block\"});var N=p.map((function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r}));o.Legend().config({data:p.map((function(t,e){return t.name||\"Element\"+e})),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:h.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(h.width-j.width-h.margin.left-h.margin.right,h.height-h.margin.top-h.margin.bottom)/2,x=Math.max(10,x),_=[h.margin.left+x,h.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:h.width,height:h.height}).style({opacity:h.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(h.width-(h.margin.left+h.margin.right+2*x+(j?j.width:0)))/2,(h.height-(h.margin.top+h.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),h.title&&h.title.text){var V=t.select(\"g.title-group text\").style(B).text(h.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(h.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:h.backgroundColor,stroke:h.stroke});function W(t,e){return s(t)%360+h.orientation}if(h.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+h.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text((function(t,e){return this.textContent+h.radialAxis.ticksSuffix})).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===h.radialAxis.tickOrientation?\"rotate(\"+-h.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(P),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:h.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",(function(t,e){return e%(h.minorTicks+1)==0})).classed(\"minor\",(function(t,e){return!(e%(h.minorTicks+1)==0)})).style(F),J.selectAll(\".minor\").style({stroke:h.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:h.tickLength?x-h.tickLength:0,x2:x}).style({display:h.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+h.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+h.labelOffset,i=h.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:h.angularAxis.labelsVisible?\"block\":\"none\"}).text((function(t,e){return e%(h.minorTicks+1)!=0?\"\":w?w[t]+h.angularAxis.ticksSuffix:t+h.angularAxis.ticksSuffix})).style(B);h.angularAxis.rewriteTicks&&K.text((function(t,e){return e%(h.minorTicks+1)!=0?\"\":h.angularAxis.rewriteTicks(this.textContent,e)}));var Q=n.max(R.selectAll(\".angular-tick text\")[0].map((function(t,e){return t.getCTM().e+t.getBBox().width})));D.attr({transform:\"translate(\"+[x+Q,h.margin.top]+\")\"});var $=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||$){var et=[];p.forEach((function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter((function(t,r){return r==e})),n.geometry=t.geometry,n.orientation=h.orientation,n.direction=h.direction,n.index=e,et.push({data:t,geometryConfig:n})}));var rt=n.nest().key((function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"})).entries(et),nt=[];rt.forEach((function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map((function(t,e){return[t]}))):nt.push(t.values)})),nt.forEach((function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map((function(t,e){return i(o[r].defaultConfig(),t)}));o[r]().config(n)()}))}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!k){var ft=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",(function(t,e){var r=o.util.getMousePos(Y).angle;ft.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-h.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])})).on(\"mouseout.angular-guide\",(function(t,e){ot.select(\"line\").style({opacity:0})}))}var ht=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",(function(t,e){var n=o.util.getMousePos(Y).radius;ht.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,h.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])})).on(\"mouseout.radial-guide\",(function(t,e){ht.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()})),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",(function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};k&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,f=this.getBoundingClientRect(),h=t.node().getBoundingClientRect(),p=[f.left+f.width/2-U[0]-h.left,f.top+f.height/2-U[1]-h.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})})).on(\"mousemove.tooltip\",(function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()})).on(\"mouseout.tooltip\",(function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})}))}))}(c),this},h.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach((function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)})),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},h.getLiveConfig=function(){return u},h.getinputConfig=function(){return c},h.radialScale=function(t){return r},h.angularScale=function(t){return s},h.svg=function(){return t},n.rebind(h,f,\"on\"),h},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map((function(e,r){var n=e*Math.PI/180;return[e,t(n)]}))},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach((function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)}));var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map((function(t,e){return r[e]||r[0]}))},o.util.fillArrays=function(t,e,r){return e.forEach((function(e,n){t[e]=o.util.ensureArray(t[e],r)})),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map((function(t,e){return n.sum(t)}))},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter((function(t,e,r){return r.indexOf(t)==e}))},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce((function(t,e){if(\"undefined\"!=typeof t)return t[e]}),t);\"undefined\"!=typeof a&&(e.reduce((function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]}),t),r.reduce((function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]}),t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each((function(t,i){var a=!!t[0].data.yStack,o=t.map((function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])})),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius((function(t){return e.radialScale(t[1])})).angle((function(t){return e.angularScale(t[0])*Math.PI/180}));c.line=function(r,i,a){var s=r[2]?o[a].map((function(t,e){return[t[0],t[1]+t[2]]})):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var f=e.angularScale.range(),h=Math.abs(f[1]-f[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle((function(t){return-h/2})).endAngle((function(t){return h/2})).innerRadius((function(t){return e.radialScale(l+(t[2]||0))})).outerRadius((function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])}));c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var m=g.selectAll(\"path.mark\").data((function(t,e){return t}));m.enter().append(\"path\").attr({class:\"mark\"}),m.style(d).each(c[e.geometryType]),m.exit().remove(),g.exit().remove()}))}return a.config=function(e){return arguments.length?(e.forEach((function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)})),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map((function(t,r){return[].concat(t).map((function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a}))})),o=n.merge(a);o=o.filter((function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)})),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map((function(t,e){return t.color})),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,f=u?e.height:c*o.length,h=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=h.enter().append(\"svg\").attr({width:300,height:f+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),m=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,f]);if(u){var v=h.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);v.enter().append(\"stop\"),v.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),h.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=h.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,m(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(m).orient(\"right\"),b=h.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text((function(t,e){return o[e].name})),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",f=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(f);var h=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*h+l,m=p.height+2*h;return r.attr({d:\"M\"+[[l,-m/2],[l,-m/4],[a.hasTick?0:l,0],[l,m/4],[l,m/2],[g,m/2],[g,-m/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-m/2+2*h]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map((function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach((function(t,r){o.util.translator.apply(null,t.concat(e))})),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n})),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map((function(t,e){return t.geometry})));r.data.forEach((function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)}))}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach((function(t,r){o.util.translator.apply(null,t.concat(e))})),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach((function(t,e){u[c[l.indexOf(t.key)]]=t.value})),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":745,\"../../../lib\":778,d3:169}],901:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,f=new s;function h(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return h.isPolar=!0,h.svg=function(){return i.svg()},h.getConfig=function(){return e},h.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},h.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},h.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,f.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},h.undo=function(){f.undo()},h.redo=function(){f.redo()},h},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":643,\"../../../lib\":778,\"./micropolar\":900,\"./undo_manager\":902,d3:169}],902:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n||(e.splice(r+1,e.length-r),e.push(t),r=e.length-1),this},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],903:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o.strRotate,l=o.strTranslate,c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../plots\"),h=t(\"../../plots/cartesian/axes\"),p=t(\"../cartesian/set_convert\"),d=t(\"./set_convert\"),g=t(\"../cartesian/autorange\").doAutoRange,m=t(\"../cartesian/dragbox\"),v=t(\"../../components/dragelement\"),y=t(\"../../components/fx\"),x=t(\"../../components/titles\"),b=t(\"../cartesian/select\").prepSelect,_=t(\"../cartesian/select\").selectOnClick,w=t(\"../cartesian/select\").clearSelect,T=t(\"../../lib/setcursor\"),k=t(\"../../lib/clear_gl_canvases\"),M=t(\"../../plot_api/subroutines\").redrawReglTraces,A=t(\"../../constants/alignment\").MID_SHIFT,S=t(\"./constants\"),E=t(\"./helpers\"),C=o._,L=o.mod,I=o.deg2rad,P=o.rad2deg;function z(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=z.prototype;function D(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function R(t,e){return e[o.findIndexOfMin(e,(function(e){return o.angleDist(t,e)}))]}function F(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}e.exports=function(t,e){return new z(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),f.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=S.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var f=this.framework.selectAll(\".polarsublayer\").data(l,String);f.enter().append(\"g\").attr(\"class\",(function(t){return\"polarsublayer \"+t})).each((function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}})),f.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,s=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-s[1]);var f=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(s[1]-s[0]),p=e.sector;this.sectorInRad=p.map(I);var d,g,m,v,y,x=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=L(a,360),l=s+o,c=Math.cos(I(s)),u=Math.sin(I(s)),f=Math.cos(I(l)),h=Math.sin(I(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&h<=0?0:Math.max(u,h);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&f>=0?0:Math.min(c,f);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&h>=0?0:Math.min(u,h);n=l>=360?1:c<=0&&f<=0?0:Math.max(c,f);return[e,r,n,i]}(p),b=x[2]-x[0],_=x[3]-x[1],w=h/f,T=Math.abs(_/b);w>T?(d=f,y=(h-(g=f*T))/n.h/2,m=[o[0],o[1]],v=[s[0]+y,s[1]-y]):(g=h,y=(f-(d=h/T))/n.w/2,m=[o[0]+y,o[1]-y],v=[s[0],s[1]]),this.xLength2=d,this.yLength2=g,this.xDomain2=m,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*m[0],M=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=d/b,S=this.innerRadius=e.hole*A,E=this.cx=k-A*x[0],C=this.cy=M+A*x[3],P=this.cxx=E-k,z=this.cyy=C-M;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],_realSide:i.side,domain:[S/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:m}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var O=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",O).attr(\"transform\",l(P,z)),r.frontplot.attr(\"transform\",l(k,M)).call(u.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",O).attr(\"transform\",l(E,C)).call(c.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({},r,n);return d(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);p(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),g(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,f=r.cx,p=r.cy,d=e.radialaxis,g=L(e.sector[0],360),m=r.radialAxis,v=u<a;r.fillViewInitialKey(\"radialaxis.angle\",d.angle),r.fillViewInitialKey(\"radialaxis.range\",m.range.slice()),m.setGeometry(),\"auto\"===m.tickangle&&g>90&&g<=270&&(m.tickangle=180);var y=function(t){return l(m.l2p(t.x)+u,0)},x=D(d);if(r.radialTickLayout!==x&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=x),v){m.setScale();var b=h.calcTicks(m),_=h.clipEnds(m,b),w=h.getTickSigns(m)[2];h.drawTicks(n,m,{vals:b,layer:i[\"radial-axis\"],path:h.makeTickPath(m,0,w),transFn:y,crisp:!1}),h.drawGrid(n,m,{vals:_,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(m.r2p(t.x)+u)},transFn:o.noop,crisp:!1}),h.drawLabels(n,m,{vals:b,layer:i[\"radial-axis\"],transFn:y,labelFns:h.makeLabelFns(m,0)})}var T=r.radialAxisAngle=r.vangles?P(R(I(d.angle),r.vangles)):d.angle,k=l(f,p),M=k+s(-T);F(i[\"radial-axis\"],v&&(d.showticklabels||d.ticks),{transform:M}),F(i[\"radial-grid\"],v&&d.showgrid,{transform:k}),F(i[\"radial-line\"].select(\"line\"),v&&d.showline,{x1:u,y1:0,x2:a,y2:0,transform:M}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,l=this.id+\"title\",c=void 0!==r?r:this.radialAxisAngle,f=I(c),h=Math.cos(f),p=Math.sin(f),d=0;if(s.title){var g=u.bBox(this.layers[\"radial-axis\"].node()).height,m=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*m:g+.8*m}this.layers[\"radial-axis-title\"]=x.draw(n,l,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:C(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*h+d*p,y:o-i/2*p+d*h,\"text-anchor\":\"middle\"},transform:{rotate:-c}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,f=r.cx,p=r.cy,d=e.angularaxis,g=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",d.rotation),g.setGeometry(),g.setScale();var m=function(t){return g.t2g(t.x)};\"linear\"===g.type&&\"radians\"===g.thetaunit&&(g.tick0=P(g.tick0),g.dtick=P(g.dtick));var v=function(t){return l(f+a*Math.cos(t),p-a*Math.sin(t))},y=h.makeLabelFns(g,0).labelStandoff,x={xFn:function(t){var e=m(t);return Math.cos(e)*y},yFn:function(t){var e=m(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(y+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*A)},anchorFn:function(t){var e=m(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=m(t);return-.5*(1+Math.sin(n))*r}},b=D(d);r.angularTickLayout!==b&&(i[\"angular-axis\"].selectAll(\".\"+g._id+\"tick\").remove(),r.angularTickLayout=b);var _,w=h.calcTicks(g);if(\"linear\"===e.gridshape?(_=w.map(m),o.angleDelta(_[0],_[1])<0&&(_=_.slice().reverse())):_=null,r.vangles=_,\"category\"===g.type&&(w=w.filter((function(t){return o.isAngleInsideSector(m(t),r.sectorInRad)}))),g.visible){var T=\"inside\"===g.ticks?-1:1,k=(g.linewidth||1)/2;h.drawTicks(n,g,{vals:w,layer:i[\"angular-axis\"],path:\"M\"+T*k+\",0h\"+T*g.ticklen,transFn:function(t){var e=m(t);return v(e)+s(-P(e))},crisp:!1}),h.drawGrid(n,g,{vals:w,layer:i[\"angular-grid\"],path:function(t){var e=m(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[f+u*r,p-u*n]+\"L\"+[f+a*r,p-a*n]},transFn:o.noop,crisp:!1}),h.drawLabels(n,g,{vals:w,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return v(m(t))},labelFns:x})}F(i[\"angular-line\"].select(\"path\"),d.showline,{d:r.pathSubplot(),transform:l(f,p)}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e,r,s=this,c=s.gd,u=s.layers,f=t._zoomlayer,h=S.MINZOOM,p=S.OFFEDGE,d=s.radius,g=s.innerRadius,x=s.cx,T=s.cy,k=s.cxx,M=s.cyy,A=s.sectorInRad,C=s.vangles,L=s.radialAxis,I=E.clampTiny,P=E.findXYatLength,z=E.findEnclosingVertexAngles,O=S.cornerHalfWidth,D=S.cornerLen/2,R=m.makeDragger(u,\"path\",\"maindrag\",\"crosshair\");n.select(R).attr(\"d\",s.pathSubplot()).attr(\"transform\",l(x,T));var F,B,N,j,U,V,q,H,G,Y={element:R,gd:c,subplot:s.id,plotinfo:{id:s.id,xaxis:s.xaxis,yaxis:s.yaxis},xaxes:[s.xaxis],yaxes:[s.yaxis]};function W(t,e){return Math.sqrt(t*t+e*e)}function X(t,e){return W(t-k,e-M)}function Z(t,e){return Math.atan2(M-e,t-k)}function J(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function K(t,e){if(0===t)return s.pathSector(2*O);var r=D/t,n=e-r,i=e+r,a=Math.max(0,Math.min(t,d)),o=a-O,l=a+O;return\"M\"+J(o,n)+\"A\"+[o,o]+\" 0,0,0 \"+J(o,i)+\"L\"+J(l,i)+\"A\"+[l,l]+\" 0,0,1 \"+J(l,n)+\"Z\"}function Q(t,e,r){if(0===t)return s.pathSector(2*O);var n,i,a=J(t,e),o=J(t,r),l=I((a[0]+o[0])/2),c=I((a[1]+o[1])/2);if(l&&c){var u=c/l,f=-1/u,h=P(O,u,l,c);n=P(D,f,h[0][0],h[0][1]),i=P(D,f,h[1][0],h[1][1])}else{var p,d;c?(p=D,d=O):(p=O,d=D),n=[[l-p,c-d],[l+p,c-d]],i=[[l-p,c+d],[l+p,c+d]]}return\"M\"+n.join(\"L\")+\"L\"+i.reverse().join(\"L\")+\"Z\"}function $(t,e){return e=Math.max(Math.min(e,d),g),t<p?t=0:d-t<p?t=d:e<p?e=0:d-e<p&&(e=d),Math.abs(e-t)>h?(t<e?(N=t,j=e):(N=e,j=t),!0):(N=null,j=null,!1)}function tt(t,e){t=t||U,e=e||\"M0,0Z\",H.attr(\"d\",t),G.attr(\"d\",e),m.transitionZoombox(H,G,V,q),V=!0;var r={};at(r),c.emit(\"plotly_relayouting\",r)}function et(t,n){var i,a,o=F+(t*=e),l=B+(n*=r),c=X(F,B),u=Math.min(X(o,l),d),f=Z(F,B);$(c,u)&&(i=U+s.pathSector(j),N&&(i+=s.pathSector(N)),a=K(N,f)+K(j,f)),tt(i,a)}function rt(t,e,r,n){var i=E.findIntersectionXY(r,n,r,[t-k,M-e]);return W(i[0],i[1])}function nt(t,e){var r,n,i=F+t,a=B+e,o=Z(F,B),l=Z(i,a),c=z(o,C),u=z(l,C);$(rt(F,B,c[0],c[1]),Math.min(rt(i,a,u[0],u[1]),d))&&(r=U+s.pathSector(j),N&&(r+=s.pathSector(N)),n=[Q(N,c[0],c[1]),Q(j,c[0],c[1])].join(\" \")),tt(r,n)}function it(){if(m.removeZoombox(c),null!==N&&null!==j){var t={};at(t),m.showDoubleClickNotifier(c),a.call(\"_guiRelayout\",c,t)}}function at(t){var e=L._rl,r=(e[1]-e[0])/(1-g/d)/d,n=[e[0]+(N-g)*r,e[0]+(j-g)*r];t[s.id+\".radialaxis.range\"]=n}function ot(t,e){var r=c._fullLayout.clickmode;if(m.removeZoombox(c),2===t){var n={};for(var i in s.viewInitial)n[s.id+\".\"+i]=s.viewInitial[i];c.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",c,n)}r.indexOf(\"select\")>-1&&1===t&&_(e,c,[s.xaxis],[s.yaxis],s.id,Y),r.indexOf(\"event\")>-1&&y.click(c,e,s.id)}Y.prepFn=function(t,n,a){var l=c._fullLayout.dragmode,u=R.getBoundingClientRect();c._fullLayout._calcInverseTransform(c);var h=c._fullLayout._invTransform;e=c._fullLayout._invScaleX,r=c._fullLayout._invScaleY;var p=o.apply3DTransform(h)(n-u.left,a-u.top);if(F=p[0],B=p[1],C){var g=E.findPolygonOffset(d,A[0],A[1],C);F+=k+g[0],B+=M+g[1]}switch(l){case\"zoom\":Y.moveFn=C?nt:et,Y.clickFn=ot,Y.doneFn=it,function(){N=null,j=null,U=s.pathSubplot(),V=!1;var t=c._fullLayout[s.id];q=i(t.bgcolor).getLuminance(),(H=m.makeZoombox(f,q,x,T,U)).attr(\"fill-rule\",\"evenodd\"),G=m.makeCorners(f,x,T),w(c)}();break;case\"select\":case\"lasso\":b(t,n,a,Y,l)}},R.onmousemove=function(t){y.hover(c,t,s.id),c._fullLayout._lasthover=R,c._fullLayout._hoversubplot=s.id},R.onmouseout=function(t){c._dragging||v.unhover(c,t)},v.init(Y)},O.updateRadialDrag=function(t,e,r){var i=this,c=i.gd,u=i.layers,f=i.radius,h=i.innerRadius,p=i.cx,d=i.cy,g=i.radialAxis,y=S.radialDragBoxSize,x=y/2;if(g.visible){var b,_,T,A=I(i.radialAxisAngle),E=g._rl,C=E[0],L=E[1],z=E[r],O=.75*(E[1]-E[0])/(1-e.hole)/f;r?(b=p+(f+x)*Math.cos(A),_=d-(f+x)*Math.sin(A),T=\"radialdrag\"):(b=p+(h-x)*Math.cos(A),_=d-(h-x)*Math.sin(A),T=\"radialdrag-inner\");var D,B,N,j=m.makeRectDragger(u,T,\"crosshair\",-x,-x,y,y),U={element:j,gd:c};F(n.select(j),g.visible&&h<f,{transform:l(b,_)}),U.prepFn=function(){D=null,B=null,N=null,U.moveFn=V,U.doneFn=q,w(c)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<S.MINDRAG&&(t=0,e=0),[t,e]},v.init(U)}function V(t,e){if(D)D(t,e);else{var n=[t,-e],a=[Math.cos(A),Math.sin(A)],s=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(s)||(D=s<.5?H:G)}var l={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(l),c.emit(\"plotly_relayouting\",l)}function q(){null!==B?a.call(\"_guiRelayout\",c,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",c,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=b+t,a=_+e;B=Math.atan2(d-a,n-p),i.vangles&&(B=R(B,i.vangles)),B=P(B);var o=l(p,d)+s(-B);u[\"radial-axis\"].attr(\"transform\",o),u[\"radial-line\"].select(\"line\").attr(\"transform\",o);var c=i.gd._fullLayout,f=c[i.id];i.updateRadialAxisTitle(c,f,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(A),Math.sin(A)]);if(N=z-O*n,O>0==(r?N>C:N<L)){var s=c._fullLayout,l=s[i.id];g.range[r]=N,g._rl[r]=N,i.updateRadialAxis(s,l),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var f in i.traceHash){var h=i.traceHash[f],p=o.filterVisible(h);h[0][0].trace._module.plot(c,i,p,l),a.traceIs(f,\"gl\")&&p.length&&(u=!0)}u&&(k(c),M(c))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,c=e.radius,f=e.angularAxis,h=e.cx,p=e.cy,d=e.cxx,g=e.cyy,y=S.angularDragBoxSize,x=m.makeDragger(i,\"path\",\"angulardrag\",\"move\"),b={element:x,gd:r};function _(t,e){return Math.atan2(g+y-e,t-d-y)}n.select(x).attr(\"d\",e.pathAnnulus(c,c+y)).attr(\"transform\",l(h,p)).call(T,\"move\");var A,E,C,L,I,z,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),D=O.selectAll(\".point\"),R=O.selectAll(\".textpoint\");function F(c,m){var v=e.gd._fullLayout,y=v[e.id],x=_(A+c*t._invScaleX,E+m*t._invScaleY),b=P(x-z);if(L=C+b,i.frontplot.attr(\"transform\",l(e.xOffset2,e.yOffset2)+s([-b,d,g])),e.vangles){I=e.radialAxisAngle+b;var w=l(h,p)+s(-b),T=l(h,p)+s(-I);i.bg.attr(\"transform\",w),i[\"radial-grid\"].attr(\"transform\",w),i[\"radial-axis\"].attr(\"transform\",T),i[\"radial-line\"].select(\"line\").attr(\"transform\",T),e.updateRadialAxisTitle(v,y,I)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",l(d,g)+s(b));D.each((function(){var t=n.select(this),e=u.getTranslate(t);t.attr(\"transform\",l(e.x,e.y)+s([b]))})),R.each((function(){var t=n.select(this),e=t.select(\"text\"),r=u.getTranslate(t);t.attr(\"transform\",s([b,e.attr(\"x\"),e.attr(\"y\")])+l(r.x,r.y))})),f.rotation=o.modHalf(L,360),e.updateAngularAxis(v,y),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(u.hideOutsideRangePoints,e);var S=!1;for(var F in e.traceHash)if(a.traceIs(F,\"gl\")){var N=e.traceHash[F],j=o.filterVisible(N);N[0][0].trace._module.plot(r,e,j,y),j.length&&(S=!0)}S&&(k(r),M(r));var U={};B(U),r.emit(\"plotly_relayouting\",U)}function B(t){t[e.id+\".angularaxis.rotation\"]=L,e.vangles&&(t[e.id+\".radialaxis.angle\"]=I)}function N(){R.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}b.prepFn=function(n,i,a){var s=t[e.id];C=s.angularaxis.rotation;var l=x.getBoundingClientRect();A=i-l.left,E=a-l.top,r._fullLayout._calcInverseTransform(r);var c=o.apply3DTransform(t._invTransform)(A,E);A=c[0],E=c[1],z=_(A,E),b.moveFn=F,b.doneFn=N,w(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(b.prepFn=o.noop,T(n.select(x),null)),v.init(b)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?E.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?E.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/titles\":738,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/setcursor\":799,\"../../plot_api/subroutines\":818,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/dragbox\":836,\"../cartesian/select\":847,\"../cartesian/set_convert\":848,\"../plots\":891,\"./constants\":892,\"./helpers\":893,\"./set_convert\":904,d3:169,tinycolor2:576}],904:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",f=\"d\"+i,h=u in e?c(e[u]):0,p=e[f]?c(e[f]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=h+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,f=u.map(a),h={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return h*t+p},g=function(t){return(t-p)/h};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(f)?[u[0],u[0]+360]:f.map(g).map(o);break;case\"category\":var m=t._categories.length,v=t.period?Math.max(t.period,m):m;0===v&&(v=1),s=c=function(t){return 2*t*Math.PI/v},i=l=function(t){return t*v/Math.PI/2},t.range=[0,v]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":778,\"../cartesian/set_convert\":848}],905:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,f=o.handleDefaults,h=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function m(t,e){return n.coerce(s,l,u,t,e)}for(var v=0;v<d;v++){var y=p[v];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),m(\"uirevision\",e.uirevision);var x={};x[h]=[v/d,(v+1)/d],a(l,e,m,x),o.id=y,f(s,l,m,o)}}},{\"../lib\":778,\"../plot_api/plot_template\":817,\"./domain\":855}],906:[function(t,e,r){\"use strict\";['Variables are inserted using %{variable}, for example \"y: %{y}\".','Numbers are formatted using d3-format\\'s syntax %{variable:d3-format}, for example \"Price: %{y:$.2f}\".',t(\"../constants/docs\").FORMAT_LINK,\"for details on the formatting syntax.\",'Dates are formatted using d3-time-format\\'s syntax %{variable|d3-time-format}, for example \"Day: %{2019-01-01|%A}\".',t(\"../constants/docs\").DATE_FORMAT_LINK,\"for details on the date formatting syntax.\"].join(\" \");function n(t){var e=t.description?\" \"+t.description:\"\",r=t.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";e+=\"Finally, the template string has access to \",e=1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}return e}r.hovertemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r},r.texttemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"calc\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r}},{\"../constants/docs\":748}],907:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":778,\"../../plots/get_data\":865,\"./layout_attributes\":908,\"./layout_defaults\":909,\"./ternary\":910}],908:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:{text:a.title.text,font:a.title.font},color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,minexponent:a.minexponent,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../cartesian/layout_attributes\":842,\"../domain\":855}],909:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),f=t(\"./layout_attributes\"),h=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var f=0;f<h.length;f++)s=t[o=h[f]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,m=e.caxis;p.min+g.min+m.min>=u&&(p.min=0,g.min=0,m.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=f[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var h=o(\"color\"),p=h!==i.color.dflt?h:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,m=o(\"title.text\",g);e._hovertitle=m===g?m:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:h,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:f,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../cartesian/line_grid_defaults\":844,\"../cartesian/tick_label_defaults\":849,\"../cartesian/tick_mark_defaults\":850,\"../cartesian/tick_value_defaults\":851,\"../subplot_defaults\":905,\"./layout_attributes\":908}],910:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o.strTranslate,l=o._,c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,p=t(\"../plots\"),d=t(\"../cartesian/axes\"),g=t(\"../../components/dragelement\"),m=t(\"../../components/fx\"),v=t(\"../../components/dragelement/helpers\"),y=v.freeMode,x=v.rectMode,b=t(\"../../components/titles\"),_=t(\"../cartesian/select\").prepSelect,w=t(\"../cartesian/select\").selectOnClick,T=t(\"../cartesian/select\").clearSelect,k=t(\"../cartesian/select\").clearSelectionsCache,M=t(\"../cartesian/constants\");function A(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=A;var S=A.prototype;S.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},S.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),p.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(c.fill,r.bgcolor)},S.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),u.setClipUrl(this.layers.backplot,n,e),u.setClipUrl(this.layers.grids,n,e)},S.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",(function(t){return\"toplevel \"+t})).each((function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach((function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)}))})),i.order()};var E=Math.sqrt(4/3);S.adjustLayout=function(t,e){var r,n,i,a,o,l,p=this,d=t.domain,g=(d.x[0]+d.x[1])/2,m=(d.y[0]+d.y[1])/2,v=d.x[1]-d.x[0],y=d.y[1]-d.y[0],x=v*e.w,b=y*e.h,_=t.sum,w=t.aaxis.min,T=t.baxis.min,k=t.caxis.min;x>E*b?i=(a=b)*E:a=(i=x)/E,o=v*i/x,l=y*a/b,r=e.l+e.w*g-i/2,n=e.t+e.h*(1-m)-a/2,p.x0=r,p.y0=n,p.w=i,p.h=a,p.sum=_,p.xaxis={type:\"linear\",range:[w+2*k-_,_-w-2*T],domain:[g-o/2,g+o/2],_id:\"x\"},f(p.xaxis,p.graphDiv._fullLayout),p.xaxis.setScale(),p.xaxis.isPtWithinRange=function(t){return t.a>=p.aaxis.range[0]&&t.a<=p.aaxis.range[1]&&t.b>=p.baxis.range[1]&&t.b<=p.baxis.range[0]&&t.c>=p.caxis.range[1]&&t.c<=p.caxis.range[0]},p.yaxis={type:\"linear\",range:[w,_-T-k],domain:[m-l/2,m+l/2],_id:\"y\"},f(p.yaxis,p.graphDiv._fullLayout),p.yaxis.setScale(),p.yaxis.isPtWithinRange=function(){return!0};var M=p.yaxis.domain[0],A=p.aaxis=h({},t.aaxis,{range:[w,_-T-k],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[M,M+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});f(A,p.graphDiv._fullLayout),A.setScale();var S=p.baxis=h({},t.baxis,{range:[_-w-k,T],side:\"bottom\",domain:p.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});f(S,p.graphDiv._fullLayout),S.setScale();var C=p.caxis=h({},t.caxis,{range:[_-w-T,k],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[M,M+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});f(C,p.graphDiv._fullLayout),C.setScale();var L=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDef.select(\"path\").attr(\"d\",L),p.layers.plotbg.select(\"path\").attr(\"d\",L);var I=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDefRelative.select(\"path\").attr(\"d\",I);var P=s(r,n);p.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),p.clipDefRelative.select(\"path\").attr(\"transform\",null);var z=s(r-S._offset,n+a);p.layers.baxis.attr(\"transform\",z),p.layers.bgrid.attr(\"transform\",z);var O=s(r+i/2,n)+\"rotate(30)\"+s(0,-A._offset);p.layers.aaxis.attr(\"transform\",O),p.layers.agrid.attr(\"transform\",O);var D=s(r+i/2,n)+\"rotate(-30)\"+s(0,-C._offset);p.layers.caxis.attr(\"transform\",D),p.layers.cgrid.attr(\"transform\",D),p.drawAxes(!0),p.layers.aline.select(\"path\").attr(\"d\",A.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(c.stroke,A.linecolor||\"#000\").style(\"stroke-width\",(A.linewidth||0)+\"px\"),p.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(c.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),p.layers.cline.select(\"path\").attr(\"d\",C.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(c.stroke,C.linecolor||\"#000\").style(\"stroke-width\",(C.linewidth||0)+\"px\"),p.graphDiv._context.staticPlot||p.initInteractions(),u.setClipUrl(p.layers.frontplot,p._hasClipOnAxisFalse?null:p.clipId,p.graphDiv)},S.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var s=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=b.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:l(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-s,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=b.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:l(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=b.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:l(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},S.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=d.calcTicks(t),f=d.clipEnds(t,u),h=d.makeTransTickFn(t),p=d.getTickSigns(t)[2],g=o.deg2rad(30),m=p*(t.linewidth||1)/2,v=p*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+m+\"l\"+Math.sin(g)*v+\",\"+Math.cos(g)*v:\"M\"+m+\",0l\"+Math.cos(g)*v+\",\"+-Math.sin(g)*v,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];d.drawTicks(r,t,{vals:\"inside\"===t.ticks?f:u,layer:s,path:b,transFn:h,crisp:!1}),d.drawGrid(r,t,{vals:f,layer:this.layers[i+\"grid\"],path:_,transFn:h,crisp:!1}),d.drawLabels(r,t,{vals:u,layer:s,transFn:h,labelFns:d.makeLabelFns(t,0,30)})};var C=M.MINZOOM/2+.87,L=\"m-0.87,.5h\"+C+\"v3h-\"+(C+5.2)+\"l\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l2.6,1.5l-\"+C/2+\",\"+.87*C+\"Z\",I=\"m0.87,.5h-\"+C+\"v3h\"+(C+5.2)+\"l-\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l-2.6,1.5l\"+C/2+\",\"+.87*C+\"Z\",P=\"m0,1l\"+C/2+\",\"+.87*C+\"l2.6,-1.5l-\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l-\"+(C/2+2.6)+\",\"+(.87*C+4.5)+\"l2.6,1.5l\"+C/2+\",-\"+.87*C+\"Z\",z=!0;function O(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}S.clearSelect=function(){k(this.dragOptions),T(this.dragOptions.gd)},S.initInteractions=function(){var t,e,r,n,f,h,p,d,v,b,T,k,A=this,S=A.layers.plotbg.select(\"path\").node(),C=A.graphDiv,D=C._fullLayout._zoomlayer;function R(t){var e={};return e[A.id+\".aaxis.min\"]=t.a,e[A.id+\".baxis.min\"]=t.b,e[A.id+\".caxis.min\"]=t.c,e}function F(t,e){var r=C._fullLayout.clickmode;O(C),2===t&&(C.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",C,R({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&w(e,C,[A.xaxis],[A.yaxis],A.id,A.dragOptions),r.indexOf(\"event\")>-1&&m.click(C,e,A.id)}function B(t,e){return 1-e/A.h}function N(t,e){return 1-(t+(A.h-e)/Math.sqrt(3))/A.w}function j(t,e){return(t-(A.h-e)/Math.sqrt(3))/A.w}function U(i,a){var o=r+i*t,s=n+a*e,l=Math.max(0,Math.min(1,B(0,n),B(0,s))),c=Math.max(0,Math.min(1,N(r,n),N(o,s))),u=Math.max(0,Math.min(1,j(r,n),j(o,s))),g=(l/2+u)*A.w,m=(1-l/2-c)*A.w,y=(g+m)/2,x=m-g,_=(1-l)*A.h,w=_-x/E;x<M.MINZOOM?(p=f,T.attr(\"d\",v),k.attr(\"d\",\"M0,0Z\")):(p={a:f.a+l*h,b:f.b+c*h,c:f.c+u*h},T.attr(\"d\",v+\"M\"+g+\",\"+_+\"H\"+m+\"L\"+y+\",\"+w+\"L\"+g+\",\"+_+\"Z\"),k.attr(\"d\",\"M\"+r+\",\"+n+\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2ZM\"+g+\",\"+_+L+\"M\"+m+\",\"+_+I+\"M\"+y+\",\"+w+P)),b||(T.transition().style(\"fill\",d>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),k.transition().style(\"opacity\",1).duration(200),b=!0),C.emit(\"plotly_relayouting\",R(p))}function V(){O(C),p!==f&&(a.call(\"_guiRelayout\",C,R(p)),z&&C.data&&C._context.showTips&&(o.notifier(l(C,\"Double-click to zoom back out\"),\"long\"),z=!1))}function q(t,e){var r=t/A.xaxis._m,n=e/A.yaxis._m,i=[(p={a:f.a-n,b:f.b+(r+n)/2,c:f.c-(r-n)/2}).a,p.b,p.c].sort(o.sorterAsc),a=i.indexOf(p.a),l=i.indexOf(p.b),c=i.indexOf(p.c);i[0]<0&&(i[1]+i[0]/2<0?(i[2]+=i[0]+i[1],i[0]=i[1]=0):(i[2]+=i[0]/2,i[1]+=i[0]/2,i[0]=0),p={a:i[a],b:i[l],c:i[c]},e=(f.a-p.a)*A.yaxis._m,t=(f.c-p.c-f.b+p.b)*A.xaxis._m);var h=s(A.x0+t,A.y0+e);A.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var d=s(-t,-e);A.clipDefRelative.select(\"path\").attr(\"transform\",d),A.aaxis.range=[p.a,A.sum-p.b-p.c],A.baxis.range=[A.sum-p.a-p.c,p.b],A.caxis.range=[A.sum-p.a-p.b,p.c],A.drawAxes(!1),A._hasClipOnAxisFalse&&A.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(u.hideOutsideRangePoints,A),C.emit(\"plotly_relayouting\",R(p))}function H(){a.call(\"_guiRelayout\",C,R(p))}this.dragOptions={element:S,gd:C,plotinfo:{id:A.id,domain:C._fullLayout[A.id].domain,xaxis:A.xaxis,yaxis:A.yaxis},subplot:A.id,prepFn:function(a,l,u){A.dragOptions.xaxes=[A.xaxis],A.dragOptions.yaxes=[A.yaxis],t=C._fullLayout._invScaleX,e=C._fullLayout._invScaleY;var g=A.dragOptions.dragmode=C._fullLayout.dragmode;y(g)?A.dragOptions.minDrag=1:A.dragOptions.minDrag=void 0,\"zoom\"===g?(A.dragOptions.moveFn=U,A.dragOptions.clickFn=F,A.dragOptions.doneFn=V,function(t,e,a){var l=S.getBoundingClientRect();r=e-l.left,n=a-l.top,C._fullLayout._calcInverseTransform(C);var u=C._fullLayout._invTransform,g=o.apply3DTransform(u)(r,n);r=g[0],n=g[1],f={a:A.aaxis.range[0],b:A.baxis.range[1],c:A.caxis.range[1]},p=f,h=A.aaxis.range[1]-f.a,d=i(A.graphDiv._fullLayout[A.id].bgcolor).getLuminance(),v=\"M0,\"+A.h+\"L\"+A.w/2+\", 0L\"+A.w+\",\"+A.h+\"Z\",b=!1,T=D.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",s(A.x0,A.y0)).style({fill:d>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",v),k=D.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",s(A.x0,A.y0)).style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),A.clearSelect(C)}(0,l,u)):\"pan\"===g?(A.dragOptions.moveFn=q,A.dragOptions.clickFn=F,A.dragOptions.doneFn=H,f={a:A.aaxis.range[0],b:A.baxis.range[1],c:A.caxis.range[1]},p=f,A.clearSelect(C)):(x(g)||y(g))&&_(a,l,u,A.dragOptions,g)}},S.onmousemove=function(t){m.hover(C,t,A.id),C._fullLayout._lasthover=S,C._fullLayout._hoversubplot=A.id},S.onmouseout=function(t){C._dragging||g.unhover(C,t)},g.init(this.dragOptions)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/titles\":738,\"../../lib\":778,\"../../lib/extend\":768,\"../../registry\":911,\"../cartesian/axes\":828,\"../cartesian/constants\":834,\"../cartesian/select\":847,\"../cartesian/set_convert\":848,\"../plots\":891,d3:169,tinycolor2:576}],911:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),f=l.extendFlat,h=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in v(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&f(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,h=u.name;if(\"mapbox\"===h){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==h&&\"mapbox\"!==h||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),v(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&h(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function m(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function v(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&h(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&h(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&h(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":m(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":766,\"./lib/extend\":768,\"./lib/is_plain_object\":779,\"./lib/loggers\":782,\"./lib/noop\":787,\"./lib/push_unique\":793,\"./plots/attributes\":824,\"./plots/layout_attributes\":882}],912:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),f=o({},c,s(e.tileClass)),h=t._context||{};if(e.width&&(f.width=e.width),e.height&&(f.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){f.annotations=[];var p=Object.keys(f);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(f[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)f.annotations.push(e.annotations[r]);var g=Object.keys(f).filter((function(t){return t.match(/^scene\\d*$/)}));if(g.length){var m={};for(\"thumbnail\"===e.tileClass&&(m={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var v=f[g[r]];v.xaxis||(v.xaxis={}),v.yaxis||(v.yaxis={}),v.zaxis||(v.zaxis={}),a(v.xaxis,m),a(v.yaxis,m),a(v.zaxis,m),v._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:f,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:h.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":778,\"../registry\":911}],913:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.width=e.width||null,e.height=e.height||null,e.imageDataOnly=!0,new Promise((function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format.replace(\"-\",\".\"),c.then((function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)})).then((function(t){s(t)})).catch((function(t){r&&(r._snapshotInProgress=!1),l(t)}))}))}},{\"../lib\":778,\"../plot_api/to_image\":820,\"./filesaver\":914,\"./helpers\":915}],914:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise((function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var f=\"svg\"===r?\",\":\";base64,\";return i.octetStream(f+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))}))}},{\"../lib\":778,\"./helpers\":915}],915:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)},r.encodeJSON=function(t){return\"data:application/json,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});if(\"full-json\"===e)return new window.Blob([t],{type:\"application/json;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":911}],916:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":912,\"./download\":913,\"./helpers\":915,\"./svgtoimg\":917,\"./toimage\":918,\"./tosvg\":919}],917:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise((function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var f,h,p=t.canvas,d=t.scale||1,g=t.width||300,m=t.height||150,v=d*g,y=d*m,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?h=a.encodeSVG(l):(f=a.createBlob(l,\"svg\"),h=a.createObjectURL(f)),p.width=v,p.height=y,b.onload=function(){var r;switch(f=null,a.revokeObjectURL(h),\"svg\"!==c&&x.drawImage(b,0,0,v,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=h;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(f=null,a.revokeObjectURL(h),o(r),!t.promise)return e.emit(\"error\",r)},b.src=h}));return t.promise?r:e}},{\"../lib\":778,\"./helpers\":915,events:110}],918:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),f=u.gd;f.style.position=\"absolute\",f.style.left=\"-5000px\",document.body.appendChild(f);var h=o.getRedrawFunc(f);return i.call(\"plot\",f,u.data,u.layout,u.config).then(h).then((function(){var t=o.getDelay(f._fullLayout);setTimeout((function(){var t=l(f),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:f._fullLayout.width,height:f._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){f&&document.body.removeChild(f)}}),t)})).catch((function(t){r.emit(\"error\",t)})),r}},{\"../lib\":778,\"../registry\":911,\"./cloneplot\":912,\"./helpers\":915,\"./svgtoimg\":917,\"./tosvg\":919,events:110}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,f=t._fullLayout,h=f._paper,p=f._toppaper,d=f.width,g=f.height;h.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,f.paper_bgcolor);var m=f._basePlotModules||[];for(u=0;u<m.length;u++){var v=m[u];v.toSVG&&v.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&h.node().appendChild(b)}}if(f._draggers&&f._draggers.remove(),h.node().style.background=\"\",h.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each((function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()})),f._gradientUrlQueryParts){var _=[];for(var w in f._gradientUrlQueryParts)_.push(w);_.length&&h.selectAll(_.join(\",\")).each((function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}))}\"pdf\"!==e&&\"eps\"!==e||h.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),h.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),h.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(h.attr(\"width\",r*d),h.attr(\"height\",r*g),h.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var T=(new window.XMLSerializer).serializeToString(h.node());return T=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,(function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()}));return e.remove(),r}(T),T=(T=T.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(T=(T=(T=T.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),T}},{\"../components/color\":643,\"../components/drawing\":665,\"../constants/xmlns_namespaces\":754,\"../lib\":778,d3:169}],920:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":778}],921:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/font_attributes\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=s({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),f=c({},n.marker.line.width,{dflt:0}),h=c({width:f,editType:\"calc\"},o(\"marker.line\")),p=c({line:h,editType:\"calc\"},o(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,texttemplate:a({editType:\"plot\"},{keys:l.eventDataKeys}),hovertext:n.hovertext,hovertemplate:i({},{keys:l.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:c({},u,{}),insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:c({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:p,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"./constants\":923}],922:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"../../components/colorscale/helpers\").hasColorscale,o=t(\"../../components/colorscale/calc\"),s=t(\"./arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,c,u,f,h=n.getFromId(t,e.xaxis||\"x\"),p=n.getFromId(t,e.yaxis||\"y\"),d={msUTC:!(!e.base&&0!==e.base)};\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\",d),u=p.makeCalcdata(e,\"y\"),c=i(e,p,\"y\",u),f=!!e.yperiodalignment):(r=p.makeCalcdata(e,\"y\",d),u=h.makeCalcdata(e,\"x\"),c=i(e,h,\"x\",u),f=!!e.xperiodalignment);for(var g=Math.min(c.length,r.length),m=new Array(g),v=0;v<g;v++)m[v]={p:c[v],s:r[v]},f&&(m[v].orig_p=u[v]),e.ids&&(m[v].id=String(e.ids[v]));return a(e,\"marker\")&&o(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),a(e,\"marker.line\")&&o(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),s(m,e),l(m,e),m}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189,\"./arrays_to_calcdata\":920}],923:[function(t,e,r){\"use strict\";e.exports={TEXTPAD:3,eventDataKeys:[\"value\",\"label\"]}},{}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/constraints\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,T;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,f=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=f(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=f(c,0,u);var h=n(o);for(o=h?o:0,a=0;a<s.length;a++)s[a].b=o,h&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":f(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.offset?_.push(T):b.push(T);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,f=a.length!==o.length,h=s*(1-n.gap),m=l(i,e._id)+c[0][0].trace.orientation,v=i._alignmentOpts[m]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,T=v[w.alignmentgroup]||{},k=Object.keys(T.offsetGroups||{}).length,M=(x=k?h/k:f?h/u:h)*(1-(n.groupgap||0));b=k?((2*w._offsetIndex+1-k)*x-M)/2:f?((2*y+1-u)*x-M)/2:-M/2;var A=_[0].t;A.barwidth=M,A.poffset=b,A.bargroupwidth=h,A.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,f)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r];if(void 0===n[0].trace.base)for(var i=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),o=0;o<n.length;o++){var s=n[o];if(s.p!==a){var l=i.put(s.p,s.b+s.s);l&&(s.b=l)}}}}(o),i.norm?(v(o),y(r,o,i)):m(r,o)}(t,e,r,_,u),b.length&&f(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.base?_.push(T):b.push(T);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});h(e,o,i),function(t,e,r){var n,i,o,l,c,u,f=x(t),h=e.traces;for(l=0;l<h.length;l++)if(n=h[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<h.length;l++){n=h[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),m=g+d;u.b=g,u[f]=m,r.norm||(p.push(m),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],f=0;f<u.length;f++){var p=u[f];if(p.s!==a)p.b+p.s===o.get(p.p,p.s)&&(p._outmost=!0)}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&f(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var f=1e4/(c-l),h=s.round=function(t){return String(Math.round(f*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],m=g[o]-g.w/2;if(n(m)){var v=g[o]+g.w/2,y=h(g.p);s[y]?s[y]=[Math.min(m,s[y][0]),Math.max(v,s[y][1])]:s[y]=[m,v]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function f(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{unitMinDiff:n.xCat||n.yCat,sepNegVal:!1,overlapNoMerge:!n.norm});h(t,o,n),n.norm?(v(o),y(e,o,n)):m(e,o)}}function h(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,f=c._offset||c.offset,h=u.poffset;if(i(f)){for(o=Array.prototype.slice.call(f,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=h);for(r=o.length;r<s.length;r++)o.push(h);u.poffset=o}else void 0!==f&&(u.poffset=f);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===f){for(o=[],r=0;r<s.length;r++)o.push(h+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===f&&(u.poffset=h+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),f=0;f<a.length;f++){var h=a[f],p=h.w=u?c[f]:c;h[n]=h.p+(l?s[f]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,f=n[a],h=f[0],p=h.trace,d=[];for(u=0;u<f.length;u++)l=(o=f[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=h.t,m=g.poffset,v=g.barwidth,y=Array.isArray(m),x=Array.isArray(v);for(u=0;u<f.length;u++){o=f[u];var b=y?m[u]:m,_=x?v[u]:v;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function m(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!1,u=0;u<a.length;u++){var f=a[u],h=f.b,p=h+f.s;f[n]=p,l.push(p),f.hasB&&l.push(h),f.hasB&&f.b||(c=!0)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:c,padded:!0})}}function v(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),f=\"stack\"===r.mode?l:u;function h(e){return n(t.c2l(e))&&(e<u-c||e>f+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,m=[],v=!1,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var T=_.b,k=T+_.s;_[o]=k,m.push(k),y=y||h(k),_.hasB&&(m.push(T),y=y||h(T)),_.hasB&&_.b||(v=!0)}}g._extremes[t._id]=s.findExtremes(t,m,{tozero:v,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],f=0;f<a.length;f++){var h=a[f];if(!0===h.visible&&o.traceIs(h,\"bar\")&&h.xaxis===r._id&&h.yaxis===n._id&&(\"h\"===h.orientation?l.push(s[f]):c.push(s[f]),h._computePh))for(var p=t.calcdata[f],d=0;d<p.length;d++)\"function\"==typeof p[d].ph0&&(p[d].ph0=p[d].ph0()),\"function\"==typeof p[d].ph1&&(p[d].ph1=p[d].ph1())}var g={xCat:\"category\"===r.type||\"multicategory\"===r.type,yCat:\"category\"===n.type||\"multicategory\"===n.type,mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,g),u(t,n,r,l,g)},setGroupPositions:u}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"./sieve.js\":934,\"fast-isnumeric\":241}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./style_defaults\"),c=t(\"../../plots/cartesian/constraints\").getAxisGroup,u=t(\"./attributes\"),f=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=c(r,a)+i,s=r._alignmentOpts||{},l=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var f=u[l];f?f.traces.push(e):f=u[l]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var h=n(\"offsetgroup\"),p=f.offsetGroups,d=p[h];h&&(d||(d=p[h]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function p(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),u=!(!1===o.moduleHasCliponaxis),h=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=!!o.hasPathbar,g=Array.isArray(a)||\"auto\"===a,m=g||\"inside\"===a,v=g||\"outside\"===a;if(m||v){var y=f(i,\"textfont\",r.font),x=n.extendFlat({},y),b=!(t.textfont&&t.textfont.color);if(b&&delete x.color,f(i,\"insidetextfont\",x),d){var _=n.extendFlat({},y);b&&delete _.color,f(i,\"pathbar.textfont\",_)}v&&f(i,\"outsidetextfont\",y),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),u&&i(\"cliponaxis\"),h&&i(\"textangle\"),i(\"texttemplate\")}m&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,c){function f(r,i){return n.coerce(t,e,u,r,i)}if(o(t,e,c,f)){s(t,e,c,f),f(\"orientation\",e.x&&!e.y?\"h\":\"v\"),f(\"base\"),f(\"offset\"),f(\"width\"),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\");var h=f(\"textposition\");p(t,e,c,f,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),l(t,e,f,r,c);var d=(e.marker.line||{}).color,g=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");g(t,e,d||i.defaultLine,{axis:\"y\"}),g(t,e,d||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,u,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:p}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":921,\"./style_defaults\":936}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),\"h\"===r.orientation?(t.label=t.y,t.value=t.x):(t.label=t.x,t.value=t.y),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":778,\"fast-isnumeric\":241,tinycolor2:576}],928:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth,l=t(\"../../plots/cartesian/axes\").hoverLabelText,c=t(\"../../constants/numerical\").BADNUM;function u(t,e,r,i){var a,s,u,f,h,p,d,g=t.cd,m=g[0].trace,v=g[0].t,y=\"closest\"===i,x=\"waterfall\"===m.type,b=t.maxHoverDistance;function _(t){return t[u]-t.w/2}function w(t){return t[u]+t.w/2}var T=y?_:function(t){return Math.min(_(t),t.p-v.bardelta/2)},k=y?w:function(t){return Math.max(w(t),t.p+v.bardelta/2)};function M(t,e){return n.inbox(t-a,e-a,b+Math.min(1,Math.abs(e-t)/d)-1)}function A(t){return M(T(t),k(t))}function S(t){var e=s,r=t.b,i=t[f];if(x){var a=Math.abs(t.rawS)||0;e>0?i+=a:e<0&&(i-=a)}return n.inbox(r-e,i-e,b+(i-e)/(i-r)-1)}\"h\"===m.orientation?(a=r,s=e,u=\"y\",f=\"x\",h=S,p=A):(a=e,s=r,u=\"x\",f=\"y\",p=S,h=A);var E=t[u+\"a\"],C=t[f+\"a\"];d=Math.abs(E.r2c(E.range[1])-E.r2c(E.range[0]));var L=n.getDistanceFunction(i,h,p,(function(t){return(h(t)+p(t))/2}));if(n.getClosest(g,L,t),!1!==t.index&&g[t.index].p!==c){y||(T=function(t){return Math.min(_(t),t.p-v.bargroupwidth/2)},k=function(t){return Math.max(w(t),t.p+v.bargroupwidth/2)});var I=g[t.index],P=m.base?I.b+I.s:I.s;t[f+\"0\"]=t[f+\"1\"]=C.c2p(I[f],!0),t[f+\"LabelVal\"]=P;var z=v.extents[v.extents.round(I.p)];t[u+\"0\"]=E.c2p(y?T(I):z[0],!0),t[u+\"1\"]=E.c2p(y?k(I):z[1],!0);var O=void 0!==I.orig_p;return t[u+\"LabelVal\"]=O?I.orig_p:I.p,t.labelLabel=l(E,t[u+\"LabelVal\"]),t.valueLabel=l(C,t[f+\"LabelVal\"]),t.baseLabel=l(C,I.b),t.spikeDistance=(S(I)+function(t){return M(_(t),w(t))}(I))/2-b,t[u+\"Spike\"]=E.c2p(I.p,!0),o(I,m,t),t.hovertemplate=m.hovertemplate,t}}function f(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=u(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,l=o[a.index];return a.color=f(s,l),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(l,s,a),[a]}},hoverOnBars:u,getTraceColor:f}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./helpers\":927}],929:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],animatable:!0,meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/marker_colorbar\":1205,\"./arrays_to_calcdata\":920,\"./attributes\":921,\"./calc\":922,\"./cross_trace_calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":928,\"./layout_attributes\":930,\"./layout_defaults\":931,\"./plot\":932,\"./select\":933,\"./style\":935}],930:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,f={},h=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===h){var g=d.xaxis+d.yaxis;f[g]&&(u=!0),f[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==h&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./layout_attributes\":930}],932:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,f=t(\"./uniform_text\"),h=f.recordMinTextSize,p=f.clearMinTextSize,d=t(\"./style\"),g=t(\"./helpers\"),m=t(\"./constants\"),v=t(\"./attributes\"),y=v.text,x=v.textposition,b=t(\"../../components/fx/helpers\").appendArrayPointValue,_=m.TEXTPAD;function w(t){return t.id}function T(t){if(t.ids)return w}function k(t,e){return t<e?1:-1}function M(t,e,r,n){var i;return!e.uniformtext.mode&&A(r)?(n&&(i=n()),t.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){i&&i()})).each(\"interrupt\",(function(){i&&i()}))):t}function A(t){return t&&t.duration>0}function S(t){return\"auto\"===t?0:t}function E(t,e){var r=Math.PI/180*e,n=Math.abs(Math.sin(r)),i=Math.abs(Math.cos(r));return{x:t.width*i+t.height*n,y:t.width*n+t.height*i}}function C(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||\"end\",u=\"end\"===c,f=\"start\"===c,h=((a.leftToRight||0)+1)/2,p=1-h,d=i.width,g=i.height,m=Math.abs(e-t),v=Math.abs(n-r),y=m>2*_&&v>2*_?_:0;m-=2*y,v-=2*y;var x=S(l);\"auto\"!==l||d<=m&&g<=v||!(d>m||g>v)||(d>v||g>m)&&d<g==m<v||(x+=90);var b=E(i,x),w=1;s&&(w=Math.min(1,m/b.x,v/b.y));var T=i.left*p+i.right*h,M=(i.top+i.bottom)/2,A=(t+_)*p+(e-_)*h,C=(r+n)/2,L=0,I=0;if(f||u){var P=(o?b.x:b.y)/2,z=o?k(t,e):k(r,n);o?f?(A=t+z*y,L=-z*P):(A=e-z*y,L=z*P):f?(C=r+z*y,I=-z*P):(C=n-z*y,I=z*P)}return{textX:T,textY:M,targetX:A,targetY:C,anchorX:L,anchorY:I,scale:w,rotate:x}}e.exports={plot:function(t,e,r,f,m,v){var w=e.xaxis,L=e.yaxis,I=t._fullLayout;m||(m={mode:I.barmode,norm:I.barmode,gap:I.bargap,groupgap:I.bargroupgap},p(\"bar\",I));var P=a.makeTraceGroups(f,r,\"trace bars\").each((function(r){var c=n.select(this),f=r[0].trace,p=\"waterfall\"===f.type,P=\"funnel\"===f.type,z=\"bar\"===f.type||P,O=0;p&&f.connector.visible&&\"between\"===f.connector.mode&&(O=f.connector.line.width/2);var D=\"h\"===f.orientation,R=A(m),F=a.ensureSingle(c,\"g\",\"points\"),B=T(f),N=F.selectAll(\"g.point\").data(a.identity,B);N.enter().append(\"g\").classed(\"point\",!0),N.exit().remove(),N.each((function(c,p){var T,A,P=n.select(this),F=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,L,D),B=F[0][0],N=F[0][1],j=F[1][0],U=F[1][1],V=0==(D?N-B:U-j);if(V&&z&&g.getLineWidth(f,c)&&(V=!1),V||(V=!(i(B)&&i(N)&&i(j)&&i(U))),c.isBlank=V,V&&(D?N=B:U=j),O&&!V&&(D?(B-=k(B,N)*O,N+=k(B,N)*O):(j-=k(j,U)*O,U+=k(j,U)*O)),\"waterfall\"===f.type){if(!V){var q=f[c.dir].marker;T=q.line.width,A=q.color}}else T=g.getLineWidth(f,c),A=c.mc||f.marker.color;function H(t){var e=n.round(T/2%1,2);return 0===m.gap&&0===m.groupgap?n.round(Math.round(t)-e,2):t}if(!t._context.staticPlot){var G=s.opacity(A)<1||T>.01?H:function(t,e,r){return r&&t===e?t:Math.abs(t-e)>=2?H(t):t>e?Math.ceil(t):Math.floor(t)};B=G(B,N,D),N=G(N,B,D),j=G(j,U,!D),U=G(U,j,!D)}var Y=M(a.ensureSingle(P,\"path\"),I,m,v);if(Y.style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",isNaN((N-B)*(U-j))||V&&t._context.staticPlot?\"M0,0Z\":\"M\"+B+\",\"+j+\"V\"+U+\"H\"+N+\"V\"+j+\"Z\").call(l.setClipUrl,e.layerClipId,t),!I.uniformtext.mode&&R){var W=l.makePointStyleFns(f);l.singlePointStyle(c,Y,f,W,t)}!function(t,e,r,n,i,s,c,f,p,m,v){var w,T=e.xaxis,A=e.yaxis,L=t._fullLayout;function I(e,r,n){return a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t)}var P=n[0].trace,z=\"h\"===P.orientation,O=function(t,e,r,n,i){var o,s=e[0].trace;o=s.texttemplate?function(t,e,r,n,i){var o=e[0].trace,s=a.castOption(o,r,\"texttemplate\");if(!s)return\"\";var l,c,f,h,p=\"waterfall\"===o.type,d=\"funnel\"===o.type;\"h\"===o.orientation?(l=\"y\",c=i,f=\"x\",h=n):(l=\"x\",c=n,f=\"y\",h=i);function g(t){return u(h,+t,!0).text}var m=e[r],v={};v.label=m.p,v.labelLabel=v[l+\"Label\"]=(y=m.p,u(c,y,!0).text);var y;var x=a.castOption(o,m.i,\"text\");(0===x||x)&&(v.text=x);v.value=m.s,v.valueLabel=v[f+\"Label\"]=g(m.s);var _={};b(_,o,m.i),p&&(v.delta=+m.rawS||m.s,v.deltaLabel=g(v.delta),v.final=m.v,v.finalLabel=g(v.final),v.initial=v.final-v.delta,v.initialLabel=g(v.initial));d&&(v.value=m.s,v.valueLabel=g(v.value),v.percentInitial=m.begR,v.percentInitialLabel=a.formatPercent(m.begR),v.percentPrevious=m.difR,v.percentPreviousLabel=a.formatPercent(m.difR),v.percentTotal=m.sumR,v.percenTotalLabel=a.formatPercent(m.sumR));var w=a.castOption(o,m.i,\"customdata\");w&&(v.customdata=w);return a.texttemplateString(s,v,t._d3locale,_,v,o._meta||{})}(t,e,r,n,i):s.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){return u(o?r:n,+t,!0).text}var f,h=i.textinfo,p=t[e],d=h.split(\"+\"),g=[],m=function(t){return-1!==d.indexOf(t)};m(\"label\")&&g.push((v=t[e].p,u(o?n:r,v,!0).text));var v;m(\"text\")&&(0===(f=a.castOption(i,p.i,\"text\"))||f)&&g.push(f);if(s){var y=+p.rawS||p.s,x=p.v,b=x-y;m(\"initial\")&&g.push(c(b)),m(\"delta\")&&g.push(c(y)),m(\"final\")&&g.push(c(x))}if(l){m(\"value\")&&g.push(c(p.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(f=a.formatPercent(p.begR),w&&(f+=\" of initial\"),g.push(f)),m(\"percent previous\")&&(f=a.formatPercent(p.difR),w&&(f+=\" of previous\"),g.push(f)),m(\"percent total\")&&(f=a.formatPercent(p.sumR),w&&(f+=\" of total\"),g.push(f))}return g.join(\"<br>\")}(e,r,n,i):g.getValue(s.text,r);return g.coerceString(y,o)}(L,n,i,T,A);w=function(t,e){var r=g.getValue(t.textposition,e);return g.coerceEnumerated(x,r)}(P,i);var D=\"stack\"===m.mode||\"relative\"===m.mode,R=n[i],F=!D||R._outmost;if(!O||\"none\"===w||(R.isBlank||s===c||f===p)&&(\"auto\"===w||\"inside\"===w))return void r.select(\"text\").remove();var B=L.font,N=d.getBarColor(n[i],P),j=d.getInsideTextFont(P,i,B,N),U=d.getOutsideTextFont(P,i,B),V=r.datum();z?\"log\"===T.type&&V.s0<=0&&(s=T.range[0]<T.range[1]?0:T._length):\"log\"===A.type&&V.s0<=0&&(f=A.range[0]<A.range[1]?A._length:0);var q,H,G,Y,W,X=Math.abs(c-s)-2*_,Z=Math.abs(p-f)-2*_;\"outside\"===w&&(F||R.hasB||(w=\"inside\"));if(\"auto\"===w)if(F){w=\"inside\",W=a.ensureUniformFontSize(t,j),q=I(r,O,W),H=l.bBox(q.node()),G=H.width,Y=H.height;var J=G<=X&&Y<=Z,K=G<=Z&&Y<=X,Q=z?X>=G*(Z/Y):Z>=Y*(X/G);G>0&&Y>0&&(J||K||Q)?w=\"inside\":(w=\"outside\",q.remove(),q=null)}else w=\"inside\";if(!q){W=a.ensureUniformFontSize(t,\"outside\"===w?U:j);var $=(q=I(r,O,W)).attr(\"transform\");if(q.attr(\"transform\",\"\"),H=l.bBox(q.node()),G=H.width,Y=H.height,q.attr(\"transform\",$),G<=0||Y<=0)return void q.remove()}var tt,et,rt=P.textangle;\"outside\"===w?(et=\"both\"===P.constraintext||\"outside\"===P.constraintext,tt=function(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,f=i.height,h=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*_?_:0:h>2*_?_:0;var d=1;l&&(d=s?Math.min(1,p/f):Math.min(1,h/u));var g=S(c),m=E(i,g),v=(s?m.x:m.y)/2,y=(i.left+i.right)/2,x=(i.top+i.bottom)/2,b=(t+e)/2,w=(r+n)/2,T=0,M=0,A=s?k(e,t):k(r,n);s?(b=e-A*o,T=A*v):(w=n+A*o,M=-A*v);return{textX:y,textY:x,targetX:b,targetY:w,anchorX:T,anchorY:M,scale:d,rotate:g}}(s,c,f,p,H,{isHorizontal:z,constrained:et,angle:rt})):(et=\"both\"===P.constraintext||\"inside\"===P.constraintext,tt=C(s,c,f,p,H,{isHorizontal:z,constrained:et,angle:rt,anchor:P.insidetextanchor}));tt.fontSize=W.size,h(P.type,tt,L),R.transform=tt,M(q,L,m,v).attr(\"transform\",a.getTextTransform(tt))}(t,e,P,r,p,B,N,j,U,m,v),e.layerClipId&&l.hideOutsideRangePoint(c,P.select(\"text\"),w,L,f.xcalendar,f.ycalendar)}));var j=!1===f.cliponaxis;l.setClipUrl(c,j?null:e.layerClipId,t)}));c.getComponentMethod(\"errorbars\",\"plot\")(t,P,e,m)},toMoveInsideBar:C}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./attributes\":921,\"./constants\":923,\"./helpers\":927,\"./style\":935,\"./uniform_text\":937,d3:169,\"fast-isnumeric\":241}],933:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var f=i[r],h=\"ct\"in f?f.ct:n(f,a,o,c,l);e.contains(h,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(f.x),y:o.c2d(f.y)}),f.selected=1):f.selected=0}return u}},{}],934:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a,{unitMinDiff:e.unitMinDiff});this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":753,\"../../lib\":778}],935:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./uniform_text\").resizeText,c=t(\"./attributes\"),u=c.textfont,f=c.insidetextfont,h=c.outsidetextfont,p=t(\"./helpers\");function d(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),g(t,e,r)}function g(t,e,r){t.selectAll(\"text\").each((function(t){var i=n.select(this),s=o.ensureUniformFontSize(r,m(i,t,e,r));a.font(i,s)}))}function m(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=_(e,r);a=y(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=x(r,e.i,i));return a}function v(t,e,r){return b(u,t.textfont,e,r)}function y(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),b(f,t.insidetextfont,e,a)}function x(t,e,r){var n=v(t,e,r);return b(h,t.outsidetextfont,e,n)}function b(t,e,r,n){e=e||{};var i=p.getValue(e.family,r),a=p.getValue(e.size,r),o=p.getValue(e.color,r);return{family:p.coerceString(t.family,i,n.family),size:p.coerceNumber(t.size,a,n.size),color:p.coerceColor(t.color,o,n.color)}}function _(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\");l(t,e,\"bar\");var r=e.size(),i=t._fullLayout;e.style(\"opacity\",(function(t){return t[0].trace.opacity})).each((function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")})),e.selectAll(\"g.points\").each((function(e){d(n.select(this),e[0].trace,t)})),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:g,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each((function(t){var i,s=n.select(this);if(t.selected){i=o.ensureUniformFontSize(r,m(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)}))}(t.selectAll(\"text\"),e,r)}(r,i,t):(d(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:y,getOutsideTextFont:x,getBarColor:_,resizeText:l}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../registry\":911,\"./attributes\":921,\"./helpers\":927,\"./uniform_text\":937,d3:169}],936:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":643,\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654}],937:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");function a(t){return\"_\"+t+\"Text_minsize\"}e.exports={recordMinTextSize:function(t,e,r){if(r.uniformtext.mode){var n=a(t),i=r.uniformtext.minsize,o=e.scale*e.fontSize;e.hide=o<i,r[n]=r[n]||1/0,e.hide||(r[n]=Math.min(r[n],Math.max(o,i)))}},clearMinTextSize:function(t,e){e[a(t)]=void 0},resizeText:function(t,e,r){var a=t._fullLayout,o=a[\"_\"+r+\"Text_minsize\"];if(o){var s,l=\"hide\"===a.uniformtext.mode;switch(r){case\"funnelarea\":case\"pie\":case\"sunburst\":s=\"g.slice\";break;case\"treemap\":s=\"g.slice, g.pathbar\";break;default:s=\"g.points > g.point\"}e.selectAll(s).each((function(t){var e=t.transform;e&&(e.scale=l&&e.hide?0:o/e.fontSize,n.select(this).select(\"text\").attr(\"transform\",i.getTextTransform(e)))}))}}}},{\"../../lib\":778,d3:169}],938:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatterpolar/attributes\":1261}],939:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),f=c.makeCalcdata(e,\"theta\"),h=e._length,p=new Array(h),d=u,g=f,m=0;m<h;m++)p[m]={p:g[m],s:d[m]};function v(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(v(\"width\"),v(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var f=c({},e.radialaxis,{_id:\"x\"}),h=e.angularaxis;o(t,h,f,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../registry\":911,\"../bar/arrays_to_calcdata\":920,\"../bar/cross_trace_calc\":924,\"../scatter/calc_selection\":1189}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":778,\"../bar/style_defaults\":936,\"../scatterpolar/defaults\":1263,\"./attributes\":938}],941:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,f=t.subplot,h=f.radialAxis,p=f.angularAxis,d=f.vangles,g=d?l:i.isPtInsideSector,m=t.maxHoverDistance,v=p._period||2*Math.PI,y=Math.abs(h.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);h.range[0]>h.range[1]&&(x+=Math.PI);if(n.getClosest(c,(function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?m+Math.min(1,Math.abs(t.thetag1-t.thetag0)/v)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0}),t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,f,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":683,\"../../lib\":778,\"../../plots/polar/helpers\":893,\"../bar/hover\":928,\"../scatterpolar/hover\":1265}],942:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"../scatterpolar/format_labels\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":894,\"../bar/select\":933,\"../bar/style\":935,\"../scatter/marker_colorbar\":1205,\"../scatterpolar/format_labels\":1264,\"./attributes\":938,\"./calc\":939,\"./defaults\":940,\"./hover\":941,\"./layout_attributes\":943,\"./layout_defaults\":944,\"./plot\":945}],943:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],944:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":778,\"./layout_attributes\":943}],945:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,f=e.angularAxis,h=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var f=[s.findEnclosingVertexAngles(c,t.vangles)[0],(c+u)/2,s.findEnclosingVertexAngles(u,t.vangles)[1]];return s.pathPolygonAnnulus(n,i,c,u,f,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each((function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each((function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=f.c2g(t.p0),d=t.thetag1=f.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),m=(p+d)/2;t.ct=[l.c2p(g*Math.cos(m)),c.c2p(g*Math.sin(m))],e=h(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)})),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../plots/polar/helpers\":893,d3:169,\"fast-isnumeric\":241}],946:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",editType:\"calc\"},dy:{valType:\"number\",editType:\"calc\"},xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},q1:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},median:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},q3:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},lowerfence:{valType:\"data_array\",editType:\"calc\"},upperfence:{valType:\"data_array\",editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},notchspan:{valType:\"data_array\",editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],editType:\"calc\"},mean:{valType:\"data_array\",editType:\"calc\"},sd:{valType:\"data_array\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},quartilemethod:{valType:\"enumerated\",values:[\"linear\",\"exclusive\",\"inclusive\"],dflt:\"linear\",editType:\"calc\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),o=t(\"../../lib\"),s=t(\"../../constants/numerical\").BADNUM,l=o._;e.exports=function(t,e){var r,c,y,x,b,_,w,T=t._fullLayout,k=i.getFromId(t,e.xaxis||\"x\"),M=i.getFromId(t,e.yaxis||\"y\"),A=[],S=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(y=k,x=\"x\",b=M,_=\"y\",w=!!e.yperiodalignment):(y=M,x=\"y\",b=k,_=\"x\",w=!!e.xperiodalignment);var E,C,L,I,P,z,O=function(t,e,r,i){var s,l=e+\"0\"in t,c=\"d\"+e in t;if(e in t||l&&c){var u=r.makeCalcdata(t,e);return[a(t,r,e,u),u]}s=l?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||o.isDateTime(t.name)&&\"date\"===r.type)?t.name:i;for(var f=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]),h=t._length,p=new Array(h),d=0;d<h;d++)p[d]=f;return[p]}(e,_,b,T[S]),D=O[0],R=O[1],F=o.distinctVals(D),B=F.vals,N=F.minDiff/2,j=\"all\"===(e.boxpoints||e.points)?o.identity:function(t){return t.v<E.lf||t.v>E.uf};if(e._hasPreCompStats){var U=e[x],V=function(t){return y.d2c((e[t]||[])[r])},q=1/0,H=-1/0;for(r=0;r<e._length;r++){var G=D[r];if(n(G)){if((E={}).pos=E[_]=G,w&&R&&(E.orig_p=R[r]),E.q1=V(\"q1\"),E.med=V(\"median\"),E.q3=V(\"q3\"),C=[],U&&o.isArrayOrTypedArray(U[r]))for(c=0;c<U[r].length;c++)(z=y.d2c(U[r][c]))!==s&&(u(P={v:z,i:[r,c]},e,[r,c]),C.push(P));if(E.pts=C.sort(f),I=(L=E[x]=C.map(h)).length,E.med!==s&&E.q1!==s&&E.q3!==s&&E.med>=E.q1&&E.q3>=E.med){var Y=V(\"lowerfence\");E.lf=Y!==s&&Y<=E.q1?Y:p(E,L,I);var W=V(\"upperfence\");E.uf=W!==s&&W>=E.q3?W:d(E,L,I);var X=V(\"mean\");E.mean=X!==s?X:I?o.mean(L,I):(E.q1+E.q3)/2;var Z=V(\"sd\");E.sd=X!==s&&Z>=0?Z:I?o.stdev(L,I,E.mean):E.q3-E.q1,E.lo=g(E),E.uo=m(E);var J=V(\"notchspan\");J=J!==s&&J>0?J:v(E,I),E.ln=E.med-J,E.un=E.med+J;var K=E.lf,Q=E.uf;e.boxpoints&&L.length&&(K=Math.min(K,L[0]),Q=Math.max(Q,L[I-1])),e.notched&&(K=Math.min(K,E.ln),Q=Math.max(Q,E.un)),E.min=K,E.max=Q}else{var $;o.warn([\"Invalid input - make sure that q1 <= median <= q3\",\"q1 = \"+E.q1,\"median = \"+E.med,\"q3 = \"+E.q3].join(\"\\n\")),$=E.med!==s?E.med:E.q1!==s?E.q3!==s?(E.q1+E.q3)/2:E.q1:E.q3!==s?E.q3:0,E.med=$,E.q1=E.q3=$,E.lf=E.uf=$,E.mean=E.sd=$,E.ln=E.un=$,E.min=E.max=$}q=Math.min(q,E.min),H=Math.max(H,E.max),E.pts2=C.filter(j),A.push(E)}}e._extremes[y._id]=i.findExtremes(y,[q,H],{padded:!0})}else{var tt=y.makeCalcdata(e,x),et=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(B,N),rt=B.length,nt=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(rt);for(r=0;r<e._length;r++)if(z=tt[r],n(z)){var it=o.findBin(D[r],et);it>=0&&it<rt&&(u(P={v:z,i:r},e,r),nt[it].push(P))}var at=1/0,ot=-1/0,st=e.quartilemethod,lt=\"exclusive\"===st,ct=\"inclusive\"===st;for(r=0;r<rt;r++)if(nt[r].length>0){var ut,ft;if((E={}).pos=E[_]=B[r],C=E.pts=nt[r].sort(f),I=(L=E[x]=C.map(h)).length,E.min=L[0],E.max=L[I-1],E.mean=o.mean(L,I),E.sd=o.stdev(L,I,E.mean),E.med=o.interp(L,.5),I%2&&(lt||ct))lt?(ut=L.slice(0,I/2),ft=L.slice(I/2+1)):ct&&(ut=L.slice(0,I/2+1),ft=L.slice(I/2)),E.q1=o.interp(ut,.5),E.q3=o.interp(ft,.5);else E.q1=o.interp(L,.25),E.q3=o.interp(L,.75);E.lf=p(E,L,I),E.uf=d(E,L,I),E.lo=g(E),E.uo=m(E);var ht=v(E,I);E.ln=E.med-ht,E.un=E.med+ht,at=Math.min(at,E.ln),ot=Math.max(ot,E.un),E.pts2=C.filter(j),A.push(E)}e._extremes[y._id]=i.findExtremes(y,e.notched?tt.concat([at,ot]):tt,{padded:!0})}return function(t,e){if(o.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],i={},a=0;a<n.length;a++)i[n[a].i]=a;o.tagSelected(n,e,i)}}(A,e),A.length>0?(A[0].t={num:T[S],dPos:N,posLetter:_,valLetter:x,labels:{med:l(t,\"median:\"),min:l(t,\"min:\"),q1:l(t,\"q1:\"),q3:l(t,\"q3:\"),max:l(t,\"max:\"),mean:\"sd\"===e.boxmean?l(t,\"mean \\xb1 \\u03c3:\"):l(t,\"mean:\"),lf:l(t,\"lower fence:\"),uf:l(t,\"upper fence:\")}},T[S]++,A):[{t:{empty:!0}}]};var c={text:\"tx\",hovertext:\"htx\"};function u(t,e,r){for(var n in c)o.isArrayOrTypedArray(e[n])&&(Array.isArray(r)?o.isArrayOrTypedArray(e[n][r[0]])&&(t[c[n]]=e[n][r[0]][r[1]]):t[c[n]]=e[n][r])}function f(t,e){return t.v-e.v}function h(t){return t.v}function p(t,e,r){return 0===r?t.q1:Math.min(t.q1,e[Math.min(o.findBin(2.5*t.q1-1.5*t.q3,e,!0)+1,r-1)])}function d(t,e,r){return 0===r?t.q3:Math.max(t.q3,e[Math.max(o.findBin(2.5*t.q3-1.5*t.q1,e),0)])}function g(t){return 4*t.q1-3*t.q3}function m(t){return 4*t.q3-3*t.q1}function v(t,e){return 0===e?0:1.57*(t.q3-t.q1)/Math.sqrt(e)}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"fast-isnumeric\":241}],948:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/constraints\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,f=e._fullLayout,h=o._id,p=h.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(o.c2l(c[l].pos,!0)),g+=(c[l].pts2||[]).length;if(d.length){var m=i.distinctVals(d,{unitMinDiff:\"category\"===o.type||\"multicategory\"===o.type}),v=m.minDiff/2;n.minDtick(o,m.minDiff,m.vals[0],!0);var y=f[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===f[t+\"mode\"]&&y>1,b=1-f[t+\"gap\"],_=1-f[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,T,k,M,A,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,I=E.side;if(L)w=T=M=L/2,k=0;else if(w=v,x){var P=a(f,o._id)+E.orientation,z=(f._alignmentOpts[P]||{})[E.alignmentgroup]||{},O=Object.keys(z.offsetGroups||{}).length,D=O||y;T=w*b*_/D,k=2*w*(((O?E._offsetIndex:C.num)+.5)/D-.5)*b,M=w*b/D}else T=w*b*_,k=0,M=w;C.dPos=w,C.bPos=k,C.bdPos=T,C.wHover=M;var R,F,B,N,j,U,V=k+T,q=Boolean(L);if(\"positive\"===I?(A=w*(L?1:.5),R=V,S=R=k):\"negative\"===I?(A=R=k,S=w*(L?1:.5),F=V):(A=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>A?(q=!0,j=Y,B=W):W>R&&(j=Y,B=A)),W<=A&&(B=A);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=A,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[h]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,vpadLinearized:!0,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(f)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/constraints\":835}],949:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../scatter/period_defaults\"),s=t(\"../bar/defaults\").handleGroupingDefaults,l=t(\"../../plots/cartesian/axis_autotype\"),c=t(\"./attributes\");function u(t,e,r,a){function o(t){var e=0;return t&&t.length&&(e+=1,n.isArrayOrTypedArray(t[0])&&t[0].length&&(e+=1)),e}function s(e){return n.validate(t[e],c[e])}var u,f=r(\"y\"),h=r(\"x\");if(\"box\"===e.type){var p=r(\"q1\"),d=r(\"median\"),g=r(\"q3\");e._hasPreCompStats=p&&p.length&&d&&d.length&&g&&g.length,u=Math.min(n.minRowLength(p),n.minRowLength(d),n.minRowLength(g))}var m,v,y=o(f),x=o(h),b=y&&n.minRowLength(f),_=x&&n.minRowLength(h),w=a.calendar,T={autotypenumbers:a.autotypenumbers};if(e._hasPreCompStats)switch(String(x)+String(y)){case\"00\":var k=s(\"x0\")||s(\"dx\");m=(s(\"y0\")||s(\"dy\"))&&!k?\"h\":\"v\",v=u;break;case\"10\":m=\"v\",v=Math.min(u,_);break;case\"20\":m=\"h\",v=Math.min(u,h.length);break;case\"01\":m=\"h\",v=Math.min(u,b);break;case\"02\":m=\"v\",v=Math.min(u,f.length);break;case\"12\":m=\"v\",v=Math.min(u,_,f.length);break;case\"21\":m=\"h\",v=Math.min(u,h.length,b);break;case\"11\":v=0;break;case\"22\":var M,A=!1;for(M=0;M<h.length;M++)if(\"category\"===l(h[M],w,T)){A=!0;break}if(A)m=\"v\",v=Math.min(u,_,f.length);else{for(M=0;M<f.length;M++)if(\"category\"===l(f[M],w,T)){A=!0;break}A?(m=\"h\",v=Math.min(u,h.length,b)):(m=\"v\",v=Math.min(u,_,f.length))}}else y>0?(m=\"v\",v=x>0?Math.min(_,b):Math.min(b)):x>0?(m=\"h\",v=Math.min(_)):v=0;if(v){e._length=v;var S=r(\"orientation\",m);e._hasPreCompStats?\"v\"===S&&0===x?(r(\"x0\",0),r(\"dx\",1)):\"h\"===S&&0===y&&(r(\"y0\",0),r(\"dy\",1)):\"v\"===S&&0===x?r(\"x0\"):\"h\"===S&&0===y&&r(\"y0\"),i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a)}else e.visible=!1}function f(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,c,\"marker.outliercolor\"),s=r(\"marker.line.outliercolor\"),l=\"outliers\";e._hasPreCompStats?l=\"all\":(o||s)&&(l=\"suspectedoutliers\");var u=r(a+\"points\",l);u?(r(\"jitter\",\"all\"===u?.3:0),r(\"pointpos\",\"all\"===u?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===u&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var f=r(\"hoveron\");\"all\"!==f&&-1===f.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function s(r,i){return n.coerce(t,e,c,r,i)}if(u(t,e,s,i),!1!==e.visible){o(t,e,i,s);var l=e._hasPreCompStats;l&&(s(\"lowerfence\"),s(\"upperfence\")),s(\"line.color\",(t.marker||{}).color||r),s(\"line.width\"),s(\"fillcolor\",a.addOpacity(e.line.color,.5));var h=!1;if(l){var p=s(\"mean\"),d=s(\"sd\");p&&p.length&&(h=!0,d&&d.length&&(h=\"sd\"))}s(\"boxmean\",h),s(\"whiskerwidth\"),s(\"width\"),s(\"quartilemethod\");var g=!1;if(l){var m=s(\"notchspan\");m&&m.length&&(g=!0)}else n.validate(t.notchwidth,c.notchwidth)&&(g=!0);s(\"notched\",g)&&s(\"notchwidth\"),f(t,e,s,{prefix:\"box\"})}},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,c,t)}for(var o=0;o<t.length;o++){var l=(i=t[o]).type;\"box\"!==l&&\"violin\"!==l||(r=i._input,\"group\"===e[l+\"mode\"]&&s(r,i,e,a))}},handleSampleDefaults:u,handlePointsDefaults:f}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/axis_autotype\":829,\"../../registry\":911,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"./attributes\":946}],950:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],951:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,f,h,p,d,g,m,v,y,x,b,_,w=t.cd,T=t.xa,k=t.ya,M=w[0].trace,A=w[0].t,S=\"violin\"===M.type,E=[],C=A.bdPos,L=A.wHover,I=function(t){return u.c2l(t.pos)+A.bPos-u.c2l(p)};S&&\"both\"!==M.side?(\"positive\"===M.side&&(m=function(t){var e=I(t);return a.inbox(e,e+L,v)},x=C,b=0),\"negative\"===M.side&&(m=function(t){var e=I(t);return a.inbox(e-L,e,v)},x=0,b=C)):(m=function(t){var e=I(t);return a.inbox(e-L,e+L,v)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-h,t.span[1]-h,v)}:function(t){return a.inbox(t.min-h,t.max-h,v)},\"h\"===M.orientation?(h=e,p=r,d=_,g=m,l=\"y\",u=k,c=\"x\",f=T):(h=r,p=e,d=m,g=_,l=\"x\",u=T,c=\"y\",f=k);var P=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}v=t.maxHoverDistance-P,y=t.maxSpikeDistance-P;var O=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,O,t),!1===t.index)return[];var D=w[t.index],R=M.line.color,F=(M.marker||{}).color;o.opacity(R)&&M.line.width?t.color=R:o.opacity(F)&&M.boxpoints?t.color=F:t.color=M.fillcolor,t[l+\"0\"]=u.c2p(D.pos+A.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+A.bPos+x,!0),t[l+\"LabelVal\"]=void 0!==D.orig_p?D.orig_p:D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/v,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(M.boxmean||(M.meanline||{}).visible)&&j.push(\"mean\"),(M.boxpoints||M.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=f.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(A.labels?A.labels[V]+\" \":\"\")+n.hoverLabelText(f,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===M.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,f=t.ya,h=c[0].trace,p=u.c2p(e),d=f.c2p(r),g=a.quadrature((function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)}),(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(f.c2p(t.y)-d)-e,1-3/e)})),m=!1,v=0;v<c.length;v++){o=c[v];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,m=[v,y])}}if(!m)return!1;l=(o=c[m[0]]).pts[m[1]];var b=u.c2p(l.x,!0),_=f.c2p(l.y,!0),w=l.mrc||1;n=i.extendFlat({},t,{index:l.i,color:(h.marker||{}).color,name:h.name,x0:b-w,x1:b+w,y0:_-w,y1:_+w,spikeDistance:t.distance,hovertemplate:h.hovertemplate});var T,k=o.orig_p,M=void 0!==k?k:o.pos;return\"h\"===h.orientation?(T=f,n.xLabelVal=l.x,n.yLabelVal=M):(T=u,n.xLabelVal=M,n.yLabelVal=l.y),n[T._id.charAt(0)+\"Spike\"]=T.c2p(o.pos,!0),s(l,h,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],952:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":946,\"./calc\":947,\"./cross_trace_calc\":948,\"./defaults\":949,\"./event_data\":950,\"./hover\":951,\"./layout_attributes\":953,\"./layout_defaults\":954,\"./plot\":955,\"./select\":956,\"./style\":957}],953:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,(function(r,n){return i.coerce(t,e,a,r,n)}),\"box\")},_supply:o}},{\"../../lib\":778,\"../../registry\":911,\"./layout_attributes\":953}],955:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\");function o(t,e,r,a){var o,s,l=\"h\"===r.orientation,c=e.val,u=e.pos,f=!!u.rangebreaks,h=a.bPos,p=a.wdPos||0,d=a.bPosPxOffset||0,g=r.whiskerwidth||0,m=r.notched||!1,v=m?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var y=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);y.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),y.exit().remove(),y.each((function(t){if(t.empty)return\"M0,0Z\";var e=u.c2l(t.pos+h,!0),a=u.l2p(e-o)+d,y=u.l2p(e+s)+d,x=f?(a+y)/2:u.l2p(e)+d,b=r.whiskerwidth,_=f?a*b+(1-b)*x:u.l2p(e-p)+d,w=f?y*b+(1-b)*x:u.l2p(e+p)+d,T=u.l2p(e-o*v)+d,k=u.l2p(e+s*v)+d,M=c.c2p(t.q1,!0),A=c.c2p(t.q3,!0),S=i.constrain(c.c2p(t.med,!0),Math.min(M,A)+1,Math.max(M,A)-1),E=void 0===t.lf||!1===r.boxpoints,C=c.c2p(E?t.min:t.lf,!0),L=c.c2p(E?t.max:t.uf,!0),I=c.c2p(t.ln,!0),P=c.c2p(t.un,!0);l?n.select(this).attr(\"d\",\"M\"+S+\",\"+T+\"V\"+k+\"M\"+M+\",\"+a+\"V\"+y+(m?\"H\"+I+\"L\"+S+\",\"+k+\"L\"+P+\",\"+y:\"\")+\"H\"+A+\"V\"+a+(m?\"H\"+P+\"L\"+S+\",\"+T+\"L\"+I+\",\"+a:\"\")+\"ZM\"+M+\",\"+x+\"H\"+C+\"M\"+A+\",\"+x+\"H\"+L+(0===g?\"\":\"M\"+C+\",\"+_+\"V\"+w+\"M\"+L+\",\"+_+\"V\"+w)):n.select(this).attr(\"d\",\"M\"+T+\",\"+S+\"H\"+k+\"M\"+a+\",\"+M+\"H\"+y+(m?\"V\"+I+\"L\"+k+\",\"+S+\"L\"+y+\",\"+P:\"\")+\"V\"+A+\"H\"+a+(m?\"V\"+P+\"L\"+T+\",\"+S+\"L\"+a+\",\"+I:\"\")+\"ZM\"+x+\",\"+M+\"V\"+C+\"M\"+x+\",\"+A+\"V\"+L+(0===g?\"\":\"M\"+_+\",\"+C+\"H\"+w+\"M\"+_+\",\"+L+\"H\"+w))}))}function s(t,e,r,n){var o=e.x,s=e.y,l=n.bdPos,c=n.bPos,u=r.boxpoints||r.points;i.seedPseudoRandom();var f=t.selectAll(\"g.points\").data(u?function(t){return t.forEach((function(t){t.t=n,t.trace=r})),t}:[]);f.enter().append(\"g\").attr(\"class\",\"points\"),f.exit().remove();var h=f.selectAll(\"path\").data((function(t){var e,n,a=t.pts2,o=Math.max((t.max-t.min)/10,t.q3-t.q1),s=1e-9*o,f=.01*o,h=[],p=0;if(r.jitter){if(0===o)for(p=1,h=new Array(a.length),e=0;e<a.length;e++)h[e]=1;else for(e=0;e<a.length;e++){var d=Math.max(0,e-5),g=a[d].v,m=Math.min(a.length-1,e+5),v=a[m].v;\"all\"!==u&&(a[e].v<t.lf?v=Math.min(v,t.lf):g=Math.max(g,t.uf));var y=Math.sqrt(f*(m-d)/(v-g+s))||0;y=i.constrain(Math.abs(y),0,1),h.push(y),p=Math.max(y,p)}n=2*r.jitter/(p||1)}for(e=0;e<a.length;e++){var x=a[e],b=x.v,_=r.jitter?n*h[e]*(i.pseudoRandom()-.5):0,w=t.pos+c+l*(r.pointpos+_);\"h\"===r.orientation?(x.y=w,x.x=b):(x.x=w,x.y=b),\"suspectedoutliers\"===u&&b<t.uo&&b>t.lo&&(x.so=!0)}return a}));h.enter().append(\"path\").classed(\"point\",!0),h.exit().remove(),h.call(a.translatePoints,o,s)}function l(t,e,r,a){var o,s,l=e.val,c=e.pos,u=!!c.rangebreaks,f=a.bPos,h=a.bPosPxOffset||0,p=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var d=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);d.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),d.exit().remove(),d.each((function(t){var e=c.c2l(t.pos+f,!0),i=c.l2p(e-o)+h,a=c.l2p(e+s)+h,d=u?(i+a)/2:c.l2p(e)+h,g=l.c2p(t.mean,!0),m=l.c2p(t.mean-t.sd,!0),v=l.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+g+\",\"+i+\"V\"+a+(\"sd\"===p?\"m0,0L\"+m+\",\"+d+\"L\"+g+\",\"+i+\"L\"+v+\",\"+d+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+g+\"H\"+a+(\"sd\"===p?\"m0,0L\"+d+\",\"+m+\"L\"+i+\",\"+g+\"L\"+d+\",\"+v+\"Z\":\"\"))}))}e.exports={plot:function(t,e,r,a){var c=e.xaxis,u=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each((function(t){var e,r,i=n.select(this),a=t[0],f=a.t,h=a.trace;(f.wdPos=f.bdPos*h.whiskerwidth,!0!==h.visible||f.empty)?i.remove():(\"h\"===h.orientation?(e=u,r=c):(e=c,r=u),o(i,{pos:e,val:r},h,f),s(i,{x:c,y:u},h,f),l(i,{pos:e,val:r},h,f))}))},plotBoxAndWhiskers:o,plotPoints:s,plotBoxMean:l}},{\"../../components/drawing\":665,\"../../lib\":778,d3:169}],956:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],957:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each((function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}}));else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}}))},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":643,\"../../components/drawing\":665,d3:169}],958:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={xperiod:i.xperiod,xperiod0:i.xperiod0,xperiodalignment:i.xperiodalignment,x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":778,\"../box/attributes\":946,\"../ohlc/attributes\":1133}],959:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),o=t(\"../ohlc/calc\").calcCommon;function s(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,l=i.getFromId(t,e.xaxis),c=i.getFromId(t,e.yaxis),u=l.makeCalcdata(e,\"x\"),f=a(e,l,\"x\",u),h=o(t,e,u,f,c,s);return h.length?(n.extendFlat(h[0].t,{num:r._numBoxes,dPos:n.distinctVals(f).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,h):[{t:{empty:!0}}]}},{\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../ohlc/calc\":1134}],960:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"../scatter/period_defaults\"),s=t(\"./attributes\");function l(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}a(t,e,c,i)?(o(t,e,i,c,{x:!0}),c(\"line.width\"),l(t,e,c,\"increasing\"),l(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":643,\"../../lib\":778,\"../ohlc/ohlc_defaults\":1138,\"../scatter/period_defaults\":1207,\"./attributes\":958}],961:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":841,\"../box/cross_trace_calc\":948,\"../box/layout_attributes\":953,\"../box/layout_defaults\":954,\"../box/plot\":955,\"../box/style\":957,\"../ohlc/hover\":1136,\"../ohlc/select\":1140,\"./attributes\":958,\"./calc\":959,\"./defaults\":960}],962:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach((function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,autotypenumbersDflt:r.autotypenumbers,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})}))}(t,e,r,o)}},{\"../../plot_api/plot_template\":817,\"./axis_defaults\":967}],963:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;for(var i=1/0,a=-1/0,o=e.length,s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":778}],964:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":642,\"../../plots/font_attributes\":856,\"./axis_attributes\":966}],965:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,g,m,v,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,T=\"a\"===y?e.a.length:e.b.length,k=\"a\"===y?e.b.length:e.a.length,M=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),A=\"a\"===y?function(e){return t.evalxy([],e,M)}:function(e){return t.evalxy([],M,e)};x&&(s=Math.max(0,Math.min(k-2,M)),l=M-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),I=C>0?Math.floor:Math.ceil,P=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,O=C>0?Math.max:Math.min,D=I(S+L),R=P(E-L),F=[[f=A(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=O(S,a),v=(m=z(E,a+C))-g,u=Math.max(0,Math.min(T-2,Math.floor(.5*(g+m)))),h=A(m),x&&(p=o(u,g-u),d=o(u,m-u),c.push([f[0]+p[0]/3*v,f[1]+p[1]/3*v]),c.push([h[0]-d[0]/3*v,h[1]-d[1]/3*v])),c.push(h),F.push(c),f=h;return F}},{\"../../lib\":778}],966:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autotypenumbers:a.autotypenumbers,autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":642,\"../../constants/docs\":748,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/font_attributes\":856}],967:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),f=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var h=r.letter,p=r.font||{},d=n[h+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function m(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name),g(\"autotypenumbers\",r.autotypenumbersDflt);var v=g(\"type\");(\"-\"===v&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=f(e,n,{autotypenumbers:t.autotypenumbers})}(e,r.data),\"-\"===e.type?e.type=\"linear\":v=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",h+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"minexponent\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=h,\"date\"===v)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,v),l(t,e,g,v,r),c(t,e,g,{data:r.data,dataAttr:h});var b=m(\"gridcolor\",i(y,.3)),_=m(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var T=m(\"startlinecolor\",y),k=m(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!T||!!k)||(delete e.startlinecolor,delete e.startlinewidth);var M=m(\"endlinecolor\",y),A=m(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!M||!!A)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.minexponent,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/axis_autotype\":829,\"../../plots/cartesian/category_order_defaults\":832,\"../../plots/cartesian/set_convert\":848,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_value_defaults\":851,\"../../registry\":911,\"./attributes\":964}],968:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),f=t(\"./smooth_fill_2d_array\"),h=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,m=e.baxis,v=e.x,y=e.y,x=[];v&&i(v)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&h(e,g,m,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;v=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var T=\"index\"===g.cheatertype?b.length:b,k=\"index\"===m.cheatertype?_.length:_;v=a(T,k,e.cheaterslope)}e._x=v=u(v),e._y=y=u(y),f(v,b,_),f(y,b,_),p(e),e.setScale();var M=o(v),A=o(y),S=.5*(M[1]-M[0]),E=.5*(M[1]+M[0]),C=.5*(A[1]-A[0]),L=.5*(A[1]+A[0]);return M=[E-1.3*S,E+1.3*S],A=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,M,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,A,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,m),w.clipsegments=c(e._xctrl,e._yctrl,g,m),w.x=v,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../heatmap/clean_2d_array\":1067,\"../heatmap/convert_column_xyz\":1069,\"./array_minmax\":963,\"./calc_clippath\":969,\"./calc_gridlines\":970,\"./calc_labels\":971,\"./cheater_basis\":973,\"./set_convert\":986,\"./smooth_fill_2d_array\":987}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,f=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=f;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[f][i],o[u-i]=e[f][i];for(s.push({x:a,y:o,bicubic:l}),i=f,a=[],o=[];i>=0;i--)a[f-i]=t[i][0],o[f-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,f,h,p,d,g,m,v,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],T=b._boundarylines=[],k=t[\"_\"+r],M=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var A=t._xctrl,S=t._yctrl,E=A[0].length,C=A.length,L=t._a.length,I=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var P=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,f,p,d,g,m,v=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(I-2,a))),s=a-o,x.length=I,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,f=t.evalxy([],i,a),M.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),v.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),v.push(f[0]-d[0]/3),y.push(f[1]-d[1]/3)),v.push(f[0]),y.push(f[1]),l=f;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=I,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<I;a++)o=Math.min(I-2,a),s=a-o,f=t.evalxy([],i,a),M.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),v.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),m=t.dxydj([],c,a-1,u,1),v.push(f[0]-m[0]/3),y.push(f[1]-m[1]/3)),v.push(f[0]),y.push(f[1]),l=f;return x.axisLetter=e,x.axis=b,x.crossAxis=M,x.value=n,x.constvar=r,x.index=h,x.x=v,x.y=y,x.smoothing=M.smoothing,x}function O(n){var i,a,o,s,l,c=[],u=[],f={};if(f.length=x.length,f.crossLength=k.length,\"b\"===e)for(o=Math.max(0,Math.min(I-2,n)),l=Math.min(1,Math.max(0,n-o)),f.xy=function(e){return t.evalxy([],e,n)},f.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=A[n*P][i],u[i]=S[n*P][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),f.xy=function(e){return t.evalxy([],n,e)},f.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=A[i][n*P],u[i]=S[i][n*P];return f.axisLetter=e,f.axis=b,f.crossAxis=M,f.value=x[n],f.constvar=r,f.index=n,f.x=c,f.y=u,f.smoothing=M.smoothing,f}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort((function(t,e){return t-e})))[0]-1,f=c[1]+1,h=u;h<f;h++)(o=b.arraytick0+b.arraydtick*h)<0||o>x.length-1||_.push(i(O(o),{color:b.gridcolor,width:b.gridwidth}));for(h=u;h<f;h++)if(s=b.arraytick0+b.arraydtick*h,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(m=x[s],v=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=m+(v-m)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(i(O(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(i(O(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort((function(t,e){return t-e})))[0],f=c[1],h=u;h<=f;h++)p=b.tick0+b.dtick*h,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(h=u-1;h<f+1;h++)for(p=b.tick0+b.dtick*h,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":768,\"../../plots/cartesian/axes\":828}],971:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":768,\"../../plots/cartesian/axes\":828}],972:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,f=(c*c*a-l*l*s)*n,h=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(h&&u/h),e[1]+(h&&f/h)],[e[0]-(p&&u/p),e[1]-(p&&f/p)]]}},{}],973:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],f=n(t)?t.length:t,h=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(f-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(h-1));var g=1/0,m=-1/0;for(a=0;a<h;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(h-1),i=0;i<f;i++)c=(p?(p[i]-p[0])*o:i/(f-1))-l*r,g=Math.min(c,g),m=Math.max(c,m),u[a][i]=c;var v=1/(m-g),y=-g*v;for(a=0;a<h;a++)for(i=0;i<f;i++)u[a][i]=v*u[a][i]+y;return u}},{\"../../lib\":778}],974:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,f,h,p,d,g,m,v,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),f=0;f<w;f++)t[f]=i(t[f],_),e[f]=i(e[f],_);for(u=0,h=0;u<b;u++,h+=l?3:1)for(p=t[h],d=e[h],g=r[u],m=o[u],c=0,f=0;c<x;c++,f+=s?3:1)p[f]=g[c],d[f]=m[c];if(s)for(u=0,h=0;u<b;u++,h+=l?3:1){for(c=1,f=3;c<x-1;c++,f+=3)v=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[h][f-1]=v[0][0],e[h][f-1]=v[0][1],t[h][f+1]=v[1][0],e[h][f+1]=v[1][1];y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=y[0],e[h][1]=y[1],y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=y[0],e[h][_-2]=y[1]}if(l)for(f=0;f<_;f++){for(h=3;h<w-3;h+=3)v=n([t[h-3][f],e[h-3][f]],[t[h][f],e[h][f]],[t[h+3][f],e[h+3][f]],l),t[h-1][f]=v[0][0],e[h-1][f]=v[0][1],t[h+1][f]=v[1][0],e[h+1][f]=v[1][1];y=a([t[0][f],e[0][f]],[t[2][f],e[2][f]],[t[3][f],e[3][f]]),t[1][f]=y[0],e[1][f]=y[1],y=a([t[w-1][f],e[w-1][f]],[t[w-3][f],e[w-3][f]],[t[w-4][f],e[w-4][f]]),t[w-2][f]=y[0],e[w-2][f]=y[1]}if(s&&l)for(h=1;h<w;h+=(h+1)%3==0?2:1){for(f=3;f<_-3;f+=3)v=n([t[h][f-3],e[h][f-3]],[t[h][f],e[h][f]],[t[h][f+3],e[h][f+3]],s),t[h][f-1]=.5*(t[h][f-1]+v[0][0]),e[h][f-1]=.5*(e[h][f-1]+v[0][1]),t[h][f+1]=.5*(t[h][f+1]+v[1][0]),e[h][f+1]=.5*(e[h][f+1]+v[1][1]);y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=.5*(t[h][1]+y[0]),e[h][1]=.5*(e[h][1]+y[1]),y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=.5*(t[h][_-2]+y[0]),e[h][_-2]=.5*(e[h][_-2]+y[1])}return[t,e]}},{\"../../lib\":778,\"./catmull_rom\":972}],975:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],976:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=1-i,d=p*p,g=p*i*2,m=-3*d,v=3*(d-g),y=3*(g-h),x=3*h,b=a*a,_=b*a,w=1-a,T=w*w,k=T*w;for(f=0;f<t.length;f++)o=m*(u=t[f])[n][r]+v*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=m*u[n+1][r]+v*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=m*u[n+2][r]+v*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=m*u[n+3][r]+v*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[f]=k*o+3*(T*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,f=1-i,h=f*f,p=f*i*2,d=-3*h,g=3*(h-p),m=3*(p-u),v=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+m*c[n][r+2]+v*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+m*c[n+1][r+2]+v*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),n*=3;var h=a*a,p=h*a,d=1-a,g=d*d,m=g*d;for(u=0;u<t.length;u++)o=(f=t[u])[n][r+1]-f[n][r],s=f[n+1][r+1]-f[n+1][r],l=f[n+2][r+1]-f[n+2][r],c=f[n+3][r+1]-f[n+3][r],e[u]=m*o+3*(g*a*s+d*h*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],977:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=h*i,d=1-i,g=d*d,m=g*d,v=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),T=3*(b-v),k=3*v;for(f=0;f<t.length;f++)o=_*(u=t[f])[n][r]+w*u[n+1][r]+T*u[n+2][r]+k*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+T*u[n+2][r+1]+k*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+T*u[n+2][r+2]+k*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+T*u[n+2][r+3]+k*u[n+3][r+3],e[f]=m*o+3*(g*i*s+d*h*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3;var h=a*a,p=h*a,d=1-a,g=d*d,m=g*d;for(u=0;u<t.length;u++)o=(f=t[u])[n+1][r]-f[n][r],s=f[n+1][r+1]-f[n][r+1],l=f[n+1][r+2]-f[n][r+2],c=f[n+1][r+3]-f[n][r+3],e[u]=m*o+3*(g*a*s+d*h*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,f=a*a,h=1-a,p=h*h,d=h*a*2,g=-3*p,m=3*(p-d),v=3*(d-f),y=3*f;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+m*c[n+1][r]+v*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+m*c[n+1][r+1]+v*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],978:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,f;e||(e=[]);var h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));h*=3,p*=3;var m=d*d,v=m*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,T=1-g,k=T*T,M=k*T;for(f=0;f<t.length;f++)i=b*(u=t[f])[p][h]+3*(x*d*u[p][h+1]+y*m*u[p][h+2])+v*u[p][h+3],s=b*u[p+1][h]+3*(x*d*u[p+1][h+1]+y*m*u[p+1][h+2])+v*u[p+1][h+3],l=b*u[p+2][h]+3*(x*d*u[p+2][h+1]+y*m*u[p+2][h+2])+v*u[p+2][h+3],c=b*u[p+3][h]+3*(x*d*u[p+3][h+1]+y*m*u[p+3][h+2])+v*u[p+3][h+3],e[f]=M*i+3*(k*g*s+T*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));h*=3;var m=d*d,v=m*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+g*f[p+1][h],s=_*f[p][h+1]+g*f[p+1][h+1],l=_*f[p][h+2]+g*f[p+1][h+1],c=_*f[p][h+3]+g*f[p+1][h+1],e[u]=b*i+3*(x*d*s+y*m*l)+v*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));p*=3;var m=g*g,v=m*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+d*f[p][h+1],s=_*f[p+1][h]+d*f[p+1][h+1],l=_*f[p+2][h]+d*f[p+2][h+1],c=_*f[p+3][h]+d*f[p+3][h+1],e[u]=b*i+3*(x*g*s+y*m*l)+v*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),f=Math.max(0,Math.min(Math.floor(n),o)),h=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-f)),d=1-p,g=1-h;for(l=0;l<t.length;l++)i=g*(c=t[l])[f][u]+h*c[f][u+1],s=g*c[f+1][u]+h*c[f+1][u+1],e[l]=d*i+p*s;return e}}},{}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":642,\"../../lib\":778,\"./ab_defaults\":962,\"./attributes\":964,\"./xy_defaults\":988}],980:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":964,\"./calc\":968,\"./defaults\":979,\"./plot\":985}],981:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],982:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":778}],984:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),f=Math.sqrt(a[0]*a[0]+a[1]*a[1]),h=(i[0]*a[0]+i[1]*a[1])/u/f;c=Math.max(0,h)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],985:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=c.strRotate,f=c.strTranslate,h=t(\"../../constants/alignment\");function p(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each((function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),f=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",f).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")})),u.exit().remove()}function d(t,e,r,a,o,c,h,p){var d=c.selectAll(\"text.\"+p).data(h);d.enter().append(\"text\").classed(p,!0);var g=0,m={};return d.each((function(o,c){var h;if(\"auto\"===o.axis.tickangle)h=s(a,e,r,o.xy,o.dxy);else{var p=(o.axis.tickangle+180)*Math.PI/180;h=s(a,e,r,o.xy,[Math.cos(p),Math.sin(p)])}c||(m={angle:h.angle,flip:h.flip});var d=(o.endAnchor?-1:1)*h.flip,v=n.select(this).attr({\"text-anchor\":d>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),y=i.bBox(this);v.attr(\"transform\",f(h.p[0],h.p[1])+u(h.angle)+f(o.axis.labelpadding*d,.3*y.height)),g=Math.max(g,y.width+o.axis.labelpadding)})),d.exit().remove(),m.maxExtent=g,m}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,f=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each((function(e){var r=n.select(this),i=e[0],h=i.trace,g=h.aaxis,m=h.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",h.opacity),p(l,u,x,g,\"a\",g._gridlines),p(l,u,x,m,\"b\",m._gridlines),p(l,u,y,g,\"a\",g._minorgridlines),p(l,u,y,m,\"b\",m._minorgridlines),p(l,u,b,g,\"a-boundary\",g._boundarylines),p(l,u,b,m,\"b-boundary\",m._boundarylines);var w=d(t,l,u,h,i,_,g._labels,\"a-label\"),T=d(t,l,u,h,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,f,h,p,d=c.aggNums(Math.min,null,r.a),g=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+g),f=m,h=r.ab2xy(u,f,!0),p=r.dxyda_rough(u,f),void 0===o.angle&&c.extendFlat(o,s(r,i,a,h,r.dxydb_rough(u,f)));v(t,e,r,n,h,p,r.aaxis,i,a,o,\"a-title\"),u=d,f=.5*(m+y),h=r.ab2xy(u,f,!0),p=r.dxydb_rough(u,f),void 0===l.angle&&c.extendFlat(l,s(r,i,a,h,r.dxyda_rough(u,f)));v(t,e,r,n,h,p,r.baxis,i,a,l,\"b-title\")}(t,_,h,i,l,u,w,T),function(t,e,r,n,i){var s,l,u,f,h=r.select(\"#\"+t._clipPathId);h.size()||(h=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(h,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(f=0;f<d.length;f++)s=d[f],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var m=\"M\"+g.join(\"L\")+\"Z\";h.attr(\"id\",t._clipPathId),p.attr(\"d\",m)}(h,i,f,l,u)}))};var g=h.LINE_SPACING,m=(1-h.MID_SHIFT)/g+1;function v(t,e,r,a,o,c,h,p,d,v,y){var x=[];h.title.text&&x.push(h.title.text);var b=e.selectAll(\"text.\"+y).data(x),_=v.maxExtent;b.enter().append(\"text\").classed(y,!0),b.each((function(){var e=s(r,p,d,o,c);-1===[\"start\",\"both\"].indexOf(h.showticklabels)&&(_=0);var a=h.title.font.size;_+=a+h.title.offset;var y=(v.angle+(v.flip<0?180:0)-e.angle+450)%360,x=y>90&&y<270,b=n.select(this);b.text(h.title.text).call(l.convertToTspans,t),x&&(_=(-l.lineCount(b)+m)*g*a-_),b.attr(\"transform\",f(e.p[0],e.p[1])+u(e.angle)+f(0,_)).attr(\"text-anchor\",\"middle\").call(i.font,h.title.font)})),b.exit().remove()}},{\"../../components/drawing\":665,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"./makepath\":982,\"./map_1d_array\":983,\"./orient_text\":984,d3:169}],986:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,f=t.aaxis,h=t.baxis,p=e[0],d=e[c-1],g=r[0],m=r[u-1],v=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=v*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,m+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<m},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>m},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,f.smoothing,h.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,f.smoothing,h.smoothing),t.dxydi=s([t._xctrl,t._yctrl],f.smoothing,h.smoothing),t.dxydj=l([t._xctrl,t._yctrl],f.smoothing,h.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var f,h,p,d,g=0,m=0,v=[];n<e[0]?(f=0,h=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(f=c-2,h=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):h=o-(f=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,m=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,m=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(v,f,p,h,d),l[0]+=v[0]*g,l[1]+=v[1]*g),m&&(t.dxydj(v,f,p,h,d),l[0]+=v[0]*m,l[1]+=v[1]*m)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=v*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":798,\"./compute_control_points\":974,\"./constants\":975,\"./create_i_derivative_evaluator\":976,\"./create_j_derivative_evaluator\":977,\"./create_spline_evaluator\":978}],987:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function f(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var h,p,d,g,m,v,y,x,b,_,w,T=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=f(i,a)),T=Math.max(T,Math.abs(t[a][i]));if(!s.length)return t;var k=0,M=0,A=s.length;do{for(k=0,o=0;o<A;o++){i=s[o],a=l[o];var S,E,C,L,I,P,z=0,O=0;0===i?(C=e[I=Math.min(c-1,2)],L=e[1],S=t[a][I],O+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[I=Math.max(0,c-3)],L=e[c-2],S=t[a][I],O+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(h=r[a+1]-r[a],O+=((p=r[a]-r[a-1])*t[a+1][i]+h*t[a-1][i])/(p+h),z++),0===a?(C=r[P=Math.min(u-1,2)],L=r[1],S=t[P][i],O+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[P=Math.max(0,u-3)],L=r[u-2],S=t[P][i],O+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(h=e[i+1]-e[i],O+=((p=e[i]-e[i-1])*t[a][i+1]+h*t[a][i-1])/(p+h),z++),z?O/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(m=r[a+1]-r[a])*(v=r[a]-r[a-1])*(m+v),O=((y=d*g*(d+g))*(v*t[a+1][i]+m*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(v+m))),k+=(_=(b=O-t[a][i])/T)*_,w=z?0:.85,t[a][i]+=b*(1+w)}k=Math.sqrt(k)}while(M++<100&&k>1e-5);return n.log(\"Smoother converged to\",k,\"after\",M,\"iterations\"),t}},{\"../../lib\":778}],988:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":778}],989:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},geojson:l({},i.geojson,{}),featureidkey:i.featureidkey,text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n(),showlegend:l({},o.showlegend,{dflt:!1})},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":642,\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scattergeo/attributes\":1229}],990:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var f=0;f<c;f++){var h=u[f]={},p=e.locations[f],d=e.z[f];r(p)&&n(d)?(h.loc=p,h.z=d):(h.loc=null,h.z=i),h.index=f}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc_selection\":1189,\"fast-isnumeric\":241}],991:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");if(l&&l.length&&n.isArrayOrTypedArray(c)&&c.length){e._length=Math.min(l.length,c.length);var u,f=s(\"geojson\");(\"string\"==typeof f&&\"\"!==f||n.isPlainObject(f))&&(u=\"geojson-id\"),\"geojson-id\"===s(\"locationmode\",u)&&s(\"featureidkey\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)}else e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":989}],992:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t.ct=a.ct,t}},{}],993:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,f=u[0].trace,h=t.subplot,p=[e,r],d=[e+360,r];for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains(p)&&(c=!c),o._polygons[l].contains(d)&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(h.mockAxis,h.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=String(r.loc),s=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),l=-1!==s.indexOf(\"name\"),c=-1!==s.indexOf(\"location\"),u=-1!==s.indexOf(\"z\"),f=-1!==s.indexOf(\"text\"),h=[];!l&&c?t.nameOverride=o:(l&&(t.nameOverride=e.name),c&&h.push(o));u&&h.push(t.zLabel);f&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,f,o),[t]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./attributes\":989}],994:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\",\"showLegend\"],meta:{}}},{\"../../plots/geo\":860,\"../heatmap/colorbar\":1068,\"./attributes\":989,\"./calc\":990,\"./defaults\":991,\"./event_data\":992,\"./hover\":993,\"./plot\":995,\"./select\":996,\"./style\":997}],995:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/geo_location_utils\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../plots/cartesian/autorange\").findExtremes,l=t(\"./style\").style;e.exports={calcGeoJSON:function(t,e){for(var r=t[0].trace,n=e[r.geo],i=n._subplot,l=r.locationmode,c=r._length,u=\"geojson-id\"===l?a.extractTraceFeature(t):o(r,i.topojson),f=[],h=[],p=0;p<c;p++){var d=t[p],g=\"geojson-id\"===l?d.fOut:a.locationToFeature(l,d.loc,u);if(g){d.geojson=g,d.ct=g.properties.ct,d._polygons=a.feature2polygons(g);var m=a.computeBbox(g);f.push(m[0],m[2]),h.push(m[1],m[3])}else d.geojson=null}if(\"geojson\"===n.fitbounds&&\"geojson-id\"===l){var v=a.computeBbox(a.getTraceGeojson(r));f=[v[0],v[2]],h=[v[1],v[3]]}var y={padded:!0};r._extremes.lon=s(n.lonaxis._ax,f,y),r._extremes.lat=s(n.lataxis._ax,h,y)},plot:function(t,e,r){var a=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(a,r,\"trace choropleth\").each((function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)}))}}},{\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/topojson_utils\":806,\"../../plots/cartesian/autorange\":827,\"./style\":997,d3:169}],996:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],997:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each((function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)})),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../components/drawing\":665,d3:169}],998:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:s({},n.featureidkey,{}),below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:s({},n.marker.line.color,{editType:\"plot\"}),width:s({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:s({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:s({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:s({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]}),showlegend:s({},o.showlegend,{dflt:!1})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../choropleth/attributes\":989}],999:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/geojson_utils\").makeBlank,l=t(\"../../lib/geo_location_utils\");function c(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var a=o.makeSelectedPointStyleFns(r),s=0;s<t.length;s++){var l=t[s];l.fOut&&(l.fOut.properties.mo2=a.selectedOpacityFn(l))}e={type:\"identity\",property:\"mo2\"}}else e=i.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return i.extendFlat(n.fill.paint,{\"fill-opacity\":e}),i.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,o={layout:{visibility:\"none\"},paint:{}},u={layout:{visibility:\"none\"},paint:{}},f=e._opts={fill:o,line:u,geojson:s()};if(!r)return f;var h=l.extractTraceFeature(t);if(!h)return f;var p,d,g,m=a.makeColorScaleFuncFromTrace(e),v=e.marker,y=v.line||{};i.isArrayOrTypedArray(v.opacity)&&(p=function(t){var e=t.mo;return n(e)?+i.constrain(e,0,1):0}),i.isArrayOrTypedArray(y.color)&&(d=function(t){return t.mlc}),i.isArrayOrTypedArray(y.width)&&(g=function(t){return t.mlw});for(var x=0;x<t.length;x++){var b=t[x],_=b.fOut;if(_){var w=_.properties;w.fc=m(b.z),p&&(w.mo=p(b)),d&&(w.mlc=d(b)),g&&(w.mlw=g(b)),b.ct=w.ct,b._polygons=l.feature2polygons(_)}}var T=p?{type:\"identity\",property:\"mo\"}:v.opacity;return i.extendFlat(o.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":T}),i.extendFlat(u.paint,{\"line-color\":d?{type:\"identity\",property:\"mlc\"}:y.color,\"line-width\":g?{type:\"identity\",property:\"mlw\"}:y.width,\"line-opacity\":T}),o.layout.visibility=\"visible\",u.layout.visibility=\"visible\",f.geojson={type:\"FeatureCollection\",features:h},c(t),f},convertOnSelect:c}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/geojson_utils\":772,\"fast-isnumeric\":241}],1e3:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(s(\"featureidkey\"),e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":998}],1001:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\",\"showLegend\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":885,\"../choropleth/calc\":990,\"../choropleth/event_data\":992,\"../choropleth/hover\":993,\"../choropleth/select\":996,\"../heatmap/colorbar\":1068,\"./attributes\":998,\"./defaults\":1e3,\"./plot\":1002}],1002:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.type=\"choroplethmapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":883,\"./convert\":999}],1003:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){l[t]=a[t]})),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1004:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],f=i[c],h=a[c],p=Math.sqrt(u*u+f*f+h*h);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1005:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var f={xaxis:0,yaxis:1,zaxis:2},h={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[f[e]];return a(t,(function(t){return n.d2l(t)*o}))}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=h[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),m=e.lightposition;return g.lightPosition=[m.x,m.y,m.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/gl3d/zip3\":881,\"gl-cone3d\":260}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1003}],1007:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1003,\"./calc\":1004,\"./convert\":1005,\"./defaults\":1006}],1008:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,f=c.INTERVAL_OPS,h=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,hoverongaps:n.hoverongaps,connectgaps:l({},n.connectgaps,{}),fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(f),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},h.color,{editType:\"style+colorbars\"}),width:{valType:\"number\",min:0,editType:\"style+colorbars\"},dash:o,smoothing:l({},h.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../constants/docs\":748,\"../../constants/filter_ops\":749,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../heatmap/attributes\":1065,\"../scatter/attributes\":1187}],1009:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var f=c.start,h=o(c),p=c.size||1,d=Math.floor((h-f)/p)+1;isFinite(p)||(p=1,d=1);var g=f-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":655,\"../heatmap/calc\":1066,\"./end_plus\":1019,\"./set_contours\":1027}],1010:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t[0],i=n.z;switch(e.type){case\"levels\":var a=Math.min(i[0][0],i[0][1]);for(r=0;r<t.length;r++){var o=t[r];o.prefixBoundary=!o.edgepaths.length&&(a>o.level||o.starts.length&&a===o.level)}break;case\"constraint\":if(n.prefixBoundary=!1,n.edgepaths.length)return;var s=n.x.length,l=n.y.length,c=-1/0,u=1/0;for(r=0;r<l;r++)u=Math.min(u,i[r][0]),u=Math.min(u,i[r][s-1]),c=Math.max(c,i[r][0]),c=Math.max(c,i[r][s-1]);for(r=1;r<s-1;r++)u=Math.min(u,i[0][r]),u=Math.min(u,i[l-1][r]),c=Math.max(c,i[0][r]),c=Math.max(c,i[l-1][r]);var f,h,p=e.value;switch(e._operation){case\">\":p>c&&(n.prefixBoundary=!0);break;case\"<\":(p<u||n.starts.length&&p===u)&&(n.prefixBoundary=!0);break;case\"[]\":f=Math.min(p[0],p[1]),((h=Math.max(p[0],p[1]))<u||f>c||n.starts.length&&h===u)&&(n.prefixBoundary=!0);break;case\"][\":f=Math.min(p[0],p[1]),h=Math.max(p[0],p[1]),f<u&&h>c&&(n.prefixBoundary=!0)}}}},{}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var f=n.extractOpts(e);r._fillgradient=f.reversescale?n.flipScale(f.colorscale):f.colorscale,r._zrange=[f.min,f.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":655,\"./end_plus\":1019,\"./make_color_map\":1024}],1012:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],1013:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,f){var h,p,d,g=e.contours,m=r(\"contours.operation\");(g._operation=c[m],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===m?h=g.showlines=!0:(h=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),h)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,f)}},{\"../../components/color\":643,\"../../constants/filter_ops\":749,\"./label_defaults\":1023,\"fast-isnumeric\":241}],1014:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":749,\"fast-isnumeric\":241}],1015:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],1016:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths),starts:n.extendDeep([],t.starts)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));for(;o.starts.length;)a.starts.push(l(o.starts.shift()));return[a]}}},{\"../../lib\":778}],1017:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./constraint_defaults\"),s=t(\"./contours_defaults\"),l=t(\"./style_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(i(t,e,f,u)){a(t,e,u,f),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"hoverongaps\");var h=\"constraint\"===f(\"contours.type\");f(\"connectgaps\",n.isArray1D(e.z)),h?o(t,e,f,u,r):(s(t,e,f,(function(r){return n.coerce2(t,e,c,r)})),l(t,e,f,u))}else e.visible=!1}},{\"../../lib\":778,\"../heatmap/xyz_defaults\":1079,\"../scatter/period_defaults\":1207,\"./attributes\":1008,\"./constraint_defaults\":1013,\"./contours_defaults\":1015,\"./style_defaults\":1029}],1018:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,f=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},h=o.start;h<c;h+=s)if(l.push(n.extendFlat({level:h,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},f)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":778,\"./constraint_mapping\":1014,\"./end_plus\":1019}],1019:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],1020:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),f=t.crossings[u],h=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),p=[s(t,e,[-h[0],-h[1]])],d=t.z.length,g=t.z[0].length,m=e.slice(),v=h.slice();for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(h[0]||h[1])<0?0:1],t.crossings[u]=i.SADDLEREMAINDER[f]):delete t.crossings[u],!(h=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}p.push(s(t,e,h)),e[0]+=h[0],e[1]+=h[1],u=e.join(\",\"),a(p[p.length-1],p[p.length-2],o,l)&&p.pop();var y=h[0]&&(e[0]<0||e[0]>g-2)||h[1]&&(e[1]<0||e[1]>d-2);if(e[0]===m[0]&&e[1]===m[1]&&h[0]===v[0]&&h[1]===v[1]||r&&y)break;f=t.crossings[u]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,T,k,M,A,S,E,C,L,I,P,z,O=a(p[0],p[p.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<p.length;c++)L=p[c],I=p[c-1],P=void 0,z=void 0,P=L[2]-I[2],z=L[3]-I[3],D+=M=Math.sqrt(P*P+z*z),F.push(M);var N=D/F.length*R;function j(t){return p[t%p.length]}for(c=p.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(O&&c===p.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];T=c-b+_+1,k=Math.floor((c+b+_+2)/2),w=O||c!==p.length-2?O||-1!==b?T%2?j(k):[(j(k)[0]+j(k+1)[0])/2,(j(k)[1]+j(k+1)[1])/2]:p[0]:p[p.length-1],p.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),O&&(c===p.length-2?p[_]=p[p.length-1]:0===c&&(p[p.length-1]=p[0]))}for(p.splice(0,B),c=0;c<p.length;c++)p[c].length=2;if(!(p.length<2))if(O)p.pop(),t.paths.push(p);else{r||n.log(\"Unclosed interior contour?\",t.level,m.join(\",\"),p.join(\"L\"));var U=!1;for(A=0;A<t.edgepaths.length;A++)if(E=t.edgepaths[A],!U&&a(E[0],p[p.length-1],o,l)){p.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],p[0],o,l)){V=!0,p.shift(),t.edgepaths.splice(A,1),S===A?t.paths.push(p.concat(C)):(S>A&&S--,t.edgepaths[S]=C.concat(p,E));break}V||(t.edgepaths[A]=p.concat(E))}for(A=0;A<t.edgepaths.length&&!U;A++)a((E=t.edgepaths[A])[E.length-1],p[0],o,l)&&(p.shift(),t.edgepaths[A]=E.concat(p),U=!0);U||t.edgepaths.push(p)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":778,\"./constants\":1012}],1021:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach((function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))})),s}},{\"../../components/color\":643,\"../heatmap/hover\":1072}],1022:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1008,\"./calc\":1009,\"./colorbar\":1011,\"./defaults\":1017,\"./hover\":1021,\"./plot\":1026,\"./style\":1028}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":778}],1024:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var f,h,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),m=new Array(d);if(\"heatmap\"===e.coloring){var v=u.min,y=u.max;for(h=0;h<d;h++)f=p[h],g[h]=f[0]*(y-v)+v,m[h]=f[1];var x=n.extent([v,y,e.start,e.start+s*(l-1)]),b=x[v<y?0:1],_=x[v<y?1:0];b!==v&&(g.splice(0,0,b),m.splice(0,0,m[0])),_!==y&&(g.push(_),m.push(m[m.length-1]))}else for(h=0;h<d;h++)f=p[h],g[h]=(f[0]*(l+c-1)-c/2)*s+r,m[h]=f[1];return i.makeColorScaleFunc({domain:g,range:m},{noNumericCheck:!0})}},{\"../../components/colorscale\":655,\"./end_plus\":1019,d3:169}],1025:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,f,h=t[0].z,p=h.length,d=h[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[h[r][e],h[r][e+1]],[h[r+1][e],h[r+1][e+1]]],f=0;f<t.length;f++)(c=i((u=t[f]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":1012}],1026:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"../../plots/cartesian/set_convert\"),u=t(\"../heatmap/plot\"),f=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),p=t(\"./empty_pathinfo\"),d=t(\"./convert_to_constraints\"),g=t(\"./close_boundaries\"),m=t(\"./constants\"),v=m.LABELOPTIMIZER;function y(t,e){var r,n,o,s,l,c,u,f=\"\",h=0,p=t.edgepaths.map((function(t,e){return e})),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function m(t){return Math.abs(t[0]-e[0][0])<.01}function v(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[h],t.smoothing),f+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(h),1),r=t.edgepaths[h][t.edgepaths[h].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",h,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!v(r)?n=e[1]:m(r)?n=e[0]:g(r)?n=e[3]:v(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;f+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}h=s,(d=-1===p.indexOf(h))&&(h=p[0],f+=\"Z\")}for(h=0;h<t.paths.length;h++)f+=a.smoothclosed(t.paths[h],t.smoothing);return f}function x(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,f=Math.sin(c)*a,h=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(f)+Math.cos(c)*o);if(h<1||p<1)return 1/0;var d=v.EDGECOST*(1/(h-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-f,y=s+u,x=l+f,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,T=Math.sin(_.theta)*_.width/2,k=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-T,_.x+w,_.y+T)/(e.height+_.height),M=_.level===e.level,A=M?v.SAMELEVELDISTANCE:1;if(k<=A)return 1/0;d+=v.NEIGHBORCOST*(M?v.SAMELEVELFACTOR:1)/(k-A)}return d}function b(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)i[(r=n[e])[0]][r[1]]=0;return t.zmask=i,i}r.plot=function(t,e,o,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each((function(o){var s=n.select(this),v=o[0],x=v.trace,_=v.x,w=v.y,T=x.contours,k=p(T,e,v),M=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===T.coloring&&(A=[o]),u(t,e,A,M),f(k),h(k);var S=l.c2p(_[0],!0),E=l.c2p(_[_.length-1],!0),C=c.c2p(w[0],!0),L=c.c2p(w[w.length-1],!0),I=[[S,L],[E,L],[E,C],[S,C]],P=k;\"constraint\"===T.type&&(P=d(k,T._operation)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,I,T),function(t,e,r,a){var o=\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation,s=\"M\"+r.join(\"L\")+\"Z\";o&&g(e,a);var l=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(o?e:[]);l.enter().append(\"path\"),l.exit().remove(),l.each((function(t){var e=(t.prefixBoundary?s:\"\")+y(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(s,P,I,T),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,f=l.showlabels,h=u&&f,p=r.createLines(c,u||f,e),d=r.createLineClip(c,h,o,s.trace.uid),g=t.selectAll(\"g.contourlabels\").data(f?[0]:[]);if(g.exit().remove(),g.enter().append(\"g\").classed(\"contourlabels\",!0),f){var v=[],y=[];i.clearLocationCache();var x=r.labelFormatter(o,s),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,T=_._length,k=w._length,M=_.range,A=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),I=Math.max(_.c2p(S,!0),0),P=Math.min(_.c2p(E,!0),T),z=Math.max(w.c2p(L,!0),0),O=Math.min(w.c2p(C,!0),k),D={};M[0]<M[1]?(D.left=I,D.right=P):(D.left=P,D.right=I),A[0]<A[1]?(D.top=z,D.bottom=O):(D.top=O,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,v.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(T*T+k*k),F=m.LABELDISTANCE*R/Math.max(1,e.length/m.LABELINCREASE);p.each((function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each((function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*m.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),m.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,v)}}))})),b.remove(),r.drawLabels(g,y,o,d,h?v:null)}f&&!u&&p.remove()}(s,k,t,v,T),function(t,e,r,n,o){var s=n.trace,l=r._fullLayout._clips,c=\"clip\"+s.uid,u=l.selectAll(\"#\"+c).data(s.connectgaps?[]:[0]);if(u.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",c),u.exit().remove(),!1===s.connectgaps){var p={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:b(n),smoothing:0};f([p]),h([p]),g([p],{type:\"levels\"}),i.ensureSingle(u,\"path\",\"\").attr(\"d\",(p.prefixBoundary?\"M\"+o.join(\"L\")+\"Z\":\"\")+y(p,o))}else c=null;a.setClipUrl(t,c,r)}(s,e,t,v,I)}))},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data((function(t){return t.pedgepaths||t.edgepaths}));o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",(function(t){return a.smoothopen(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data((function(t){return t.ppaths||t.paths}));s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",(function(t){return a.smoothclosed(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e){var r=t._fullLayout,n=e.trace,i=n.contours,a={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"};if(i.labelformat)a.tickformat=i.labelformat,c(a,r);else{var s=o.extractOpts(n);if(s&&s.colorbar&&s.colorbar._axis)a=s.colorbar._axis;else{if(\"constraint\"===i.type){var u=i.value;Array.isArray(u)?a.range=[u[0],u[u.length-1]]:a.range=[u,u]}else a.range=[i.start,i.end],a.nticks=(i.end-i.start)/i.size;a.range[0]===a.range[1]&&(a.range[1]+=a.range[0]||1),a.nticks||(a.nticks=1e3),c(a,r),l.prepTicks(a),a._tmin=null,a._tmax=null}}return function(t){return l.tickText(a,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(s.convertToTspans,n);var o=r.node(),l=a.bBox(o,!0);return{text:i,width:l.width,height:l.height,fontSize:+o.style[\"font-size\"].replace(\"px\",\"\"),level:t,dy:(l.top+l.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,f=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-f)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+f/2,l=e.max-(s+f)/2);for(var h=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,f),m=x(g,r,n,a);m<h&&(h=m,u=g,c=d)}if(h>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(h<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.fontSize,a=e.width+i/3,o=Math.max(0,e.height-i/3),s=t.x,l=t.y,c=t.theta,u=Math.sin(c),f=Math.cos(c),h=function(t,e){return[s+t*f-e*u,l+t*u+e*f]},p=[h(-a/2,-o/2),h(-a/2,o/2),h(a/2,o/2),h(a/2,-o/2)];r.push({text:e.text,x:s,y:l,dy:e.dy,theta:c,level:e.level,width:a,height:o}),n.push(p)},r.drawLabels=function(t,e,r,a,o){var l=t.selectAll(\"text\").data(e,(function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta}));if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each((function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(s.convertToTspans,r)})),o){for(var c=\"\",u=0;u<o.length;u++)c+=\"M\"+o[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/set_convert\":848,\"../heatmap/plot\":1076,\"./close_boundaries\":1010,\"./constants\":1012,\"./convert_to_constraints\":1016,\"./empty_pathinfo\":1018,\"./find_all_paths\":1020,\"./make_crossings\":1025,d3:169}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,f=r.end,h=t._input.contours;if(u>f&&(r.start=h.start=f,f=r.end=h.end=u,u=r.start),!(r.size>0))c=u===f?1:a(u,f,t.ncontours).dtick,h.size=r.size=c}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1028:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,f=!u&&\"lines\"===a.coloring,h=!u&&\"fill\"===a.coloring,p=f||h?o(r):null;e.selectAll(\"g.contourlevel\").each((function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,f?p(t.level):s.color,s.dash)}));var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each((function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(f?p(t.level):s.color)})})),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(h){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",(function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)})),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}})),a(t)}},{\"../../components/drawing\":665,\"../heatmap/style\":1077,\"./make_color_map\":1024,d3:169}],1029:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":653,\"./label_defaults\":1023}],1030:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=i.contours;e.exports=o({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:s.type,start:s.start,end:s.end,size:s.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:s.showlines,showlabels:s.showlabels,labelfont:s.labelfont,labelformat:s.labelformat,operation:s.operation,value:s.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:i.line.color,width:i.line.width,dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../contour/attributes\":1008,\"../heatmap/attributes\":1065}],1031:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),f=t(\"../carpet/lookup_carpetid\"),h=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=f(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,f,h,p,d,g,m=e._carpetTrace,v=m.aaxis,y=m.baxis;v._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,v,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,h=e._b=e._b||e.b,r=r?v.makeCalcdata(e,\"_a\"):[],h=h?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,f=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,f,x,v),w=\"scaled\"===e.ytype?\"\":h,T=c(e,w,p,d,g.length,y),k={a:_,b:T,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[k]}(t,e);return h(e,e._z),g}}},{\"../../components/colorscale/calc\":651,\"../../lib\":778,\"../carpet/lookup_carpetid\":981,\"../contour/set_contours\":1027,\"../heatmap/clean_2d_array\":1067,\"../heatmap/convert_column_xyz\":1069,\"../heatmap/find_empties\":1071,\"../heatmap/interp2d\":1074,\"../heatmap/make_bound_array\":1075,\"./defaults\":1032}],1032:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,(function(r){return n.coerce2(t,e,a,r)})),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":778,\"../contour/constraint_defaults\":1013,\"../contour/contours_defaults\":1015,\"../contour/style_defaults\":1029,\"../heatmap/xyz_defaults\":1079,\"./attributes\":1030}],1033:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":841,\"../contour/colorbar\":1011,\"../contour/style\":1028,\"./attributes\":1030,\"./calc\":1031,\"./defaults\":1032,\"./plot\":1034}],1034:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),f=t(\"../contour/constants\"),h=t(\"../contour/convert_to_constraints\"),p=t(\"../contour/empty_pathinfo\"),d=t(\"../contour/close_boundaries\"),g=t(\"../carpet/lookup_carpetid\"),m=t(\"../carpet/axis_aligned_line\");function v(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function y(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function x(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,b){var _=e.xaxis,w=e.yaxis;s.makeTraceGroups(b,r,\"contour\").each((function(r){var b=n.select(this),T=r[0],k=T.trace,M=k._carpetTrace=g(t,k),A=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var S=T.a,E=T.b,C=k.contours,L=p(C,e,T),I=\"constraint\"===C.type,P=C._operation,z=I?\"=\"===P?\"lines\":\"fill\":C.coloring,O=[[S[0],E[E.length-1]],[S[S.length-1],E[E.length-1]],[S[S.length-1],E[0]],[S[0],E[0]]];l(L);var D=1e-8*(S[S.length-1]-S[0]),R=1e-8*(E[E.length-1]-E[0]);c(L,D,R);var F,B,N,j,U=L;\"constraint\"===C.type&&(U=h(L,P)),function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(a=t[r],o=a.pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}(L,H);var V=[];for(j=A.clipsegments.length-1;j>=0;j--)F=A.clipsegments[j],B=i([],F.x,_.c2p),N=i([],F.y,w.c2p),B.reverse(),N.reverse(),V.push(a(B,N,F.bicubic));var q=\"M\"+V.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,f,h,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(h=0;h<e.length;h++)c=e[h],u=i([],c.x,r.c2p),f=i([],c.y,n.c2p),d.push(a(u,f,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(b,A.clipsegments,_,w,I,z),function(t,e,r,i,a,l,c,u,f,h,p){var g=\"fill\"===h;g&&d(a,t.contours);var v=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(g?a:[]);v.enter().append(\"path\"),v.exit().remove(),v.each((function(t){var e=(t.prefixBoundary?p:\"\")+function(t,e,r,n,i,a,l,c){var u,f,h,p,d,g,v,y=\"\",x=e.edgepaths.map((function(t,e){return e})),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function T(t){return Math.abs(t[1]-r[0][1])<w}function k(t){return Math.abs(t[1]-r[2][1])<w}function M(t){return Math.abs(t[0]-r[0][0])<_}function A(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,o,s,u=\"\";for(T(t)&&!A(t)||k(t)&&!M(t)?(s=i.aaxis,o=m(i,a,[t[0],e[0]],.5*(t[1]+e[1]))):(s=i.baxis,o=m(i,a,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<o.length;r++)for(u+=s.smoothing?\"C\":\"L\",n=0;n<o[r].length;n++){var f=o[r][n];u+=[l.c2p(f[0]),c.c2p(f[1])]+\" \"}return u}u=0,f=null;for(;x.length;){var E=e.edgepaths[u][0];for(f&&(y+=S(f,E)),v=o.smoothopen(e.edgepaths[u].map(n),e.smoothing),y+=b?v:v.replace(/^M/,\"L\"),x.splice(x.indexOf(u),1),f=e.edgepaths[u][e.edgepaths[u].length-1],d=-1,p=0;p<4;p++){if(!f){s.log(\"Missing end?\",u,e);break}for(T(f)&&!A(f)?h=r[1]:M(f)?h=r[0]:k(f)?h=r[3]:A(f)&&(h=r[2]),g=0;g<e.edgepaths.length;g++){var C=e.edgepaths[g][0];Math.abs(f[0]-h[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(h[1]-C[1])>=0&&(h=C,d=g):Math.abs(f[1]-h[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(h[0]-C[0])>=0&&(h=C,d=g):s.log(\"endpt to newendpt is not vert. or horz.\",f,h,C)}if(d>=0)break;y+=S(f,h),f=h}if(d===e.edgepaths.length){s.log(\"unclosed perimeter path\");break}u=d,(b=-1===x.indexOf(u))&&(u=x[0],y+=S(f,h)+\"Z\",f=null)}for(u=0;u<e.paths.length;u++)y+=o.smoothclosed(e.paths[u].map(n),e.smoothing);return y}(0,t,l,c,u,f,r,i);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(k,b,_,w,U,O,H,M,A,z,q),function(t,e,r,i,a,l,c){var h=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,m=u.createLines(h,p||d,e),b=u.createLineClip(h,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,T=l.yaxis,k=w._length,M=T._length,A=[[[0,0],[k,0],[k,M],[0,M]]],S=[];s.clearLocationCache();var E=u.labelFormatter(r,i),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:k,center:k/2,top:0,bottom:M,middle:M/2},I=Math.sqrt(k*k+M*M),P=f.LABELDISTANCE*I/Math.max(1,e.length/f.LABELINCREASE);m.each((function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each((function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],f=i.b[i.b.length-1];function h(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=y(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*x(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-f)<.1)&&(r=y(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*x(e,r)/2)),n}var p=v(t,0,1),d=v(t,n.total,n.total-1),g=h(o[0],p),m=n.total-h(o[o.length-1],d);n.min<g&&(n.min=g);n.max>m&&(n.max=m);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*f.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/P),f.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,A)}}))})),C.remove(),u.drawLabels(_,S,r,b,g?A:null)}d&&!p&&m.remove()}(b,L,t,T,C,e,M),o.setClipUrl(b,M._clipPathId,t)}function H(t){var e=M.ab2xy(t[0],t[1],!0);return[_.c2p(e[0]),w.c2p(e[1])]}}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../carpet/axis_aligned_line\":965,\"../carpet/lookup_carpetid\":981,\"../carpet/makepath\":982,\"../carpet/map_1d_array\":983,\"../contour/close_boundaries\":1010,\"../contour/constants\":1012,\"../contour/convert_to_constraints\":1016,\"../contour/empty_pathinfo\":1018,\"../contour/find_all_paths\":1020,\"../contour/make_crossings\":1025,\"../contour/plot\":1026,d3:169}],1035:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i(),showlegend:s({},a.showlegend,{dflt:!1})},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scattermapbox/attributes\":1252}],1036:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,f=0;f<r;f++){var h=l[f]={},p=e.lon[f],d=e.lat[f];if(h.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[f];h.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],1037:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,f=[],h=e.z,p=e.radius,d=i.isArrayOrTypedArray(h)&&h.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var m=t[u],v=m.lonlat;if(v[0]!==s){var y={};if(d){var x=m.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),f.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:v},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],T=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)T.push(_[u][0],_[u][1]);var k=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?k:1/(b.max-b.min),\"heatmap-color\":T,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:f},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geojson_utils\":772,\"fast-isnumeric\":241}],1038:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1035}],1039:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],1040:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var f=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(f,f.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../scattermapbox/hover\":1257}],1041:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),formatLabels:t(\"../scattermapbox/format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"showLegend\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":885,\"../heatmap/colorbar\":1068,\"../scattermapbox/format_labels\":1256,\"./attributes\":1035,\"./calc\":1036,\"./defaults\":1038,\"./event_data\":1039,\"./hover\":1040,\"./plot\":1042}],1042:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.type=\"densitymapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":883,\"./convert\":1037}],1043:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":778}],1044:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:s({editType:\"plot\"},{keys:l.eventDataKeys.concat([\"label\",\"value\"])}),text:n.text,textposition:c({},n.textposition,{dflt:\"auto\"}),insidetextanchor:c({},n.insidetextanchor,{dflt:\"middle\"}),textangle:c({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:c({},n.orientation,{}),offset:c({},n.offset,{arrayOk:!1}),width:c({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:c({},i.color,{dflt:u.defaultLine}),width:c({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":643,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187,\"./constants\":1046}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"./arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return t===s?0:t}e.exports=function(t,e){var r,c,u,f,h,p,d=n.getFromId(t,e.xaxis||\"x\"),g=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=d.makeCalcdata(e,\"x\"),u=g.makeCalcdata(e,\"y\"),c=i(e,g,\"y\",u),p=!!e.yperiodalignment):(r=g.makeCalcdata(e,\"y\"),u=d.makeCalcdata(e,\"x\"),c=i(e,d,\"x\",u),p=!!e.xperiodalignment);var m,v=Math.min(c.length,r.length),y=new Array(v);for(e._base=[],f=0;f<v;f++){r[f]<0&&(r[f]=s);var x=!1;r[f]!==s&&f+1<v&&r[f+1]!==s&&(x=!0),h=y[f]={p:c[f],s:r[f],cNext:x},e._base[f]=-.5*h.s,p&&(y[f].orig_p=u[f]),e.ids&&(h.id=String(e.ids[f])),0===f&&(y[0].vTotal=0),y[0].vTotal+=l(h.s),h.begR=l(h.s)/l(y[0].s)}for(f=0;f<v;f++)(h=y[f]).s!==s&&(h.sumR=h.s/y[0].vTotal,h.difR=void 0!==m?h.s/m:1,m=h.s);return a(y,e),o(y,e),y}},{\"../../constants/numerical\":753,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189,\"./arrays_to_calcdata\":1043}],1046:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],1047:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],f=[],h=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?h.push(r):f.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,f,g),n(t,c,l,h,g),i=0;i<u.length;i++){r=u[i];for(var m=0;m<r.length;m++)m+1<r.length&&(r[m].nextP0=r[m+1].p0,r[m].nextS0=r[m+1].s0,r[m].nextP1=r[m+1].p1,r[m].nextS1=r[m+1].s1)}}},{\"../bar/cross_trace_calc\":924}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function u(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,u)){s(t,e,i,u),u(\"orientation\",e.y&&!e.x?\"v\":\"h\"),u(\"offset\"),u(\"width\");var f=u(\"text\");u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");a(t,e,i,u,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"===e.textposition||e.texttemplate||u(\"textinfo\",Array.isArray(f)?\"text+value\":\"value\");var p=u(\"marker.color\",r);if(u(\"marker.line.color\",c.defaultLine),u(\"marker.line.width\"),u(\"connector.visible\"))u(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return c.addOpacity(e,.5*c.opacity(e))}(p)),u(\"connector.line.width\")&&(u(\"connector.line.color\"),u(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.funnelmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":1044}],1049:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1050:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,f=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=f.s,s.percentInitial=f.begR,s.percentInitialLabel=a(f.begR,1),s.percentPrevious=f.difR,s.percentPreviousLabel=a(f.difR,1),s.percentTotal=f.sumR,s.percentTotalLabel=a(f.sumR,1);var h=f.hi||c.hoverinfo,p=[];if(h&&\"none\"!==h&&\"skip\"!==h){var d=\"all\"===h,g=h.split(\"+\"),m=function(t){return d||-1!==g.indexOf(t)};m(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),m(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),m(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,f),[s]}}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/hover\":928}],1051:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/select\":933,\"./attributes\":1044,\"./calc\":1045,\"./cross_trace_calc\":1047,\"./defaults\":1048,\"./event_data\":1049,\"./hover\":1050,\"./layout_attributes\":1052,\"./layout_defaults\":1053,\"./plot\":1054,\"./style\":1055}],1052:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":778,\"./layout_attributes\":1052}],1054:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;function c(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,u){var f=t._fullLayout;l(\"funnel\",f),function(t,e,r,s){var l=e.xaxis,u=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),f=r[0].trace,h=i.ensureSingle(s,\"g\",\"regions\");if(f.connector&&f.connector.visible){var p=\"h\"===f.orientation,d=h.selectAll(\"g.region\").data(i.identity);d.enter().append(\"g\").classed(\"region\",!0),d.exit().remove();var g=d.size();d.each((function(r,s){if(s===g-1||r.cNext){var f=c(r,l,u,p),h=f[0],d=f[1],m=\"\";h[0]!==o&&d[0]!==o&&h[1]!==o&&d[1]!==o&&h[2]!==o&&d[2]!==o&&h[3]!==o&&d[3]!==o&&(m+=p?\"M\"+h[0]+\",\"+d[1]+\"L\"+h[2]+\",\"+d[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+d[1]+\"Z\":\"M\"+h[1]+\",\"+d[1]+\"L\"+h[2]+\",\"+d[3]+\"V\"+d[2]+\"L\"+h[1]+\",\"+d[0]+\"Z\"),\"\"===m&&(m=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(a.setClipUrl,e.layerClipId,t)}}))}else h.remove()}))}(t,e,r,u),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each((function(r){var o=n.select(this),u=r[0].trace,f=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var h=\"h\"===u.orientation,p=f.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each((function(r,o){if(o===d-1||r.cNext){var u=c(r,s,l,h),f=u[0],p=u[1],g=\"\";void 0!==f[3]&&void 0!==p[3]&&(h?(g+=\"M\"+f[0]+\",\"+p[1]+\"L\"+f[2]+\",\"+p[2],g+=\"M\"+f[1]+\",\"+p[1]+\"L\"+f[3]+\",\"+p[2]):(g+=\"M\"+f[1]+\",\"+p[1]+\"L\"+f[2]+\",\"+p[3],g+=\"M\"+f[1]+\",\"+p[0]+\"L\"+f[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,u),s.plot(t,e,r,u,{mode:f.funnelmode,norm:f.funnelmode,gap:f.funnelgap,groupgap:f.funnelgroupgap})}},{\"../../components/drawing\":665,\"../../constants/numerical\":753,\"../../lib\":778,\"../bar/plot\":932,\"../bar/uniform_text\":937,d3:169}],1055:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l(t,s,\"funnel\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".regions\").each((function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,s.connector.fillcolor)})),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/interactions\":752,\"../bar/style\":935,\"../bar/uniform_text\":937,d3:169}],1056:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:l({},n.marker.line.color,{dflt:null}),width:l({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:l({},n.scalegroup,{}),textinfo:l({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),texttemplate:s({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),hoverinfo:l({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),textposition:l({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:l({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161}],1057:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"funnelarea\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1058:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1163}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../pie/defaults\").handleLabelsAndValues;e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,i,r,a)}var u=c(\"labels\"),f=c(\"values\"),h=s(u,f),p=h.len;if(e._hasLabels=h.hasLabels,e._hasValues=h.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),p){e._length=p,c(\"marker.line.width\")&&c(\"marker.line.color\",l.paper_bgcolor),c(\"marker.colors\"),c(\"scalegroup\");var d,g=c(\"text\"),m=c(\"texttemplate\");if(m||(d=c(\"textinfo\",Array.isArray(g)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),m||d&&\"none\"!==d){var v=c(\"textposition\");o(t,e,l,c,v,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,l,c),c(\"title.text\")&&(c(\"title.position\"),n.coerceFont(c,\"title.font\",l.font)),c(\"aspectratio\"),c(\"baseratio\")}else e.visible=!1}},{\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"../pie/defaults\":1164,\"./attributes\":1056}],1060:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1172,\"./attributes\":1056,\"./base_plot\":1057,\"./calc\":1058,\"./defaults\":1059,\"./layout_attributes\":1061,\"./layout_defaults\":1062,\"./plot\":1063,\"./style\":1064}],1061:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1168}],1062:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":778,\"./layout_attributes\":1061}],1063:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=a.strScale,s=a.strTranslate,l=t(\"../../lib/svg_text_utils\"),c=t(\"../bar/plot\").toMoveInsideBar,u=t(\"../bar/uniform_text\"),f=u.recordMinTextSize,h=u.clearMinTextSize,p=t(\"../pie/helpers\"),d=t(\"../pie/plot\"),g=d.attachFxHandlers,m=d.determineInsideTextFont,v=d.layoutAreas,y=d.prerenderTitles,x=d.positionTitleOutside,b=d.formatSliceLabel;function _(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;h(\"funnelarea\",r),y(e,t),v(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each((function(e){var u=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var f,h,p=[];for(p.push(u()),f=t.length-1;f>-1;f--)if(!(h=t[f]).hidden){var d=h.v/l;c+=d,p.push(u())}var g=1/0,m=-1/0;for(f=0;f<p.length;f++)a=p[f],g=Math.min(g,a[1]),m=Math.max(m,a[1]);for(f=0;f<p.length;f++)p[f][1]-=(m+g)/2;var v=p[p.length-1][0],y=e.r,x=(m-g)/2,b=y/v,_=y/x*n;for(e.r=_*x,f=0;f<p.length;f++)p[f][0]*=b,p[f][1]*=_;var w=[-(a=p[0])[0],a[1]],T=[a[0],a[1]],k=0;for(f=t.length-1;f>-1;f--)if(!(h=t[f]).hidden){var M=p[k+=1][0],A=p[k][1];h.TL=[-M,A],h.TR=[M,A],h.BL=w,h.BR=T,h.pxmid=(S=h.TR,E=h.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=h.TL,T=h.TR}var S,E}(e),u.each((function(){var u=n.select(this).selectAll(\"g.slice\").data(e);u.enter().append(\"g\").classed(\"slice\",!0),u.exit().remove(),u.each((function(o,s){if(o.hidden)n.select(this).selectAll(\"path,g\").remove();else{o.pointNumber=o.i,o.curveNumber=d.index;var u=h.cx,v=h.cy,y=n.select(this),x=y.selectAll(\"path.surface\").data([o]);x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),y.call(g,t,e);var w=\"M\"+(u+o.TR[0])+\",\"+(v+o.TR[1])+_(o.TR,o.BR)+_(o.BR,o.BL)+_(o.BL,o.TL)+\"Z\";x.attr(\"d\",w),b(t,o,h);var T=p.castOption(d.textposition,o.pts),k=y.selectAll(\"g.slicetext\").data(o.text&&\"none\"!==T?[0]:[]);k.enter().append(\"g\").classed(\"slicetext\",!0),k.exit().remove(),k.each((function(){var h=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),p=a.ensureUniformFontSize(t,m(d,o,r.font));h.text(o.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p).call(l.convertToTspans,t);var g,y,x,b=i.bBox(h.node()),_=Math.min(o.BL[1],o.BR[1])+v,w=Math.max(o.TL[1],o.TR[1])+v;y=Math.max(o.TL[0],o.BL[0])+u,x=Math.min(o.TR[0],o.BR[0])+u,(g=c(y,x,_,w,b,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})).fontSize=p.size,f(d.type,g,r),e[s].transform=g,h.attr(\"transform\",a.getTextTransform(g))}))}}));var v=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);v.enter().append(\"g\").classed(\"titletext\",!0),v.exit().remove(),v.each((function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),c=d.title.text;d._meta&&(c=a.templateString(c,d._meta)),e.text(c).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(l.convertToTspans,t);var u=x(h,r._size);e.attr(\"transform\",s(u.x,u.y)+o(Math.min(1,u.scale))+s(u.tx,u.ty))}))}))}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../bar/plot\":932,\"../bar/uniform_text\":937,\"../pie/helpers\":1166,\"../pie/plot\":1170,d3:169}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\"),a=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._funnelarealayer.selectAll(\".trace\");a(t,e,\"funnelarea\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(i,t,e)}))}))}},{\"../bar/uniform_text\":937,\"../pie/style_one\":1172,d3:169}],1065:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=s({z:{valType:\"data_array\",editType:\"calc\"},x:s({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:s({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:s({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:s({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:s({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:s({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),xperiod:s({},n.xperiod,{impliedEdits:{xtype:\"scaled\"}}),yperiod:s({},n.yperiod,{impliedEdits:{ytype:\"scaled\"}}),xperiod0:s({},n.xperiod0,{impliedEdits:{xtype:\"scaled\"}}),yperiod0:s({},n.yperiod0,{impliedEdits:{ytype:\"scaled\"}}),xperiodalignment:s({},n.xperiodalignment,{impliedEdits:{xtype:\"scaled\"}}),yperiodalignment:s({},n.yperiodalignment,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},hoverongaps:{valType:\"boolean\",dflt:!0,editType:\"none\"},connectgaps:{valType:\"boolean\",editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:a(),showlegend:s({},i.showlegend,{dflt:!1})},{transforms:void 0},o(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1066:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../histogram2d/calc\"),l=t(\"../../components/colorscale/calc\"),c=t(\"./convert_column_xyz\"),u=t(\"./clean_2d_array\"),f=t(\"./interp2d\"),h=t(\"./find_empties\"),p=t(\"./make_bound_array\"),d=t(\"../../constants/numerical\").BADNUM;function g(t){for(var e=[],r=t.length,n=0;n<r;n++){var i=t[n];i!==d&&e.push(i)}return e}e.exports=function(t,e){var r,m,v,y,x,b,_,w,T,k,M,A=a.getFromId(t,e.xaxis||\"x\"),S=a.getFromId(t,e.yaxis||\"y\"),E=n.traceIs(e,\"contour\"),C=n.traceIs(e,\"histogram\"),L=n.traceIs(e,\"gl2d\"),I=E?\"best\":e.zsmooth;if(A._minDtick=0,S._minDtick=0,C)y=(M=s(t,e)).orig_x,r=M.x,m=M.x0,v=M.dx,w=M.orig_y,x=M.y,b=M.y0,_=M.dy,T=M.z;else{var P=e.z;i.isArray1D(P)?(c(e,A,S,\"x\",\"y\",[\"z\"]),r=e._x,x=e._y,P=e._z):(y=e.x?A.makeCalcdata(e,\"x\"):[],w=e.y?S.makeCalcdata(e,\"y\"):[],r=o(e,A,\"x\",y),x=o(e,S,\"y\",w),e._x=r,e._y=x),m=e.x0,v=e.dx,b=e.y0,_=e.dy,T=u(P,e,A,S)}function z(t){I=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if((A.rangebreaks||S.rangebreaks)&&(T=function(t,e,r){for(var n=[],i=-1,a=0;a<r.length;a++)if(e[a]!==d){i++,n[i]=[];for(var o=0;o<r[a].length;o++)t[o]!==d&&n[i].push(r[a][o])}return n}(r,x,T),C||(r=g(r),x=g(x),e._x=r,e._y=x)),C||!E&&!e.connectgaps||(e._emptypoints=h(T),f(T,e._emptypoints)),\"fast\"===I)if(\"log\"===A.type||\"log\"===S.type)z(\"log axis found\");else if(!C){if(r.length){var O=(r[r.length-1]-r[0])/(r.length-1),D=Math.abs(O/100);for(k=0;k<r.length-1;k++)if(Math.abs(r[k+1]-r[k]-O)>D){z(\"x scale is not linear\");break}}if(x.length&&\"fast\"===I){var R=(x[x.length-1]-x[0])/(x.length-1),F=Math.abs(R/100);for(k=0;k<x.length-1;k++)if(Math.abs(x[k+1]-x[k]-R)>F){z(\"y scale is not linear\");break}}}var B=i.maxRowLength(T),N=\"scaled\"===e.xtype?\"\":r,j=p(e,N,m,v,B,A),U=\"scaled\"===e.ytype?\"\":x,V=p(e,U,b,_,T.length,S);L||(e._extremes[A._id]=a.findExtremes(A,j),e._extremes[S._id]=a.findExtremes(S,V));var q={x:j,y:V,z:T,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(e.xperiodalignment&&y&&(q.orig_x=y),e.yperiodalignment&&w&&(q.orig_y=w),N&&N.length===j.length-1&&(q.xCenter=N),U&&U.length===V.length-1&&(q.yCenter=U),C&&(q.xRanges=M.xRanges,q.yRanges=M.yRanges,q.pts=M.pts),E||l(t,e,{vals:T,cLetter:\"z\"}),E&&e.contours&&\"heatmap\"===e.contours.coloring){var H={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};q.xfill=p(H,N,m,v,B,A),q.yfill=p(H,U,b,_,T.length,S)}return[q]}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../histogram2d/calc\":1098,\"./clean_2d_array\":1067,\"./convert_column_xyz\":1069,\"./find_empties\":1071,\"./interp2d\":1074,\"./make_bound_array\":1075}],1067:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,f,h;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,f=0;f<t.length;f++)s=Math.max(s,t[f].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(f=0;f<o.length;f++)n[o[f]]=f;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var m=g(r),v=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(f=0;f<s;f++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,f),y[f]=new Array(l),h=0;h<l;h++)y[f][h]=p(d(t,v(f),m(h)));return y}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],1068:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/align_period\");e.exports=function(t,e,r,o,s,l){var c=t._length,u=e.makeCalcdata(t,o),f=r.makeCalcdata(t,s);u=a(t,e,o,u),f=a(t,r,s,f);var h,p,d,g,m=t.text,v=void 0!==m&&n.isArray1D(m),y=t.hovertext,x=void 0!==y&&n.isArray1D(y),b=n.distinctVals(u),_=b.vals,w=n.distinctVals(f),T=w.vals,k=[],M=T.length,A=_.length;for(h=0;h<l.length;h++)k[h]=n.init2dArray(M,A);v&&(d=n.init2dArray(M,A)),x&&(g=n.init2dArray(M,A));var S=n.init2dArray(M,A);for(h=0;h<c;h++)if(u[h]!==i&&f[h]!==i){var E=n.findBin(u[h]+b.minDiff/2,_),C=n.findBin(f[h]+w.minDiff/2,T);for(p=0;p<l.length;p++){var L=t[l[p]];k[p][C][E]=L[h],S[C][E]=h}v&&(d[C][E]=m[h]),x&&(g[C][E]=y[h])}for(t[\"_\"+o]=_,t[\"_\"+s]=T,p=0;p<l.length;p++)t[\"_\"+l[p]]=k[p];v&&(t._text=d),x&&(t._hovertext=g),e&&\"category\"===e.type&&(t[\"_\"+o+\"CategoryMap\"]=_.map((function(t){return e._categories[t]}))),r&&\"category\"===r.type&&(t[\"_\"+s+\"CategoryMap\"]=T.map((function(t){return r._categories[t]}))),t._after2before=S}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./style_defaults\"),s=t(\"../../components/colorscale/defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}i(t,e,u,c)?(a(t,e,c,u),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\"),o(t,e,u,c),u(\"hoverongaps\"),u(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),s(t,e,c,u,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../scatter/period_defaults\":1207,\"./attributes\":1065,\"./style_defaults\":1078,\"./xyz_defaults\":1079}],1071:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],f={},h=[],p=t[0],d=[],g=[0,0,0],m=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<m;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(f[[r,i]]=[r,i,s]),u.push([r,i,s])):h.push([r,i]));for(;h.length;){for(l={},c=!1,o=h.length-1;o>=0;o--)(s=((f[[(r=(a=h[o])[0])-1,i=a[1]]]||g)[2]+(f[[r+1,i]]||g)[2]+(f[[r,i-1]]||g)[2]+(f[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],h.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)f[a]=l[a],u.push(l[a])}return u.sort((function(t,e){return e[2]-t[2]}))}},{\"../../lib\":778}],1072:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,f,h,p,d=t.cd[0],g=d.trace,m=t.xa,v=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,T=d.zmask,k=g.zhoverformat,M=y,A=x;if(!1!==t.index){try{h=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(h<0||h>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(M=[2*y[0]-y[1]],S=1;S<y.length;S++)M.push((y[S]+y[S-1])/2);for(M.push([2*y[y.length-1]-y[y.length-2]]),A=[2*x[0]-x[1]],S=1;S<x.length;S++)A.push((x[S]+x[S-1])/2);A.push([2*x[x.length-1]-x[x.length-2]])}h=Math.max(0,Math.min(M.length-2,i.findBin(e,M))),p=Math.max(0,Math.min(A.length-2,i.findBin(r,A)))}var E,C,L=m.c2p(y[h]),I=m.c2p(y[h+1]),P=v.c2p(x[p]),z=v.c2p(x[p+1]);c?(E=d.orig_x||y,C=d.orig_y||x,I=L,u=E[h],z=P,f=C[p]):(E=d.orig_x||_||y,C=d.orig_y||w||x,u=_?E[h]:(E[h]+E[h+1])/2,f=w?C[p]:(C[p]+C[p+1])/2,m&&\"category\"===m.type&&(u=y[h]),v&&\"category\"===v.type&&(f=x[p]),g.zsmooth&&(L=I=m.c2p(u),P=z=v.c2p(f)));var O=b[p][h];if(T&&!T[p][h]&&(O=void 0),void 0!==O||g.hoverongaps){var D;Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?D=d.hovertext[p][h]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(D=d.text[p][h]);var R=o(g),F={type:\"linear\",range:[R.min,R.max],hoverformat:k,_separators:m._separators,_numFormat:m._numFormat},B=a.tickText(F,O,\"hover\").text;return[i.extendFlat(t,{index:g._after2before?g._after2before[p][h]:[p,h],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:L,x1:I,y0:P,y1:z,xLabelVal:u,yLabelVal:f,zLabelVal:O,zLabel:B,text:D})]}}},{\"../../components/colorscale\":655,\"../../components/fx\":683,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1073:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1065,\"./calc\":1066,\"./colorbar\":1068,\"./defaults\":1070,\"./hover\":1072,\"./plot\":1076,\"./style\":1077}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,f,h,p,d,g,m,v=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,h=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(f=u[o+c[1]])&&(0===p?g=m=f:(g=Math.min(g,f),m=Math.max(m,f)),h++,p+=f);if(0===h)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/h,void 0===d?h<4&&(v=1):(t[a][o]=(1+r)*t[a][o]-r*d,m>g&&(v=Math.max(v,Math.abs(t[a][o]-d)/(m-g))))}return v}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":778}],1075:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,f=[],h=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return h?e.slice(0,o):e.slice(0,o+1);if(h||d)f=e.slice(0,o);else if(1===o)f=[e[0]-.5,e[0]+.5];else{for(f=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)f.push(.5*(e[u-1]+e[u]));f.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var m=f[f.length-1],v=m-f[f.length-2];for(u=g;u<o;u++)m+=v,f.push(m)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=h||d?0:-.5;u<o;u++)f.push(l+c*u)}return f}},{\"../../lib\":778,\"../../registry\":911}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function f(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,h){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(h,r,\"hm\").each((function(e){var r,h,g,m,v,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,T=b.x,k=b.y,M=b.xCenter,A=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),I=!1,P=!1;for(y=0;void 0===r&&y<T.length-1;)r=p.c2p(T[y]),y++;for(y=T.length-1;void 0===h&&y>0;)h=p.c2p(T[y]),y--;for(h<r&&(g=h,h=r,r=g,I=!0),y=0;void 0===m&&y<k.length-1;)m=d.c2p(k[y]),y++;for(y=k.length-1;void 0===v&&y>0;)v=d.c2p(k[y]),y--;if(v<m&&(g=m,m=v,v=g,P=!0),S&&(M=T,A=k,T=b.xfill,k=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),h=Math.min((1+z)*p._length,h),m=Math.max(-z*d._length,m),v=Math.min((1+z)*d._length,v)}var O=Math.round(h-r),D=Math.round(v-m);if(O<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=O,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=I?function(t){return L-1-t}:o.identity,j=P?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(T[t])-r),0,O)},j=function(t){return o.constrain(Math.round(d.c2p(k[t])-m),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=I?0:1,K=P?0:1,Q=0,$=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(O*D*4)}catch(t){rt=new Array(O*D*4)}if(\"best\"===E){var it,at,ot,st=M||T,lt=A||k,ct=new Array(st.length),ut=new Array(lt.length),ft=new Array(O),ht=M?u:c,pt=A?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-m);for(y=0;y<O;y++)ft[y]=ht(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<O;y++,nt+=4)f(rt,nt,W=kt(at,ot,ft[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<O;y++)W=Tt(Y[y],1),f(rt,nt=4*(Z*O+N(y)),W);var dt=U.createImageData(O,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,mt=gt.length;for(H=0;H<mt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var vt=_.xgap,yt=_.ygap,xt=Math.floor(vt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=Tt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-vt,Z[1]-Z[0]-yt))}$=Math.round($/Q),tt=Math.round(tt/Q),et=Math.round(et/Q);var _t=i(\"rgb(\"+$+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+Q,t._hmlumcount=(t._hmlumcount||0)+Q*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:O,x:r,y:m,\"xlink:href\":B.toDataURL(\"image/png\")})}function Tt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),Q+=e,$+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function kt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return Tt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,Tt(i+r.frac*c+n.frac*(u+r.frac*a))}}))}},{\"../../components/colorscale\":655,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../registry\":911,d3:169,tinycolor2:576}],1077:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",(function(t){return t.trace.opacity}))}},{d3:169}],1078:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,f,h=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===h||!h.length)return 0;if(i.isArray1D(t.z)){u=r(l),f=r(c);var p=i.minRowLength(u),d=i.minRowLength(f);if(0===p||0===d)return 0;e._length=Math.min(p,d,h.length)}else{if(u=o(l,r),f=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(h))return 0;r(\"transpose\"),e._length=null}return\"heatmapgl\"===t.type||\"contourgl\"===t.type||a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":778,\"../../registry\":911,\"fast-isnumeric\":241}],1080:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}l.zsmooth={valType:\"enumerated\",values:[\"fast\",!1],dflt:\"fast\",editType:\"calc\"},a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../heatmap/attributes\":1065}],1081:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={zsmooth:\"fast\",z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y,this.options.zsmooth=t.zsmooth;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var f=0;f<4;f++)s[4*l+f]=u[f]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c,u,f=this.scene.xaxis,h=this.scene.yaxis;!1===t.zsmooth&&(c={ppad:r.x[1]-r.x[0]},u={ppad:r.y[1]-r.y[0]}),t._extremes[f._id]=i.findExtremes(f,r.x,c),t._extremes[h._id]=i.findExtremes(h,r.y,u)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"gl-heatmap2d\":271}],1082:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,l,s)?(l(\"text\"),l(\"zsmooth\"),a(t,e,s,l,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../heatmap/xyz_defaults\":1079,\"./attributes\":1080}],1083:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":868,\"../heatmap/calc\":1066,\"../heatmap/colorbar\":1068,\"./attributes\":1080,\"./convert\":1081,\"./defaults\":1082}],1084:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"./bin_attributes\":1086,\"./constants\":1090}],1085:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1086:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1087:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":241}],1088:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function f(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=h(i,a),s=0;s<10;s++){var l=h(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function h(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,h=-.1*e,p=t-h,d=r[0],g=r[1],m=Math.min(f(d+h,d+p,n,a),f(g+h,g+p,n,a)),v=Math.min(f(d+c,d+h,n,a),f(g+c,g+h,n,a));if(m>v&&v<Math.abs(g-d)/4e3?(s=m,l=!1):(s=Math.min(m,v),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var f=u(c,x,!1,a);(c+f)/2<e+t&&(c=f)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":753,\"../../plots/cartesian/axes\":828}],1089:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),f=t(\"./bin_label_vals\");function h(t,e,r,s,l){var c,u,f,p,d,g,m,v=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},T=function(t){return r.c2r(t,0,p)},k=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function M(t,e,r){e[t+\"Found\"]?(e[t]=k(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],v+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var A=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((f=u[c]).visible){var L=b.dirs[c];d=f[\"_\"+L+\"pos0\"]=r.makeCalcdata(f,L),A=i.concat(A,d),delete f[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete f._autoBin,f[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(f,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===f.type&&(C=!0))}p=u[0][s+\"calendar\"];var I=o.autoBin(A,r,b.nbins,E,p,b.sizeFound&&b.size),P=u[0]._autoBin={};if(g=P[b.dirs[0]]={},C&&(b.size||(I.start=T(o.tickIncrement(w(I.start),I.size,!0,p))),void 0===b.end&&(I.end=T(o.tickIncrement(w(I.end),I.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===I._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[I,d,!0];I=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),f=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)f=!0;else if(f){var g=h(t,s,r,n,!0),m=g[0],v=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],v?d.push(s):p=Math.min(p,m.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,v)}(m=f.cumulative||{}).enabled&&\"include\"!==m.currentbin&&(\"decreasing\"===m.direction?I.start=T(o.tickIncrement(w(I.start),I.size,!0,p)):I.end=T(o.tickIncrement(w(I.end),I.size,!1,p))),b.size=I.size,b.sizeFound||(g.size=I.size,i.nestedProperty(u[0],v+\".size\").set(I.size)),M(\"start\",b,I),M(\"end\",b,I)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[v]||{},O=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),O.start=r.l2r(j),F||i.nestedProperty(e,v+\".start\").set(O.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);O.end=r.l2r(H),q||i.nestedProperty(e,v+\".start\").set(O.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[v]=i.extendFlat({},e[v]||{}),delete e._input[G],delete e[G]),[O,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],m=[],v=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=h(t,e,v,y),T=w[0],k=w[1],M=\"string\"==typeof T.size,A=[],S=M?A:T,E=[],C=[],L=[],I=0,P=e.histnorm,z=e.histfunc,O=-1!==P.indexOf(\"density\");_.enabled&&O&&(P=P.replace(/ ?density$/,\"\"),O=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[P],N=!1,j=function(t){return v.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(T.start),p=j(T.end)+(r-o.tickIncrement(r,T.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,T.size,!1,b),g.push((r+a)/2),m.push(R),L.push([]),A.push(r),O&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;A.push(r),M||\"date\"!==v.type||(S={start:j(S.start),end:j(S.end),size:S.size}),t._fullLayout._roundFnOpts||(t._fullLayout._roundFnOpts={});var U=e[\"_\"+y+\"bingroup\"],V={leftGap:1/0,rightGap:1/0};U&&(t._fullLayout._roundFnOpts[U]||(t._fullLayout._roundFnOpts[U]=V),V=t._fullLayout._roundFnOpts[U]);var q,H=m.length,G=!0,Y=V.leftGap,W=V.rightGap,X={};for(r=0;r<k.length;r++){var Z=k[r];(d=i.findBin(Z,S))>=0&&d<H&&(I+=F(d,r,m,D,C),G&&L[d].length&&Z!==k[L[d][0]]&&(G=!1),L[d].push(r),X[r]=d,Y=Math.min(Y,Z-A[d]),W=Math.min(W,A[d+1]-Z))}V.leftGap=Y,V.rightGap=W,G||(q=function(e,r){return function(){var n=t._fullLayout._roundFnOpts[U];return f(n.leftGap,n.rightGap,A,v,b)(e,r)}}),N&&(I=u(m,C)),B&&B(m,I,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(m,_.direction,_.currentbin);var J=Math.min(g.length,m.length),K=[],Q=0,$=J-1;for(r=0;r<J;r++)if(m[r]){Q=r;break}for(r=J-1;r>=Q;r--)if(m[r]){$=r;break}for(r=Q;r<=$;r++)if(n(g[r])&&n(m[r])){var tt={p:g[r],s:m[r],b:0};_.enabled||(tt.pts=L[r],G?tt.ph0=tt.ph1=L[r].length?k[L[r][0]]:g[r]:(e._computePh=!0,tt.ph0=q(A[r]),tt.ph1=q(A[r+1],!0))),K.push(tt)}return 1===K.length&&(K[0].width1=o.tickIncrement(K[0].p,T.size,!1,b)-K[0].p),s(K,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(K,e,X),K},calcAllAutoBins:h}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../bar/arrays_to_calcdata\":920,\"./average\":1085,\"./bin_functions\":1087,\"./bin_label_vals\":1088,\"./norm_functions\":1096,\"fast-isnumeric\":241}],1090:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=t(\"../../plots/cartesian/constraints\").getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,f,h,p,d,g,m,v=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function T(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"]||\"\",c=v[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(v[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var k=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],h=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var M=r[p+\"axis\"],A=l(e,M)+r.orientation;(k[A]||{})[r.alignmentgroup]&&(h=A)}h||\"overlay\"===e.barmode||(h=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}h?(x[h]||(x[h]=[]),x[h].push(r)):b.push(r)}for(h in x)if(1!==(f=x[h]).length){var S=!1;for(f.length&&(r=f[0],S=_(\"bingroup\")),h=S||h,d=0;d<f.length;d++){var E=(r=f[d])._input.bingroup;E&&E!==h&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",h+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=h,T(r,h,w(r))}}else b.push(f[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(m=0;m<2;m++){var L=_((p=u[m])+\"bingroup\",C?C+\"__\"+p:null);T(r,L,p)}else T(r,C,w(r))}for(h in v){var I=v[h];for(f=I.traces,g=0;g<c.length;g++){var P,z,O=c[g],D=O.name;if(\"nbins\"!==D||!I.sizeFound){for(d=0;d<f.length;d++){if(r=f[d],p=I.dirs[d],P=O.aStr[p],void 0!==s(r._input,P).get()){I[D]=_(P),I[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,P).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<f.length;d++)(r=f[d])[\"_\"+p+\"bingroup\"]&&_(P,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||I.sizeFound||I.nbinsFound||(r=f[0],I[D]=_(P))}}}}},{\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"../bar/defaults\":925}],1092:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),f=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"orientation\",f&&!u?\"h\":\"v\"),p=\"v\"===h?\"x\":\"y\",d=\"v\"===h?\"y\":\"x\",g=u&&f?Math.min(i.minRowLength(u)&&i.minRowLength(f)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var m=(e.marker.line||{}).color,v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,m||a.defaultLine,{axis:\"y\"}),v(t,e,m||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":643,\"../../lib\":778,\"../../registry\":911,\"../bar/style_defaults\":936,\"./attributes\":1084}],1093:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return o}}},{\"../../plots/cartesian/axes\":828,\"../bar/hover\":928}],1095:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/cross_trace_calc\":924,\"../bar/layout_attributes\":930,\"../bar/layout_defaults\":931,\"../bar/plot\":932,\"../bar/select\":933,\"../bar/style\":935,\"../scatter/marker_colorbar\":1205,\"./attributes\":1084,\"./calc\":1089,\"./cross_trace_defaults\":1091,\"./defaults\":1092,\"./event_data\":1093,\"./hover\":1094}],1096:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1097:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat;e.exports=c({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:c({},n.bingroup,{}),xbingroup:c({},n.bingroup,{}),ybingroup:c({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:s({},{keys:\"z\"}),showlegend:c({},o.showlegend,{dflt:!1})},l(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../heatmap/attributes\":1065,\"../histogram/attributes\":1084,\"../histogram/bin_attributes\":1086}],1098:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function f(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function h(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var f=(e||[])[o];c[o]=void 0===f?[u(t[o]),u(t[o+1],!0)]:[f,f]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),m=i.getFromId(t,e.yaxis),v=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,v)},b=function(t){return m.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],T=_[1],k=c(t,e,m,\"y\"),M=k[0],A=k[1],S=e._length;T.length>S&&T.splice(S,T.length-S),A.length>S&&A.splice(S,A.length-S);var E=[],C=[],L=[],I=\"string\"==typeof w.size,P=\"string\"==typeof M.size,z=[],O=[],D=I?z:w,R=P?O:M,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),Q=x(w.end)+(K-i.tickIncrement(K,J,!1,v))/1e6;for(r=K;r<Q;r=i.tickIncrement(r,J,!1,v))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var $,tt=C.length,et=(r-K)/tt,rt=($=K+et/2,g.c2r($,0,v)),nt=M.size,it=b(M.start),at=b(M.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),O.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}O.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return m.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,I),X=u(E.length,R,lt,P)),I||\"date\"!==g.type||(D=f(x,D)),P||\"date\"!==m.type||(R=f(b,R));var ut=!0,ft=!0,ht=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,mt=1/0,vt=1/0;for(r=0;r<S;r++){var yt=T[r],xt=A[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ht[p]?ht[p]=yt:ht[p]!==yt&&(ut=!1)),ft&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ft=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),mt=Math.min(mt,xt-O[d]),vt=Math.min(vt,O[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:T,xRanges:h(z,ut&&ht,dt,gt,g,v),x0:rt,dx:et,y:A,yRanges:h(O,ft&&pt,mt,vt,m,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../histogram/average\":1085,\"../histogram/bin_functions\":1087,\"../histogram/bin_label_vals\":1088,\"../histogram/calc\":1089,\"../histogram/norm_functions\":1096}],1099:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../heatmap/style_defaults\":1078,\"./attributes\":1097,\"./sample_defaults\":1102}],1100:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],f=c[1],h=t.cd[0],p=h.xRanges[f],d=h.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":828,\"../heatmap/hover\":1072}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../heatmap/calc\":1066,\"../heatmap/colorbar\":1068,\"../heatmap/plot\":1076,\"../heatmap/style\":1077,\"../histogram/cross_trace_defaults\":1091,\"../histogram/event_data\":1093,\"./attributes\":1097,\"./defaults\":1099,\"./hover\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":778,\"../../registry\":911}],1103:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:{color:i.line.color,width:o({},i.line.width,{dflt:.5}),dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../contour/attributes\":1008,\"../histogram2d/attributes\":1097}],1104:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,(function(r){return n.coerce2(t,e,s,r)})),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":778,\"../contour/contours_defaults\":1015,\"../contour/style_defaults\":1029,\"../histogram2d/sample_defaults\":1102,\"./attributes\":1103}],1105:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../contour/calc\":1009,\"../contour/colorbar\":1011,\"../contour/hover\":1021,\"../contour/plot\":1026,\"../contour/style\":1028,\"../histogram/cross_trace_defaults\":1091,\"./attributes\":1103,\"./defaults\":1104}],1106:[function(t,e,r){\"use strict\";for(var n=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../lib/extend\").extendFlat,o=t(\"./constants\").colormodel,s=[\"rgb\",\"rgba\",\"rgba256\",\"hsl\",\"hsla\"],l=[],c=[],u=0;u<s.length;u++){var f=o[s[u]];l.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(f.zminDflt||f.min).join(\", \")+\"].\"),c.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(f.zmaxDflt||f.max).join(\", \")+\"].\")}e.exports=a({source:{valType:\"string\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},colormodel:{valType:\"enumerated\",values:s,editType:\"calc\"},zmin:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},zmax:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",dflt:1,editType:\"calc\"},dy:{valType:\"number\",dflt:1,editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"data_array\",editType:\"plot\"},hoverinfo:a({},n.hoverinfo,{flags:[\"x\",\"y\",\"z\",\"color\",\"name\",\"text\"],dflt:\"x+y+z+text+name\"}),hovertemplate:i({},{keys:[\"z\",\"color\",\"colormodel\"]}),transforms:void 0})},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"./constants\":1108}],1107:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\"),a=t(\"fast-isnumeric\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../lib\").maxRowLength,l=t(\"./helpers\").getImageSize;function c(t,e,r,i){return function(a){return n.constrain((a-t)*e,r,i)}}function u(t,e){return function(r){return n.constrain(r,t,e)}}e.exports=function(t,e){var r,n;if(e._hasZ)r=e.z.length,n=s(e.z);else if(e._hasSource){var f=l(e.source);r=f.height,n=f.width}var h,p=o.getFromId(t,e.xaxis||\"x\"),d=o.getFromId(t,e.yaxis||\"y\"),g=p.d2c(e.x0)-e.dx/2,m=d.d2c(e.y0)-e.dy/2,v=[g,g+n*e.dx],y=[m,m+r*e.dy];if(p&&\"log\"===p.type)for(h=0;h<n;h++)v.push(g+h*e.dx);if(d&&\"log\"===d.type)for(h=0;h<r;h++)y.push(m+h*e.dy);return e._extremes[p._id]=o.findExtremes(p,v),e._extremes[d._id]=o.findExtremes(d,y),e._scaler=function(t){var e=i.colormodel[t.colormodel],r=(e.colormodel||t.colormodel).length;t._sArray=[];for(var n=0;n<r;n++)e.min[n]!==t.zmin[n]||e.max[n]!==t.zmax[n]?t._sArray.push(c(t.zmin[n],(e.max[n]-e.min[n])/(t.zmax[n]-t.zmin[n]),e.min[n],e.max[n])):t._sArray.push(u(e.min[n],e.max[n]));return function(e){for(var n=e.slice(0,r),i=0;i<r;i++){var o=n[i];if(!a(o))return!1;n[i]=t._sArray[i](o)}return n}}(e),[{x0:g,y0:m,z:e.z,w:n,h:r}]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./constants\":1108,\"./helpers\":1111,\"fast-isnumeric\":241}],1108:[function(t,e,r){\"use strict\";e.exports={colormodel:{rgb:{min:[0,0,0],max:[255,255,255],fmt:function(t){return t.slice(0,3)},suffix:[\"\",\"\",\"\"]},rgba:{min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},rgba256:{colormodel:\"rgba\",zminDflt:[0,0,0,0],zmaxDflt:[255,255,255,255],min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},hsl:{min:[0,0,0],max:[360,100,100],fmt:function(t){var e=t.slice(0,3);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\"]},hsla:{min:[0,0,0,0],max:[360,100,100,1],fmt:function(t){var e=t.slice(0,4);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\",\"\"]}}}},{}],1109:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./constants\"),o=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX;e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"source\"),e.source&&!e.source.match(o)&&delete e.source,e._hasSource=!!e.source;var s,l=r(\"z\");(e._hasZ=!(void 0===l||!l.length||!l[0]||!l[0].length),e._hasZ||e._hasSource)?(r(\"x0\"),r(\"y0\"),r(\"dx\"),r(\"dy\"),e._hasZ?(r(\"colormodel\",\"rgb\"),r(\"zmin\",(s=a.colormodel[e.colormodel]).zminDflt||s.min),r(\"zmax\",s.zmaxDflt||s.max)):e._hasSource&&(e.colormodel=\"rgba256\",s=a.colormodel[e.colormodel],e.zmin=s.zminDflt,e.zmax=s.zmaxDflt),r(\"text\"),r(\"hovertext\"),r(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../lib\":778,\"../../snapshot/helpers\":915,\"./attributes\":1106,\"./constants\":1108}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){return\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t.color=e.color,t.colormodel=e.trace.colormodel,t.z||(t.z=e.color),t}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"image-size\"),i=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX,a=t(\"buffer/\").Buffer;r.getImageSize=function(t){var e=t.replace(i,\"\"),r=new a(e,\"base64\");return n(r)}},{\"../../snapshot/helpers\":915,\"buffer/\":111,\"image-size\":444}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"./constants\");e.exports=function(t,e,r){var o=t.cd[0],s=o.trace,l=t.xa,c=t.ya;if(!(n.inbox(e-o.x0,e-(o.x0+o.w*s.dx),0)>0||n.inbox(r-o.y0,r-(o.y0+o.h*s.dy),0)>0)){var u,f=Math.floor((e-o.x0)/s.dx),h=Math.floor(Math.abs(r-o.y0)/s.dy);if(s._hasZ?u=o.z[h][f]:s._hasSource&&(u=s._canvas.el.getContext(\"2d\").getImageData(f,h,1,1).data),u){var p,d=o.hi||s.hoverinfo;if(d){var g=d.split(\"+\");-1!==g.indexOf(\"all\")&&(g=[\"color\"]),-1!==g.indexOf(\"color\")&&(p=!0)}var m,v=a.colormodel[s.colormodel],y=v.colormodel||s.colormodel,x=y.length,b=s._scaler(u),_=v.suffix,w=[];(s.hovertemplate||p)&&(w.push(\"[\"+[b[0]+_[0],b[1]+_[1],b[2]+_[2]].join(\", \")),4===x&&w.push(\", \"+b[3]+_[3]),w.push(\"]\"),w=w.join(\"\"),t.extraText=y.toUpperCase()+\": \"+w),Array.isArray(s.hovertext)&&Array.isArray(s.hovertext[h])?m=s.hovertext[h][f]:Array.isArray(s.text)&&Array.isArray(s.text[h])&&(m=s.text[h][f]);var T=c.c2p(o.y0+(h+.5)*s.dy),k=o.x0+(f+.5)*s.dx,M=o.y0+(h+.5)*s.dy,A=\"[\"+u.slice(0,s.colormodel.length).join(\", \")+\"]\";return[i.extendFlat(t,{index:[h,f],x0:l.c2p(o.x0+f*s.dx),x1:l.c2p(o.x0+(f+1)*s.dx),y0:T,y1:T,color:b,xVal:k,xLabelVal:k,yVal:M,yLabelVal:M,zLabelVal:A,text:m,hovertemplateLabels:{zLabel:A,colorLabel:w,\"color[0]Label\":b[0]+_[0],\"color[1]Label\":b[1]+_[1],\"color[2]Label\":b[2]+_[2],\"color[3]Label\":b[3]+_[3]}})]}}}},{\"../../components/fx\":683,\"../../lib\":778,\"./constants\":1108}],1113:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"image\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"noSortingByValue\"],animatable:!1,meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1106,\"./calc\":1107,\"./defaults\":1109,\"./event_data\":1110,\"./hover\":1112,\"./plot\":1114,\"./style\":1115}],1114:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.strTranslate,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"./constants\"),l=i.isIOS()||i.isSafari()||i.isIE();e.exports=function(t,e,r,c){var u=e.xaxis,f=e.yaxis,h=!(l||t._context._exportedPlot);i.makeTraceGroups(c,r,\"im\").each((function(e){var r=n.select(this),l=e[0],c=l.trace,p=h&&!c._hasZ&&c._hasSource&&\"linear\"===u.type&&\"linear\"===f.type;c._fastImage=p;var d,g,m,v,y,x,b=l.z,_=l.x0,w=l.y0,T=l.w,k=l.h,M=c.dx,A=c.dy;for(x=0;void 0===d&&x<T;)d=u.c2p(_+x*M),x++;for(x=T;void 0===g&&x>0;)g=u.c2p(_+x*M),x--;for(x=0;void 0===v&&x<k;)v=f.c2p(w+x*A),x++;for(x=k;void 0===y&&x>0;)y=f.c2p(w+x*A),x--;if(g<d&&(m=g,g=d,d=m),y<v&&(m=v,v=y,y=m),!p){d=Math.max(-.5*u._length,d),g=Math.min(1.5*u._length,g),v=Math.max(-.5*f._length,v),y=Math.min(1.5*f._length,y)}var S=Math.round(g-d),E=Math.round(y-v);if(S<=0||E<=0){r.selectAll(\"image\").data([]).exit().remove()}else{var C=r.selectAll(\"image\").data([e]);C.enter().append(\"svg:image\").attr({xmlns:o.svg,preserveAspectRatio:\"none\"}),C.exit().remove();var L=\"image-rendering: optimizeSpeed; image-rendering: -moz-crisp-edges; image-rendering: -o-crisp-edges; image-rendering: -webkit-optimize-contrast; image-rendering: optimize-contrast; image-rendering: crisp-edges; image-rendering: pixelated;\";if(p){var I=i.simpleMap(u.range,u.r2l),P=i.simpleMap(f.range,f.r2l),z=I[1]<I[0],O=P[1]>P[0];if(z||O){var D=d+S/2,R=v+E/2;L+=\"transform:\"+a(D+\"px\",R+\"px\")+\"scale(\"+(z?-1:1)+\",\"+(O?-1:1)+\")\"+a(-D+\"px\",-R+\"px\")+\";\"}}C.attr(\"style\",L);var F=new Promise((function(t){if(c._hasZ)t();else if(c._hasSource)if(c._canvas&&c._canvas.el.width===T&&c._canvas.el.height===k&&c._canvas.source===c.source)t();else{var e=document.createElement(\"canvas\");e.width=T,e.height=k;var r=e.getContext(\"2d\");c._image=c._image||new Image;var n=c._image;n.onload=function(){r.drawImage(n,0,0),c._canvas={el:e,source:c.source},t()},n.setAttribute(\"src\",c.source)}})).then((function(){var t;if(c._hasZ)t=B((function(t,e){return b[e][t]})).toDataURL(\"image/png\");else if(c._hasSource)if(p)t=c.source;else{var e=c._canvas.el.getContext(\"2d\").getImageData(0,0,T,k).data;t=B((function(t,r){var n=4*(r*T+t);return[e[n],e[n+1],e[n+2],e[n+3]]})).toDataURL(\"image/png\")}C.attr({\"xlink:href\":t,height:E,width:S,x:d,y:v})}));t._promises.push(F)}function B(t){var e=document.createElement(\"canvas\");e.width=S,e.height=E;var r,n=e.getContext(\"2d\"),a=function(t){return i.constrain(Math.round(u.c2p(_+t*M)-d),0,S)},o=function(t){return i.constrain(Math.round(f.c2p(w+t*A)-v),0,E)},h=s.colormodel[c.colormodel],p=h.colormodel||c.colormodel,g=h.fmt;for(x=0;x<l.w;x++){var m=a(x),y=a(x+1);if(y!==m&&!isNaN(y)&&!isNaN(m))for(var b=0;b<l.h;b++){var T=o(b),k=o(b+1);k===T||isNaN(k)||isNaN(T)||!t(x,b)||(r=c._scaler(t(x,b)),n.fillStyle=r?p+\"(\"+g(r).join(\",\")+\")\":\"rgba(0,0,0,0)\",n.fillRect(m,T,y-m,k-T))}}return e}}))}},{\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"./constants\":1108,d3:169}],1115:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".im image\").style(\"opacity\",(function(t){return t[0].trace.opacity}))}},{d3:169}],1116:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,f=t(\"../../constants/delta.js\"),h=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"step\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},h,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},h,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:f.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:f.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:f.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:f.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},h,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,minexponent:c.minexponent,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":642,\"../../constants/delta.js\":747,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1117:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"indicator\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1118:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1119:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),f=t(\"../../plots/cartesian/tick_label_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var m,v,y,x,b,_,w=new Array(2);function T(t,e){return n.coerce(y,x,i.gauge,t,e)}function k(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),m=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(m||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),v=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(m||v||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),T(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),T(\"bgcolor\",p.paper_bgcolor),T(\"borderwidth\"),T(\"bordercolor\"),T(\"bar.color\"),T(\"bar.line.color\"),T(\"bar.line.width\"),T(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:h}),T(\"threshold.value\"),T(\"threshold.thickness\"),T(\"threshold.line.width\"),T(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),k(\"visible\"),e._range=k(\"range\",e._range);var M={outerTicks:!0};c(b,_,k,\"linear\"),f(b,_,k,\"linear\",M),u(b,_,k,M)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_mark_defaults\":850,\"../../plots/cartesian/tick_value_defaults\":851,\"../../plots/domain\":855,\"./attributes\":1116,\"./constants.js\":1119}],1121:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1116,\"./base_plot\":1117,\"./calc\":1118,\"./defaults\":1120,\"./plot\":1122}],1122:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.strScale,o=i.strTranslate,s=i.rad2deg,l=t(\"../../constants/alignment\").MID_SHIFT,c=t(\"../../components/drawing\"),u=t(\"./constants\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../plots/cartesian/axes\"),p=t(\"../../plots/cartesian/axis_defaults\"),d=t(\"../../plots/cartesian/position_defaults\"),g=t(\"../../plots/cartesian/layout_attributes\"),m=t(\"../../components/color\"),v={left:\"start\",center:\"middle\",right:\"end\"},y={left:0,center:.5,right:1},x=/[yzafpn\\xb5mkMGTPEZY]/;function b(t){return t&&t.duration>0}function _(t){t.each((function(t){m.stroke(n.select(this),t.line.color)})).each((function(t){m.fill(n.select(this),t.color)})).style(\"stroke-width\",(function(t){return t.line.width}))}function w(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,g,t,e)}return p(a,o,l,s,n),d(a,o,l,s),o}function T(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(f.convertToTspans,i).call(c.font,e),c.bBox(o.node())}function M(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,p){var d,g=t._fullLayout;b(r)&&p&&(d=p()),i.makeTraceGroups(g._indicatorlayer,e,\"trace\").each((function(e){var p,A,S,E,C,L=e[0].trace,I=n.select(this),P=L._hasGauge,z=L._isAngular,O=L._isBullet,D=L.domain,R={w:g._size.w*(D.x[1]-D.x[0]),h:g._size.h*(D.y[1]-D.y[0]),l:g._size.l+g._size.w*D.x[0],r:g._size.r+g._size.w*(1-D.x[1]),t:g._size.t+g._size.h*(1-D.y[1]),b:g._size.b+g._size.h*D.y[0]},F=R.l+R.w/2,B=R.t+R.h/2,N=Math.min(R.w/2,R.h),j=u.innerRadius*N,U=L.align||\"center\";if(A=B,P){if(z&&(p=F,A=B+N/2,S=function(t){return function(t,e){var r=Math.sqrt(t.width/2*(t.width/2)+t.height*t.height);return[e/r,t,e]}(t,.9*j)}),O){var V=u.bulletPadding,q=1-u.bulletNumberDomainSize+V;p=R.l+(q+(1-q)*y[U])*R.w,S=function(t){return T(t,(u.bulletNumberDomainSize-V)*R.w,R.h)}}}else p=R.l+y[U]*R.w,S=function(t){return T(t,R.w,R.h)};!function(t,e,r,s){var l,u,p,d=r[0].trace,g=s.numbersX,_=s.numbersY,T=d.align||\"center\",A=v[T],S=s.transitionOpts,E=s.onComplete,C=i.ensureSingle(e,\"g\",\"numbers\"),L=[];d._hasNumber&&L.push(\"number\");d._hasDelta&&(L.push(\"delta\"),\"left\"===d.delta.position&&L.reverse());var I=C.selectAll(\"text\").data(L);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(x)||r(i).slice(-1).match(x))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,(function(t){return parseInt(t)-1})),o=w(t,{tickformat:a});return function(t){return Math.abs(t)<1?h.tickText(o,t).text:r(t)}}I.enter().append(\"text\"),I.attr(\"text-anchor\",(function(){return A})).attr(\"class\",(function(t){return t})).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),I.exit().remove();var z,O=d.mode+d.align;d._hasDelta&&(z=function(){var e=w(t,{tickformat:d.delta.valueformat},d._range);e.setScale(),h.prepTicks(e);var i=function(t){return h.tickText(e,t).text},a=function(t){return d.delta.relative?t.relativeDelta:t.delta},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?d.delta.increasing.symbol:d.delta.decreasing.symbol)+e(t)},s=function(t){return t.delta>=0?d.delta.increasing.color:d.delta.decreasing.color};void 0===d._deltaLastValue&&(d._deltaLastValue=a(r[0]));var l=C.select(\"text.delta\");function p(){l.text(o(a(r[0]),i)).call(m.fill,s(r[0])).call(f.convertToTspans,t)}return l.call(c.font,d.delta.font).call(m.fill,s({delta:d._deltaLastValue})),b(S)?l.transition().duration(S.duration).ease(S.easing).tween(\"text\",(function(){var t=n.select(this),e=a(r[0]),l=d._deltaLastValue,c=P(d.delta.valueformat,i,l,e),u=n.interpolateNumber(l,e);return d._deltaLastValue=e,function(e){t.text(o(u(e),c)),t.call(m.fill,s({delta:u(e)}))}})).each(\"end\",(function(){p(),E&&E()})).each(\"interrupt\",(function(){p(),E&&E()})):p(),u=k(o(a(r[0]),i),d.delta.font,A,t),l}(),O+=d.delta.position+d.delta.font.size+d.delta.font.family+d.delta.valueformat,O+=d.delta.increasing.symbol+d.delta.decreasing.symbol,p=u);d._hasNumber&&(!function(){var e=w(t,{tickformat:d.number.valueformat},d._range);e.setScale(),h.prepTicks(e);var i=function(t){return h.tickText(e,t).text},a=d.number.suffix,o=d.number.prefix,s=C.select(\"text.number\");function u(){var e=\"number\"==typeof r[0].y?o+i(r[0].y)+a:\"-\";s.text(e).call(c.font,d.number.font).call(f.convertToTspans,t)}b(S)?s.transition().duration(S.duration).ease(S.easing).each(\"end\",(function(){u(),E&&E()})).each(\"interrupt\",(function(){u(),E&&E()})).attrTween(\"text\",(function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);d._lastValue=r[0].y;var s=P(d.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(o+s(e(r))+a)}})):u(),l=k(o+i(r[0].y)+a,d.number.font,A,t)}(),O+=d.number.font.size+d.number.font.family+d.number.valueformat+d.number.suffix+d.number.prefix,p=l);if(d._hasDelta&&d._hasNumber){var D,R,F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=[(u.left+u.right)/2,(u.top+u.bottom)/2],N=.75*d.delta.font.size;\"left\"===d.delta.position&&(D=M(d,\"deltaPos\",0,-1*(l.width*y[d.align]+u.width*(1-y[d.align])+N),O,Math.min),R=F[1]-B[1],p={width:l.width+u.width+N,height:Math.max(l.height,u.height),left:u.left+D,right:l.right,top:Math.min(l.top,u.top+R),bottom:Math.max(l.bottom,u.bottom+R)}),\"right\"===d.delta.position&&(D=M(d,\"deltaPos\",0,l.width*(1-y[d.align])+u.width*y[d.align]+N,O,Math.max),R=F[1]-B[1],p={width:l.width+u.width+N,height:Math.max(l.height,u.height),left:l.left,right:u.right+D,top:Math.min(l.top,u.top+R),bottom:Math.max(l.bottom,u.bottom+R)}),\"bottom\"===d.delta.position&&(D=null,R=u.height,p={width:Math.max(l.width,u.width),height:l.height+u.height,left:Math.min(l.left,u.left),right:Math.max(l.right,u.right),top:l.bottom-l.height,bottom:l.bottom+u.height}),\"top\"===d.delta.position&&(D=null,R=l.top,p={width:Math.max(l.width,u.width),height:l.height+u.height,left:Math.min(l.left,u.left),right:Math.max(l.right,u.right),top:l.bottom-l.height-u.height,bottom:l.bottom}),z.attr({dx:D,dy:R})}(d._hasNumber||d._hasDelta)&&C.attr(\"transform\",(function(){var t=s.numbersScaler(p);O+=t[2];var e,r=M(d,\"numbersScale\",1,t[0],O,Math.min);d._scaleNumbers||(r=1),e=d._isAngular?_-r*p.bottom:_-r*(p.top+p.bottom)/2,d._numbersTop=r*p.top+e;var n=p[T];\"center\"===T&&(n=(p.left+p.right)/2);var i=g-r*n;return i=M(d,\"numbersTranslate\",0,i,O,Math.max),o(i,e)+a(r)}))}(t,I,e,{numbersX:p,numbersY:A,numbersScaler:S,transitionOpts:r,onComplete:d}),P&&(E={range:L.gauge.axis.range,color:L.gauge.bgcolor,line:{color:L.gauge.bordercolor,width:0},thickness:1},C={range:L.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:L.gauge.bordercolor,width:L.gauge.borderwidth},thickness:1});var H=I.selectAll(\"g.angular\").data(z?e:[]);H.exit().remove();var G=I.selectAll(\"g.angularaxis\").data(z?e:[]);G.exit().remove(),z&&function(t,e,r,i){var a,c,u,f,p=r[0].trace,d=i.size,g=i.radius,m=i.innerRadius,v=i.gaugeBg,y=i.gaugeOutline,x=[d.l+d.w/2,d.t+d.h/2+g/2],T=i.gauge,k=i.layer,M=i.transitionOpts,A=i.onComplete,S=Math.PI/2;function E(t){var e=p.gauge.axis.range[0],r=(t-e)/(p.gauge.axis.range[1]-e)*Math.PI-S;return r<-S?-S:r>S?S:r}function C(t){return n.svg.arc().innerRadius((m+g)/2-t/2*(g-m)).outerRadius((m+g)/2+t/2*(g-m)).startAngle(-S)}function L(t){t.attr(\"d\",(function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()}))}T.enter().append(\"g\").classed(\"angular\",!0),T.attr(\"transform\",o(x[0],x[1])),k.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),k.selectAll(\"g.xangularaxistick,path,text\").remove(),(a=w(t,p.gauge.axis)).type=\"linear\",a.range=p.gauge.axis.range,a._id=\"xangularaxis\",a.setScale();var I=function(t){return(a.range[0]-t.x)/(a.range[1]-a.range[0])*Math.PI+Math.PI},P={},z=h.makeLabelFns(a,0).labelStandoff;P.xFn=function(t){var e=I(t);return Math.cos(e)*z},P.yFn=function(t){var e=I(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*l)},P.anchorFn=function(t){var e=I(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},P.heightFn=function(t,e,r){var n=I(t);return-.5*(1+Math.sin(n))*r};var O=function(t){return o(x[0]+g*Math.cos(t),x[1]-g*Math.sin(t))};u=function(t){return O(I(t))};if(c=h.calcTicks(a),f=h.getTickSigns(a)[2],a.visible){f=\"inside\"===a.ticks?-1:1;var D=(a.linewidth||1)/2;h.drawTicks(t,a,{vals:c,layer:k,path:\"M\"+f*D+\",0h\"+f*a.ticklen,transFn:function(t){var e=I(t);return O(e)+\"rotate(\"+-s(e)+\")\"}}),h.drawLabels(t,a,{vals:c,layer:k,transFn:u,labelFns:P})}var R=[v].concat(p.gauge.steps),F=T.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(_),F.exit().remove();var B=C(p.gauge.bar.thickness),N=T.selectAll(\"g.value-arc\").data([p.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");b(M)?(j.transition().duration(M.duration).ease(M.easing).each(\"end\",(function(){A&&A()})).each(\"interrupt\",(function(){A&&A()})).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),p._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(_),N.exit().remove(),R=[];var H=p.gauge.threshold.value;H&&R.push({range:[H,H],color:p.gauge.threshold.color,line:{color:p.gauge.threshold.line.color,width:p.gauge.threshold.line.width},thickness:p.gauge.threshold.thickness});var G=T.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(_),G.exit().remove();var Y=T.selectAll(\"g.gauge-outline\").data([y]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(_),Y.exit().remove()}(t,0,e,{radius:N,innerRadius:j,gauge:H,layer:G,size:R,gaugeBg:E,gaugeOutline:C,transitionOpts:r,onComplete:d});var Y=I.selectAll(\"g.bullet\").data(O?e:[]);Y.exit().remove();var W=I.selectAll(\"g.bulletaxis\").data(O?e:[]);W.exit().remove(),O&&function(t,e,r,n){var i,a,s,l,c,f=r[0].trace,p=n.gauge,d=n.layer,g=n.gaugeBg,v=n.gaugeOutline,y=n.size,x=f.domain,T=n.transitionOpts,k=n.onComplete;p.enter().append(\"g\").classed(\"bullet\",!0),p.attr(\"transform\",o(y.l,y.t)),d.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),d.selectAll(\"g.xbulletaxistick,path,text\").remove();var M=y.h,A=f.gauge.bar.thickness*M,S=x.x[0],E=x.x[0]+(x.x[1]-x.x[0])*(f._hasNumber||f._hasDelta?1-u.bulletNumberDomainSize:1);(i=w(t,f.gauge.axis))._id=\"xbulletaxis\",i.domain=[S,E],i.setScale(),a=h.calcTicks(i),s=h.makeTransTickFn(i),l=h.getTickSigns(i)[2],c=y.t+y.h,i.visible&&(h.drawTicks(t,i,{vals:\"inside\"===i.ticks?h.clipEnds(i,a):a,layer:d,path:h.makeTickPath(i,c,l),transFn:s}),h.drawLabels(t,i,{vals:a,layer:d,transFn:s,labelFns:h.makeLabelFns(i,c)}));function C(t){t.attr(\"width\",(function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))})).attr(\"x\",(function(t){return i.c2p(t.range[0])})).attr(\"y\",(function(t){return.5*(1-t.thickness)*M})).attr(\"height\",(function(t){return t.thickness*M}))}var L=[g].concat(f.gauge.steps),I=p.selectAll(\"g.bg-bullet\").data(L);I.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),I.select(\"rect\").call(C).call(_),I.exit().remove();var P=p.selectAll(\"g.value-bullet\").data([f.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(M-A)/2).call(_),b(T)?P.select(\"rect\").transition().duration(T.duration).ease(T.easing).each(\"end\",(function(){k&&k()})).each(\"interrupt\",(function(){k&&k()})).attr(\"width\",Math.max(0,i.c2p(Math.min(f.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(f.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var z=r.filter((function(){return f.gauge.threshold.value})),O=p.selectAll(\"g.threshold-bullet\").data(z);O.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),O.select(\"line\").attr(\"x1\",i.c2p(f.gauge.threshold.value)).attr(\"x2\",i.c2p(f.gauge.threshold.value)).attr(\"y1\",(1-f.gauge.threshold.thickness)/2*M).attr(\"y2\",(1-(1-f.gauge.threshold.thickness)/2)*M).call(m.stroke,f.gauge.threshold.line.color).style(\"stroke-width\",f.gauge.threshold.line.width),O.exit().remove();var D=p.selectAll(\"g.gauge-outline\").data([v]);D.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),D.select(\"rect\").call(C).call(_),D.exit().remove()}(t,0,e,{gauge:Y,layer:W,size:R,gaugeBg:E,gaugeOutline:C,transitionOpts:r,onComplete:d});var X=I.selectAll(\"text.title\").data(e);X.exit().remove(),X.enter().append(\"text\").classed(\"title\",!0),X.attr(\"text-anchor\",(function(){return O?v.right:v[L.title.align]})).text(L.title.text).call(c.font,L.title.font).call(f.convertToTspans,t),X.attr(\"transform\",(function(){var t,e=R.l+R.w*y[L.title.align],r=u.titlePadding,n=c.bBox(X.node());if(P){if(z)if(L.gauge.axis.visible)t=c.bBox(G.node()).top-r-n.bottom;else t=R.t+R.h/2-N/2-n.bottom-r;O&&(t=A-(n.top+n.bottom)/2,e=R.l-u.bulletPadding*R.w)}else t=L._numbersTop-r-n.bottom;return o(e,t)}))}))}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_defaults\":830,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/cartesian/position_defaults\":845,\"./constants\":1119,d3:169}],1123:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i(),showlegend:s({},o.showlegend,{dflt:!1})},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../streamtube/calc\").processGrid,a=t(\"../streamtube/calc\").filter;e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length),e._x=a(e.x,e._len),e._y=a(e.y,e._len),e._z=a(e.z,e._len),e._value=a(e.value,e._len);var r=i(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;for(var o=1/0,s=-1/0,l=0;l<e._len;l++){var c=e._value[l];o=Math.min(o,c),s=Math.max(s,c)}e._minValues=o,e._maxValues=s,e._vMin=void 0===e.isomin||null===e.isomin?o:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?s:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651,\"../streamtube/calc\":1295}],1125:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function c(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,f=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var h=this.data.hovertext||this.data.text;return Array.isArray(h)&&void 0!==h[f]?t.textLabel=h[f]:h&&(t.textLabel=h),!0}},u.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=h(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[c.min,c.max],l.colormap=i(t),this.mesh.update(l)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()};var f=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"];function h(t){t._meshI=[],t._meshJ=[],t._meshK=[];var e,r,n,i,a,o,s,c=t.surface.show,u=t.spaceframe.show,h=t.surface.fill,p=t.spaceframe.fill,d=!1,g=!1,m=0,v=t._Xs,y=t._Ys,x=t._Zs,b=v.length,_=y.length,w=x.length,T=f.indexOf(t._gridFill.replace(/-/g,\"\").replace(/\\+/g,\"\")),k=function(t,e,r){switch(T){case 5:return r+w*e+w*_*t;case 4:return r+w*t+w*b*e;case 3:return e+_*r+_*w*t;case 2:return e+_*t+_*b*r;case 1:return t+b*r+b*w*e;default:return t+b*e+b*_*r}},M=t._minValues,A=t._maxValues,S=t._vMin,E=t._vMax;function C(t,e,s){for(var l=o.length,c=r;c<l;c++)if(t===n[c]&&e===i[c]&&s===a[c])return c;return-1}function L(){r=e}function I(){n=[],i=[],a=[],o=[],e=0,L()}function P(t,r,s,l){return n.push(t),i.push(r),a.push(s),o.push(l),++e-1}function z(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function O(t){s=t}function D(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function R(t,e){return null===t?e:t}function F(e,r,n){L();var i,a,o,l=[r],c=[n];if(s>=1)l=[r],c=[n];else if(s>0){var u=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-s),l=z(a,r,o),c=z(a,n,o),u=z(a,i,o),f=e[0],h=e[1],p=e[2];return{xyzv:[[r,n,c],[c,l,r],[n,i,u],[u,c,n],[i,r,l],[l,u,i]],abc:[[f,h,-1],[-1,-1,f],[h,p,-1],[-1,-1,h],[p,f,-1],[-1,-1,p]]}}(r,n);l=u.xyzv,c=u.abc}for(var f=0;f<l.length;f++){r=l[f],n=c[f];for(var h=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],y=r[p][3],x=n[p]>-1?n[p]:C(d,g,v);h[p]=x>-1?x:P(d,g,v,R(e,y))}i=h[0],a=h[1],o=h[2],t._meshI.push(i),t._meshJ.push(a),t._meshK.push(o),++m}}function B(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function N(t,e,r){return t>=e&&t<=r}function j(t){var e=.001*(E-S);return t>=S-e&&t<=E+e}function U(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t._x[i],t._y[i],t._z[i],t._value[i]])}return r}function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[N(e[0][3],n,i),N(e[1][3],n,i),N(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return j(e[0][3])&&j(e[1][3])&&j(e[2][3])?(F(t,e,r),!0):a<3&&V(t,e,r,S,E,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach((function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],f=e[a[1]],h=e[a[2]],p=B(h,u,n,i),d=B(h,f,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,f,d],[r[a[0]],r[a[1]],-1])||o,c=!0}})),c||[[0,1,2],[1,2,0],[2,0,1]].forEach((function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],f=e[a[1]],h=e[a[2]],p=B(f,u,n,i),d=B(h,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}})),o}function q(t,e,r,n){var i=!1,a=U(e),o=[N(a[0][3],r,n),N(a[1][3],r,n),N(a[2][3],r,n),N(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return g&&(i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]];if(g)i=F(t,[c,u,f],[e[l[0]],e[l[1]],e[l[2]]])||i;else{var p=B(h,c,r,n),d=B(h,u,r,n),m=B(h,f,r,n);i=F(null,[p,d,m],[-1,-1,-1])||i}s=!0}})),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]],p=B(f,c,r,n),d=B(f,u,r,n),m=B(h,u,r,n),v=B(h,c,r,n);g?(i=F(t,[c,v,p],[e[l[0]],-1,-1])||i,i=F(t,[u,d,m],[e[l[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[p,d,m,v],[-1,-1,-1,-1])||i,s=!0}})),s||[[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach((function(l){if(o[l[0]]&&!o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]],p=B(u,c,r,n),d=B(f,c,r,n),m=B(h,c,r,n);g?(i=F(t,[c,p,d],[e[l[0]],-1,-1])||i,i=F(t,[c,d,m],[e[l[0]],-1,-1])||i,i=F(t,[c,m,p],[e[l[0]],-1,-1])||i):i=F(null,[p,d,m],[-1,-1,-1])||i,s=!0}})),i)}function H(t,e,r,n,i,a,o,s,l,c,u){var f=!1;return d&&(D(t,\"A\")&&(f=q(null,[e,r,n,a],c,u)||f),D(t,\"B\")&&(f=q(null,[r,n,i,l],c,u)||f),D(t,\"C\")&&(f=q(null,[r,a,o,l],c,u)||f),D(t,\"D\")&&(f=q(null,[n,a,s,l],c,u)||f),D(t,\"E\")&&(f=q(null,[r,n,a,l],c,u)||f)),g&&(f=q(t,[r,n,a,l],c,u)||f),f}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,U([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,U([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,f=!1,h=function(){f=V(t,[s,l,c],[-1,-1,-1],i,a)||f,f=V(t,[c,u,s],[-1,-1,-1],i,a)||f},p=o[0],d=o[1],g=o[2];return p&&(s=z(U([k(e,r-0,n-0)])[0],U([k(e-1,r-0,n-0)])[0],p),l=z(U([k(e,r-0,n-1)])[0],U([k(e-1,r-0,n-1)])[0],p),c=z(U([k(e,r-1,n-1)])[0],U([k(e-1,r-1,n-1)])[0],p),u=z(U([k(e,r-1,n-0)])[0],U([k(e-1,r-1,n-0)])[0],p),h()),d&&(s=z(U([k(e-0,r,n-0)])[0],U([k(e-0,r-1,n-0)])[0],d),l=z(U([k(e-0,r,n-1)])[0],U([k(e-0,r-1,n-1)])[0],d),c=z(U([k(e-1,r,n-1)])[0],U([k(e-1,r-1,n-1)])[0],d),u=z(U([k(e-1,r,n-0)])[0],U([k(e-1,r-1,n-0)])[0],d),h()),g&&(s=z(U([k(e-0,r-0,n)])[0],U([k(e-0,r-0,n-1)])[0],g),l=z(U([k(e-0,r-1,n)])[0],U([k(e-0,r-1,n-1)])[0],g),c=z(U([k(e-1,r-1,n)])[0],U([k(e-1,r-1,n-1)])[0],g),u=z(U([k(e-1,r-0,n)])[0],U([k(e-1,r-0,n-1)])[0],g),h()),f}function X(t,e,r,n,i,a,o,s,l,c,u,f){var h=t;return f?(d&&\"even\"===t&&(h=null),H(h,e,r,n,i,a,o,s,l,c,u)):(d&&\"odd\"===t&&(h=null),H(h,l,s,o,a,i,n,r,e,c,u))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<w;c++)for(var u=1;u<_;u++)a.push(Y(t,k(l,u-1,c-1),k(l,u-1,c),k(l,u,c-1),k(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<b;c++)for(var u=1;u<w;u++)a.push(Y(t,k(c-1,l,u-1),k(c,l,u-1),k(c-1,l,u),k(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<_;c++)for(var u=1;u<b;u++)a.push(Y(t,k(u-1,c-1,l),k(u-1,c,l),k(u,c-1,l),k(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function Q(t,e,r){for(var n=1;n<w;n++)for(var i=1;i<_;i++)for(var a=1;a<b;a++)X(t,k(a-1,i-1,n-1),k(a-1,i-1,n),k(a-1,i,n-1),k(a-1,i,n),k(a,i-1,n-1),k(a,i-1,n),k(a,i,n-1),k(a,i,n),e,r,(a+i+n)%2)}function $(t,e,r){d=!0,Q(t,e,r),d=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<w;u++)for(var f=1;f<_;f++)o.push(W(t,c,f,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<b;u++)for(var f=1;f<w;f++)o.push(W(t,u,c,f,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<_;u++)for(var f=1;f<b;f++)o.push(W(t,f,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(I(),function(){for(var e=0;e<b;e++)for(var r=0;r<_;r++)for(var n=0;n<w;n++){var i=k(e,r,n);P(t._x[i],t._y[i],t._z[i],t._value[i])}}(),u&&p&&(O(p),g=!0,Q(null,S,E),g=!1),c&&h){O(h);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var f=1===r?.5:s/(r-1),d=(1-f)*S+f*E,T=Math.abs(d-M)>Math.abs(d-A)?[M,d]:[d,A];$(e,T[0],T[1])}}var C=[[Math.min(S,A),Math.max(S,A)],[Math.min(M,E),Math.max(M,E)]];[\"x\",\"y\",\"z\"].forEach((function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){O(s.fill);var c=[],u=[],f=[];if(s.locations.length)for(var h=0;h<s.locations.length;h++){var p=l(s.locations[h],\"x\"===e?v:\"y\"===e?y:x);0===p.distRatio?c.push(p.id):p.id>0&&(u.push(p.id),\"x\"===e?f.push([p.distRatio,0,0]):\"y\"===e?f.push([0,p.distRatio,0]):f.push([0,0,p.distRatio]))}else c=nt(1,\"x\"===e?b-1:\"y\"===e?_-1:w-1);u.length>0&&(r[i]=\"x\"===e?tt(null,u,a,o,f,r[i]):\"y\"===e?et(null,u,a,o,f,r[i]):rt(null,u,a,o,f,r[i]),i++),c.length>0&&(r[i]=\"x\"===e?Z(null,c,a,o,r[i]):\"y\"===e?J(null,c,a,o,r[i]):K(null,c,a,o,r[i]),i++)}var d=t.caps[e];d.show&&d.fill&&(O(d.fill),r[i]=\"x\"===e?Z(null,[0,b-1],a,o,r[i]):\"y\"===e?J(null,[0,_-1],a,o,r[i]):K(null,[0,w-1],a,o,r[i]),i++)}})),0===m&&I(),t._meshX=n,t._meshY=i,t._meshZ=a,t._meshIntensity=o,t._Xs=v,t._Ys=y,t._Zs=x}(),t}e.exports={findNearestOnAxis:l,generateIsoMeshes:h,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new c(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"gl-mesh3d\":309}],1126:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),f=a(\"z\"),h=a(\"value\");c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach((function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))})),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach((function(t){a(t)})),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,r,i,(function(r,i){return n.coerce(t,e,a,r,i)}))},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1123}],1127:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1123,\"./calc\":1124,\"./convert\":1125,\"./defaults\":1126}],1128:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},intensitymode:{valType:\"enumerated\",values:[\"vertex\",\"cell\"],dflt:\"vertex\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"}),showlegend:s({},o.showlegend,{dflt:!1})})},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../surface/attributes\":1311}],1129:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1130:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function f(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var h=f.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function m(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}h.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.data._cellCenter?t.traceCoordinate=t.data.dataCoordinate:t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,f=t.x.length,h=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!m(t.i,f)||!m(t.j,f)||!m(t.k,f))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(h):t.alphahull>0?a(t.alphahull,h):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,h);var v={positions:h,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\";var x=t.intensitymode;v[x+\"Intensity\"]=t.intensity,v[x+\"IntensityBounds\"]=[y.min,y.max],v.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],v.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],v.cellColors=p(t.facecolor)):(this.color=t.color,v.meshColor=l(t.color));this.mesh.update(v)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new f(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"alpha-shape\":69,\"convex-hull\":135,\"delaunay-triangulate\":171,\"gl-mesh3d\":309}],1131:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map((function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null}));return e.every((function(t){return t&&t.length===e[0].length}))&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach((function(t){l(t)})),l(\"contour.show\")&&(l(\"contour.color\"),l(\"contour.width\")),\"intensity\"in t?(l(\"intensity\"),l(\"intensitymode\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1128}],1132:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1128,\"./calc\":1129,\"./convert\":1130,\"./defaults\":1131}],1133:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function f(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={xperiod:i.xperiod,xperiod0:i.xperiod0,xperiodalignment:i.xperiodalignment,x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:f(l),decreasing:f(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":664,\"../../components/fx/attributes\":674,\"../../constants/delta.js\":747,\"../../lib\":778,\"../scatter/attributes\":1187}],1134:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r,n){return{o:t,h:e,l:r,c:n}}function c(t,e,r,o,l,c){for(var u=l.makeCalcdata(e,\"open\"),f=l.makeCalcdata(e,\"high\"),h=l.makeCalcdata(e,\"low\"),p=l.makeCalcdata(e,\"close\"),d=Array.isArray(e.text),g=Array.isArray(e.hovertext),m=!0,v=null,y=!!e.xperiodalignment,x=[],b=0;b<o.length;b++){var _=o[b],w=u[b],T=f[b],k=h[b],M=p[b];if(_!==s&&w!==s&&T!==s&&k!==s&&M!==s){M===w?null!==v&&M!==v&&(m=M>v):m=M>w,v=M;var A=c(w,T,k,M);A.pos=_,A.yc=(w+M)/2,A.i=b,A.dir=m?\"increasing\":\"decreasing\",A.x=A.pos,A.y=[k,T],y&&(A.orig_p=r[b]),d&&(A.tx=e.text[b]),g&&(A.htx=e.hovertext[b]),x.push(A)}else x.push({pos:_,empty:!0})}return e._extremes[l._id]=a.findExtremes(l,n.concat(h,f),{padded:!0}),x.length&&(x[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),x}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),s=function(t,e,r){var i=r._minDiff;if(!i){var a,s=t._fullData,l=[];for(i=1/0,a=0;a<s.length;a++){var c=s[a];if(\"ohlc\"===c.type&&!0===c.visible&&c.xaxis===e._id){l.push(c);var u=e.makeCalcdata(c,\"x\");c._origX=u;var f=o(r,e,\"x\",u);c._xcalc=f;var h=n.distinctVals(f).minDiff;h&&isFinite(h)&&(i=Math.min(i,h))}}for(i===1/0&&(i=1),a=0;a<l.length;a++)l[a]._minDiff=i}return i*r.tickwidth}(t,r,e),u=e._minDiff;e._minDiff=null;var f=e._origX;e._origX=null;var h=e._xcalc;e._xcalc=null;var p=c(t,e,f,h,i,l);return e._extremes[r._id]=a.findExtremes(r,h,{vpad:u/2}),p.length?(n.extendFlat(p[0].t,{wHover:u/2,tickLen:s}),p):[{t:{empty:!0}}]},calcCommon:c}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}i(t,e,c,l)?(a(t,e,l,c,{x:!0}),c(\"line.width\"),c(\"line.dash\"),s(t,e,c,\"increasing\"),s(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"tickwidth\"),l._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":778,\"../scatter/period_defaults\":1207,\"./attributes\":1133,\"./ohlc_defaults\":1138}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,f=l[0].t,h=u.type,p=\"ohlc\"===h?\"l\":\"min\",d=\"ohlc\"===h?\"h\":\"max\",g=f.bPos||0,m=f.bdPos||f.tickLen,v=f.wHover,y=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function x(t){var r=function(t){return t.pos+g-e}(t);return a.inbox(r-v,r+v,i)}function b(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function _(t){return(x(t)+b(t))/2}i=t.maxHoverDistance-y,s=t.maxSpikeDistance-y;var w=a.getDistanceFunction(n,x,b,_);if(a.getClosest(l,w,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var k=u[T.dir],M=k.line.color;return o.opacity(M)&&k.line.width?t.color=M:t.color=k.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=void 0!==T.orig_p?T.orig_p:T.pos,t.spikeDistance=_(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function f(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,f=[],h=u(t,e,r,a);if(!h)return[];var p=o[h.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],m={},v=0;v<g.length;v++){var y,x=g[v],b=l[x][h.index],_=s.c2p(b,!0);b in m?(y=m[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},h)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",f.push(y),m[b]=y)}return f}function h(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,f=a[0].t,h=u(t,e,r,i);if(!h)return[];var p=a[h.index],d=h.index=p.i,g=p.dir;function m(t){return f.labels[t]+n.hoverLabelText(o,l[t][d])}var v=p.hi||l.hoverinfo,y=v.split(\"+\"),x=\"all\"===v,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[m(\"open\"),m(\"high\"),m(\"low\"),m(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),h.extraText=w.join(\"<br>\"),h.y0=h.y1=o.c2p(p.yc,!0),[h]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?f(t,e,r,n):h(t,e,r,n)},hoverSplit:f,hoverOnPoints:h}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../constants/delta.js\":747,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1137:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":841,\"./attributes\":1133,\"./calc\":1134,\"./defaults\":1135,\"./hover\":1136,\"./plot\":1139,\"./select\":1140,\"./style\":1141}],1138:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var f=Math.min(s.length,l.length,c.length,u.length);return o&&(f=Math.min(f,i.minRowLength(o))),e._length=f,f}}},{\"../../lib\":778,\"../../registry\":911}],1139:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.yaxis,s=e.xaxis,l=!!s.rangebreaks;i.makeTraceGroups(a,r,\"trace ohlc\").each((function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var c=a.tickLen,u=e.selectAll(\"path\").data(i.identity);u.enter().append(\"path\"),u.exit().remove(),u.attr(\"d\",(function(t){if(t.empty)return\"M0,0Z\";var e=s.c2p(t.pos-c,!0),r=s.c2p(t.pos+c,!0),n=l?(e+r)/2:s.c2p(t.pos,!0);return\"M\"+e+\",\"+o.c2p(t.o,!0)+\"H\"+n+\"M\"+n+\",\"+o.c2p(t.h,!0)+\"V\"+o.c2p(t.l,!0)+\"M\"+r+\",\"+o.c2p(t.c,!0)+\"H\"+n}))}}))}},{\"../../lib\":778,d3:169}],1140:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1141:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each((function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}}))}))}},{\"../../components/color\":643,\"../../components/drawing\":665,d3:169}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1143:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":865,\"./plot\":1148}],1144:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=t(\"fast-isnumeric\");function u(t,e,r){t.valueInds.push(e),t.count+=r}function f(t,e,r){return{categoryInds:t,color:e,rawColor:r,valueInds:[],count:0}}function h(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var p,d,g,m=r.map((function(t){var e;if(\"trace\"===t.categoryorder)e=null;else if(\"array\"===t.categoryorder)e=t.categoryarray;else{e=o(t.values);for(var r=!0,n=0;n<e.length;n++)if(!c(e[n])){r=!1;break}e.sort(r?l.sorterAsc:void 0),\"category descending\"===t.categoryorder&&(e=e.reverse())}return function(t,e){e=null==e?[]:e.map((function(t){return t}));var r={},n={},i=[];e.forEach((function(t,e){r[t]=0,n[t]=e}));for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map((function(t){return r[t]}));return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)}));p=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map((function(t){return t.displayindex}))))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach((function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,m[e])}));var v,y=e.line;y?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),v=s.tryColorscale(y)):v=l.identity;var x,b,_,w,T,k=r[0].values.length,M={},A=m.map((function(t){return t.inds}));for(g=0,x=0;x<k;x++){var S=[];for(b=0;b<A.length;b++)S.push(A[b][x]);d=p[x%p.length],g+=d;var E=(_=x,w=void 0,T=void 0,l.isArrayOrTypedArray(y.color)?T=w=y.color[_%y.color.length]:w=y.color,{color:v(w),rawColor:T}),C=S+\"-\"+E.rawColor;void 0===M[C]&&(M[C]=f(S,E.color,E.rawColor)),h(M[C],x,d)}var L,I=r.map((function(t,e){return function(t,e,r,n,i){return{dimensionInd:t,containerInd:e,displayInd:r,dimensionLabel:n,count:i,categories:[],dragX:null}}(e,t._index,t._displayindex,t.label,g)}));for(x=0;x<k;x++)for(d=p[x%p.length],b=0;b<I.length;b++){var P=I[b].containerInd,z=m[b].inds[x],O=I[b].categories;if(void 0===O[z]){var D=e.dimensions[P]._categoryarray[z],R=e.dimensions[P]._ticktext[z];O[z]={dimensionInd:b,categoryInd:L=z,categoryValue:D,displayInd:L,categoryLabel:R,valueInds:[],count:0,dragY:null}}u(O[z],x,d)}return n(function(t,e,r){var n=t.map((function(t){return t.categories.length})).reduce((function(t,e){return Math.max(t,e)}));return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(I,M,g))}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/filter_unique.js\":769,\"../../lib/gup\":775,\"fast-isnumeric\":241}],1145:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,f,h);o(e,f,h),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),h(\"hoveron\"),h(\"hovertemplate\"),h(\"arrangement\"),h(\"bundlecolors\"),h(\"sortpaths\"),h(\"counts\");var g={family:f.font.family,size:Math.round(f.font.size),color:f.font.color};n.coerceFont(h,\"labelfont\",g);var m={family:f.font.family,size:Math.round(f.font.size/1.2),color:f.font.color};n.coerceFont(h,\"tickfont\",m)}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/domain\":855,\"../parcoords/merge_length\":1158,\"./attributes\":1142}],1146:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1142,\"./base_plot\":1143,\"./calc\":1144,\"./defaults\":1145,\"./plot\":1148}],1147:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../../components/drawing\"),c=t(\"tinycolor2\"),u=t(\"../../lib/svg_text_utils\");function f(t,e,r,i){var a=t.map(R.bind(0,e,r)),c=i.selectAll(\"g.parcatslayer\").data([null]);c.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var f=c.selectAll(\"g.trace.parcats\").data(a,h),v=f.enter().append(\"g\").attr(\"class\",\"trace parcats\");f.attr(\"transform\",(function(t){return s(t.x,t.y)})),v.append(\"g\").attr(\"class\",\"paths\");var y=f.select(\"g.paths\").selectAll(\"path.path\").data((function(t){return t.paths}),h);y.attr(\"fill\",(function(t){return t.model.color}));var _=y.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",0);b(_),y.attr(\"d\",(function(t){return t.svgD})),_.empty()||y.sort(d),y.exit().remove(),y.on(\"mouseover\",g).on(\"mouseout\",m).on(\"click\",x),v.append(\"g\").attr(\"class\",\"dimensions\");var k=f.select(\"g.dimensions\").selectAll(\"g.dimension\").data((function(t){return t.dimensions}),h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",(function(t){return s(t.x,0)})),k.exit().remove();var M=k.selectAll(\"g.category\").data((function(t){return t.categories}),h),A=M.enter().append(\"g\").attr(\"class\",\"category\");M.attr(\"transform\",(function(t){return s(0,t.y)})),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),M.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),w(A);var S=M.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h);S.each((function(){o.raiseToTop(this)})),S.attr(\"fill\",(function(t){return t.color}));var z=S.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);S.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})).attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"})),T(z),S.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var O=e._fullLayout.paper_bgcolor;M.select(\"text.catlabel\").attr(\"text-anchor\",(function(t){return p(t)?\"start\":\"end\"})).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",O+\" -1px  1px 2px, \"+O+\" 1px  1px 2px, \"+O+\"  1px -1px 2px, \"+O+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",(function(t){return p(t)?t.width+5:-5})).attr(\"y\",(function(t){return t.height/2})).text((function(t){return t.model.categoryLabel})).each((function(t){l.font(n.select(this),t.parcatsViewModel.categorylabelfont),u.convertToTspans(n.select(this),e)})),A.append(\"text\").attr(\"class\",\"dimlabel\"),M.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"})).attr(\"x\",(function(t){return t.width/2})).attr(\"y\",-5).text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})).each((function(t){l.font(n.select(this),t.parcatsViewModel.labelfont)})),M.selectAll(\"rect.bandrect\").on(\"mouseover\",E).on(\"mouseout\",C),M.exit().remove(),k.call(n.behavior.drag().origin((function(t){return{x:t.x,y:0}})).on(\"dragstart\",L).on(\"drag\",I).on(\"dragend\",P)),f.each((function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")})),f.exit().remove()}function h(t){return t.key}function p(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function d(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function g(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),_(n.select(this));var e=v(t),r=y(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event,constraints:r}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var i,s,l,u=n.mouse(this)[0],f=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,p=f._fullLayout,d=p._paperdiv.node().getBoundingClientRect(),g=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(l=0;l<t.leftXs.length-1;l++)if(t.leftXs[l]+t.dimWidths[l]-2<=u&&u<=t.leftXs[l+1]+2){var m=t.parcatsViewModel.dimensions[l],x=t.parcatsViewModel.dimensions[l+1];i=(m.x+m.width+x.x)/2,s=(t.topYs[l]+t.topYs[l+1]+t.height)/2;break}var b=t.parcatsViewModel.x+i,w=t.parcatsViewModel.y+s,T=c.mostReadable(t.model.color,[\"black\",\"white\"]),k=t.model.count,M=k/t.parcatsViewModel.model.count,A={countLabel:k,probabilityLabel:M.toFixed(3)},S=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&S.push([\"Count:\",A.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&S.push([\"P:\",A.probabilityLabel].join(\" \"));var E=S.join(\"<br>\"),C=n.mouse(f)[0];a.loneHover({trace:h,x:b-d.left+g.left,y:w-d.top+g.top,text:E,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:T,idealAlign:C<b?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:A,eventData:[{data:h._input,fullData:h,count:k,probability:M}]},{container:p._hoverlayer.node(),outerContainer:p._paper.node(),gd:f})}}}function m(t){if(!t.parcatsViewModel.dragDimension&&(b(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(d),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t),r=y(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event,constraints:r})}}function v(t){for(var e=[],r=z(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function y(t){for(var e={},r=t.parcatsViewModel.model.dimensions,n=0;n<r.length;n++){var i=r[n],a=i.categories[t.model.categoryInds[n]];e[i.containerInd]=a.categoryValue}return void 0!==t.model.rawColor&&(e.color=t.model.rawColor),e}function x(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t),r=y(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event,constraints:r})}}function b(t){t.attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",(function(t){return c.mostReadable(t.model.color,[\"black\",\"white\"])})).attr(\"stroke-width\",.3)}function w(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function T(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function k(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter((function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color}))}function M(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=n.select(t.parentNode).selectAll(\"rect.bandrect\"),l=[];s.each((function(t){k(t).each((function(t){Array.prototype.push.apply(l,v(t))}))}));var c={};c[a.dimensionInd]=a.categoryValue,o.emit(e,{points:l,event:r,constraints:c})}function A(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=k(i),l=[];s.each((function(t){Array.prototype.push.apply(l,v(t))}));var c={};c[a.dimensionInd]=a.categoryValue,void 0!==i.rawColor&&(c.color=i.rawColor),o.emit(e,{points:l,event:r,constraints:c})}function S(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=n.select(r.parentNode).select(\"rect.catrect\"),c=l.node().getBoundingClientRect(),u=l.datum(),f=u.parcatsViewModel,h=f.model.dimensions[u.model.dimensionInd],p=f.trace,d=c.top+c.height/2;f.dimensions.length>1&&h.displayInd===f.dimensions.length-1?(i=c.left,a=\"left\"):(i=c.left+c.width,a=\"right\");var g=u.model.count,m=u.model.categoryLabel,v=g/u.parcatsViewModel.model.count,y={countLabel:g,categoryLabel:m,probabilityLabel:v.toFixed(3)},x=[];-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&x.push([\"Count:\",y.countLabel].join(\" \")),-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&x.push([\"P(\"+y.categoryLabel+\"):\",y.probabilityLabel].join(\" \"));var b=x.join(\"<br>\");return{trace:p,x:o*(i-e.left),y:s*(d-e.top),text:b,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:a,hovertemplate:p.hovertemplate,hovertemplateLabels:y,eventData:[{data:p._input,fullData:p,count:g,category:m,probability:v}]}}function E(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),l=t.parcatsViewModel.hoveron;if(\"color\"===l?(!function(t){var e=n.select(t).datum(),r=k(e);_(r),r.each((function(){o.raiseToTop(this)})),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter((function(t){return t.color===e.color})).each((function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)}))}(this),A(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each((function(t){var e=k(t);_(e),e.each((function(){o.raiseToTop(this)}))})),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),M(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===l?e=S(r,s,this):\"color\"===l?e=function(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=r.getBoundingClientRect(),u=n.select(r).datum(),f=u.categoryViewModel,h=f.parcatsViewModel,p=h.model.dimensions[f.model.dimensionInd],d=h.trace,g=l.y+l.height/2;h.dimensions.length>1&&p.displayInd===h.dimensions.length-1?(i=l.left,a=\"left\"):(i=l.left+l.width,a=\"right\");var m=f.model.categoryLabel,v=u.parcatsViewModel.model.count,y=0;u.categoryViewModel.bands.forEach((function(t){t.color===u.color&&(y+=t.count)}));var x=f.model.count,b=0;h.pathSelection.each((function(t){t.model.color===u.color&&(b+=t.model.count)}));var _=y/v,w=y/b,T=y/x,k={countLabel:v,categoryLabel:m,probabilityLabel:_.toFixed(3)},M=[];-1!==f.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&M.push([\"Count:\",k.countLabel].join(\" \")),-1!==f.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(M.push(\"P(color \\u2229 \"+m+\"): \"+k.probabilityLabel),M.push(\"P(\"+m+\" | color): \"+w.toFixed(3)),M.push(\"P(color | \"+m+\"): \"+T.toFixed(3)));var A=M.join(\"<br>\"),S=c.mostReadable(u.color,[\"black\",\"white\"]);return{trace:d,x:o*(i-e.left),y:s*(g-e.top),text:A,color:u.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:S,fontSize:10,idealAlign:a,hovertemplate:d.hovertemplate,hovertemplateLabels:k,eventData:[{data:d._input,fullData:d,category:m,count:v,probability:_,categorycount:x,colorcount:b,bandcolorcount:y}]}}(r,s,this):\"dimension\"===l&&(e=function(t,e,r){var i=[];return n.select(r.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each((function(){i.push(S(t,e,this))})),i}(r,s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function C(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(b(e.pathSelection),w(e.dimensionSelection.selectAll(\"g.category\")),T(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(d),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?A(this,\"plotly_unhover\",n.event):M(this,\"plotly_unhover\",n.event)}}function L(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each((function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map((function(t){return t.displayInd})),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each((function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)})))})),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function I(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],f=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==f&&s+o.height>f.y+f.height/2&&(o.model.displayInd=f.model.displayInd,f.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var h=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==h&&a.model.dragX<h.x+h.width&&(a.model.displayInd=h.model.displayInd,h.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}N(t.parcatsViewModel),B(t.parcatsViewModel),D(t.parcatsViewModel),O(t.parcatsViewModel)}}function P(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=z(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),o=t.initialDragDimensionDisplayInds.some((function(t,e){return t!==a[e]}));o&&a.forEach((function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r}));var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map((function(t){return t.displayInd}));if(s=t.initialDragCategoryDisplayInds.some((function(t,e){return t!==l[e]}))){var c=t.model.categories.slice().sort((function(t,e){return t.displayInd-e.displayInd})),u=c.map((function(t){return t.categoryValue})),f=c.map((function(t){return t.categoryLabel}));e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[f],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?A(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):M(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,N(t.parcatsViewModel),B(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each((function(){D(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)})).each(\"end\",(function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])}))}}function z(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data((function(t){return t.paths}),h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",(function(t){return t.svgD}))}function D(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data((function(t){return t.dimensions}),h);var i=t.dimensionSelection.selectAll(\"g.category\").data((function(t){return t.categories}),h);r(t.dimensionSelection).attr(\"transform\",(function(t){return s(t.x,0)})),r(i).attr(\"transform\",(function(t){return s(0,t.y)})),i.select(\".dimlabel\").text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})),i.select(\".catlabel\").attr(\"text-anchor\",(function(t){return p(t)?\"start\":\"end\"})).attr(\"x\",(function(t){return p(t)?t.width+5:-5})).each((function(t){var e,r;p(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)}));var a=i.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h),l=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);a.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})),T(l),a.each((function(){o.raiseToTop(this)})),a.exit().remove()}function R(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),f=Math.floor(c*(s.y[1]-s.y[0])),h=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:h,y:p,width:u,height:f,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};return i.dimensions&&(N(g),B(g)),g}function F(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function B(t){var e=t.dimensions,r=t.model,n=e.map((function(t){return t.categories.map((function(t){return t.y}))})),i=t.model.dimensions.map((function(t){return t.categories.map((function(t){return t.displayInd}))})),a=t.model.dimensions.map((function(t){return t.displayInd})),o=t.dimensions.map((function(t){return t.model.dimensionInd})),s=e.map((function(t){return t.x})),l=e.map((function(t){return t.width})),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function f(t){var e=t.categoryInds.map((function(t,e){return i[e][t]}));return o.map((function(t){return e[t]}))}c.sort((function(e,r){var n=f(e),i=f(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0}));for(var h=new Array(c.length),p=e[0].model.count,d=e[0].categories.map((function(t){return t.height})).reduce((function(t,e){return t+e})),g=0;g<c.length;g++){var m,v=c[g];m=p>0?d*(v.count/p):0;for(var y,x=new Array(n.length),b=0;b<v.categoryInds.length;b++){var _=v.categoryInds[b],w=i[b][_],T=a[b];x[T]=n[T][w],n[T][w]+=m;var k=t.dimensions[T].categories[w],M=k.bands.length,A=k.bands[M-1];if(void 0===A||v.rawColor!==A.rawColor){var S=void 0===A?0:A.y+A.height;k.bands.push({key:S,color:v.color,rawColor:v.rawColor,height:m,width:k.width,count:v.count,y:S,categoryViewModel:k,parcatsViewModel:t})}else{var E=k.bands[M-1];E.height+=m,E.count+=v.count}}y=\"hspline\"===t.pathShape?F(s,x,l,m,.5):F(s,x,l,m,0),h[g]={key:v.valueInds[0],model:v,height:m,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=h}function N(t){var e=t.model.dimensions.map((function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}}));e.sort((function(t,e){return t.displayInd-e.displayInd}));var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(j(t,a))}t.dimensions=r}function j(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],f=t.model.maxCats,h=e.categories.length,p=e.count,d=t.height-8*(f-1),g=8*(f-h)/2,m=e.categories.map((function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}}));for(m.sort((function(t,e){return t.displayInd-e.displayInd})),c=0;c<h;c++)l=m[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){f(r,t,n,e)}},{\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_api\":814,d3:169,tinycolor2:576}],1148:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1147}],1149:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1150:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=t(\"../../lib\").strTranslate,c=n.bar.snapRatio;function u(t,e){return t*(1-c)+e*c}var f=n.bar.snapClose;function h(t,e){return t*(1-f)+e*f}function p(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],c=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return u(l,c);if(i*r<i*d||p===o)return u(d,l);c=l,l=d}}function d(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function g(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function m(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map((function(t){return t.map((function(t){return Math.max(0,t*e)})).sort(s)}))}function y(){i.select(document.body).style(\"cursor\",null)}function x(t){t.attr(\"stroke-dasharray\",m)}function b(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");x(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function _(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,f=NaN,h=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(f=r?r-1:NaN,p&&p[0]>e){h=r;break}}if(a=u,isNaN(a)&&(a=isNaN(f)||isNaN(h)?isNaN(f)?h:f:e-c[f][1]<c[h][0]-e?f:h),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function w(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),b(t.parentNode)}function T(t,e){var r=_(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",(function(t){i.event.preventDefault(),t.parent.inBrushDrag||T(this,t)})).on(\"mouseleave\",(function(t){t.parent.inBrushDrag||y()})).call(i.behavior.drag().on(\"dragstart\",(function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=_(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter((function(t){return t[0]!==l[0]&&t[1]!==l[1]}))),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)})).on(\"drag\",(function(t){w(this,t)})).on(\"dragend\",(function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(T(t,e),w(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,y(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),b(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[p(0,l,a.newExtent[0],a.stayingIntervals),p(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?b(t.parentNode,s):(s(),b(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)})))}function M(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function S(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return 1===n.length&&n[0][0]>n[0][1]&&(n=[]),n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map((function(t){return t.slice().sort(s)})).sort(M)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=S(r),e=r.reduce((function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]}),[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map((function(t){return t.slice()}))}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(d).call(g).style(\"pointer-events\",\"auto\").attr(\"transform\",l(0,n.verticalPadding)),e.call(k).attr(\"height\",(function(t){return t.height-n.verticalPadding}));var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",(function(t){return t.height})).call(x);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",(function(t){return t.height})).call(x)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map((function(t){return t.sort(s)})),t=e.multiselect?S(t.sort(M)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map((function(t){var e=[p(0,r,t[0],[]),p(1,r,t[1],[])];if(e[1]>e[0])return e})).filter((function(t){return t}))).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":778,\"../../lib/gup\":775,\"./constants\":1153,d3:169}],1151:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})),window.setTimeout((function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")}),60)}},{\"../../constants/xmlns_namespaces\":754,\"../../plots/get_data\":865,\"./plot\":1160,d3:169}],1152:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gup\":775}],1153:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1154:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),f=t(\"./constants\").maxDimensionCount,h=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var f=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:f},l.setConvert(e._ax,i.layout),a(\"multiselect\");var h=a(\"constraintrange\");h&&(e.constraintrange=u.cleanRanges(h,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>f&&(n.log(\"parcoords traces support up to \"+f+\" dimensions at the moment\"),d.splice(f));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),m=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),h(e,g,\"values\",m);var v={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",v),n.coerceFont(u,\"tickfont\",v),n.coerceFont(u,\"rangefont\",v),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"../../plots/domain\":855,\"./attributes\":1149,\"./axisbrush\":1150,\"./constants\":1153,\"./merge_length\":1158}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":778}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1149,\"./base_plot\":1151,\"./calc\":1152,\"./defaults\":1154,\"./plot\":1160}],1157:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=new Uint8Array(4),c=new Uint8Array(4),u={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function f(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function h(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:l})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],f(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame((function(){s(l+1)}))),r.drawCompleted=!1)}(0)}function p(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}function d(t,e){return(t>>>8*e)%256/255}function g(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function v(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function y(t,e,r,n,i,a,o,l,c,u,f,h,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var m=t.lines.canvasOverdrag,v=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:f,resolution:[y,x],viewBoxPos:[o+m,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:h,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+m)+(t.pad.l-m)+t.layoutWidth*v.x[0],scissorWidth:(n===r?y-o+m:c+.5)+(n===e?o+m:0),scissorY:l+t.pad.b+t.layoutHeight*v.y[0],scissorHeight:u,viewportX:t.pad.l-m+t.layoutWidth*v.x[0],viewportY:t.pad.b+t.layoutHeight*v.y[0],viewportWidth:y,viewportHeight:x},p)}function x(t){var e=Math.max(0,Math.floor(2047*t[0]),0),r=Math.min(2047,Math.ceil(2047*t[1]),2047);return[Math.min(e,r),Math.max(e,r)]}e.exports=function(t,e){var r,n,l,m,b,_=e.context,w=e.pick,T=e.regl,k={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[v(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),A=T.texture(u),S=[];C(e);var E=T({profile:!1,blend:{enable:_,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!_,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:A,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function C(t){r=t.model,n=t.viewModel,l=n.dimensions.slice(),m=l[0]?l[0].values.length:0;var e=r.lines,i=w?e.color.map((function(t,r){return r/e.color.length})):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var l=0;l<o;l++)i[a++]=l<e.length?e[l].paddedUnitValues[s]:.5;i[a++]=d(s,2),i[a++]=d(s,1),i[a++]=d(s,0),i[a++]=(n=r[s],Math.max(1e-6,Math.min(.999999,n)))}return i}(m,l,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[v(n)](g(n/4,e,r))}(M,m,a),_||w||(A=T.texture(s.extendFlat({data:p(r.unitToColor,255)},u)))}return{render:function(t,e,n){var i,a,o,s=t.length,c=1/0,u=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<c&&(c=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>u&&(u=t[i].dim1.canvasX,o=i);0===s&&f(T,0,0,r.canvasWidth,r.canvasHeight);var p=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<l.length?l[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=new Array(16384);for(e=0;e<16384;e++)o[e]=255;if(!t)for(e=0;e<l.length;e++){var s=e%8,c=(e-s)/8,u=Math.pow(2,s),f=l[e].brush.filter.get();if(!(f.length<2)){var h=x(f[0])[1];for(r=1;r<f.length;r++){var p=x(f[r]);for(n=h+1;n<p[0];n++)o[8*n+c]&=~u;h=Math.max(h,p[1])}}}var d={shape:[8,2048],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:o};return b?b(d):b=T.texture(d),{maskTexture:b,maskHeight:2048,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(_);for(i=0;i<s;i++){var d=t[i],g=d.dim0.crossfilterDimensionIndex,v=d.dim1.crossfilterDimensionIndex,M=d.canvasX,A=d.canvasY,C=M+d.panelSizeX;if(e||!S[g]||S[g][0]!==M||S[g][1]!==C){S[g]=[M,C];var L=y(r,a,o,i,g,v,M,A,d.panelSizeX,d.panelSizeY,d.dim0.crossfilterDimensionIndex,_?0:w?2:1,p);k.clearOnly=n;var I=e?r.lines.blockLineCount:m;h(T,E,k,I,m,L)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:c}),c},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",A.destroy(),b&&b.destroy(),M)M[e].destroy()},update:C}}},{\"../../lib\":778,\"./constants\":1153,glslify:439}],1158:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=o.strRotate,l=o.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/drawing\"),f=t(\"../../components/colorscale\"),h=t(\"../../lib/gup\"),p=h.keyFun,d=h.repeat,g=h.unwrap,m=t(\"./helpers\"),v=t(\"./constants\"),y=t(\"./axisbrush\"),x=t(\"./lines\");function b(t,e,r){return o.aggNums(t,null,e,r)}function _(t,e){return T(b(Math.min,t,e),b(Math.max,t,e))}function w(t){var e=t.range;return e?T(e[0],e[1]):_(t.values,t._length)}function T(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function k(t,e,r,i,a){var o,s,l=w(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map((function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)}))):n.scale.linear().domain(l).range([t-e,e])}function M(t){if(t.tickvals){var e=w(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map((function(t){return(t-e[0])/(e[1]-e[0])})))}}function A(t){var e=t.map((function(t){return t[0]})),r=t.map((function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")})),a=\"rgb\".split(\"\").map((function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i}));return function(t){return a.map((function(e){return e(t)}))}}function S(t){return t.dimensions.some((function(t){return t.brush.filterSpecified}))}function E(t,e,r){var a=g(e),s=a.trace,l=m.convertTypedArray(a.lineColor),c=s.line,u={color:i(v.deselectedLineColor)},h=f.extractOpts(c),p=h.reversescale?f.flipScale(a.cscale):a.cscale,d=s.domain,y=s.dimensions,x=t.width,b=s.labelangle,_=s.labelside,T=s.labelfont,k=s.tickfont,M=s.rangefont,S=o.extendDeepNoArrays({},c,{color:l.map(n.scale.linear().domain(w({values:l,range:[h.min,h.max],_length:s._length}))),blockLineCount:v.blockLineCount,canvasOverdrag:v.overdrag*v.canvasPixelRatio}),E=Math.floor(x*(d.x[1]-d.x[0])),C=Math.floor(t.height*(d.y[1]-d.y[0])),L=t.margin||{l:80,r:80,t:100,b:80},I=E,P=C;return{key:r,colCount:y.filter(m.isVisible).length,dimensions:y,tickDistance:v.tickDistance,unitToColor:A(p),lines:S,deselectedLines:u,labelAngle:b,labelSide:_,labelFont:T,tickFont:k,rangeFont:M,layoutWidth:x,layoutHeight:t.height,domain:d,translateX:d.x[0]*x,translateY:t.height-d.y[1]*t.height,pad:L,canvasWidth:I*v.canvasPixelRatio+2*S.canvasOverdrag,canvasHeight:P*v.canvasPixelRatio,width:I,height:P,canvasPixelRatio:v.canvasPixelRatio}}function C(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=v.verticalPadding/a,f=function(t,e){return n.scale.linear().range([e,t-e])}(a,v.verticalPadding),h={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return h.dimensions=s.filter(m.isVisible).map((function(i,s){var d=function(t,e){return n.scale.linear().domain(w(t)).range([e,1-e])}(i,u),g=p[i.label];p[i.label]=(g||0)+1;var x=i.label+(g?\"__\"+g:\"\"),b=i.constraintrange,_=b&&b.length;_&&!Array.isArray(b[0])&&(b=[b]);var T=_?b.map((function(t){return t.map(d)})):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var E,C=i.tickvals;function L(t,e){return{val:t,text:E[e]}}function I(t,e){return t.val-e.val}if(Array.isArray(C)&&C.length){E=i.ticktext,Array.isArray(E)&&E.length?E.length>C.length?E=E.slice(0,C.length):C.length>E.length&&(C=C.slice(0,E.length)):E=C.map(n.format(i.tickformat));for(var P=1;P<C.length;P++)if(C[P]<C[P-1]){for(var z=C.map(L).sort(I),O=0;O<C.length;O++)C[O]=z[O].val,E[O]=z[O].text;break}}else C=void 0;return A=m.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:C,ticktext:E,ordinal:m.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(d),unitTickvals:C&&C.map(d),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:f,domainScale:k(a,v.verticalPadding,i,C,E),ordinalScale:M(i),parent:h,model:r,brush:y.makeBrush(t,_,T,(function(){t.linePickActive(!1)}),(function(){var e=h;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=S(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))}),(function(r){if(h.focusLayer.render(h.panels,!0),h.pickLayer&&h.pickLayer.render(h.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=d.invert,a=r.map((function(t){return t.map(n).sort(o.sorterAsc)})).sort((function(t,e){return t[0]-e[0]}));e.filterChanged(h.key,i._index,a)}}))}})),h}function L(t){t.classed(v.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\")}function I(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function P(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function z(t,e){return a.tickText(t._ax,e,!1).text}function O(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return z(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var f=t._fullLayout,h=f._toppaper,b=f._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=T(l.range[0],l.range[1]):l.range=_(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var w,k,M=(w=!0,k=!1,{linePickActive:function(t){return arguments.length?w=!!t:w},contextShown:function(t){return arguments.length?k=!!t:k}}),A=e.filter((function(t){return g(t).trace.visible})).map(E.bind(0,r)).map(C.bind(0,M,i));b.each((function(t,e){return o.extendFlat(t,A[e])}));var D=b.selectAll(\".gl-canvas\").each((function(t){t.viewModel=A[0],t.model=t.viewModel?t.viewModel.model:null})),R=null;D.filter((function(t){return t.pick})).style(\"pointer-events\",\"auto\").on(\"mousemove\",(function(t){if(M.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],f=u?c[2]+256*(c[1]+256*c[0]):null,h={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:f};f!==R&&(u?i.hover(h):i.unhover&&i.unhover(h),R=f)}})),D.style(\"opacity\",(function(t){return t.pick?0:1})),h.style(\"background\",\"rgba(255, 255, 255, 0)\");var F=h.selectAll(\".\"+v.cn.parcoords).data(A,p);F.exit().remove(),F.enter().append(\"g\").classed(v.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),F.attr(\"transform\",(function(t){return l(t.model.translateX,t.model.translateY)}));var B=F.selectAll(\".\"+v.cn.parcoordsControlView).data(d,p);B.enter().append(\"g\").classed(v.cn.parcoordsControlView,!0),B.attr(\"transform\",(function(t){return l(t.model.pad.l,t.model.pad.t)}));var N=B.selectAll(\".\"+v.cn.yAxis).data((function(t){return t.dimensions}),p);N.enter().append(\"g\").classed(v.cn.yAxis,!0),B.each((function(t){P(N,t)})),D.each((function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=x(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}})),N.attr(\"transform\",(function(t){return l(t.xScale(t.xIndex),0)})),N.call(n.behavior.drag().origin((function(t){return t})).on(\"drag\",(function(t){var e=t.parent;M.linePickActive(!1),t.x=Math.max(-v.overdrag,Math.min(t.model.width+v.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,N.sort((function(t,e){return t.x-e.x})).each((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio})),P(N,e),N.filter((function(e){return 0!==Math.abs(t.xIndex-e.xIndex)})).attr(\"transform\",(function(t){return l(t.xScale(t.xIndex),0)})),n.select(this).attr(\"transform\",l(t.x,0)),N.each((function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!S(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)})).on(\"dragend\",(function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,P(N,e),n.select(this).attr(\"transform\",(function(t){return l(t.x,0)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!S(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),M.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map((function(t){return t.crossfilterDimensionIndex})))}))),N.exit().remove();var j=N.selectAll(\".\"+v.cn.axisOverlays).data(d,p);j.enter().append(\"g\").classed(v.cn.axisOverlays,!0),j.selectAll(\".\"+v.cn.axis).remove();var U=j.selectAll(\".\"+v.cn.axis).data(d,p);U.enter().append(\"g\").classed(v.cn.axis,!0),U.each((function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat((function(e){return m.isOrdinal(t)?e:z(t.model.dimensions[t.visibleIndex],e)})).scale(r)),u.font(U.selectAll(\"text\"),t.model.tickFont)})),U.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),U.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\");var V=j.selectAll(\".\"+v.cn.axisHeading).data(d,p);V.enter().append(\"g\").classed(v.cn.axisHeading,!0);var q=V.selectAll(\".\"+v.cn.axisTitle).data(d,p);q.enter().append(\"text\").classed(v.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"pointer-events\",\"auto\"),q.text((function(t){return t.label})).each((function(e){var r=n.select(this);u.font(r,e.model.labelFont),c.convertToTspans(r,t)})).attr(\"transform\",(function(t){var e=I(t.model.labelAngle,t.model.labelSide),r=v.axisTitleOffset;return(e.dir>0?\"\":l(0,2*r+t.model.height))+s(e.degrees)+l(-r*e.dx,-r*e.dy)})).attr(\"text-anchor\",(function(t){var e=I(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"}));var H=j.selectAll(\".\"+v.cn.axisExtent).data(d,p);H.enter().append(\"g\").classed(v.cn.axisExtent,!0);var G=H.selectAll(\".\"+v.cn.axisExtentTop).data(d,p);G.enter().append(\"g\").classed(v.cn.axisExtentTop,!0),G.attr(\"transform\",l(0,-v.axisExtentOffset));var Y=G.selectAll(\".\"+v.cn.axisExtentTopText).data(d,p);Y.enter().append(\"text\").classed(v.cn.axisExtentTopText,!0).call(L),Y.text((function(t){return O(t,!0)})).each((function(t){u.font(n.select(this),t.model.rangeFont)}));var W=H.selectAll(\".\"+v.cn.axisExtentBottom).data(d,p);W.enter().append(\"g\").classed(v.cn.axisExtentBottom,!0),W.attr(\"transform\",(function(t){return l(0,t.model.height+v.axisExtentOffset)}));var X=W.selectAll(\".\"+v.cn.axisExtentBottomText).data(d,p);X.enter().append(\"text\").classed(v.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(L),X.text((function(t){return O(t,!1)})).each((function(t){u.font(n.select(this),t.model.rangeFont)})),y.ensureAxisBrush(j)}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"./axisbrush\":1150,\"./constants\":1153,\"./helpers\":1155,\"./lines\":1157,\"color-rgba\":127,d3:169}],1160:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},f=r._size;e.forEach((function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()}));n(t,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map((function(t){return t.slice()})),s=\"dimensions[\"+n+\"].constraintrange\",f=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===f[s]){var h=a.constraintrange;f[s]=h||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter((function(t){return!a(t)})).sort((function(t){return l[e].indexOf(t)})).forEach((function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)})),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":791,\"./helpers\":1155,\"./parcoords\":1159}],1161:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/template_attributes\").texttemplateAttrs,c=t(\"../../lib/extend\").extendFlat,u=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:c({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),texttemplate:l({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:c({},u,{}),insidetextorientation:{valType:\"enumerated\",values:[\"horizontal\",\"radial\",\"tangential\",\"auto\"],dflt:\"auto\",editType:\"plot\"},insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),automargin:{valType:\"boolean\",dflt:!1,editType:\"plot\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:c({},u,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:c({},u,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1162:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"pie\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../components/color\"),o={};function s(t){return function(e,r){return!!e&&(!!(e=i(e)).isValid()&&(e=a.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function l(t,e){var r,n=JSON.stringify(t),a=e[n];if(!a){for(a=t.slice(),r=0;r<t.length;r++)a.push(i(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)a.push(i(t[r]).darken(20).toHexString());e[n]=a}return a}e.exports={calc:function(t,e){var r,i,a=[],o=t._fullLayout,l=o.hiddenlabels||[],c=e.labels,u=e.marker.colors||[],f=e.values,h=e._length,p=e._hasValues&&h;if(e.dlabel)for(c=new Array(h),r=0;r<h;r++)c[r]=String(e.label0+r*e.dlabel);var d={},g=s(o[\"_\"+e.type+\"colormap\"]),m=0,v=!1;for(r=0;r<h;r++){var y,x,b;if(p){if(y=f[r],!n(y))continue;if((y=+y)<0)continue}else y=1;void 0!==(x=c[r])&&\"\"!==x||(x=r);var _=d[x=String(x)];void 0===_?(d[x]=a.length,(b=-1!==l.indexOf(x))||(m+=y),a.push({v:y,label:x,color:g(u[r],x),i:r,pts:[r],hidden:b})):(v=!0,(i=a[_]).v+=y,i.pts.push(r),i.hidden||(m+=y),!1===i.color&&u[r]&&(i.color=g(u[r],x)))}return(\"funnelarea\"===e.type?v:e.sort)&&a.sort((function(t,e){return e.v-t.v})),a[0]&&(a[0].vTotal=m),a},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],s=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=l(a,o));for(var c=0,u=0;u<i.length;u++){var f=i[u];if(f[0].trace.type===r)for(var h=0;h<f.length;h++){var p=f[h];!1===p.color&&(s[p.label]?p.color=s[p.label]:(s[p.label]=p.color=a[c%a.length],c++))}}},makePullColorFn:s,generateExtendedColors:l}},{\"../../components/color\":643,\"fast-isnumeric\":241,tinycolor2:576}],1164:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./attributes\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText;function l(t,e){var r=Array.isArray(t),a=i.isArrayOrTypedArray(e),o=Math.min(r?t.length:1/0,a?e.length:1/0);if(isFinite(o)||(o=0),o&&a){for(var s,l=0;l<o;l++){var c=e[l];if(n(c)&&c>0){s=!0;break}}s||(o=0)}return{hasLabels:r,hasValues:a,len:o}}e.exports={handleLabelsAndValues:l,supplyDefaults:function(t,e,r,n){function c(r,n){return i.coerce(t,e,a,r,n)}var u=l(c(\"labels\"),c(\"values\")),f=u.len;if(e._hasLabels=u.hasLabels,e._hasValues=u.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),f){e._length=f,c(\"marker.line.width\")&&c(\"marker.line.color\"),c(\"marker.colors\"),c(\"scalegroup\");var h,p=c(\"text\"),d=c(\"texttemplate\");if(d||(h=c(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),d||h&&\"none\"!==h){var g=c(\"textposition\");s(t,e,n,c,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),(Array.isArray(g)||\"auto\"===g||\"outside\"===g)&&c(\"automargin\"),(\"inside\"===g||\"auto\"===g||Array.isArray(g))&&c(\"insidetextorientation\")}o(e,n,c);var m=c(\"hole\");if(c(\"title.text\")){var v=c(\"title.position\",m?\"middle center\":\"top center\");m||\"middle center\"!==v||(e.title.position=\"top center\"),i.coerceFont(c,\"title.font\",n.font)}c(\"sort\"),c(\"direction\"),c(\"rotation\"),c(\"pull\")}else e.visible=!1}}},{\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"./attributes\":1161,\"fast-isnumeric\":241}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":679}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return-1!==t.indexOf(\"e\")?t.replace(/[.]?0+e/,\"e\"):-1!==t.indexOf(\".\")?t.replace(/[.]?0+$/,\"\"):t}r.formatPiePercent=function(t,e){var r=i((100*t).toPrecision(3));return n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=i(t.toPrecision(10));return n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n||\"\"===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0},r.getRotationAngle=function(t){return(\"auto\"===t?0:t)*Math.PI/180}},{\"../../lib\":778}],1167:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1161,\"./base_plot\":1162,\"./calc\":1163,\"./defaults\":1164,\"./layout_attributes\":1168,\"./layout_defaults\":1169,\"./plot\":1170,\"./style\":1171,\"./style_one\":1172}],1168:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":778,\"./layout_attributes\":1168}],1170:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=l.strScale,u=l.strTranslate,f=t(\"../../lib/svg_text_utils\"),h=t(\"../bar/uniform_text\"),p=h.recordMinTextSize,d=h.clearMinTextSize,g=t(\"../bar/constants\").TEXTPAD,m=t(\"./helpers\"),v=t(\"./event_data\"),y=t(\"../../lib\").isValidTextValue;function x(t,e,r){var i=r[0],o=i.trace,s=i.cx,c=i.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",(function(t){var r=e._fullLayout,u=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var f=u.hoverinfo;if(Array.isArray(f)&&(f=a.castHoverinfo({hoverinfo:[m.castOption(f,t.pts)],_module:o._module},r,0)),\"all\"===f&&(f=\"label+text+value+percent+name\"),u.hovertemplate||\"none\"!==f&&\"skip\"!==f&&f){var h=t.rInscribed||0,p=s+t.pxmid[0]*(1-h),d=c+t.pxmid[1]*(1-h),g=r.separators,y=[];if(f&&-1!==f.indexOf(\"label\")&&y.push(t.label),t.text=m.castOption(u.hovertext||u.text,t.pts),f&&-1!==f.indexOf(\"text\")){var x=t.text;l.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=m.formatPieValue(t.v,g),f&&-1!==f.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/i.vTotal,t.percentLabel=m.formatPiePercent(t.percent,g),f&&-1!==f.indexOf(\"percent\")&&y.push(t.percentLabel);var b=u.hoverlabel,_=b.font;a.loneHover({trace:o,x0:p-h*i.r,x1:p+h*i.r,y:d,text:y.join(\"<br>\"),name:u.hovertemplate||-1!==f.indexOf(\"name\")?u.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:m.castOption(b.bgcolor,t.pts)||t.color,borderColor:m.castOption(b.bordercolor,t.pts),fontFamily:m.castOption(_.family,t.pts),fontSize:m.castOption(_.size,t.pts),fontColor:m.castOption(_.color,t.pts),nameLength:m.castOption(b.namelength,t.pts),textAlign:m.castOption(b.align,t.pts),hovertemplate:m.castOption(u.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[v(t,u)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[v(t,u)],event:n.event})}})),t.on(\"mouseout\",(function(t){var r=e._fullLayout,i=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[v(s,i)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(a.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)})),t.on(\"click\",(function(t){var r=e._fullLayout,i=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[v(t,i)],a.click(e,n.event))}))}function b(t,e,r){var n=m.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=m.castOption(t._input.textfont.color,e.pts));var i=m.castOption(t.insidetextfont.family,e.pts)||m.castOption(t.textfont.family,e.pts)||r.family,a=m.castOption(t.insidetextfont.size,e.pts)||m.castOption(t.textfont.size,e.pts)||r.size;return{color:n||o.contrast(e.color),family:i,size:a}}function _(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=l.templateString(a,n._meta));var o=s.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(s.font,n.title.font).call(f.convertToTspans,e),c=s.bBox(o.node(),!0);r.titleBox={width:c.width,height:c.height},o.remove()}}function w(t,e,r){var n=r.r||e.rpx1,i=e.rInscribed;if(e.startangle===e.stopangle)return{rCenter:1-i,scale:0,rotate:0,textPosAngle:0};var a,o=e.ring,s=1===o&&Math.abs(e.startangle-e.stopangle)===2*Math.PI,l=e.halfangle,c=e.midangle,u=r.trace.insidetextorientation,f=\"horizontal\"===u,h=\"tangential\"===u,p=\"radial\"===u,d=\"auto\"===u,g=[];if(!d){var m,v=function(r,i){if(function(t,e){var r=t.startangle,n=t.stopangle;return r>e&&e>n||r<e&&e<n}(e,r)){var s=Math.abs(r-e.startangle),l=Math.abs(r-e.stopangle),c=s<l?s:l;(a=\"tan\"===i?k(t,n,o,c,0):T(t,n,o,c,Math.PI/2)).textPosAngle=r,g.push(a)}};if(f||h){for(m=4;m>=-4;m-=2)v(Math.PI*m,\"tan\");for(m=4;m>=-4;m-=2)v(Math.PI*(m+1),\"tan\")}if(f||p){for(m=4;m>=-4;m-=2)v(Math.PI*(m+1.5),\"rad\");for(m=4;m>=-4;m-=2)v(Math.PI*(m+.5),\"rad\")}}if(s||d||f){var y=Math.sqrt(t.width*t.width+t.height*t.height);if((a={scale:i*n*2/y,rCenter:1-i,rotate:0}).textPosAngle=(e.startangle+e.stopangle)/2,a.scale>=1)return a;g.push(a)}(d||p)&&((a=T(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(a)),(d||h)&&((a=k(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(a));for(var x=0,b=0,_=0;_<g.length;_++){var w=g[_].scale;if(b<w&&(b=w,x=_),!d&&b>=1)break}return g[x]}function T(t,e,r,n,i){e=Math.max(0,e-2*g);var a=t.width/t.height,o=S(a,n,e,r);return{scale:2*o/t.height,rCenter:M(a,o/e),rotate:A(i)}}function k(t,e,r,n,i){e=Math.max(0,e-2*g);var a=t.height/t.width,o=S(a,n,e,r);return{scale:2*o/t.width,rCenter:M(a,o/e),rotate:A(i+Math.PI/2)}}function M(t,e){return Math.cos(e)-t*e}function A(t){return(180/Math.PI*t+720)%180-90}function S(t,e,r,n){var i=t+1/(2*Math.tan(e));return r*Math.min(1/(Math.sqrt(i*i+.5)+i),n/(Math.sqrt(t*t+n/2)+t))}function E(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function C(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function L(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=P(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),f=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(f+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?f*=2:-1!==a.title.position.indexOf(\"right\")&&(f+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=f/t.titleBox.width,n=I(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function I(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function P(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function z(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=I(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+P(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=I(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var f=o*r.vTotal;\"funnelarea\"===i.type&&(f/=(1+i.baseratio)/2,f/=i.aspectratio),r.r=Math.sqrt(f)}}}(t,r)}function O(t,e){return[t*Math.sin(e),-t*Math.cos(e)]}function D(t,e,r){var n=t._fullLayout,i=r.trace,a=i.texttemplate,o=i.textinfo;if(!a&&o&&\"none\"!==o){var s,c=o.split(\"+\"),u=function(t){return-1!==c.indexOf(t)},f=u(\"label\"),h=u(\"text\"),p=u(\"value\"),d=u(\"percent\"),g=n.separators;if(s=f?[e.label]:[],h){var v=m.getFirstFilled(i.text,e.pts);y(v)&&s.push(v)}p&&s.push(m.formatPieValue(e.v,g)),d&&s.push(m.formatPiePercent(e.v/r.vTotal,g)),e.text=s.join(\"<br>\")}if(a){var x=l.castOption(i,e.i,\"texttemplate\");if(x){var b=function(t){return{label:t.label,value:t.v,valueLabel:m.formatPieValue(t.v,n.separators),percent:t.v/r.vTotal,percentLabel:m.formatPiePercent(t.v/r.vTotal,n.separators),color:t.color,text:t.text,customdata:l.castOption(i,t.i,\"customdata\")}}(e),_=m.getFirstFilled(i.text,e.pts);(y(_)||\"\"===_)&&(b.text=_),e.text=l.texttemplateString(x,b,t._fullLayout._d3locale,b,i._meta||{})}else e.text=\"\"}}function R(t,e){var r=t.rotate*Math.PI/180,n=Math.cos(r),i=Math.sin(r),a=(e.left+e.right)/2,o=(e.top+e.bottom)/2;t.textX=a*n-o*i,t.textY=a*i+o*n,t.noCenter=!0}e.exports={plot:function(t,e){var r=t._fullLayout,a=r._size;d(\"pie\",r),_(e,t),z(e,a);var h=l.makeTraceGroups(r._pielayer,e,\"trace\").each((function(e){var h=n.select(this),d=e[0],g=d.trace;!function(t){var e,r,n,i=t[0],a=i.r,o=i.trace,s=m.getRotationAngle(o.rotation),l=2*Math.PI/i.vTotal,c=\"px0\",u=\"px1\";if(\"counterclockwise\"===o.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;s+=l*t[e].v,l*=-1,c=\"px1\",u=\"px0\"}for(n=O(a,s),e=0;e<t.length;e++)(r=t[e]).hidden||(r[c]=n,r.startangle=s,s+=l*r.v/2,r.pxmid=O(a,s),r.midangle=s,s+=l*r.v/2,n=O(a,s),r.stopangle=s,r[u]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-o.hole,r.rInscribed=E(r,i))}(e),h.attr(\"stroke-linejoin\",\"round\"),h.each((function(){var v=n.select(this).selectAll(\"g.slice\").data(e);v.enter().append(\"g\").classed(\"slice\",!0),v.exit().remove();var y=[[[],[]],[[],[]]],_=!1;v.each((function(i,a){if(i.hidden)n.select(this).selectAll(\"path,g\").remove();else{i.pointNumber=i.i,i.curveNumber=g.index,y[i.pxmid[1]<0?0:1][i.pxmid[0]<0?0:1].push(i);var o=d.cx,c=d.cy,u=n.select(this),h=u.selectAll(\"path.surface\").data([i]);if(h.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),u.call(x,t,e),g.pull){var v=+m.castOption(g.pull,i.pts)||0;v>0&&(o+=v*i.pxmid[0],c+=v*i.pxmid[1])}i.cxFinal=o,i.cyFinal=c;var T=g.hole;if(i.v===d.vTotal){var k=\"M\"+(o+i.px0[0])+\",\"+(c+i.px0[1])+L(i.px0,i.pxmid,!0,1)+L(i.pxmid,i.px0,!0,1)+\"Z\";T?h.attr(\"d\",\"M\"+(o+T*i.px0[0])+\",\"+(c+T*i.px0[1])+L(i.px0,i.pxmid,!1,T)+L(i.pxmid,i.px0,!1,T)+\"Z\"+k):h.attr(\"d\",k)}else{var M=L(i.px0,i.px1,!0,1);if(T){var A=1-T;h.attr(\"d\",\"M\"+(o+T*i.px1[0])+\",\"+(c+T*i.px1[1])+L(i.px1,i.px0,!1,T)+\"l\"+A*i.px0[0]+\",\"+A*i.px0[1]+M+\"Z\")}else h.attr(\"d\",\"M\"+o+\",\"+c+\"l\"+i.px0[0]+\",\"+i.px0[1]+M+\"Z\")}D(t,i,d);var S=m.castOption(g.textposition,i.pts),E=u.selectAll(\"g.slicetext\").data(i.text&&\"none\"!==S?[0]:[]);E.enter().append(\"g\").classed(\"slicetext\",!0),E.exit().remove(),E.each((function(){var u=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),h=l.ensureUniformFontSize(t,\"outside\"===S?function(t,e,r){var n=m.castOption(t.outsidetextfont.color,e.pts)||m.castOption(t.textfont.color,e.pts)||r.color,i=m.castOption(t.outsidetextfont.family,e.pts)||m.castOption(t.textfont.family,e.pts)||r.family,a=m.castOption(t.outsidetextfont.size,e.pts)||m.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(g,i,r.font):b(g,i,r.font));u.text(i.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,h).call(f.convertToTspans,t);var v,y=s.bBox(u.node());if(\"outside\"===S)v=C(y,i);else if(v=w(y,i,d),\"auto\"===S&&v.scale<1){var x=l.ensureUniformFontSize(t,g.outsidetextfont);u.call(s.font,x),v=C(y=s.bBox(u.node()),i)}var T=v.textPosAngle,k=void 0===T?i.pxmid:O(d.r,T);if(v.targetX=o+k[0]*v.rCenter+(v.x||0),v.targetY=c+k[1]*v.rCenter+(v.y||0),R(v,y),v.outside){var M=v.targetY;i.yLabelMin=M-y.height/2,i.yLabelMid=M,i.yLabelMax=M+y.height/2,i.labelExtraX=0,i.labelExtraY=0,_=!0}v.fontSize=h.size,p(g.type,v,r),e[a].transform=v,u.attr(\"transform\",l.getTextTransform(v))}))}function L(t,e,r,n){var a=n*(e[0]-t[0]),o=n*(e[1]-t[1]);return\"a\"+n*d.r+\",\"+n*d.r+\" 0 \"+i.largeArc+(r?\" 1 \":\" 0 \")+a+\",\"+o}}));var T=n.select(this).selectAll(\"g.titletext\").data(g.title.text?[0]:[]);if(T.enter().append(\"g\").classed(\"titletext\",!0),T.exit().remove(),T.each((function(){var e,r=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),i=g.title.text;g._meta&&(i=l.templateString(i,g._meta)),r.text(i).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,g.title.font).call(f.convertToTspans,t),e=\"middle center\"===g.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(d):L(d,a),r.attr(\"transform\",u(e.x,e.y)+c(Math.min(1,e.scale))+u(e.tx,e.ty))})),_&&function(t,e){var r,n,i,a,o,s,l,c,u,f,h,p,d;function g(t,e){return t.pxmid[1]-e.pxmid[1]}function v(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,c,u,h,p=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),d=n?t.yLabelMin:t.yLabelMax,g=n?t.yLabelMax:t.yLabelMin,v=t.cyFinal+o(t.px0[1],t.px1[1]),y=p-d;if(y*l>0&&(t.labelExtraY=y),Array.isArray(e.pull))for(c=0;c<f.length;c++)(u=f[c])===t||(m.castOption(e.pull,t.pts)||0)>=(m.castOption(e.pull,u.pts)||0)||((t.pxmid[1]-u.pxmid[1])*l>0?(y=u.cyFinal+o(u.px0[1],u.px1[1])-d-t.labelExtraY)*l>0&&(t.labelExtraY+=y):(g+t.labelExtraY-v)*l>0&&(i=3*s*Math.abs(c-f.indexOf(t)),(h=u.cxFinal+a(u.px0[0],u.px1[0])+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=h)))}for(n=0;n<2;n++)for(i=n?g:v,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(c=t[n][r]).sort(i),u=t[1-n][r],f=u.concat(c),p=[],h=0;h<c.length;h++)void 0!==c[h].yLabelMid&&p.push(c[h]);for(d=!1,h=0;n&&h<u.length;h++)if(void 0!==u[h].yLabelMid){d=u[h];break}for(h=0;h<p.length;h++){var x=h&&p[h-1];d&&!h&&(x=d),y(p[h],x)}}}(y,g),function(t,e){t.each((function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");t.transform.targetX+=t.labelExtraX,t.transform.targetY+=t.labelExtraY,i.attr(\"transform\",l.getTextTransform(t.transform));var a=t.cxFinal+t.pxmid[0],s=\"M\"+a+\",\"+(t.cyFinal+t.pxmid[1]),c=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var u=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(u)>Math.abs(f)?s+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(a+t.labelExtraX+c):s+=\"l\"+t.labelExtraX+\",\"+u+\"v\"+(f-u)+\"h\"+c}else s+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+c;l.ensureSingle(r,\"path\",\"textline\").call(o.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:s,fill:\"none\"})}else r.select(\"path.textline\").remove()}))}(v,g),_&&g.automargin){var k=s.bBox(h.node()),M=g.domain,A=a.w*(M.x[1]-M.x[0]),S=a.h*(M.y[1]-M.y[0]),E=(.5*A-d.r)/a.w,I=(.5*S-d.r)/a.h;i.autoMargin(t,\"pie.\"+g.uid+\".automargin\",{xl:M.x[0]-E,xr:M.x[1]+E,yb:M.y[0]-I,yt:M.y[1]+I,l:Math.max(d.cx-d.r-k.left,0),r:Math.max(k.right-(d.cx+d.r),0),b:Math.max(k.bottom-(d.cy+d.r),0),t:Math.max(d.cy-d.r-k.top,0),pad:5})}}))}));setTimeout((function(){h.selectAll(\"tspan\").each((function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))}))}),0)},formatSliceLabel:D,transformInsideText:w,determineInsideTextFont:b,positionTitleOutside:L,prerenderTitles:_,layoutAreas:z,attachFxHandlers:x,computeTransform:R}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../bar/constants\":923,\"../bar/uniform_text\":937,\"./event_data\":1165,\"./helpers\":1166,d3:169}],1171:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\"),a=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._pielayer.selectAll(\".trace\");a(t,e,\"pie\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(i,t,e)}))}))}},{\"../bar/uniform_text\":937,\"./style_one\":1172,d3:169}],1172:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":643,\"./helpers\":1166}],1173:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1187}],1174:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,f=this.pickXYData=t.xy,h=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(f){if(n=f,e=f.length>>>1,h)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),m=i(t.marker.border.color),v=t.opacity*t.marker.opacity;g[3]*=v,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,m[3]*=v,this.pointcloudOptions.borderColor=m;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,T=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:T}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:T})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/autorange\":827,\"../scatter/get_trace_color\":1197,\"gl-pointcloud2d\":324}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":778,\"./attributes\":1173}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":868,\"../scatter3d/calc\":1216,\"./attributes\":1173,\"./convert\":1174,\"./defaults\":1175}],1177:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../plots/template_attributes\").hovertemplateAttrs,c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,f=t(\"../../lib/extend\").extendFlat,h=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=h({hoverinfo:f({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),customdata:void 0,node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:f(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":642,\"../../components/colorscale/attributes\":650,\"../../components/fx/attributes\":674,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),f=t(\"../../registry\");function h(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var h={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:h,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[h],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),f.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)h(t,e)}},{\"../../components/dragelement\":662,\"../../components/fx/layout_attributes\":684,\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/select\":847,\"../../plots/get_data\":865,\"../../registry\":911,\"./plot\":1183}],1179:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),f=o(a.customdata),h={},p={},d=a.colorscales.length;for(e=0;e<d;e++){var g=a.colorscales[e],m=l.extractScale(g,{cLetter:\"c\"}),v=l.makeColorScaleFunc(m);p[g.label]=v}var y=0;for(e=0;e<a.value.length;e++)a.source[e]>y&&(y=a.source[e]),a.target[e]>y&&(y=a.target[e]);var x,b=y+1;t.node._count=b;var _=t.node.groups,w={};for(e=0;e<_.length;e++){var T=_[e];for(x=0;x<T.length;x++){var k=T[x],M=b+e;w.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):w[k]=M}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var S=a.value[e],E=a.source[e],C=a.target[e];if(S>0&&s(E,b)&&s(C,b)&&(!w.hasOwnProperty(E)||!w.hasOwnProperty(C)||w[E]!==w[C])){w.hasOwnProperty(C)&&(C=w[C]),w.hasOwnProperty(E)&&(E=w[E]),C=+C,h[E=+E]=h[C]=!0;var L=\"\";a.label&&a.label[e]&&(L=a.label[e]);var I=null;L&&p.hasOwnProperty(L)&&(I=p[L]),c.push({pointNumber:e,label:L,color:u?a.color[e]:a.color,customdata:f?a.customdata[e]:a.customdata,concentrationscale:I,source:E,target:C,value:+S}),A.source.push(E),A.target.push(C)}}var P=b+_.length,z=o(r.color),O=o(r.customdata),D=[];for(e=0;e<P;e++)if(h[e]){var R=r.label[e];D.push({group:e>b-1,childrenNodes:[],pointNumber:e,label:R,color:z?r.color[e]:r.color,customdata:O?r.customdata[e]:r.customdata})}var F=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some((function(t){return t.length>1}))}(P,A.source,A.target)&&(F=!0),{circular:F,links:c,nodes:D,groups:_,groupLookup:w}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gup\":775,\"strongly-connected-components\":569}],1180:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,h){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(h.hoverlabel,t.hoverlabel),g=t.node,m=c.newContainer(e,\"node\");function v(t,e){return n.coerce(g,m,i.node,t,e)}v(\"label\"),v(\"groups\"),v(\"x\"),v(\"y\"),v(\"pad\"),v(\"thickness\"),v(\"line.color\"),v(\"line.width\"),v(\"hoverinfo\",t.hoverinfo),l(g,m,v,d),v(\"hovertemplate\");var y=h.colorway;v(\"color\",m.label.map((function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}))),v(\"customdata\");var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,T=o(h.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(T,b.value.length)),_(\"customdata\"),u(x,b,{name:\"colorscales\",handleItemDefaults:f}),s(e,h,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),m.x.length&&m.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},h.font)),e._length=null}},{\"../../components/color\":643,\"../../components/fx/hoverlabel_defaults\":681,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../../plots/domain\":855,\"./attributes\":1177,tinycolor2:576}],1182:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1177,\"./base_plot\":1178,\"./calc\":1179,\"./defaults\":1181,\"./plot\":1183,\"./select.js\":1185}],1183:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function f(t,e){return t.filter((function(t){return t.key===e.traceId}))}function h(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function m(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function v(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===i})).style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),r&&f(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(m)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===i})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),r&&f(e,t).selectAll(l.sankeyNode).filter(g(t)).call(v)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,f=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].visible&&t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",T=c(t,\"concentration:\")+\" \",k=c(t,\"incoming flow count:\")+\" \",M=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,f=0;f<i.flow.links.length;f++){var d=i.flow.links[f];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=f),d.fullData=d.trace,s=i.link.trace.link;var g=v(d),m={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:m.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?T+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:m,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each((function(){i.link.concentrationscale||h(this,.65),p(this)}))}}function v(t){var e,r;t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2,r=t.circularPathData.verticalFullExtent):(e=(t.source.x1+t.target.x0)/2,r=(t.y0+t.y1)/2);var n=[e,r];return\"v\"===t.trace.orientation&&n.reverse(),n[0]+=i.parent.translateX,n[1]+=i.parent.translateY,n}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),f=s.node().getBoundingClientRect(),d=f.left-2-c.left,g=f.right+2-c.left,m=f.top+f.height/4-c.top,v={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace,t._fullLayout._calcInverseTransform(t);var y=t._fullLayout._invScaleX,x=t._fullLayout._invScaleY,_=a.loneHover({x0:y*d,x1:y*g,y:x*m,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,k+i.node.targetLinks.length,M+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:v,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});h(_,.85),p(_)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(v,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"./constants\":1180,\"./render\":1184,d3:169}],1184:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),f=t(\"../../lib\"),h=f.strTranslate,p=t(\"../../lib/gup\"),d=p.keyFun,g=p.repeat,m=p.unwrap,v=t(\"d3-interpolate\").interpolateNumber,y=t(\"../../registry\");function x(t,e,r){var i,o=m(e),s=o.trace,u=s.domain,h=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,g=t.width*(u.x[1]-u.x[0]),v=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(h?[g,v]:[v,g]).nodeWidth(d).nodePadding(p).nodeId((function(t){return t.pointNumber})).nodes(y).links(x);var _,w,T,k=i();for(var M in i.nodePadding()<p&&f.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var A,S=parseInt(o._groupLookup[M]);for(_=0;_<k.nodes.length;_++)if(k.nodes[_].pointNumber===S){A=k.nodes[_];break}if(A){var E={pointNumber:parseInt(M),x0:A.x0,x1:A.x1,y0:A.y0,y1:A.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};k.nodes.unshift(E),A.childrenNodes.unshift(E)}}if(function(){for(_=0;_<k.nodes.length;_++){var t,e,r=k.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(T=0;T<o.length;T++)l[(e=o[T]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(T=0;T<o.length;T++)(e=o[T]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,k.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*g,s.node.y[_]*v];k.nodes[_].x0=C[0]-d/2,k.nodes[_].x1=C[0]+d/2;var L=k.nodes[_].y1-k.nodes[_].y0;k.nodes[_].y0=C[1]-L/2,k.nodes[_].y1=C[1]+L/2}if(\"snap\"===s.arrangement)!function(t){t.forEach((function(t){var e,r,n,i=0,a=t.length;for(t.sort((function(t,e){return t.y0-e.y0})),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p}))}(function(t){var e,r,n=t.map((function(t,e){return{x0:t.x0,index:e}})).sort((function(t,e){return t.x0-e.x0})),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=k.nodes));i.update(k)}return{circular:b,key:r,trace:s,guid:f.randstr(),horizontal:h,width:g,height:v,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:h?v:g,dragPerpendicular:h?g:v,arrangement:s.arrangement,sankey:i,graph:k,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}function b(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:_,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}function _(){return function(t){if(t.link.circular)return e=t.link,r=e.width/2,n=e.circularPathData,\"top\"===e.circularLinkType?\"M \"+n.targetX+\" \"+(n.targetY+r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 1 \"+(n.rightFullExtent-r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 1 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 0 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 0 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"L\"+n.targetX+\" \"+(n.targetY-r)+\"Z\":\"M \"+n.targetX+\" \"+(n.targetY-r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 0 \"+(n.rightFullExtent-r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 0 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 1 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 1 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"L\"+n.targetX+\" \"+(n.targetY+r)+\"Z\";var e,r,n,i=t.link.source.x1,a=t.link.target.x0,o=v(i,a),s=o(.5),l=o(.5),c=t.link.y0-t.link.width/2,u=t.link.y0+t.link.width/2,f=t.link.y1-t.link.width/2,h=t.link.y1+t.link.width/2;return\"M\"+i+\",\"+c+\"C\"+s+\",\"+c+\" \"+l+\",\"+f+\" \"+a+\",\"+f+\"L\"+a+\",\"+h+\"C\"+l+\",\"+h+\" \"+s+\",\"+u+\" \"+i+\",\"+u+\"Z\"}}function w(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=f.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}function T(t){t.attr(\"transform\",(function(t){return h(t.node.x0.toFixed(3),t.node.y0.toFixed(3))}))}function k(t){t.call(T)}function M(t,e){t.call(k),e.attr(\"d\",_())}function A(t){t.attr(\"width\",(function(t){return t.node.x1-t.node.x0})).attr(\"height\",(function(t){return t.visibleHeight}))}function S(t){return t.link.width>1||t.linkLineWidth>0}function E(t){return h(t.translateX,t.translateY)+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function C(t){return h(t.horizontal?0:t.labelY,t.horizontal?t.labelY:0)}function L(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function I(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function P(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function z(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function O(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function D(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])})).on(\"mousemove.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])})).on(\"mouseout.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)})).on(\"click.basic\",(function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)}))}function R(t,e,r,a){var o=i.behavior.drag().origin((function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}})).on(\"dragstart\",(function(i){if(\"fixed\"!==i.arrangement&&(f.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",(function(t){a._fullLayout._dragCover=t})),f.raiseToTop(this),i.interactionState.dragInProgress=i.node,B(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter((function(t){return t.originalX===r.node.originalX})).filter((function(t){return!t.partOfGroup}));r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius((function(t){return t.dy/2+r.nodePad/2})).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame((function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(r.graph.nodes),r.sankey.update(r.graph),M(t.filter(N(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var l=r.node.originalX;r.node.x0=l-r.visibleWidth/2,r.node.x1=l+r.visibleWidth/2,F(r,a)}}))}(t,e,i,o,a)}})).on(\"drag\",(function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),B(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),M(t.filter(N(r)),e))}})).on(\"dragend\",(function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&F(t,a)}}));t.on(\".drag\",null).call(o)}function F(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}y.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then((function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()}))}function B(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function N(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,l,c){var u=!1;f.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",(function(){u=!0}));var h=t._fullLayout._dragCover,p=r.filter((function(t){return m(t).trace.visible})).map(x.bind(null,l)),v=e.selectAll(\".\"+n.cn.sankey).data(p,d);v.exit().remove(),v.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",E),v.each((function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;f.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})})),v.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var y=v.selectAll(\".\"+n.cn.sankeyLinks).data(g,d);y.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var k=y.selectAll(\".\"+n.cn.sankeyLink).data((function(t){return t.graph.links.filter((function(t){return t.value})).map(b.bind(null,t))}),d);k.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(D,v,c.linkEvents),k.style(\"stroke\",(function(t){return S(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue})).style(\"stroke-opacity\",(function(t){return S(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})).style(\"stroke-width\",(function(t){return S(t)?t.linkLineWidth:1})).attr(\"d\",_()),k.style(\"opacity\",(function(){return t._context.staticPlot||u||h?1:0})).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),k.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var M=v.selectAll(\".\"+n.cn.sankeyNodeSet).data(g,d);M.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),M.style(\"cursor\",(function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}}));var F=M.selectAll(\".\"+n.cn.sankeyNode).data((function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort((function(t,e){return t-e})),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(w.bind(null,t))}),d);F.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(T).style(\"opacity\",(function(e){return!t._context.staticPlot&&!u||e.partOfGroup?0:1})),F.call(D,v,c.nodeEvents).call(R,k,c,t),F.transition().ease(n.ease).duration(n.duration).call(T).style(\"opacity\",(function(t){return t.partOfGroup?0:1})),F.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var B=F.selectAll(\".\"+n.cn.nodeRect).data(g);B.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(A),B.style(\"stroke-width\",(function(t){return t.nodeLineWidth})).style(\"stroke\",(function(t){return o.tinyRGB(a(t.nodeLineColor))})).style(\"stroke-opacity\",(function(t){return o.opacity(t.nodeLineColor)})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),B.transition().ease(n.ease).duration(n.duration).call(A);var N=F.selectAll(\".\"+n.cn.nodeCapture).data(g);N.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),N.attr(\"x\",(function(t){return t.zoneX})).attr(\"y\",(function(t){return t.zoneY})).attr(\"width\",(function(t){return t.zoneWidth})).attr(\"height\",(function(t){return t.zoneHeight}));var j=F.selectAll(\".\"+n.cn.nodeCentered).data(g);j.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",C),j.transition().ease(n.ease).duration(n.duration).attr(\"transform\",C);var U=j.selectAll(\".\"+n.cn.nodeLabelGuide).data(g);U.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",(function(t){return t.uniqueNodeLabelPathId})).attr(\"d\",L).attr(\"transform\",I),U.transition().ease(n.ease).duration(n.duration).attr(\"d\",L).attr(\"transform\",I);var V=j.selectAll(\".\"+n.cn.nodeLabel).data(g);V.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",P).style(\"cursor\",\"default\").style(\"fill\",\"black\"),V.style(\"text-shadow\",(function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"})).each((function(t){s.font(V,t.textFont)})),V.transition().ease(n.ease).duration(n.duration).attr(\"transform\",P);var q=V.selectAll(\".\"+n.cn.nodeLabelTextPath).data(g);q.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",(function(t){return\"#\"+t.uniqueNodeLabelPathId})).attr(\"startOffset\",O).style(\"fill\",z),q.text((function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"})).attr(\"text-anchor\",(function(t){return t.horizontal&&t.left?\"end\":\"start\"})),q.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",O).style(\"fill\",z)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../registry\":911,\"./constants\":1180,\"@plotly/d3-sankey\":56,\"@plotly/d3-sankey-circular\":55,d3:169,\"d3-force\":160,\"d3-interpolate\":162,tinycolor2:576}],1185:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1186:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.texttemplate,t,\"txt\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":778}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").texttemplateAttrs,i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../components/drawing\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},xperiod:{valType:\"any\",dflt:0,editType:\"calc\"},yperiod:{valType:\"any\",dflt:0,editType:\"calc\"},xperiod0:{valType:\"any\",editType:\"calc\"},yperiod0:{valType:\"any\",editType:\"calc\"},xperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},yperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},texttemplate:n({},{}),hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:i({},{keys:c.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:u({},s,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:u({symbol:{valType:\"enumerated\",values:l.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:u({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},a(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},a(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:o({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":650,\"../../components/drawing\":665,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906,\"./constants\":1191}],1188:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"./subtypes\"),c=t(\"./colorscale_calc\"),u=t(\"./arrays_to_calcdata\"),f=t(\"./calc_selection\");function h(t,e,r,n,i,o,s){var c=e._length,u=t._fullLayout,f=r._id,h=n._id,p=u._firstScatter[g(e)]===e.uid,d=(m(e,u,r,n)||{}).orientation,v=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};s&&(y.ppad=x.ppad=s);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===v||\"tonextx\"===v&&(p||\"h\"===d))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==v&&\"tozeroy\"!==v&&(l.hasMarkers(e)||l.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===v||\"tonexty\"===v&&(p||\"v\"===d))?x.tozero=!0:\"tonextx\"!==v&&\"tozerox\"!==v||(x.padded=!1),f&&(e._extremes[f]=a.findExtremes(r,i,y)),h&&(e._extremes[h]=a.findExtremes(n,o,x))}function p(t,e){if(l.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var s={type:\"linear\"};a.setConvert(s);for(var c=s.makeCalcdata(t.marker,\"size\"),u=new Array(e),f=0;f<e;f++)u[f]=r(c[f]);return u}return r(n.size)}}function d(t,e){var r=g(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function g(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function m(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,l,g,v,y,x,b=t._fullLayout,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),T=_.makeCalcdata(e,\"x\"),k=w.makeCalcdata(e,\"y\"),M=o(e,_,\"x\",T),A=o(e,w,\"y\",k),S=e._length,E=new Array(S),C=e.ids,L=m(e,b,_,w),I=!1;d(b,e);var P,z=\"x\",O=\"y\";L?(i.pushUnique(L.traceIndices,e._expandedIndex),(r=\"v\"===L.orientation)?(O=\"s\",P=\"x\"):(z=\"s\",P=\"y\"),y=\"interpolate\"===L.stackgaps):h(t,e,_,w,M,A,p(e,S));var D=!!e.xperiodalignment,R=!!e.yperiodalignment;for(l=0;l<S;l++){var F=E[l]={},B=n(M[l]),N=n(A[l]);B&&N?(F[z]=M[l],F[O]=A[l],D&&(F.orig_x=T[l]),R&&(F.orig_y=k[l])):L&&(r?B:N)?(F[P]=r?M[l]:A[l],F.gap=!0,y?(F.s=s,I=!0):F.s=0):F[z]=F[O]=s,C&&(F.id=String(C[l]))}if(u(E,e),c(t,e),f(E,e),L){for(l=0;l<E.length;)E[l][P]===s?E.splice(l,1):l++;if(i.sort(E,(function(t,e){return t[P]-e[P]||t.i-e.i})),I){for(l=0;l<E.length-1&&E[l].gap;)l++;for((x=E[l].s)||(x=E[l].s=0),g=0;g<l;g++)E[g].s=x;for(v=E.length-1;v>l&&E[v].gap;)v--;for(x=E[v].s,g=E.length-1;g>v;g--)E[g].s=x;for(;l<v;)if(E[++l].gap){for(g=l+1;E[g].gap;)g++;for(var j=E[l-1][P],U=E[l-1].s,V=(E[g].s-U)/(E[g][P]-j);l<g;)E[l].s=U+(E[l][P]-j)*V,l++}}}return E},calcMarkerSize:p,calcAxisExpansion:h,setFirstScatter:d,getStackOpts:m}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"./arrays_to_calcdata\":1186,\"./calc_selection\":1189,\"./colorscale_calc\":1190,\"./subtypes\":1212,\"fast-isnumeric\":241}],1189:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":778}],1190:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"./subtypes\":1212}],1191:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1192:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T=t.calcdata;for(var k in s){var M=(v=s[k]).traceIndices;if(M.length){for(y=\"interpolate\"===v.stackgaps,x=v.groupnorm,\"v\"===v.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(M.length),l=0;l<w.length;l++)w[l]=!1;p=T[M[0]];var A=new Array(p.length);for(l=0;l<p.length;l++)A[l]=p[l][b];for(l=1;l<M.length;l++){for(h=T[M[l]],c=u=0;c<h.length;c++){for(d=h[c][b];d>A[u]&&u<A.length;u++)i(h,c,A[u],l,w,y,b),c++;if(d!==A[u]){for(f=0;f<l;f++)i(T[M[f]],u,d,f,w,y,b);A.splice(u,0,d)}u++}for(;u<A.length;u++)i(h,c,A[u],l,w,y,b),c++}var S=A.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<M.length;l++)(h=T[M[l]])[0].trace._rawLength=h[0].trace._length,h[0].trace._length=S,g+=h[c].s,h[c][_]=g;if(x)for(m=(\"fraction\"===x?g:g/100)||1,l=0;l<M.length;l++){var E=T[M[l]][c];E[_]/=m,E.sNorm=E.s/m}}for(l=0;l<M.length;l++){var C=(h=T[M[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),I=Array.isArray(L);if(L&&w[l]||I){var P=L;for(L=new Array(S),c=0;c<S;c++)L[c]=h[c].gap?0:I?P[h[c].i]:P}var z=new Array(S),O=new Array(S);for(c=0;c<S;c++)z[c]=h[c].x,O[c]=h[c].y;n.calcAxisExpansion(t,C,r,a,z,O,L),h[0].t.orientation=v.orientation}}}}}},{\"./calc\":1188}],1193:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1194:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./period_defaults\"),u=t(\"./stack_defaults\"),f=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),p=t(\"./line_shape_defaults\"),d=t(\"./text_defaults\"),g=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,m){function v(r,i){return n.coerce(t,e,a,r,i)}var y=l(t,e,m,v);if(y||(e.visible=!1),e.visible){c(t,e,m,v);var x=u(t,e,m,v),b=!x&&y<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",b),s.hasLines(e)&&(h(t,e,r,m,v),p(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&f(t,e,r,m,v,{gradient:!0}),s.hasText(e)&&(v(\"texttemplate\"),d(t,e,m,v));var _=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),_.push(\"points\")),v(\"fill\",x?x.fillDflt:\"none\"),\"none\"!==e.fill&&(g(t,e,r,v),s.hasLines(e)||p(t,e,v));var w=(e.line||{}).color,T=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||_.push(\"fills\"),v(\"hoveron\",_.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,w||T||r,{axis:\"y\"}),k(t,e,w||T||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":778,\"../../registry\":911,\"./attributes\":1187,\"./constants\":1191,\"./fillcolor_defaults\":1195,\"./line_defaults\":1200,\"./line_shape_defaults\":1202,\"./marker_defaults\":1206,\"./period_defaults\":1207,\"./stack_defaults\":1210,\"./subtypes\":1212,\"./text_defaults\":1213,\"./xy_defaults\":1214}],1195:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":643,\"../../lib\":778}],1196:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a={_fullLayout:r},o=n.getFromTrace(a,e,\"x\"),s=n.getFromTrace(a,e,\"y\");return i.xLabel=n.tickText(o,t.x,!0).text,i.yLabel=n.tickText(s,t.y,!0).text,i}},{\"../../plots/cartesian/axes\":828}],1197:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":643,\"./subtypes\":1212}],1198:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,f=u[0].trace,h=t.xa,p=t.ya,d=h.c2p(e),g=p.c2p(r),m=[d,g],v=f.hoveron||\"\",y=-1!==f.mode.indexOf(\"markers\")?3:.5;if(-1!==v.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=h.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(h.c2p(t.x)-d);return n<e?r*n/e:n-e+r}),(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r}),x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=h.c2p(_.x,!0),T=p.c2p(_.y,!0),k=_.mrc||1;t.index=_.i;var M=u[0].t.orientation,A=M&&(_.sNorm||_.s),S=\"h\"===M?A:void 0!==_.orig_x?_.orig_x:_.x,E=\"v\"===M?A:void 0!==_.orig_y?_.orig_y:_.y;return n.extendFlat(t,{color:o(f,_),x0:w-k,x1:w+k,xLabelVal:S,y0:T-k,y1:T+k,yLabelVal:E,spikeDistance:x(_),hovertemplate:f.hovertemplate}),l(_,f,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,f,t),[t]}}if(-1!==v.indexOf(\"fills\")&&f._polygons){var C,L,I,P,z,O,D,R,F,B=f._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(I=B[C]).contains(m)&&(j=!j,N.push(I),q=Math.min(q,I.ymin),H=Math.max(H,I.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(P=N[C].pts,L=1;L<P.length;L++)(R=P[L-1][1])>G!=(F=P[L][1])>=G&&(O=P[L-1][0],D=P[L][0],F-R&&(z=O+(D-O)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,h._length);var Y=s.defaultLine;return s.opacity(f.fillcolor)?Y=f.fillcolor:s.opacity((f.line||{}).color)&&(Y=f.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,f.text&&!Array.isArray(f.text)?t.text=String(f.text):t.text=f.name,[t]}}}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"../../registry\":911,\"./get_trace_color\":1197}],1199:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),formatLabels:t(\"./format_labels\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"./arrays_to_calcdata\":1186,\"./attributes\":1187,\"./calc\":1188,\"./cross_trace_calc\":1192,\"./cross_trace_defaults\":1193,\"./defaults\":1194,\"./format_labels\":1196,\"./hover\":1198,\"./marker_colorbar\":1205,\"./plot\":1208,\"./select\":1209,\"./style\":1211,\"./subtypes\":1212}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,f=t(\"./constants\");e.exports=function(t,e){var r,n,a,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,I=S._length,P=E._length,z=e.connectGaps,O=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=f.minTolerance,j=t.length,U=new Array(j),V=0;function q(r){var n=t[r];if(!n)return!1;var a=e.linearized?S.l2p(n.x):S.c2p(n.x),l=e.linearized?E.l2p(n.y):E.c2p(n.y);if(a===i){if(C&&(a=S.c2p(n.x,!0)),a===i)return!1;L&&l===i&&(a*=Math.abs(S._m*P*(S._m>0?o:s)/(E._m*I*(E._m>0?o:s)))),a*=1e3}if(l===i){if(L&&(l=E.c2p(n.y,!0)),l===i)return!1;l*=1e3}return[a,l]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/I,n=t[1]/P,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==M&&H(r,n,M,A)&&(i=0),i&&e&&H(r,n,e[0]/I,e[1]/P)&&(i=0),(1+f.toleranceGrowth*i)*O}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,Q,$,tt=f.maxScreensAway,et=-I*tt,rt=I*(1+tt),nt=-P*tt,it=P*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ft(t){if(M=t[0]/I,A=t[1]/P,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=$(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else Q=$(U[V-1],t)[0],U[V++]=Q;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut($(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?$=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?$=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)||(n&&r.push(n),i&&r.push(i)),r}:\"hvh\"===D?$=lt(0,et,rt):\"vhv\"===D&&($=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ft(n),r++;r<j;r++){if(!(h=q(r))){if(z)continue;break}if(R&&e.simplify){var ht=q(r+1);if(y=Y(h,n),F&&(0===V||V===j-1)||!(y<G(h,ht)*N)){for(m=[(h[0]-n[0])/y,(h[1]-n[1])/y],p=n,x=y,b=w=T=0,g=!1,a=h,r++;r<t.length;r++){if(d=ht,ht=q(r+1),!d){if(z)continue;break}if(k=(v=[d[0]-n[0],d[1]-n[1]])[0]*m[1]-v[1]*m[0],w=Math.min(w,k),(T=Math.max(T,k))-w>G(d,ht))break;a=d,(_=v[0]*m[0]+v[1]*m[1])>x?(x=_,h=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ft(h),a!==p&&ft(p)):(p!==n&&ft(p),a!==h&&ft(h)),ft(a),r>=t.length||!d)break;ft(d),n=d}}else ft(h)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./constants\":1191}],1202:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1203:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,f=-1,h=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=h,h++):i.fill in n&&p>=0?l=p:(l=p=h,h++),l<f&&(u=!0),i._groupIndex=f=l;var d=r.slice();u&&d.sort((function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index}));var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":241}],1205:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1206:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),f=(t.line||{}).color;(c=c||{},f&&(r=f),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",f&&!Array.isArray(f)&&e.marker.color!==f?f:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":643,\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"./subtypes\":1212}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").dateTick0,i=t(\"../../constants/numerical\").ONEWEEK;function a(t,e){return n(e,t%i==0?1:0)}e.exports=function(t,e,r,n,i){if(i||(i={x:!0,y:!0}),i.x){var o=n(\"xperiod\");o&&(n(\"xperiod0\",a(o,e.xcalendar)),n(\"xperiodalignment\"))}if(i.y){var s=n(\"yperiod\");s&&(n(\"yperiod0\",a(s,e.ycalendar)),n(\"yperiodalignment\"))}}},{\"../../constants/numerical\":753,\"../../lib\":778}],1208:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),f=t(\"./link_traces\"),h=t(\"../../lib/polygon\").tester;function p(t,e,r,f,p,d,g){var m;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),f=n.extent(a.simpleMap(l.range,l.r2c)),h=i[0].trace;if(!c.hasMarkers(h))return;var p=h.marker.maxdisplayed;if(0===p)return;var d=i.filter((function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=f[0]&&t.y<=f[1]})),g=Math.ceil(d.length/p),m=0;o.forEach((function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&m++}));var v=Math.round(m*g/3+Math.floor(m/3)*g/7.1);i.forEach((function(t){delete t.vis})),d.forEach((function(t,e){0===Math.round((e+v)%g)&&(t.vis=!0)}))}(0,e,r,f,p);var v=!!g&&g.duration>0;function y(t){return v?t.transition():t}var x=r.xaxis,b=r.yaxis,_=f[0].trace,w=_.line,T=n.select(d),k=o(T,\"g\",\"errorbars\"),M=o(T,\"g\",\"lines\"),A=o(T,\"g\",\"points\"),S=o(T,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,k,r,g),!0===_.visible){var E,C;y(T).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),f[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=T;var I,P,z=\"\",O=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,O=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(f),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(f,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),m=0;m<G.length;m++)_._polygons[m]=h(G[m]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(I=R(e),P=B(e),q?L?(q+=\"L\"+I.substr(1),H=P+\"L\"+H.substr(1)):(q+=\"Z\"+I,H=P+\"Z\"+H):(q=I,H=P),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(f),t)y(r.style(\"opacity\",0).attr(\"d\",I).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",I),l.singleLineStyle(f,i)}}}}}var W=M.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(f),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(O)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),A.datum(f),S.datum(f),function(e,i,a){var o,u=a[0].trace,f=c.hasMarkers(u),h=c.hasText(u),p=tt(u),d=et,g=et;if(f||h){var m=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?m=w?K:J:_&&!w&&(m=Q),f&&(d=m),h&&(g=m)}var T,k=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);v&&k.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),f&&(T=l.makePointStyleFns(u)),o.each((function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,T,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()})),v?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each((function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()})),o.selectAll(\"text\").call(l.textPointStyle,u,t).each((function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each((function(){y(n.select(this)).attr({x:e,y:r})}))})),o.exit().remove()}(A,S,f);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(A,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter((function(t){return!t.gap&&t.vis}))}function K(t){return t.filter((function(t){return t.vis}))}function Q(t){return t.filter((function(t){return!t.gap}))}function $(t){return t.id}function tt(t){if(t.ids)return $}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,h,d=!a,g=!!a&&a.duration>0,m=f(t,e,r);((u=i.selectAll(\"g.trace\").data(m,(function(t){return t[0].trace.uid}))).enter().append(\"g\").attr(\"class\",(function(t){return\"trace scatter trace\"+t[0].trace.uid})).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each((function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each((function(t){a[t]=null})).remove(),u.order().each((function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")}))}))}(t,u,e),g)?(c&&(h=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",(function(){h&&h()})).each(\"interrupt\",(function(){h&&h()})).each((function(){i.selectAll(\"g.trace\").each((function(r,n){p(t,n,e,r,m,this,a)}))}))):u.each((function(r,n){p(t,n,e,r,m,this,a)}));d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/polygon\":790,\"../../registry\":911,\"./line_points\":1201,\"./link_traces\":1203,\"./subtypes\":1212,d3:169}],1209:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],f=s[0].trace;if(!n.hasMarkers(f)&&!n.hasText(f))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1212}],1210:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var f={orientation:e.x&&!e.y?\"h\":\"v\"},h=0;h<n.length;h++){var p=n[h],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],m=\"orientation\"===p;if((g||u)&&(c[p]=i(p,f[p]),m&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],m))))for(var v=0;v<c.traces.length-1;v++){var y=c.traces[v];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1211:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.selectAll(\"g.points\").each((function(e){o(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.text\").each((function(e){s(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":665,\"../../registry\":911,d3:169}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":778}],1213:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":778}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":778,\"../../registry\":911}],1215:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../plots/attributes\"),l=t(\"../../constants/gl3d_dashes\"),c=t(\"../../constants/gl3d_markers\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,p=n.marker,d=p.line,g=u({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},i(\"line\"));var m=e.exports=f({x:n.x,y:n.y,z:{valType:\"data_array\"},text:u({},n.text,{}),texttemplate:o({},{}),hovertext:u({},n.hovertext,{}),hovertemplate:a(),mode:u({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:g,marker:u({symbol:{valType:\"enumerated\",values:Object.keys(c),dflt:\"circle\",arrayOk:!0},size:u({},p.size,{dflt:8}),sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode,opacity:u({},p.opacity,{arrayOk:!1}),colorbar:p.colorbar,line:u({width:u({},d.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:u({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:u({},n.textfont.family,{arrayOk:!1})},hoverinfo:u({},s.hoverinfo)},\"calc\",\"nested\");m.x.editType=m.y.editType=m.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":650,\"../../constants/gl3d_dashes\":750,\"../../constants/gl3d_markers\":751,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1216:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1186,\"../scatter/colorscale_calc\":1190}],1217:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],f=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(f,!0)-c)*r],u>0){var h=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=h),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,h)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":911}],1218:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/make_bubble_size_func\"),h=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"../../plots/cartesian/axes\"),g=t(\"../../components/fx/helpers\").appendArrayPointValue,m=t(\"./calc_errors\");function v(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var y=v.prototype;function x(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function b(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function _(t,e){return e(4*t)}function w(t){return p[t]}function T(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function k(t,e){var r,n,i,a,o,s,h=[],p=t.fullSceneLayout,v=t.dataScale,y=p.xaxis,k=p.yaxis,M=p.zaxis,A=e.marker,S=e.line,E=e.x||[],C=e.y||[],L=e.z||[],I=E.length,P=e.xcalendar,z=e.ycalendar,O=e.zcalendar;for(o=0;o<I;o++)r=y.d2l(E[o],0,P)*v[0],n=k.d2l(C[o],0,z)*v[1],i=M.d2l(L[o],0,O)*v[2],h[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(I),o=0;o<I;o++)s[o]=e.text;function D(t,e){var r=p[t];return d.tickText(r,r.d2l(e),!0).text}var R=e.texttemplate;if(R){var F=t.fullLayout._d3locale,B=Array.isArray(R),N=B?Math.min(R.length,I):I,j=B?function(t){return R[t]}:function(){return R};for(s=new Array(N),o=0;o<N;o++){var U={x:E[o],y:C[o],z:L[o]},V={xLabel:D(\"xaxis\",E[o]),yLabel:D(\"yaxis\",C[o]),zLabel:D(\"zaxis\",L[o])},q={};g(q,e,o);var H=e._meta||{};s[o]=l.texttemplateString(j(o),V,F,q,U,H)}}if(a={position:h,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(S,1,I),a.lineWidth=S.width,a.lineDashes=S.dash),\"marker\"in e){var G=f(e);a.scatterColor=u(A,1,I),a.scatterSize=T(A.size,I,_,20,G),a.scatterMarker=T(A.symbol,I,w,\"\\u25cf\"),a.scatterLineWidth=A.line.width,a.scatterLineColor=u(A.line,1,I),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=x(t[r]),e[r][1]=b(t[r]));else e[0]=x(t),e[1]=b(t);return e}(e.textposition),a.textColor=u(e.textfont,1,I),a.textSize=T(e.textfont.size,I,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var Y=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var W=e.projection[Y[o]];(a.project[o]=W.show)&&(a.projectOpacity[o]=W.opacity,a.projectScale[o]=W.scale)}a.errorBounds=m(e,v,p);var X=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=X.color,a.errorLineWidth=X.lineWidth,a.errorCapSize=X.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function M(t){if(l.isArrayOrTypedArray(t)){var e=t[0];return l.isArrayOrTypedArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map((function(t){return Math.round(255*t)}))+\")\"}return null}function A(t){return l.isArrayOrTypedArray(t)?4===t.length&&\"number\"==typeof t[0]?M(t):t.map(M):null}y.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},y.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,f=h.solid;this.data=t;var p=k(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in h&&(f=h[p.lineDashes]),this.color=A(p.scatterColor)||A(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:f[0],dashScale:f[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var f=u[n],h=0;h<f.length;++h)f[h]=l[f[h]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},y.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new v(t,e.uid);return r.update(e),r}},{\"../../components/fx/helpers\":679,\"../../constants/gl3d_dashes\":750,\"../../constants/gl3d_markers\":751,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"../scatter/make_bubble_size_func\":1204,\"./calc_errors\":1217,\"delaunay-triangulate\":171,\"gl-error3d\":266,\"gl-line3d\":275,\"gl-mesh3d\":309,\"gl-scatter3d\":330}],1219:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,f,u)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),a.hasLines(e)&&(f(\"connectgaps\"),s(t,e,r,u,f)),a.hasMarkers(e)&&o(t,e,r,u,f,{noSelect:!0}),a.hasText(e)&&(f(\"texttemplate\"),l(t,e,u,f,{noSelect:!0}));var h=(e.line||{}).color,p=(e.marker||{}).color;f(\"surfaceaxis\")>=0&&f(\"surfacecolor\",h||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var m=\"projection.\"+d[g];f(m+\".show\")&&(f(m+\".opacity\"),f(m+\".scale\"))}var v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,h||p||r,{axis:\"z\"}),v(t,e,h||p||r,{axis:\"y\",inherit:\"z\"}),v(t,e,h||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1215}],1220:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../constants/gl3d_markers\":751,\"../../plots/gl3d\":870,\"./attributes\":1215,\"./calc\":1216,\"./convert\":1218,\"./defaults\":1219}],1221:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=n.marker,u=n.line,f=c.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:l({},n.mode,{dflt:\"markers\"}),text:l({},n.text,{}),texttemplate:o({editType:\"plot\"},{keys:[\"a\",\"b\",\"text\"]}),hovertext:l({},n.hovertext,{}),line:{color:u.color,width:u.width,dash:u.dash,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:l({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:f.width,editType:\"calc\"},s(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},s(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:l({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1222:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,f,h=e._length,p=new Array(h),d=!1;for(c=0;c<h;c++)if(u=e.a[c],f=e.b[c],n(u)&&n(f)){var g=r.ab2xy(+u,+f,!0),m=r.isVisible(+u,+f);m||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:f,vis:m}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,h),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":981,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1223:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),m=Math.min(d.length,g.length);if(m){e._length=m,p(\"text\"),p(\"texttemplate\"),p(\"hovertext\"),p(\"mode\",m<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&c(t,e,h,p);var v=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),v.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),\"fills\"!==p(\"hoveron\",v.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1221}],1224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1225:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r={},n=e._carpet,i=n.ab2ij([t.a,t.b]),a=Math.floor(i[0]),o=i[0]-a,s=Math.floor(i[1]),l=i[1]-s,c=n.evalxy([],a,s,o,l);return r.yLabel=c[1].toFixed(3),r}},{}],1226:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,f=c-u;return s.x0=Math.max(Math.min(s.x0,f),u),s.x1=Math.max(Math.min(s.x1,f),u),o}var h=s.cd[s.index];s.a=h.a,s.b=h.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=p._module.formatLabels(h,p);s.yLabel=g.yLabel,delete s.text;var m=[];if(!p.hovertemplate){var v=(h.hi||p.hoverinfo).split(\"+\");-1!==v.indexOf(\"all\")&&(v=[\"a\",\"b\",\"text\"]),-1!==v.indexOf(\"a\")&&y(d.aaxis,h.a),-1!==v.indexOf(\"b\")&&y(d.baxis,h.b),m.push(\"y: \"+s.yLabel),-1!==v.indexOf(\"text\")&&i(h,p,m),s.extraText=m.join(\"<br>\")}return o}function y(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,m.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":778,\"../scatter/hover\":1198}],1227:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1221,\"./calc\":1222,\"./defaults\":1223,\"./event_data\":1224,\"./format_labels\":1225,\"./hover\":1226,\"./plot\":1228}],1228:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,f={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,f,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":665,\"../../plots/cartesian/axes\":828,\"../scatter/plot\":1208}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,f=a.marker,h=a.line,p=f.line;e.exports=u({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\",\"geojson-id\"],dflt:\"ISO-3\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:{valType:\"string\",editType:\"calc\",dflt:\"id\"},mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"location\",\"text\"]}),hovertext:c({},a.hovertext,{}),textfont:a.textfont,textposition:a.textposition,line:{color:h.color,width:h.width,dash:l},connectgaps:a.connectgaps,marker:c({symbol:f.symbol,opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,colorbar:f.colorbar,line:c({width:p.width},s(\"marker.line\")),gradient:f.gradient},s(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:a.fillcolor,selected:a.selected,unselected:a.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1230:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;function c(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,u=Array.isArray(e.locations),f=u?e.locations.length:e._length,h=new Array(f);r=e.geojson?function(t){return c(t)||n(t)}:c;for(var p=0;p<f;p++){var d=h[p]={};if(u){var g=e.locations[p];d.loc=r(g)?g:null}else{var m=e.lon[p],v=e.lat[p];n(m)&&n(v)?d.lonlat=[+m,+v]:d.lonlat=[i,i]}}return o(h,e),a(t,e),s(h,e),f&&(h[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),h}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}var h,p=f(\"locations\");if(p&&p.length){var d,g=f(\"geojson\");(\"string\"==typeof g&&\"\"!==g||n.isPlainObject(g))&&(d=\"geojson-id\"),\"geojson-id\"===f(\"locationmode\",d)&&f(\"featureidkey\"),h=p.length}else{var m=f(\"lon\")||[],v=f(\"lat\")||[];h=Math.min(m.length,v.length)}h?(e._length=h,f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,f),f(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,f,{gradient:!0}),i.hasText(e)&&(f(\"texttemplate\"),s(t,e,u,f)),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)):e.visible=!1}},{\"../../lib\":778,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1229}],1232:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.geo]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},{\"../../plots/cartesian/axes\":828}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/get_trace_color\"),o=t(\"../../lib\").fillText,s=t(\"./attributes\");e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=h.projection.isLonLatOverEdges,d=h.project;if(n.getClosest(l,(function(t){var n=t.lonlat;if(n[0]===i)return 1/0;if(p(n))return 1/0;var a=d(n),o=d([e,r]),s=Math.abs(a[0]-o[0]),l=Math.abs(a[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)}),t),!1!==t.index){var g=l[t.index],m=g.lonlat,v=[u.c2p(m),f.c2p(m)],y=g.mrc||1;t.x0=v[0]-y,t.x1=v[0]+y,t.y0=v[1]-y,t.y1=v[1]+y,t.loc=g.loc,t.lon=m[0],t.lat=m[1];var x={};x[c.geo]={_subplot:h};var b=c._module.formatLabels(g,c,x);return t.lonLabel=b.lonLabel,t.latLabel=b.latLabel,t.color=a(c,g),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?s.hoverinfo.flags:i.split(\"+\"),l=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),f=-1!==a.indexOf(\"text\"),h=[];function p(t){return t+\"\\xb0\"}l?h.push(e.loc):c&&u?h.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?h.push(n.lon+p(r.lonLabel)):u&&h.push(n.lat+p(r.latLabel));f&&o(e,t,h);return h.join(\"<br>\")}(c,g,t,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/get_trace_color\":1197,\"./attributes\":1229}],1235:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":860,\"../scatter/marker_colorbar\":1205,\"../scatter/style\":1211,\"./attributes\":1229,\"./calc\":1230,\"./defaults\":1231,\"./event_data\":1232,\"./format_labels\":1233,\"./hover\":1234,\"./plot\":1236,\"./select\":1237,\"./style\":1238}],1236:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/topojson_utils\").getTopojsonFeatures,o=t(\"../../lib/geojson_utils\"),s=t(\"../../lib/geo_location_utils\"),l=t(\"../../plots/cartesian/autorange\").findExtremes,c=t(\"../../constants/numerical\").BADNUM,u=t(\"../scatter/calc\").calcMarkerSize,f=t(\"../scatter/subtypes\"),h=t(\"./style\");e.exports={calcGeoJSON:function(t,e){var r,n,i=t[0].trace,o=e[i.geo],f=o._subplot,h=i._length;if(Array.isArray(i.locations)){var p=i.locationmode,d=\"geojson-id\"===p?s.extractTraceFeature(t):a(i,f.topojson);for(r=0;r<h;r++){n=t[r];var g=\"geojson-id\"===p?n.fOut:s.locationToFeature(p,n.loc,d);n.lonlat=g?g.properties.ct:[c,c]}}var m,v,y={padded:!0};if(\"geojson\"===o.fitbounds&&\"geojson-id\"===i.locationmode){var x=s.computeBbox(s.getTraceGeojson(i));m=[x[0],x[2]],v=[x[1],x[3]]}else{for(m=new Array(h),v=new Array(h),r=0;r<h;r++)n=t[r],m[r]=n.lonlat[0],v[r]=n.lonlat[1];y.ppad=u(i,h)}i._extremes.lon=l(o.lonaxis._ax,m,y),i._extremes.lat=l(o.lataxis._ax,v,y)},plot:function(t,e,r){var a=e.layers.frontplot.select(\".scatterlayer\"),s=i.makeTraceGroups(a,r,\"trace scattergeo\");function l(t,e){t.lonlat[0]===c&&n.select(e).remove()}s.selectAll(\"*\").remove(),s.each((function(e){var r=n.select(this),a=e[0].trace;if(f.hasLines(a)||\"none\"!==a.fill){var s=o.calcTraceToLineCoords(e),c=\"none\"!==a.fill?o.makePolygon(s):o.makeLine(s);r.selectAll(\"path.js-line\").data([{geojson:c,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}f.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each((function(t){l(t,this)})),f.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each((function(t){l(t,this)})),h(t,e)}))}}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/geojson_utils\":772,\"../../lib/topojson_utils\":806,\"../../plots/cartesian/autorange\":827,\"../scatter/calc\":1188,\"../scatter/subtypes\":1212,\"./style\":1238,d3:169}],1237:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,f=t.yaxis,h=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=f.c2p(a),e.contains([o,s],null,l,t)?(h.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return h}},{\"../../constants/numerical\":753,\"../scatter/subtypes\":1212}],1238:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each((function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)}))}(t,e)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../scatter/style\":1211,d3:169}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,f=u.line,h=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,xperiod:i.xperiod,yperiod:i.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:i.xperiodalignment,yperiodalignment:i.yperiodalignment,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:f.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");h.x.editType=h.y.editType=h.x0.editType=h.y0.editType=\"calc+clearAxisTypes\",h.hovertemplate=i.hovertemplate,h.texttemplate=i.texttemplate},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../scatter/attributes\":1187,\"./constants\":1241}],1240:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../../plots/cartesian/align_period\"),l=t(\"../scatter/calc\"),c=l.calcMarkerSize,u=l.calcAxisExpansion,f=l.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),p=t(\"./convert\"),d=t(\"./scene_update\"),g=t(\"../../constants/numerical\").BADNUM,m=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,l,y=t._fullLayout,x=a.getFromId(t,e.xaxis),b=a.getFromId(t,e.yaxis),_=y._plots[e.xaxis+e.yaxis],w=e._length,T=w>=m,k=2*w,M={},A=x.makeCalcdata(e,\"x\"),S=b.makeCalcdata(e,\"y\"),E=s(e,x,\"x\",A),C=s(e,b,\"y\",S);e._x=E,e._y=C,e.xperiodalignment&&(e._origX=A),e.yperiodalignment&&(e._origY=S);var L=new Array(k);for(r=0;r<w;r++)o=E[r],l=C[r],L[2*r]=o===g?NaN:o,L[2*r+1]=l===g?NaN:l;if(\"log\"===x.type)for(r=0;r<k;r+=2)L[r]=x.c2l(L[r]);if(\"log\"===b.type)for(r=1;r<k;r+=2)L[r]=b.c2l(L[r]);if(T&&\"log\"!==x.type&&\"log\"!==b.type)M.tree=n(L);else{var I=M.ids=new Array(w);for(r=0;r<w;r++)I[r]=r}h(t,e);var P,z=function(t,e,r,n,a,o){var s=p.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,p.linePositions(t,r,n));if(s.errorX||s.errorY){var l=p.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},p.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},p.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},p.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,L,E,C),O=d(t,_);return f(y,e),T?z.marker&&(P=2*(z.marker.sizeAvg||Math.max(z.marker.size,3))):P=c(e,w),u(t,e,x,b,E,C,P),z.errorX&&v(e,x,z.errorX),z.errorY&&v(e,b,z.errorY),z.fill&&!O.fill2d&&(O.fill2d=!0),z.marker&&!O.scatter2d&&(O.scatter2d=!0),z.line&&!O.line2d&&(O.line2d=!0),!z.errorX&&!z.errorY||O.error2d||(O.error2d=!0),z.text&&!O.glText&&(O.glText=!0),z.marker&&(z.marker.snap=w),O.lineOptions.push(z.line),O.errorXOptions.push(z.errorX),O.errorYOptions.push(z.errorY),O.fillOptions.push(z.fill),O.markerOptions.push(z.marker),O.markerSelectedOptions.push(z.markerSel),O.markerUnselectedOptions.push(z.markerUnsel),O.textOptions.push(z.text),O.textSelectedOptions.push(z.textSel),O.textUnselectedOptions.push(z.textUnsel),O.selectBatch.push([]),O.unselectBatch.push([]),M._scene=O,M.index=O.count,M.x=E,M.y=C,M.positions=L,O.count++,[{x:!1,y:!1,t:M,trace:e}]}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/autorange\":827,\"../../plots/cartesian/axis_ids\":831,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"./constants\":1241,\"./convert\":1242,\"./scene_update\":1250,\"@plotly/point-cluster\":57}],1241:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1242:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/subtypes\"),h=t(\"../scatter/make_bubble_size_func\"),p=t(\"./helpers\"),d=t(\"./constants\"),g=t(\"../../constants/interactions\").DESELECTDIM,m={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1},v=t(\"../../components/fx/helpers\").appendArrayPointValue;function y(t,e){var r,i=t._fullLayout,a=e._length,o=e.textfont,l=e.textposition,c=Array.isArray(l)?l:[l],u=o.color,f=o.size,h=o.family,p={},d=e.texttemplate;if(d){p.text=[];var g=i._d3locale,m=Array.isArray(d),y=m?Math.min(d.length,a):a,x=m?function(t){return d[t]}:function(){return d};for(r=0;r<y;r++){var b={i:r},_=e._module.formatLabels(b,e,i),w={};v(w,e,r);var T=e._meta||{};p.text.push(s.texttemplateString(x(r),_,g,w,b,T))}}else Array.isArray(e.text)&&e.text.length<a?p.text=e.text.slice():p.text=e.text;if(Array.isArray(p.text))for(r=p.text.length;r<a;r++)p.text[r]=\"\";for(p.opacity=e.opacity,p.font={},p.align=[],p.baseline=[],r=0;r<c.length;r++){var k=c[r].split(/\\s+/);switch(k[1]){case\"left\":p.align.push(\"right\");break;case\"right\":p.align.push(\"left\");break;default:p.align.push(k[1])}switch(k[0]){case\"top\":p.baseline.push(\"bottom\");break;case\"bottom\":p.baseline.push(\"top\");break;default:p.baseline.push(k[0])}}if(Array.isArray(u))for(p.color=new Array(a),r=0;r<a;r++)p.color[r]=u[r];else p.color=u;if(s.isArrayOrTypedArray(f)||Array.isArray(h))for(p.font=new Array(a),r=0;r<a;r++){var M=p.font[r]={};M.size=s.isTypedArray(f)?f[r]:Array.isArray(f)?n(f[r])?f[r]:0:f,M.family=Array.isArray(h)?h[r]:h}else p.font={size:f,family:h};return p}function x(t){var e,r,n=t._length,i=t.marker,o={},l=s.isArrayOrTypedArray(i.symbol),c=s.isArrayOrTypedArray(i.color),f=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),m=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.isOpenSymbol(i.symbol)),l||c||f||d){o.colors=new Array(n),o.borderColors=new Array(n);var v=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(v[0])){var b=v;for(v=Array(n),e=0;e<n;e++)v[e]=b}for(o.colors=v,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.isOpenSymbol(_)}r&&(y[e]=v[e].slice(),v[e]=v[e].slice(),v[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=E(i.symbol[e]);else o.marker=E(i.symbol);var w,T=h(t);if(g||m){var k,M=o.sizes=new Array(n),A=o.borderSizes=new Array(n),S=0;if(g){for(e=0;e<n;e++)M[e]=T(i.size[e]),S+=M[e];k=S/n}else for(w=T(i.size),e=0;e<n;e++)M[e]=w;if(m)for(e=0;e<n;e++)A[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)A[e]=w;o.sizeAvg=k}else o.size=T(i&&i.size||10),o.borderSizes=T(i.line.width);return o}function b(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=x(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function _(t,e,r){var n={};if(!r)return n;if(r.textfont){var i={opacity:1,text:e.text,texttemplate:e.texttemplate,textposition:e.textposition,textfont:s.extendFlat({},e.textfont)};r.textfont&&s.extendFlat(i.textfont,r.textfont),n=y(t,i)}return n}function w(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var T=d.SYMBOL_SDF_SIZE,k=d.SYMBOL_SIZE,M=d.SYMBOL_STROKE,A={},S=l.symbolFuncs[0](.05*k);function E(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.isDotSymbol(t);return A[t]?A[t]:(e=c&&!o?a(1.1*k)+S:a(k),r=i(e,{w:T,h:T,viewBox:[-k,-k,k,k],stroke:s?M:-M}),A[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(f.hasText(e)&&(n.text=y(t,e),n.textSel=_(t,e,e.selected),n.textUnsel=_(t,e,e.unselected)),f.hasMarkers(e)&&(n.marker=x(e),n.markerSel=b(e,e.selected),n.markerUnsel=b(e,e.unselected),!e.unselected&&s.isArrayOrTypedArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=g*i[r]}if(f.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(d.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=w(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=w(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:x,markerSelection:b,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(f.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>d.TOO_MANY_POINTS||f.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var h=n[0],p=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=h,n[i+1]=p):(h=n[i],p=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),f=r.length/2,h={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*f),d=1/0,g=-1/0,m=0,v=0;m<f;m++,v+=4){var y=t[m];if(n(y)){var x=r[2*m+c],b=l(y,m),_=b[0],w=b[1];if(n(_)&&n(w)){var T=y-_,k=y+w;p[v+u[0]]=x-i.c2l(T),p[v+u[1]]=i.c2l(k)-x,p[v+u[2]]=0,p[v+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}h[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),h},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(f.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,h=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,g=m[p],v=m[d],y=u?u/.8+1:0,x=-v*y-.5*v;o.offset[i]=[g*y/h,x/h]}}return o}}},{\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../constants/interactions\":752,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/cartesian/axis_ids\":831,\"../../registry\":911,\"../scatter/make_bubble_size_func\":1204,\"../scatter/subtypes\":1212,\"./constants\":1241,\"./helpers\":1246,\"color-normalize\":125,\"fast-isnumeric\":241,\"svg-path-sdf\":574}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./helpers\"),o=t(\"./attributes\"),s=t(\"../scatter/constants\"),l=t(\"../scatter/subtypes\"),c=t(\"../scatter/xy_defaults\"),u=t(\"../scatter/period_defaults\"),f=t(\"../scatter/marker_defaults\"),h=t(\"../scatter/line_defaults\"),p=t(\"../scatter/fillcolor_defaults\"),d=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,g){function m(r,i){return n.coerce(t,e,o,r,i)}var v=!!t.marker&&a.isOpenSymbol(t.marker.symbol),y=l.isBubble(t),x=c(t,e,g,m);if(x){u(t,e,g,m);var b=x<s.PTS_LINESONLY?\"lines+markers\":\"lines\";m(\"text\"),m(\"hovertext\"),m(\"hovertemplate\"),m(\"mode\",b),l.hasLines(e)&&(m(\"connectgaps\"),h(t,e,r,g,m),m(\"line.shape\")),l.hasMarkers(e)&&(f(t,e,r,g,m),m(\"marker.line.width\",v||y?1:0)),l.hasText(e)&&(m(\"texttemplate\"),d(t,e,g,m));var _=(e.line||{}).color,w=(e.marker||{}).color;m(\"fill\"),\"none\"!==e.fill&&p(t,e,r,m);var T=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");T(t,e,_||w||r,{axis:\"y\"}),T(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,m)}else e.visible=!1}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/period_defaults\":1207,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"../scatter/xy_defaults\":1214,\"./attributes\":1239,\"./helpers\":1246}],1244:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,f=c.selectBatch[u],h=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},m=n.extendFlat({},p);if(f.length||h.length){var v=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(m.color=new Array(s._length),e=0;e<f.length;e++)r=f[e],m.color[r]=v||(b?x[r]:x);for(e=0;e<h.length;e++){r=h[e];var _=b?x[r]:x;m.color[r]=y||(v?_:i.addOpacity(_,a))}}c.glText[u].update(m)}}},{\"../../components/color\":643,\"../../constants/interactions\":752,\"../../lib\":778}],1245:[function(t,e,r){\"use strict\";var n=t(\"../scatter/format_labels\");e.exports=function(t,e,r){var i=t.i;return\"x\"in t||(t.x=e._x[i]),\"y\"in t||(t.y=e._y[i]),n(t,e,r)}},{\"../scatter/format_labels\":1196}],1246:[function(t,e,r){\"use strict\";var n=t(\"./constants\");r.isOpenSymbol=function(t){return\"string\"==typeof t?n.OPEN_RE.test(t):t%200>100},r.isDotSymbol=function(t){return\"string\"==typeof t?n.DOT_RE.test(t):t>200}},{\"./constants\":1241}],1247:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,f=t.index,h={pointNumber:f,x:e[f],y:r[f]};h.tx=Array.isArray(o.text)?o.text[f]:o.text,h.htx=Array.isArray(o.hovertext)?o.hovertext[f]:o.hovertext,h.data=Array.isArray(o.customdata)?o.customdata[f]:o.customdata,h.tp=Array.isArray(o.textposition)?o.textposition[f]:o.textposition;var p=o.textfont;p&&(h.ts=i.isArrayOrTypedArray(p.size)?p.size[f]:p.size,h.tc=Array.isArray(p.color)?p.color[f]:p.color,h.tf=Array.isArray(p.family)?p.family[f]:p.family);var d=o.marker;d&&(h.ms=i.isArrayOrTypedArray(d.size)?d.size[f]:d.size,h.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[f]:d.opacity,h.mx=i.isArrayOrTypedArray(d.symbol)?d.symbol[f]:d.symbol,h.mc=i.isArrayOrTypedArray(d.color)?d.color[f]:d.color);var g=d&&d.line;g&&(h.mlc=Array.isArray(g.color)?g.color[f]:g.color,h.mlw=i.isArrayOrTypedArray(g.width)?g.width[f]:g.width);var m=d&&d.gradient;m&&\"none\"!==m.type&&(h.mgt=Array.isArray(m.type)?m.type[f]:m.type,h.mgc=Array.isArray(m.color)?m.color[f]:m.color);var v=s.c2p(h.x,!0),y=l.c2p(h.y,!0),x=h.mrc||1,b=o.hoverlabel;b&&(h.hbg=Array.isArray(b.bgcolor)?b.bgcolor[f]:b.bgcolor,h.hbc=Array.isArray(b.bordercolor)?b.bordercolor[f]:b.bordercolor,h.hts=i.isArrayOrTypedArray(b.font.size)?b.font.size[f]:b.font.size,h.htc=Array.isArray(b.font.color)?b.font.color[f]:b.font.color,h.htf=Array.isArray(b.font.family)?b.font.family[f]:b.font.family,h.hnl=i.isArrayOrTypedArray(b.namelength)?b.namelength[f]:b.namelength);var _=o.hoverinfo;_&&(h.hi=Array.isArray(_)?_[f]:_);var w=o.hovertemplate;w&&(h.ht=Array.isArray(w)?w[f]:w);var T={};T[t.index]=h;var k=o._origX,M=o._origY,A=i.extendFlat({},t,{color:a(o,h),x0:v-x,x1:v+x,xLabelVal:k?k[f]:h.x,y0:y-x,y1:y+x,yLabelVal:M?M[f]:h.y,cd:T,distance:c,spikeDistance:u,hovertemplate:h.ht});return h.htx?A.text=h.htx:h.tx?A.text=h.tx:o.text&&(A.text=o.text),i.fillText(h,o,A),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(h,o,A),A}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,f,h,p,d=t.cd,g=d[0].t,m=d[0].trace,v=t.xa,y=t.ya,x=g.x,b=g.y,_=v.c2p(e),w=y.c2p(r),T=t.distance;if(g.tree){var k=v.p2c(_-T),M=v.p2c(_+T),A=y.p2c(w-T),S=y.p2c(w+T);i=\"x\"===n?g.tree.range(Math.min(k,M),Math.min(y._rl[0],y._rl[1]),Math.max(k,M),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(k,M),Math.min(A,S),Math.max(k,M),Math.max(A,S))}else i=g.ids;var E=T;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(v.c2p(s)-_))<E&&(E=u,f=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+f*f),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=v.c2p(s)-_,f=y.c2p(l)-w,(h=Math.sqrt(u*u+f*f))<E&&(E=p=h,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:[o(t,x,b,m)]},calcHover:o}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/get_trace_color\":1197}],1248:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/cross_trace_defaults\":1193,\"../scatter/marker_colorbar\":1205,\"./attributes\":1239,\"./calc\":1240,\"./defaults\":1243,\"./format_labels\":1245,\"./hover\":1247,\"./plot\":1249,\"./select\":1251}],1249:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../components/dragelement/helpers\").selectMode,c=t(\"../../lib/prepare_regl\"),u=t(\"../scatter/subtypes\"),f=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;function p(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}e.exports=function(t,e,r){if(r.length){var d,g,m=t._fullLayout,v=e._scene,y=e.xaxis,x=e.yaxis;if(v)if(c(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var b=v.count,_=m._glcanvas.data()[0].regl;if(f(t,e,r),v.dirty){if(!0===v.error2d&&(v.error2d=a(_)),!0===v.line2d&&(v.line2d=i(_)),!0===v.scatter2d&&(v.scatter2d=n(_,{constPointSize:!0})),!0===v.fill2d&&(v.fill2d=i(_)),!0===v.glText)for(v.glText=new Array(b),d=0;d<b;d++)v.glText[d]=new o(_);if(v.glText){if(b>v.glText.length){var w=b-v.glText.length;for(d=0;d<w;d++)v.glText.push(new o(_))}else if(b<v.glText.length){var T=v.glText.length-b;v.glText.splice(b,T).forEach((function(t){t.destroy()}))}for(d=0;d<b;d++)v.glText[d].update(v.textOptions[d])}if(v.line2d&&(v.line2d.update(v.lineOptions),v.lineOptions=v.lineOptions.map((function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t})),v.line2d.update(v.lineOptions)),v.error2d){var k=(v.errorXOptions||[]).concat(v.errorYOptions||[]);v.error2d.update(k)}v.scatter2d&&v.scatter2d.update(v.markerOptions),v.fillOrder=s.repeat(null,b),v.fill2d&&(v.fillOptions=v.fillOptions.map((function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=v.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(v.fillOrder[e]=u);var f,h,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(f=0;f<d.length&&isNaN(d[f+1]);)f+=2;for(h=d.length-2;h>f&&isNaN(d[h+1]);)h-=2;0!==d[f+1]&&(p=[d[f],0]),p=p.concat(d.slice(f,h+2)),0!==d[h+1]&&(p=p.concat([d[h],0]))}else if(\"tozerox\"===s.fill){for(f=0;f<d.length&&isNaN(d[f]);)f+=2;for(h=d.length-2;h>f&&isNaN(d[h]);)h-=2;0!==d[f]&&(p=[0,d[f+1]]),p=p.concat(d.slice(f,h+2)),0!==d[h]&&(p=p.concat([0,d[h+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var g=s._nexttrace;if(g){var m=v.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=g.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=v.lineOptions[e-1].positions,w=p.length/2,T=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(T.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=T}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}})),v.fill2d.update(v.fillOptions))}var M=m.dragmode,A=l(M),S=m.clickmode.indexOf(\"select\")>-1;for(d=0;d<b;d++){var E=r[d][0],C=E.trace,L=E.t,I=L.index,P=C._length,z=L.x,O=L.y;if(C.selectedpoints||A||S){if(A||(A=!0),C.selectedpoints){var D=v.selectBatch[I]=s.selIndices2selPoints(C),R={};for(g=0;g<D.length;g++)R[D[g]]=1;var F=[];for(g=0;g<P;g++)R[g]||F.push(g);v.unselectBatch[I]=F}var B=L.xpx=new Array(P),N=L.ypx=new Array(P);for(g=0;g<P;g++)B[g]=y.c2p(z[g]),N[g]=x.c2p(O[g])}else L.xpx=L.ypx=null}if(A){if(v.select2d||(v.select2d=n(m._glcanvas.data()[1].regl)),v.scatter2d){var j=new Array(b);for(d=0;d<b;d++)j[d]=v.selectBatch[d].length||v.unselectBatch[d].length?v.markerUnselectedOptions[d]:{};v.scatter2d.update(j)}v.select2d&&(v.select2d.update(v.markerOptions),v.select2d.update(v.markerSelectedOptions)),v.glText&&r.forEach((function(t){var e=((t||[])[0]||{}).trace||{};u.hasText(e)&&h(t)}))}else v.scatter2d&&v.scatter2d.update(v.markerOptions);var U={viewport:p(m,y,x),range:[(y._rl||y.range)[0],(x._rl||x.range)[0],(y._rl||y.range)[1],(x._rl||x.range)[1]]},V=s.repeat(U,v.count);v.fill2d&&v.fill2d.update(V),v.line2d&&v.line2d.update(V),v.error2d&&v.error2d.update(V.concat(V)),v.scatter2d&&v.scatter2d.update(V),v.select2d&&v.select2d.update(V),v.glText&&v.glText.forEach((function(t){t.update(U)}))}else v.init()}}},{\"../../components/dragelement/helpers\":661,\"../../lib\":778,\"../../lib/prepare_regl\":791,\"../scatter/link_traces\":1203,\"../scatter/subtypes\":1212,\"./edit_style\":1244,\"gl-text\":352,\"regl-error2d\":534,\"regl-line2d\":535,\"regl-scatter2d\":537}],1250:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,f=0;f<t;f++){if(e&&r.fillOrder[f]&&e.draw(r.fillOrder[f]),a&&r.lineOptions[f]&&a.draw(f),i&&(r.errorXOptions[f]&&i.draw(f),r.errorYOptions[f]&&i.draw(f+t)),o&&r.markerOptions[f])if(u[f].length){var h=n.repeat([],r.count);h[f]=u[f],o.draw(h)}else c[f].length||o.draw(f);s[f]&&r.textOptions[f]&&s[f].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach((function(t){t.destroy&&t.destroy()})),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":778}],1251:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,f=s._scene,h=s.index;if(!f)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var m=[],v=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(m.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):v.push(y);if(d){var x=f.scatter2d;if(m.length||v.length){if(!f.selectBatch[h].length&&!f.unselectBatch[h].length){var b=new Array(f.count);b[h]=f.markerUnselectedOptions[h],x.update.apply(x,b)}}else{var _=new Array(f.count);_[h]=f.markerOptions[h],x.update.apply(x,_)}}return f.selectBatch[h]=m,f.unselectBatch[h]=v,p&&i(r),a}},{\"../scatter/subtypes\":1212,\"./edit_style\":1244}],1252:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scattergeo/attributes\"),o=t(\"../scatter/attributes\"),s=t(\"../../plots/mapbox/layout_attributes\"),l=t(\"../../plots/attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll,h=a.line,p=a.marker;e.exports=f({lon:a.lon,lat:a.lat,mode:u({},o.mode,{dflt:\"markers\"}),text:u({},o.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"text\"]}),hovertext:u({},o.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:o.connectgaps,marker:u({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},angle:{valType:\"number\",dflt:\"auto\",arrayOk:!0},allowoverlap:{valType:\"boolean\",dflt:!1},opacity:p.opacity,size:p.size,sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode},c(\"marker\")),fill:a.fill,fillcolor:o.fillcolor,textfont:s.layers.symbol.textfont,textposition:s.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:o.selected.marker},unselected:{marker:o.unselected.marker},hoverinfo:u({},l.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/mapbox/layout_attributes\":887,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"../scattergeo/attributes\":1229}],1253:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),f=t(\"../../plots/mapbox/convert_text_opts\"),h=t(\"../../components/fx/helpers\").appendArrayPointValue,p=t(\"../../lib/svg_text_utils\").NEWLINES,d=t(\"../../lib/svg_text_utils\").BR_TAG_ALL;function g(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function m(t,e){return i.isArrayOrTypedArray(t)?e?function(e){return n(t[e])?+t[e]:0}:function(e){return t[e]}:t?function(){return t}:v}function v(){return\"\"}function y(t){return t[0]===a}e.exports=function(t,e){var r,a=e[0].trace,x=!0===a.visible&&0!==a._length,b=\"none\"!==a.fill,_=u.hasLines(a),w=u.hasMarkers(a),T=u.hasText(a),k=w&&\"circle\"===a.marker.symbol,M=w&&\"circle\"!==a.marker.symbol,A=g(),S=g(),E=g(),C=g(),L={fill:A,line:S,circle:E,symbol:C};if(!x)return L;if((b||_)&&(r=o.calcTraceToLineCoords(e)),b&&(A.geojson=o.makePolygon(r),A.layout.visibility=\"visible\",i.extendFlat(A.paint,{\"fill-color\":a.fillcolor})),_&&(S.geojson=o.makeLine(r),S.layout.visibility=\"visible\",i.extendFlat(S.paint,{\"line-width\":a.line.width,\"line-color\":a.line.color,\"line-opacity\":a.opacity})),k){var I=function(t){var e,r,a,o,u=t[0].trace,f=u.marker,h=u.selectedpoints,p=i.isArrayOrTypedArray(f.color),d=i.isArrayOrTypedArray(f.size),g=i.isArrayOrTypedArray(f.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(f):i.identity);d&&(a=c(u));g&&(o=function(t){return m(n(t)?+i.constrain(t,0,1):0)});var v,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!y(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),h&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(h)for(v=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var T=x[e].properties;v.selectedOpacityFn&&(T.mo=m(v.selectedOpacityFn(T))),v.selectedColorFn&&(T.mcc=v.selectedColorFn(T)),v.selectedSizeFn&&(T.mrc=v.selectedSizeFn(T))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||v&&v.selectedColorFn?{type:\"identity\",property:\"mcc\"}:f.color,mrc:d||v&&v.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(k=f.size,k/2),mo:g||v&&v.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(f.opacity)};var k}(e);E.geojson=I.geojson,E.layout.visibility=\"visible\",i.extendFlat(E.paint,{\"circle-color\":I.mcc,\"circle-radius\":I.mrc,\"circle-opacity\":I.mo})}if((M||T)&&(C.geojson=function(t,e){for(var r=e._fullLayout,n=t[0].trace,a=n.marker||{},o=a.symbol,s=a.angle,l=\"circle\"!==o?m(o):v,c=\"auto\"!==s?m(s,!0):v,f=u.hasText(n)?m(n.text):v,g=[],x=0;x<t.length;x++){var b=t[x];if(!y(b.lonlat)){var _,w=n.texttemplate;if(w){var T=Array.isArray(w)?w[x]||\"\":w,k=n._module.formatLabels(b,n,r),M={};h(M,n,b.i);var A=n._meta||{};_=i.texttemplateString(T,k,r._d3locale,M,b,A)}else _=f(x);_&&(_=_.replace(p,\"\").replace(d,\"\\n\")),g.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:b.lonlat},properties:{symbol:l(x),angle:c(x),text:_}})}}return{type:\"FeatureCollection\",features:g}}(e,t),i.extendFlat(C.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),M&&(i.extendFlat(C.layout,{\"icon-size\":a.marker.size/10}),\"angle\"in a.marker&&\"auto\"!==a.marker.angle&&i.extendFlat(C.layout,{\"icon-rotate\":{type:\"identity\",property:\"angle\"},\"icon-rotation-alignment\":\"map\"}),C.layout[\"icon-allow-overlap\"]=a.marker.allowoverlap,i.extendFlat(C.paint,{\"icon-opacity\":a.opacity*a.marker.opacity,\"icon-color\":a.marker.color})),T)){var P=(a.marker||{}).size,z=f(a.textposition,P);i.extendFlat(C.layout,{\"text-size\":a.textfont.size,\"text-anchor\":z.anchor,\"text-offset\":z.offset}),i.extendFlat(C.paint,{\"text-color\":a.textfont.color,\"text-opacity\":a.opacity})}return L}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geojson_utils\":772,\"../../lib/svg_text_utils\":803,\"../../plots/mapbox/convert_text_opts\":884,\"../scatter/make_bubble_size_func\":1204,\"../scatter/subtypes\":1212,\"fast-isnumeric\":241}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,f)){if(f(\"text\"),f(\"texttemplate\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),f(\"below\"),i.hasLines(e)&&(o(t,e,r,u,f,{noDash:!0}),f(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,f,{noLine:!0}),f(\"marker.allowoverlap\"),f(\"marker.angle\");var h=e.marker;\"circle\"!==h.symbol&&(n.isArrayOrTypedArray(h.size)&&(h.size=h.size[0]),n.isArrayOrTypedArray(h.color)&&(h.color=h.color[0]))}i.hasText(e)&&s(t,e,u,f,{noSelect:!0}),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1252}],1255:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},{\"../../plots/cartesian/axes\":828}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,(function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=h.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-f.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)}),t),!1!==t.index){var g=l[t.index],m=g.lonlat,v=[i.modHalf(m[0],360)+p,m[1]],y=u.c2p(v),x=f.c2p(v),b=g.mrc||1;t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b;var _={};_[c.subplot]={_subplot:h};var w=c._module.formatLabels(g,c,_);return t.lonLabel=w.lonLabel,t.latLabel=w.latLabel,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/get_trace_color\":1197}],1258:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/mapbox\":885,\"../scatter/marker_colorbar\":1205,\"../scattergeo/calc\":1230,\"./attributes\":1252,\"./defaults\":1254,\"./event_data\":1255,\"./format_labels\":1256,\"./hover\":1257,\"./plot\":1259,\"./select\":1260}],1259:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.type=\"scattermapbox\",this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(o.gd,t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(t.gd,e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],f=s[u];i.addSource(u,f),i.addLayer(u,f,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":883,\"./convert\":1253}],1260:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var f=o[r],h=f.lonlat;if(h[0]!==a){var p=[n.modHalf(h[0],360),h[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:h[0],lat:h[1]}),f.selected=1):f.selected=0}}return c}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/subtypes\":1212}],1261:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../lib/extend\").extendFlat,o=t(\"../scatter/attributes\"),s=t(\"../../plots/attributes\"),l=o.line;e.exports={mode:o.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:o.text,texttemplate:i({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:o.hovertext,line:{color:l.color,width:l.width,dash:l.dash,shape:a({},l.shape,{values:[\"linear\",\"spline\"]}),smoothing:l.smoothing,editType:\"calc\"},connectgaps:o.connectgaps,marker:o.marker,cliponaxis:a({},o.cliponaxis,{dflt:!1}),textposition:o.textposition,textfont:o.textfont,fill:a({},o.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:o.fillcolor,hoverinfo:a({},s.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:o.hoveron,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1262:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,f=r[u].radialaxis,h=r[u].angularaxis,p=f.makeCalcdata(e,\"r\"),d=h.makeCalcdata(e,\"theta\"),g=e._length,m=new Array(g),v=0;v<g;v++){var y=p[v],x=d[v],b=m[v]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(f,p,{ppad:_}),o(t,e),s(m,e),l(m,e),m}},{\"../../constants/numerical\":753,\"../../plots/cartesian/axes\":828,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1263:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");function h(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:h,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,f,r,i)}var g=h(t,e,p,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&(d(\"texttemplate\"),l(t,e,p,d));var m=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),m.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),d(\"hoveron\",m.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1261}],1264:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var a,o,s={},l=r[e.subplot]._subplot;l?(a=l.radialAxis,o=l.angularAxis):(a=(l=r[e.subplot]).radialaxis,o=l.angularaxis);var c=a.c2l(t.r);s.rLabel=i.tickText(a,c,!0).text;var u=\"degrees\"===o.thetaunit?n.rad2deg(t.theta):t.theta;return s.thetaLabel=i.tickText(o,u,!0).text,s}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1265:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");function i(t,e,r,n){var i=r.radialAxis,a=r.angularAxis;i._hovertitle=\"r\",a._hovertitle=\"\\u03b8\";var o={};o[e.subplot]={_subplot:r};var s=e._module.formatLabels(t,e,o);n.rLabel=s.rLabel,n.thetaLabel=s.thetaLabel;var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var f=l.split(\"+\");-1!==f.indexOf(\"all\")&&(f=[\"r\",\"theta\",\"text\"]),-1!==f.indexOf(\"r\")&&u(i,n.rLabel),-1!==f.indexOf(\"theta\")&&u(a,n.thetaLabel),-1!==f.indexOf(\"text\")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index)return o;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,i(c,u,l,s),s.hovertemplate=u.hovertemplate,o}},makeHoverPointText:i}},{\"../scatter/hover\":1198}],1266:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":894,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1261,\"./calc\":1262,\"./defaults\":1263,\"./format_labels\":1264,\"./hover\":1265,\"./plot\":1267}],1267:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],f=0;f<u.length;f++){var h=u[f],p=h.r;if(p===i)h.x=h.y=i;else{var d=s.c2g(p),g=l.c2g(h.theta);h.x=d*Math.cos(g),h.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":753,\"../scatter/plot\":1208}],1268:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\"),a=t(\"../../plots/template_attributes\").texttemplateAttrs;e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,texttemplate:a({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../../plots/template_attributes\":906,\"../scattergl/attributes\":1239,\"../scatterpolar/attributes\":1261}],1269:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,f=e._r=c.makeCalcdata(e,\"r\"),h=e._theta=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<f.length&&(f=f.slice(0,p)),p<h.length&&(h=h.slice(0,p)),d.r=f,d.theta=h,n(t,e);var g,m=d.opts=a.style(t,e);return p<s?g=i(e,p):m.marker&&(g=2*(m.marker.sizeAvg||Math.max(m.marker.size,3))),e._extremes.x=o.findExtremes(c,f,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":828,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242}],1270:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d=a(t,e,h,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,h,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,h,p),i.hasText(e)&&(p(\"texttemplate\"),l(t,e,h,p)),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"../scatterpolar/defaults\":1263,\"./attributes\":1268}],1271:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/format_labels\");e.exports=function(t,e,r){var i=t.i;return\"r\"in t||(t.r=e._r[i]),\"theta\"in t||(t.theta=e._theta[i]),n(t,e,r)}},{\"../scatterpolar/format_labels\":1264}],1272:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var f=t.subplot,h=u.cd[u.index],p=u.trace;if(h.r=s[u.index],h.theta=l[u.index],f.isPtInside(h))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(h,p,f,u),c}}}},{\"../scattergl/hover\":1247,\"../scatterpolar/hover\":1265}],1273:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":894,\"../scatter/marker_colorbar\":1205,\"../scattergl/select\":1251,\"./attributes\":1268,\"./calc\":1269,\"./defaults\":1270,\"./format_labels\":1271,\"./hover\":1272,\"./plot\":1274}],1274:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,f=e.angularAxis,h=o(t,e);return r.forEach((function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,m=d.r,v=d.theta,y=d.opts,x=m.slice(),b=v.slice();for(a=0;a<m.length;a++)e.isPtInside({r:m[a],theta:v[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),T=Array(g);for(a=0;a<g;a++){var k,M,A=x[a];if(i(A)){var S=u.c2g(A),E=f.c2g(b[a],p.thetaunit);k=S*Math.cos(E),M=S*Math.sin(E)}else k=M=NaN;w[a]=_[2*a]=k,T[a]=_[2*a+1]=M}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!h.fill2d&&(h.fill2d=!0),y.marker&&!h.scatter2d&&(h.scatter2d=!0),y.line&&!h.line2d&&(h.line2d=!0),y.text&&!h.glText&&(h.glText=!0),h.lineOptions.push(y.line),h.fillOptions.push(y.fill),h.markerOptions.push(y.marker),h.markerSelectedOptions.push(y.markerSel),h.markerUnselectedOptions.push(y.markerUnsel),h.textOptions.push(y.text),h.textSelectedOptions.push(y.textSel),h.textUnselectedOptions.push(y.textUnsel),h.selectBatch.push([]),h.unselectBatch.push([]),d.x=w,d.y=T,d.rawx=w,d.rawy=T,d.r=m,d.theta=v,d.positions=_,d._scene=h,d.index=h.count,h.count++}})),a(t,e,r)}}},{\"../../lib\":778,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242,\"../scattergl/plot\":1249,\"../scattergl/scene_update\":1250,\"@plotly/point-cluster\":57,\"fast-isnumeric\":241}],1275:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=a.marker,f=a.line,h=u.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"a\",\"b\",\"c\",\"text\"]}),hovertext:c({},a.hovertext,{}),line:{color:f.color,width:f.width,dash:l,shape:c({},f.shape,{values:[\"linear\",\"spline\"]}),smoothing:f.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,cliponaxis:a.cliponaxis,fill:c({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,marker:c({symbol:u.symbol,opacity:u.opacity,maxdisplayed:u.maxdisplayed,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,line:c({width:h.width,editType:\"calc\"},s(\"marker.line\")),gradient:u.gradient,editType:\"calc\"},s(\"marker\")),textfont:a.textfont,textposition:a.textposition,selected:a.selected,unselected:a.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1276:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,f,h,p,d,g=t._fullLayout[e.subplot].sum,m=e.sum||g,v={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!v[f=l[r]]){for(p=v[c[f][0]],d=v[c[f][1]],h=new Array(p.length),u=0;u<p.length;u++)h[u]=m-p[u]-d[u];v[f]=h}var y,x,b,_,w,T,k=e._length,M=new Array(k);for(r=0;r<k;r++)y=v.a[r],x=v.b[r],b=v.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),T=y,w=b-x,M[r]={x:w,y:T,a:y,b:x,c:b}):M[r]={x:!1,y:!1};return s(e,k),i(t,e),a(M,e),o(M,e),M}},{\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1277:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d,g=p(\"a\"),m=p(\"b\"),v=p(\"c\");if(g?(d=g.length,m?(d=Math.min(d,m.length),v&&(d=Math.min(d,v.length))):d=v?Math.min(d,v.length):0):m&&v&&(d=Math.min(m.length,v.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&(p(\"texttemplate\"),c(t,e,h,p));var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1275}],1278:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1279:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot;return i.aLabel=n.tickText(a.aaxis,t.a,!0).text,i.bLabel=n.tickText(a.baxis,t.b,!0).text,i.cLabel=n.tickText(a.caxis,t.c,!0).text,i}},{\"../../plots/cartesian/axes\":828}],1280:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");e.exports=function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var o=a[0];if(void 0===o.index){var s=1-o.y0/t.ya._length,l=t.xa._length,c=l*s/2,u=l-c;return o.x0=Math.max(Math.min(o.x0,u),c),o.x1=Math.max(Math.min(o.x1,u),c),a}var f=o.cd[o.index],h=o.trace,p=o.subplot;o.a=f.a,o.b=f.b,o.c=f.c,o.xLabelVal=void 0,o.yLabelVal=void 0;var d={};d[h.subplot]={_subplot:p};var g=h._module.formatLabels(f,h,d);o.aLabel=g.aLabel,o.bLabel=g.bLabel,o.cLabel=g.cLabel;var m=f.hi||h.hoverinfo,v=[];if(!h.hovertemplate){var y=m.split(\"+\");-1!==y.indexOf(\"all\")&&(y=[\"a\",\"b\",\"c\"]),-1!==y.indexOf(\"a\")&&x(p.aaxis,o.aLabel),-1!==y.indexOf(\"b\")&&x(p.baxis,o.bLabel),-1!==y.indexOf(\"c\")&&x(p.caxis,o.cLabel)}return o.extraText=v.join(\"<br>\"),o.hovertemplate=h.hovertemplate,a}function x(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../scatter/hover\":1198}],1281:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":907,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1275,\"./calc\":1276,\"./defaults\":1277,\"./event_data\":1278,\"./format_labels\":1279,\"./hover\":1280,\"./plot\":1282}],1282:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1208}],1283:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,f=u.line,h=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},f.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:h,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"../scattergl/attributes\":1239}],1284:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine;function u(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var f=l(t,e._diag[s][1]);f&&(c[1]=f.r2l(f.range[0]),c[3]=f.r2l(f.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],f=u.xaxis,h=u.yaxis,p=f._gridVals,d=h._gridVals,g=n.b+h.domain[0]*n.h,m=-h._m,v=-m*h.r2l(h.range[0],h.calendar);if(f.showgrid)for(e=0;e<p.length;e++)s=f._offset+f.l2p(p[e].x),o(\"grid\",f,s,g,s,g+h._length);if(h.showgrid)for(e=0;e<d.length;e++)l=g+v+m*d[e].x,o(\"grid\",h,f._offset,l,f._offset+f._length,l);c(t,f,h)&&(s=f._offset+f.l2p(0),o(\"zeroline\",f,s,g,s,g+h._length)),c(t,h,f)&&(l=g+v+0,o(\"zeroline\",h,f._offset,l,f._offset+f._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:\"splom\",attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(\"splom\"),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&u(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":791,\"../../plots/cartesian\":841,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_ids\":831,\"../../plots/get_data\":865,\"../../registry\":911,\"regl-line2d\":535}],1285:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),f=t(\"../../constants/numerical\").BADNUM,h=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,m,v,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],T=e._visibleDims=[];function k(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===f?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),m=i.getFromId(t,e._diag[r][1]),g&&m&&g.type!==m.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(k(g,d),m&&\"category\"===m.type&&(m._categories=g._categories.slice())):k(m,d),T.push(r)}for(s(t,e),n.extendFlat(b,c(e)),v=_.length*x>h?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<T.length;p++)d=y[r=T[p]],g=i.getFromId(t,e._diag[r][0])||{},m=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,m,_[p],_[p],v);var M=u(t,e);return M.matrix||(M.matrix=!0),M.matrixOptions=b,M.selectedOptions=l(e,e.selected),M.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242,\"./scene_update\":1292}],1286:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=t(\"../scattergl/helpers\").isOpenSymbol;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=h(\"diagonal.visible\"),g=h(\"showupperhalf\"),m=h(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||m)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),s(t,e,r,f,h);var v=c(e.marker.symbol),y=o.isBubble(e);h(\"marker.line.width\",v||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,f=new Array(s),h=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";f[i]=\"x\"+p,h[i]=\"y\"+p}var d=n(\"xaxes\",f),g=n(\"yaxes\",h),m=e._diag=new Array(s);e._xaxes={},e._yaxes={};var v=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],T=0===i,k=i===s-1,M=T&&b||k&&_?void 0:d[i],A=T&&_||k&&b?void 0:g[i];x(M,A,w,v),x(A,M,w,y),m[i]=[M,A],e._axesDim[M]=i,e._axesDim[A]=i}for(i=0;i<v.length;i++)for(a=0;a<y.length;a++){var S=v[i]+y[a];i>a&&l||i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,f,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../parcoords/merge_length\":1158,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scattergl/helpers\":1246,\"./attributes\":1283}],1287:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":778,\"../scatter/colorscale_calc\":1190,\"../scattergl/convert\":1242}],1288:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1289:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),f=t.distance,h=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===h||!1===p)return[t];for(var d,g,m=o[h],v=o[p],y=f,x=0;x<m.length;x++){var b=m[x],_=v[x],w=s.c2p(b)-c,T=l.c2p(_)-u,k=Math.sqrt(w*w+T*T);k<y&&(y=g=k,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:[i(t,m,v,a)]}}},{\"../scattergl/hover\":1247,\"./helpers\":1288}],1290:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":687,\"../../registry\":911,\"../scatter/marker_colorbar\":1205,\"./attributes\":1283,\"./base_plot\":1284,\"./calc\":1285,\"./defaults\":1286,\"./edit_style\":1287,\"./hover\":1289,\"./plot\":1291,\"./select\":1293}],1291:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../components/dragelement/helpers\").selectMode;function s(t,e){var r,s,l,c,u,f=t._fullLayout,h=f._size,p=e.trace,d=e.t,g=f._splomScenes[p.uid],m=g.matrixOptions,v=m.cdata,y=f._glcanvas.data()[0].regl,x=f.dragmode;if(0!==v.length){m.lower=p.showupperhalf,m.upper=p.showlowerhalf,m.diagonal=p.diagonal.visible;var b=p._visibleDims,_=v.length,w=g.viewOpts={};for(w.ranges=new Array(_),w.domains=new Array(_),u=0;u<b.length;u++){l=b[u];var T=w.ranges[u]=new Array(4),k=w.domains[u]=new Array(4);(r=a.getFromId(t,p._diag[l][0]))&&(T[0]=r._rl[0],T[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(s=a.getFromId(t,p._diag[l][1]))&&(T[1]=s._rl[0],T[3]=s._rl[1],k[1]=s.domain[0],k[3]=s.domain[1])}w.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===g.matrix&&(g.matrix=n(y));var M=f.clickmode.indexOf(\"select\")>-1,A=!0;if(o(x)||!!p.selectedpoints||M){var S=p._length;if(p.selectedpoints){g.selectBatch=p.selectedpoints;var E=p.selectedpoints,C={};for(l=0;l<E.length;l++)C[E[l]]=!0;var L=[];for(l=0;l<S;l++)C[l]||L.push(l);g.unselectBatch=L}var I=d.xpx=new Array(_),P=d.ypx=new Array(_);for(u=0;u<b.length;u++){if(l=b[u],r=a.getFromId(t,p._diag[l][0]))for(I[u]=new Array(S),c=0;c<S;c++)I[u][c]=r.c2p(v[u][c]);if(s=a.getFromId(t,p._diag[l][1]))for(P[u]=new Array(S),c=0;c<S;c++)P[u][c]=s.c2p(v[u][c])}if(g.selectBatch.length||g.unselectBatch.length){var z=i.extendFlat({},m,g.unselectedOptions,w),O=i.extendFlat({},m,g.selectedOptions,w);g.matrix.update(z,O),A=!1}}else d.xpx=d.ypx=null;if(A){var D=i.extendFlat({},m,w);g.matrix.update(D,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)s(t,r[n][0])}},{\"../../components/dragelement/helpers\":661,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"regl-splom\":539}],1292:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0,selectBatch:[],unselectBatch:[]},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":778}],1293:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,f=t.yaxis,h=[];if(!l)return h;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return h;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,f);if(!1===d||!1===g)return h;var m=s.xpx[d],v=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([m[w],v[w]],null,w,t)?(b.push(w),h.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var T=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},T,l.selectedOptions,l.viewOpts)):l.matrix.update(T,null),l.selectBatch=b,l.unselectBatch=_,h}},{\"../../lib\":778,\"../scatter/subtypes\":1212,\"./helpers\":1288}],1294:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){l[t]=a[t]})),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1295:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/calc\");function a(t){var e,r,i,a,s,l,c,u,f,h,p,d,g=t._x,m=t._y,v=t._z,y=t._len,x=-1/0,b=1/0,_=-1/0,w=1/0,T=-1/0,k=1/0,M=\"\";for(y&&(c=g[0],f=m[0],p=v[0]),y>1&&(u=g[y-1],h=m[y-1],d=v[y-1]),e=0;e<y;e++)x=Math.max(x,g[e]),b=Math.min(b,g[e]),_=Math.max(_,m[e]),w=Math.min(w,m[e]),T=Math.max(T,v[e]),k=Math.min(k,v[e]),a||g[e]===c||(a=!0,M+=\"x\"),s||m[e]===f||(s=!0,M+=\"y\"),l||v[e]===p||(l=!0,M+=\"z\");a||(M+=\"x\"),s||(M+=\"y\"),l||(M+=\"z\");var A=o(t._x),S=o(t._y),E=o(t._z);M=(M=(M=M.replace(\"x\",(c>u?\"-\":\"+\")+\"x\")).replace(\"y\",(f>h?\"-\":\"+\")+\"y\")).replace(\"z\",(p>d?\"-\":\"+\")+\"z\");var C=function(){y=0,A=[],S=[],E=[]};(!y||y<A.length*S.length*E.length)&&C();var L=function(t){return\"x\"===t?g:\"y\"===t?m:v},I=function(t){return\"x\"===t?A:\"y\"===t?S:E},P=function(t){return t[y-1]<t[0]?-1:1},z=L(M[1]),O=L(M[3]),D=L(M[5]),R=I(M[1]).length,F=I(M[3]).length,B=I(M[5]).length,N=!1,j=function(t,e,r){return R*(F*t+e)+r},U=P(L(M[1])),V=P(L(M[3])),q=P(L(M[5]));for(e=0;e<B-1;e++){for(r=0;r<F-1;r++){for(i=0;i<R-1;i++){var H=j(e,r,i),G=j(e,r,i+1),Y=j(e,r+1,i),W=j(e+1,r,i);if(z[H]*U<z[G]*U&&O[H]*V<O[Y]*V&&D[H]*q<D[W]*q||(N=!0),N)break}if(N)break}if(N)break}return N&&(n.warn(\"Encountered arbitrary coordinates! Unable to input data grid.\"),C()),{xMin:b,yMin:w,zMin:k,xMax:x,yMax:_,zMax:T,Xs:A,Ys:S,Zs:E,len:y,fill:M}}function o(t){return n.distinctVals(t).vals}function s(t,e){if(void 0===e&&(e=t.length),n.isTypedArray(t))return t.subarray(0,e);for(var r=[],i=0;i<e;i++)r[i]=+t[i];return r}e.exports={calc:function(t,e){e._len=Math.min(e.u.length,e.v.length,e.w.length,e.x.length,e.y.length,e.z.length),e._u=s(e.u,e._len),e._v=s(e.v,e._len),e._w=s(e.w,e._len),e._x=s(e.x,e._len),e._y=s(e.y,e._len),e._z=s(e.z,e._len);var r=a(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;var n,o,l,c=0;e.starts&&(n=s(e.starts.x||[]),o=s(e.starts.y||[]),l=s(e.starts.z||[]),c=Math.min(n.length,o.length,l.length)),e._startsX=n||[],e._startsY=o||[],e._startsZ=l||[];var u,f=0,h=1/0;for(u=0;u<e._len;u++){var p=e._u[u],d=e._v[u],g=e._w[u],m=Math.sqrt(p*p+d*d+g*g);f=Math.max(f,m),h=Math.min(h,m)}for(i(t,e,{vals:[h,f],containerStr:\"\",cLetter:\"c\"}),u=0;u<c;u++){var v=n[u];r.xMax=Math.max(r.xMax,v),r.xMin=Math.min(r.xMin,v);var y=o[u];r.yMax=Math.max(r.yMax,y),r.yMin=Math.min(r.yMin,y);var x=l[u];r.zMax=Math.max(r.zMax,x),r.zMin=Math.min(r.zMin,x)}e._slen=c,e._normMax=f,e._xbnds=[r.xMin,r.xMax],e._ybnds=[r.yMin,r.yMax],e._zbnds=[r.zMin,r.zMax]},filter:s,processGrid:a}},{\"../../components/colorscale/calc\":651,\"../../lib\":778}],1296:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var f=u.prototype;function h(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function p(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,f={};function d(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,(function(t){return n.d2l(t)*o}))}if(f.vectors=l(d(e._u,\"xaxis\"),d(e._v,\"yaxis\"),d(e._w,\"zaxis\"),u),!u)return{positions:[],cells:[]};var g=d(e._Xs,\"xaxis\"),m=d(e._Ys,\"yaxis\"),v=d(e._Zs,\"zaxis\");if(f.meshgrid=[g,m,v],f.gridFill=e._gridFill,e._slen)f.startingPositions=l(d(e._startsX,\"xaxis\"),d(e._startsY,\"yaxis\"),d(e._startsZ,\"zaxis\"));else{for(var y=m[0],x=h(g),b=h(v),_=new Array(x.length*b.length),w=0,T=0;T<x.length;T++)for(var k=0;k<b.length;k++)_[w++]=[x[T],y,b[k]];f.startingPositions=_}f.colormap=o(e),f.tubeSize=e.sizeref,f.maxLength=e.maxdisplayed;var M=d(e._xbnds,\"xaxis\"),A=d(e._ybnds,\"yaxis\"),S=d(e._zbnds,\"zaxis\"),E=p(g),C=p(m),L=p(v),I=[[M[0]-E[0],A[0]-C[0],S[0]-L[0]],[M[1]+E[1],A[1]+C[1],S[1]+L[1]]],P=n(f,I),z=s(e);P.vertexIntensityBounds=[z.min/e._normMax,z.max/e._normMax];var O=e.lightposition;return P.lightPosition=[O.x,O.y,O.z],P.ambient=e.lighting.ambient,P.diffuse=e.lighting.diffuse,P.specular=e.lighting.specular,P.roughness=e.lighting.roughness,P.fresnel=e.lighting.fresnel,P.opacity=e.opacity,e._pad=P.tubeScale*e.sizeref*2,P}f.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},f.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/gl3d/zip3\":881,\"gl-streamtube3d\":348}],1297:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1294}],1298:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\").calc,plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1294,\"./calc\":1295,\"./convert\":1296,\"./defaults\":1297}],1299:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../pie/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},count:{valType:\"flaglist\",flags:[\"branches\",\"leaves\"],dflt:\"leaves\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:u({colors:{valType:\"data_array\",editType:\"calc\"},line:{color:u({},l.marker.line.color,{dflt:null}),width:u({},l.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},o(\"marker\",{colorAttr:\"colors\",anim:!1})),leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1},editType:\"plot\"},text:l.text,textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],extras:[\"none\"],editType:\"plot\"},texttemplate:a({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:l.hovertext,hoverinfo:u({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],dflt:\"label+text+value+name\"}),hovertemplate:i({},{keys:c.eventDataKeys}),textfont:l.textfont,insidetextorientation:l.insidetextorientation,insidetextfont:l.insidetextfont,outsidetextfont:u({},l.outsidetextfont,{}),rotation:{valType:\"angle\",dflt:0,editType:\"plot\"},sort:l.sort,root:{color:{valType:\"color\",editType:\"calc\",dflt:\"rgba(0,0,0,0)\"},editType:\"calc\"},domain:s({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161,\"./constants\":1302}],1300:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"sunburst\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1301:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,s=t(\"../pie/calc\").makePullColorFn,l=t(\"../pie/calc\").generateExtendedColors,c=t(\"../../components/colorscale\").calc,u=t(\"../../constants/numerical\").ALMOST_EQUAL,f={},h={};r.calc=function(t,e){var r,l,f,h,p,d,g=t._fullLayout,m=e.ids,v=a.isArrayOrTypedArray(m),y=e.labels,x=e.parents,b=e.values,_=a.isArrayOrTypedArray(b),w=[],T={},k={},M=function(t){return t||\"number\"==typeof t},A=function(t){return!_||i(b[t])&&b[t]>=0};v?(r=Math.min(m.length,x.length),l=function(t){return M(m[t])&&A(t)},f=function(t){return String(m[t])}):(r=Math.min(y.length,x.length),l=function(t){return M(y[t])&&A(t)},f=function(t){return String(y[t])}),_&&(r=Math.min(r,b.length));for(var S=0;S<r;S++)if(l(S)){var E=f(S),C=M(x[S])?String(x[S]):\"\",L={i:S,id:E,pid:C,label:M(y[S])?String(y[S]):\"\"};_&&(L.v=+b[S]),w.push(L),p=E,T[h=C]?T[h].push(p):T[h]=[p],k[p]=1}if(T[\"\"]){if(T[\"\"].length>1){for(var I=a.randstr(),P=0;P<w.length;P++)\"\"===w[P].pid&&(w[P].pid=I);w.unshift({hasMultipleRoots:!0,id:I,pid:\"\",label:\"\"})}}else{var z,O=[];for(z in T)k[z]||O.push(z);if(1!==O.length)return a.warn([\"Multiple implied roots, cannot build\",e.type,\"hierarchy of\",e.name+\".\",\"These roots include:\",O.join(\", \")].join(\" \"));z=O[0],w.unshift({hasImpliedRoot:!0,id:z,pid:\"\",label:z})}try{d=n.stratify().id((function(t){return t.id})).parentId((function(t){return t.pid}))(w)}catch(t){return a.warn([\"Failed to build\",e.type,\"hierarchy of\",e.name+\".\",\"Error:\",t.message].join(\" \"))}var D=n.hierarchy(d),R=!1;if(_)switch(e.branchvalues){case\"remainder\":D.sum((function(t){return t.data.v}));break;case\"total\":D.each((function(t){var r=t.data.data,n=r.v;if(t.children){var i=t.children.reduce((function(t,e){return t+e.data.data.v}),0);if((r.hasImpliedRoot||r.hasMultipleRoots)&&(n=i),n<i*u)return R=!0,a.warn([\"Total value for node\",t.data.data.id,\"of\",e.name,\"is smaller than the sum of its children.\",\"\\nparent value =\",n,\"\\nchildren sum =\",i].join(\" \"))}t.value=n}))}else!function t(e,r,n){var i=0,a=e.children;if(a){for(var o=a.length,s=0;s<o;s++)i+=t(a[s],r,n);n.branches&&i++}else n.leaves&&i++;e.value=e.data.data.value=i,r._values||(r._values=[]);return r._values[e.data.data.i]=i,i}(D,e,{branches:-1!==e.count.indexOf(\"branches\"),leaves:-1!==e.count.indexOf(\"leaves\")});if(!R){var F,B;e.sort&&D.sort((function(t,e){return e.value-t.value}));var N=e.marker.colors||[],j=!!N.length;return e._hasColorscale?(j||(N=_?e.values:e._values),c(t,e,{vals:N,containerStr:\"marker\",cLetter:\"c\"}),B=o(e.marker)):F=s(g[\"_\"+e.type+\"colormap\"]),D.each((function(t){var r=t.data.data;r.color=e._hasColorscale?B(N[r.i]):F(N[r.i],r.id)})),w[0].hierarchy=D,w}},r._runCrossTraceCalc=function(t,e){var r=e._fullLayout,n=e.calcdata,i=r[t+\"colorway\"],a=r[\"_\"+t+\"colormap\"];r[\"extend\"+t+\"colors\"]&&(i=l(i,\"treemap\"===t?h:f));var o,s=0;function c(t){var e=t.data.data,r=e.id;!1===e.color&&(a[r]?e.color=a[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(a[r]=e.color=i[s%i.length],s++):e.color=o)}for(var u=0;u<n.length;u++){var p=n[u][0];p.trace.type===t&&p.hierarchy&&(o=p.trace.root.color,p.hierarchy.each(c))}},r.crossTraceCalc=function(t){return r._runCrossTraceCalc(\"sunburst\",t)}},{\"../../components/colorscale\":655,\"../../constants/numerical\":753,\"../../lib\":778,\"../pie/calc\":1163,\"d3-hierarchy\":161,\"fast-isnumeric\":241}],1302:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"]}},{}],1303:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../../components/colorscale\"),l=s.hasColorscale,c=s.handleDefaults;e.exports=function(t,e,r,s){function u(r,a){return n.coerce(t,e,i,r,a)}var f=u(\"labels\"),h=u(\"parents\");if(f&&f.length&&h&&h.length){var p=u(\"values\");p&&p.length?u(\"branchvalues\"):u(\"count\"),u(\"level\"),u(\"maxdepth\"),u(\"marker.line.width\")&&u(\"marker.line.color\",s.paper_bgcolor),u(\"marker.colors\");var d=e._hasColorscale=l(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;d&&c(t,e,s,u,{prefix:\"marker.\",cLetter:\"c\"}),u(\"leaf.opacity\",d?1:.7);var g=u(\"text\");u(\"texttemplate\"),e.texttemplate||u(\"textinfo\",Array.isArray(g)?\"text+label\":\"label\"),u(\"hovertext\"),u(\"hovertemplate\");o(t,e,s,u,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),u(\"insidetextorientation\"),u(\"sort\"),u(\"rotation\"),u(\"root.color\"),a(e,s,u),e._length=null}else e.visible=!1}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"./attributes\":1299}],1304:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/fx/helpers\").appendArrayPointValue,o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/events\"),c=t(\"./helpers\"),u=t(\"../pie/helpers\").formatPieValue;function f(t,e,r){for(var n=t.data.data,i={curveNumber:e.index,pointNumber:n.i,data:e._input,fullData:e},o=0;o<r.length;o++){var s=r[o];s in t&&(i[s]=t[s])}return\"parentString\"in t&&!c.isHierarchyRoot(t)&&(i.parent=t.parentString),a(i,e,n.i),i}e.exports=function(t,e,r,a,h){var p=a[0],d=p.trace,g=p.hierarchy,m=\"sunburst\"===d.type,v=\"treemap\"===d.type;\"_hasHoverLabel\"in d||(d._hasHoverLabel=!1),\"_hasHoverEvent\"in d||(d._hasHoverEvent=!1);t.on(\"mouseover\",(function(i){var a=r._fullLayout;if(!r._dragging&&!1!==a.hovermode){var l=r._fullData[d.index],y=i.data.data,x=y.i,b=c.isHierarchyRoot(i),_=c.getParent(g,i),w=c.getValue(i),T=function(t){return s.castOption(l,x,t)},k=T(\"hovertemplate\"),M=o.castHoverinfo(l,a,x),A=a.separators;if(k||M&&\"none\"!==M&&\"skip\"!==M){var S,E;m&&(S=p.cx+i.pxmid[0]*(1-i.rInscribed),E=p.cy+i.pxmid[1]*(1-i.rInscribed)),v&&(S=i._hoverX,E=i._hoverY);var C,L={},I=[],P=[],z=function(t){return-1!==I.indexOf(t)};M&&(I=\"all\"===M?l._module.attributes.hoverinfo.flags:M.split(\"+\")),L.label=y.label,z(\"label\")&&L.label&&P.push(L.label),y.hasOwnProperty(\"v\")&&(L.value=y.v,L.valueLabel=u(L.value,A),z(\"value\")&&P.push(L.valueLabel)),L.currentPath=i.currentPath=c.getPath(i.data),z(\"current path\")&&!b&&P.push(L.currentPath);var O=[],D=function(){-1===O.indexOf(C)&&(P.push(C),O.push(C))};L.percentParent=i.percentParent=w/c.getValue(_),L.parent=i.parentString=c.getPtLabel(_),z(\"percent parent\")&&(C=c.formatPercent(L.percentParent,A)+\" of \"+L.parent,D()),L.percentEntry=i.percentEntry=w/c.getValue(e),L.entry=i.entry=c.getPtLabel(e),!z(\"percent entry\")||b||i.onPathbar||(C=c.formatPercent(L.percentEntry,A)+\" of \"+L.entry,D()),L.percentRoot=i.percentRoot=w/c.getValue(g),L.root=i.root=c.getPtLabel(g),z(\"percent root\")&&!b&&(C=c.formatPercent(L.percentRoot,A)+\" of \"+L.root,D()),L.text=T(\"hovertext\")||T(\"text\"),z(\"text\")&&(C=L.text,s.isValidTextValue(C)&&P.push(C));var R={trace:l,y:E,text:P.join(\"<br>\"),name:k||z(\"name\")?l.name:void 0,color:T(\"hoverlabel.bgcolor\")||y.color,borderColor:T(\"hoverlabel.bordercolor\"),fontFamily:T(\"hoverlabel.font.family\"),fontSize:T(\"hoverlabel.font.size\"),fontColor:T(\"hoverlabel.font.color\"),nameLength:T(\"hoverlabel.namelength\"),textAlign:T(\"hoverlabel.align\"),hovertemplate:k,hovertemplateLabels:L,eventData:[f(i,l,h.eventDataKeys)]};m&&(R.x0=S-i.rInscribed*i.rpx1,R.x1=S+i.rInscribed*i.rpx1,R.idealAlign=i.pxmid[0]<0?\"left\":\"right\"),v&&(R.x=S,R.idealAlign=S<0?\"left\":\"right\"),o.loneHover(R,{container:a._hoverlayer.node(),outerContainer:a._paper.node(),gd:r}),d._hasHoverLabel=!0}if(v){var F=t.select(\"path.surface\");h.styleOne(F,i,l,{hovered:!0})}d._hasHoverEvent=!0,r.emit(\"plotly_hover\",{points:[f(i,l,h.eventDataKeys)],event:n.event})}})),t.on(\"mouseout\",(function(e){var i=r._fullLayout,a=r._fullData[d.index],s=n.select(this).datum();if(d._hasHoverEvent&&(e.originalEvent=n.event,r.emit(\"plotly_unhover\",{points:[f(s,a,h.eventDataKeys)],event:n.event}),d._hasHoverEvent=!1),d._hasHoverLabel&&(o.loneUnhover(i._hoverlayer.node()),d._hasHoverLabel=!1),v){var l=t.select(\"path.surface\");h.styleOne(l,s,a,{hovered:!1})}})),t.on(\"click\",(function(t){var e=r._fullLayout,a=r._fullData[d.index],s=m&&(c.isHierarchyRoot(t)||c.isLeaf(t)),u=c.getPtId(t),p=c.isEntry(t)?c.findEntryWithChild(g,u):c.findEntryWithLevel(g,u),v=c.getPtId(p),y={points:[f(t,a,h.eventDataKeys)],event:n.event};s||(y.nextLevel=v);var x=l.triggerHandler(r,\"plotly_\"+d.type+\"click\",y);if(!1!==x&&e.hovermode&&(r._hoverdata=[f(t,a,h.eventDataKeys)],o.click(r,n.event)),!s&&!1!==x&&!r._dragging&&!r._transitioning){i.call(\"_storeDirectGUIEdit\",a,e._tracePreGUI[a.uid],{level:a.level});var b={data:[{level:v}],traces:[d.index]},_={frame:{redraw:!1,duration:h.transitionTime},transition:{duration:h.transitionTime,easing:h.transitionEasing},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(e._hoverlayer.node()),i.call(\"animate\",r,b,_)}}))}},{\"../../components/fx\":683,\"../../components/fx/helpers\":679,\"../../lib\":778,\"../../lib/events\":767,\"../../registry\":911,\"../pie/helpers\":1166,\"./helpers\":1305,d3:169}],1305:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../lib/setcursor\"),o=t(\"../pie/helpers\");function s(t){return t.data.data.pid}r.findEntryWithLevel=function(t,e){var n;return e&&t.eachAfter((function(t){if(r.getPtId(t)===e)return n=t.copy()})),n||t},r.findEntryWithChild=function(t,e){var n;return t.eachAfter((function(t){for(var i=t.children||[],a=0;a<i.length;a++){var o=i[a];if(r.getPtId(o)===e)return n=t.copy()}})),n||t},r.isEntry=function(t){return!t.parent},r.isLeaf=function(t){return!t.children},r.getPtId=function(t){return t.data.data.id},r.getPtLabel=function(t){return t.data.data.label},r.getValue=function(t){return t.value},r.isHierarchyRoot=function(t){return\"\"===s(t)},r.setSliceCursor=function(t,e,n){var i=n.isTransitioning;if(!i){var o=t.datum();i=n.hideOnRoot&&r.isHierarchyRoot(o)||n.hideOnLeaves&&r.isLeaf(o)}a(t,i?null:\"pointer\")},r.getInsideTextFontKey=function(t,e,r,i,a){var o=(a||{}).onPathbar?\"pathbar.textfont\":\"insidetextfont\",s=r.data.data.i;return n.castOption(e,s,o+\".\"+t)||n.castOption(e,s,\"textfont.\"+t)||i.size},r.getOutsideTextFontKey=function(t,e,r,i){var a=r.data.data.i;return n.castOption(e,a,\"outsidetextfont.\"+t)||n.castOption(e,a,\"textfont.\"+t)||i.size},r.isOutsideText=function(t,e){return!t._hasColorscale&&r.isHierarchyRoot(e)},r.determineTextFont=function(t,e,a,o){return r.isOutsideText(t,e)?function(t,e,n){return{color:r.getOutsideTextFontKey(\"color\",t,e,n),family:r.getOutsideTextFontKey(\"family\",t,e,n),size:r.getOutsideTextFontKey(\"size\",t,e,n)}}(t,e,a):function(t,e,a,o){var s=(o||{}).onPathbar,l=e.data.data,c=l.i,u=n.castOption(t,c,(s?\"pathbar.textfont\":\"insidetextfont\")+\".color\");return!u&&t._input.textfont&&(u=n.castOption(t._input,c,\"textfont.color\")),{color:u||i.contrast(l.color),family:r.getInsideTextFontKey(\"family\",t,e,a,o),size:r.getInsideTextFontKey(\"size\",t,e,a,o)}}(t,e,a,o)},r.hasTransition=function(t){return!!(t&&t.duration>0)},r.getMaxDepth=function(t){return t.maxdepth>=0?t.maxdepth:1/0},r.isHeader=function(t,e){return!(r.isLeaf(t)||t.depth===e._maxDepth-1)},r.getParent=function(t,e){return r.findEntryWithLevel(t,s(e))},r.listPath=function(t,e){var n=t.parent;if(!n)return[];var i=e?[n.data[e]]:[n];return r.listPath(n,e).concat(i)},r.getPath=function(t){return r.listPath(t,\"label\").join(\"/\")+\"/\"},r.formatValue=o.formatPieValue,r.formatPercent=function(t,e){var r=n.formatPercent(t,0);return\"0%\"===r&&(r=o.formatPiePercent(t,e)),r}},{\"../../components/color\":643,\"../../lib\":778,\"../../lib/setcursor\":799,\"../pie/helpers\":1166}],1306:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1205,\"./attributes\":1299,\"./base_plot\":1300,\"./calc\":1301,\"./defaults\":1303,\"./layout_attributes\":1307,\"./layout_defaults\":1308,\"./plot\":1309,\"./style\":1310}],1307:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1308:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":778,\"./layout_attributes\":1307}],1309:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,f=t(\"../pie/plot\"),h=t(\"../pie/helpers\").getRotationAngle,p=f.computeTransform,d=f.transformInsideText,g=t(\"./style\").styleOne,m=t(\"../bar/style\").resizeText,v=t(\"./fx\"),y=t(\"./constants\"),x=t(\"./helpers\");function b(t,e,l,u){var f=t._fullLayout,m=!f.uniformtext.mode&&x.hasTransition(u),b=n.select(l).selectAll(\"g.slice\"),w=e[0],T=w.trace,k=w.hierarchy,M=x.findEntryWithLevel(k,T.level),A=x.getMaxDepth(T),S=f._size,E=T.domain,C=S.w*(E.x[1]-E.x[0]),L=S.h*(E.y[1]-E.y[0]),I=.5*Math.min(C,L),P=w.cx=S.l+S.w*(E.x[1]+E.x[0])/2,z=w.cy=S.t+S.h*(1-E.y[0])-L/2;if(!M)return b.remove();var O=null,D={};m&&b.each((function(t){D[x.getPtId(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!O&&x.isEntry(t)&&(O=t)}));var R=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(M).descendants(),F=M.height+1,B=0,N=A;w.hasMultipleRoots&&x.isHierarchyRoot(M)&&(R=R.slice(1),F-=1,B=1,N+=1),R=R.filter((function(t){return t.y1<=N}));var j=h(T.rotation);j&&R.forEach((function(t){t.x0+=j,t.x1+=j}));var U=Math.min(F,A),V=function(t){return(t-B)/U*I},q=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},H=function(t){return o.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,z)},G=function(t){return P+_(t)[0]*(t.transform.rCenter||0)+(t.transform.x||0)},Y=function(t){return z+_(t)[1]*(t.transform.rCenter||0)+(t.transform.y||0)};(b=b.data(R,x.getPtId)).enter().append(\"g\").classed(\"slice\",!0),m?b.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=x.getPtId(t),i=D[r],a=D[x.getPtId(M)];if(a){var o=(t.x1>a.x1?2*Math.PI:0)+j;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=x.getPtId(t.parent);b.each((function(t){if(x.getPtId(t)===l)return s=t}));var c,u=s.children;u.forEach((function(t,e){if(x.getPtId(t)===r)return c=e}));var f=u.length,h=n.interpolate(s.x0,s.x1);e={rpx0:I,rpx1:I,x0:h(c/f),x1:h((c+1)/f)}}return n.interpolate(i,e)}(t);return function(t){return H(e(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():b.exit().remove(),b.order();var W=null;if(m&&O){var X=x.getPtId(O);b.each((function(t){null===W&&x.getPtId(t)===X&&(W=t.x1)}))}var Z=b;function J(t){var e=t.parent,r=D[x.getPtId(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}m&&(Z=Z.transition().each(\"end\",(function(){var e=n.select(this);x.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:!1})}))),Z.each((function(i){var l=n.select(this),u=o.ensureSingle(l,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));i.rpx0=V(i.y0),i.rpx1=V(i.y1),i.xmid=(i.x0+i.x1)/2,i.pxmid=q(i.rpx1,i.xmid),i.midangle=-(i.xmid-Math.PI/2),i.startangle=-(i.x0-Math.PI/2),i.stopangle=-(i.x1-Math.PI/2),i.halfangle=.5*Math.min(o.angleDelta(i.x0,i.x1)||Math.PI,Math.PI),i.ring=1-i.rpx0/i.rpx1,i.rInscribed=function(t){return 0===t.rpx0&&o.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(i),m?u.transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=D[x.getPtId(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(O)if(t.parent)if(W){var a=(t.x1>W?2*Math.PI:0)+j;e={x0:a,x1:a}}else e={rpx0:I,rpx1:I},o.extendFlat(e,J(t));else e={rpx0:0,rpx1:0};else e={x0:j,x1:j};return n.interpolate(e,i)}(t);return function(t){return H(e(t))}})):u.attr(\"d\",H),l.call(v,M,t,e,{eventDataKeys:y.eventDataKeys,transitionTime:y.CLICK_TRANSITION_TIME,transitionEasing:y.CLICK_TRANSITION_EASING}).call(x.setSliceCursor,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:t._transitioning}),u.call(g,i,T);var h=o.ensureSingle(l,\"g\",\"slicetext\"),b=o.ensureSingle(h,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),_=o.ensureUniformFontSize(t,x.determineTextFont(T,i,f.font));b.text(r.formatSliceLabel(i,M,T,e,f)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(a.font,_).call(s.convertToTspans,t);var k=a.bBox(b.node());i.transform=d(k,i,w),i.transform.targetX=G(i),i.transform.targetY=Y(i);var A=function(t,e){var r=t.transform;return p(r,e),r.fontSize=_.size,c(T.type,r,f),o.getTextTransform(r)};m?b.transition().attrTween(\"transform\",(function(t){var e=function(t){var e,r=D[x.getPtId(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{textPosAngle:i.textPosAngle,scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},O)if(t.parent)if(W){var a=t.x1>W?2*Math.PI:0;e.x0=e.x1=a}else o.extendFlat(e,J(t));else e.x0=e.x1=j;else e.x0=e.x1=j;var s=n.interpolate(e.transform.textPosAngle,t.transform.textPosAngle),l=n.interpolate(e.rpx1,t.rpx1),u=n.interpolate(e.x0,t.x0),h=n.interpolate(e.x1,t.x1),p=n.interpolate(e.transform.scale,i.scale),d=n.interpolate(e.transform.rotate,i.rotate),g=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,m=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=l(t),r=u(t),n=h(t),a=function(t){return m(Math.pow(t,g))}(t),o={pxmid:q(e,(r+n)/2),rpx1:e,transform:{textPosAngle:s(t),rCenter:a,x:i.x,y:i.y}};return c(T.type,i,f),{transform:{targetX:G(o),targetY:Y(o),scale:p(t),rotate:d(t),rCenter:a}}}}(t);return function(t){return A(e(t),k)}})):b.attr(\"transform\",A(i,k))}))}function _(t){return e=t.rpx1,r=t.transform.textPosAngle,[e*Math.sin(r),-e*Math.cos(r)];var e,r}r.plot=function(t,e,r,i){var a,o,s=t._fullLayout,l=s._sunburstlayer,c=!r,f=!s.uniformtext.mode&&x.hasTransition(r);(u(\"sunburst\",s),(a=l.selectAll(\"g.trace.sunburst\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),f)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){o&&o()})).each(\"interrupt\",(function(){o&&o()})).each((function(){l.selectAll(\"g.trace\").each((function(e){b(t,e,this,r)}))}))):(a.each((function(e){b(t,e,this,r)})),s.uniformtext.mode&&m(t,s._sunburstlayer.selectAll(\".trace\"),\"sunburst\"));c&&a.exit().remove()},r.formatSliceLabel=function(t,e,r,n,i){var a=r.texttemplate,s=r.textinfo;if(!(a||s&&\"none\"!==s))return\"\";var l=i.separators,c=n[0],u=t.data.data,f=c.hierarchy,h=x.isHierarchyRoot(t),p=x.getParent(f,t),d=x.getValue(t);if(!a){var g,m=s.split(\"+\"),v=function(t){return-1!==m.indexOf(t)},y=[];if(v(\"label\")&&u.label&&y.push(u.label),u.hasOwnProperty(\"v\")&&v(\"value\")&&y.push(x.formatValue(u.v,l)),!h){v(\"current path\")&&y.push(x.getPath(t.data));var b=0;v(\"percent parent\")&&b++,v(\"percent entry\")&&b++,v(\"percent root\")&&b++;var _=b>1;if(b){var w,T=function(t){g=x.formatPercent(w,l),_&&(g+=\" of \"+t),y.push(g)};v(\"percent parent\")&&!h&&(w=d/x.getValue(p),T(\"parent\")),v(\"percent entry\")&&(w=d/x.getValue(e),T(\"entry\")),v(\"percent root\")&&(w=d/x.getValue(f),T(\"root\"))}}return v(\"text\")&&(g=o.castOption(r,u.i,\"text\"),o.isValidTextValue(g)&&y.push(g)),y.join(\"<br>\")}var k=o.castOption(r,u.i,\"texttemplate\");if(!k)return\"\";var M={};u.label&&(M.label=u.label),u.hasOwnProperty(\"v\")&&(M.value=u.v,M.valueLabel=x.formatValue(u.v,l)),M.currentPath=x.getPath(t.data),h||(M.percentParent=d/x.getValue(p),M.percentParentLabel=x.formatPercent(M.percentParent,l),M.parent=x.getPtLabel(p)),M.percentEntry=d/x.getValue(e),M.percentEntryLabel=x.formatPercent(M.percentEntry,l),M.entry=x.getPtLabel(e),M.percentRoot=d/x.getValue(f),M.percentRootLabel=x.formatPercent(M.percentRoot,l),M.root=x.getPtLabel(f),u.hasOwnProperty(\"color\")&&(M.color=u.color);var A=o.castOption(r,u.i,\"text\");return(o.isValidTextValue(A)||\"\"===A)&&(M.text=A),M.customdata=o.castOption(r,u.i,\"customdata\"),o.texttemplateString(k,M,i._d3locale,M,r._meta||{})}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../bar/style\":935,\"../bar/uniform_text\":937,\"../pie/helpers\":1166,\"../pie/plot\":1170,\"./constants\":1302,\"./fx\":1304,\"./helpers\":1305,\"./style\":1310,d3:169,\"d3-hierarchy\":161}],1310:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../bar/uniform_text\").resizeText;function s(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){var e=t._fullLayout._sunburstlayer.selectAll(\".trace\");o(t,e,\"sunburst\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(s,t,r)}))}))},styleOne:s}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/uniform_text\":937,d3:169}],1311:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},opacityscale:{valType:\"any\",editType:\"calc\"},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":643,\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906}],1312:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1313:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-linear-interpolate\").d2,o=t(\"../heatmap/interp2d\"),s=t(\"../heatmap/find_empties\"),l=t(\"../../lib\").isArrayOrTypedArray,c=t(\"../../lib/gl_format_color\").parseColorScale,u=t(\"../../lib/str2rgbarray\"),f=t(\"../../components/colorscale\").extractOpts;function h(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var p=h.prototype;p.getXat=function(t,e,r,n){var i=l(this.data.x)?l(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},p.getYat=function(t,e,r,n){var i=l(this.data.y)?l(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},p.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},p.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var d=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function g(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<d.length;r++){var n=d[r];e.push(g(t,n))}return e}function v(t){for(var e=m(t),r=t,n=0;n<d.length;n++)if(e[n]>0){r=d[n];break}return r}function y(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<d.length;a++)i*=Math.pow(d[a],Math.max(r[a],n[a]));return i}}p.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},p.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var x=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],b=x[9],_=x[13];function w(t,e,r){var n=r[8]+r[2]*e[0]+r[5]*e[1];return t[0]=(r[6]+r[0]*e[0]+r[3]*e[1])/n,t[1]=(r[7]+r[1]*e[0]+r[4]*e[1])/n,t}function T(t,e,r){return function(t,e,r,n){for(var i=[0,0],o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++)r(i,[l,c],n),t.set(l,c,a(e,i[0],i[1]))}(t,e,w,r),t}function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}p.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=y(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<b;)r*=2;for(;r>_;)r--,r/=v(r),++r<b&&(r=_);var n=Math.round(r/t);return n>1?n:1},p.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],a=t[0].shape[1],o=0|Math.floor(t[0].shape[0]*e+1),s=0|Math.floor(t[0].shape[1]*r+1),l=1+n+1,c=1+a+1,u=i(new Float32Array(l*c),[l,c]),f=[1/e,0,0,0,1/r,0,0,0,1],h=0;h<t.length;++h){this.surface.padField(u,t[h]);var p=i(new Float32Array(o*s),[o,s]);T(p,u,f),t[h]=p}},p.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},p.update=function(t){var e,r,n,a,l=this.scene,h=l.fullSceneLayout,p=this.surface,d=c(t),g=l.dataScale,m=t.z[0].length,v=t._ylength,y=l.contourLevels;this.data=t;var x=[];for(e=0;e<3;e++)for(x[e]=[],r=0;r<m;r++)x[e][r]=[];for(r=0;r<m;r++)for(n=0;n<v;n++)x[0][r][n]=this.getXat(r,n,t.xcalendar,h.xaxis),x[1][r][n]=this.getYat(r,n,t.ycalendar,h.yaxis),x[2][r][n]=this.getZat(r,n,t.zcalendar,h.zaxis);if(t.connectgaps)for(t._emptypoints=s(x[2]),o(x[2],t._emptypoints),t._interpolatedZ=[],r=0;r<m;r++)for(t._interpolatedZ[r]=[],n=0;n<v;n++)t._interpolatedZ[r][n]=x[2][r][n];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null==(a=x[e][r][n])?x[e][r][n]=NaN:a=x[e][r][n]*=g[e];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null!=(a=x[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null!=(a=x[e][r][n])&&(x[e][r][n]-=this.objectOffset[e]);var b=[i(new Float32Array(m*v),[m,v]),i(new Float32Array(m*v),[m,v]),i(new Float32Array(m*v),[m,v])];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)b[e].set(r,n,x[e][r][n]);x=[];var w={colormap:d,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacityscale:t.opacityscale,opacity:t.opacity},T=f(t);if(w.intensityBounds=[T.min,T.max],t.surfacecolor){var k=i(new Float32Array(m*v),[m,v]);for(r=0;r<m;r++)for(n=0;n<v;n++)k.set(r,n,t.surfacecolor[n][r]);b.push(k)}else w.intensityBounds[0]*=g[2],w.intensityBounds[1]*=g[2];(_<b[0].shape[0]||_<b[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(b[0].shape[0],0),this.dataScaleY=this.estimateScale(b[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(b)),t.surfacecolor&&(w.intensity=b.pop());var M=[!0,!0,!0],A=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var S=t.contours[A[e]];M[e]=S.highlight,w.showContour[e]=S.show||S.highlight,w.showContour[e]&&(w.contourProject[e]=[S.project.x,S.project.y,S.project.z],S.show?(this.showContour[e]=!0,w.levels[e]=y[e],p.highlightColor[e]=w.contourColor[e]=u(S.color),S.usecolormap?p.highlightTint[e]=w.contourTint[e]=0:p.highlightTint[e]=w.contourTint[e]=1,w.contourWidth[e]=S.width,this.contourStart[e]=S.start,this.contourEnd[e]=S.end,this.contourSize[e]=S.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),S.highlight&&(w.dynamicColor[e]=u(S.highlightcolor),w.dynamicWidth[e]=S.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(d)&&(w.vertexColor=!0),w.objectOffset=this.objectOffset,w.coords=b,p.update(w),p.visible=t.visible,p.enableDynamic=M,p.enableHighlight=M,p.snapToData=!0,\"lighting\"in t&&(p.ambientLight=t.lighting.ambient,p.diffuseLight=t.lighting.diffuse,p.specularLight=t.lighting.specular,p.roughness=t.lighting.roughness,p.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(p.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z])},p.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../heatmap/find_empties\":1071,\"../heatmap/interp2d\":1074,\"gl-surface3d\":351,ndarray:495,\"ndarray-linear-interpolate\":489}],1314:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var i=n(\"opacityscale\");\"max\"===i?e.opacityscale=[[0,.1],[1,1]]:\"min\"===i?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===i?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(0,Math.min(1,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(i)||(e.opacityscale=void 0)}function l(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports={supplyDefaults:function(t,e,r,c){var u,f;function h(r,n){return i.coerce(t,e,o,r,n)}var p=h(\"x\"),d=h(\"y\"),g=h(\"z\");if(!g||!g.length||p&&p.length<1||d&&d.length<1)e.visible=!1;else{e._xlength=Array.isArray(p)&&i.isArrayOrTypedArray(p[0])?g.length:g[0].length,e._ylength=g.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],c),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach((function(t){h(t)}));var m=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(u=0;u<3;++u){var y=\"contours.\"+v[u],x=h(y+\".show\"),b=h(y+\".highlight\");if(x||b)for(f=0;f<3;++f)h(y+\".project.\"+v[f]);x&&(h(y+\".color\"),h(y+\".width\"),h(y+\".usecolormap\")),b&&(h(y+\".highlightcolor\"),h(y+\".highlightwidth\")),h(y+\".start\"),h(y+\".end\"),h(y+\".size\")}m||(l(t,\"zmin\",\"cmin\"),l(t,\"zmax\",\"cmax\"),l(t,\"zauto\",\"cauto\")),a(t,e,c,h,{prefix:\"\",cLetter:\"c\"}),s(t,e,c,h),e._length=null}},opacityscaleDefaults:s}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1311}],1315:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1311,\"./calc\":1312,\"./convert\":1313,\"./defaults\":1314}],1316:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":626,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1317:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":865,\"./plot\":1324}],1318:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":775}],1319:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1320:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce((function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e}),0)}function f(t,e){return Object.keys(t).map((function(r){return i({},t[r],{auxiliaryBlocks:e})}))}function h(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map((function(){return c((d[0]||[\"\"]).length)}))),m=e.domain,v=Math.floor(t._fullLayout._size.w*(m.x[1]-m.x[0])),y=Math.floor(t._fullLayout._size.h*(m.y[1]-m.y[0])),x=e.header.values.length?g[0].map((function(){return e.header.height})):[n.emptyHeaderHeight],b=r.length?r[0].map((function(){return e.cells.height})):[],_=x.reduce(s,0),w=h(b,y-_+n.uplift),T=f(h(x,_),[]),k=f(w,T),M={},A=e._fullInput.columnorder.concat(p(r.map((function(t,e){return e})))),S=g.map((function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1})),E=S.reduce(s,0);S=S.map((function(t){return t/E*v}));var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:m.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-m.y[1]),size:t._fullLayout._size,width:v,maxLineWidth:C,height:y,columnOrder:A,groupHeight:y,rowBlocks:k,headerRowBlocks:T,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map((function(t){return t[0]})),gdColumnsOriginalOrder:g.map((function(t){return t[0]})),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map((function(t,e){var r=M[t];return M[t]=(r||0)+1,{key:t+\"__\"+M[t],label:t,specIndex:e,xIndex:A[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}}))};return L.columns.forEach((function(t){t.calcdata=L,t.x=u(t)})),L}},{\"../../lib/extend\":768,\"./constants\":1319,\"fast-isnumeric\":241}],1321:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map((function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}}))}},{\"../../lib/extend\":768}],1322:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort((function(t,e){return t-e})),o=i.map((function(t){return a.indexOf(t)})),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":778,\"../../plots/domain\":855,\"./attributes\":1316}],1323:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1316,\"./base_plot\":1317,\"./calc\":1318,\"./defaults\":1322,\"./plot\":1324}],1324:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").strTranslate,u=t(\"../../lib\").cancelTransition,f=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),p=t(\"../../components/color\");function d(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function m(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map((function(t){return t}))).map((function(t){return t.__data__}))}function y(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each((function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return O(e,e.length-1)+(e.length?D(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom})).attr(\"transform\",(function(t){var e=t.width+n.scrollbarWidth/2+n.scrollbarOffset;return c(e,A(t))}));var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",(function(t){return c(0,t.scrollbarState.topY||0)}));var u=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),u.attr(\"y2\",(function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2})).attr(\"stroke-opacity\",(function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4})),u.transition().delay(0).duration(0),u.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var f=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);f.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",(function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||E(e,t,null,l(s-o.barLength/2))(r)})).call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t})).on(\"drag\",E(e,t)).on(\"dragend\",(function(){}))),f.attr(\"y2\",(function(t){return t.scrollbarState.scrollableAreaHeight})),e._context.staticPlot&&(u.remove(),f.remove())}function x(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each((function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:w(r.size,n,e),color:w(r.color,n,e),family:w(r.family,n,e)};t.rowNumber=t.key,t.align=w(t.calcdata.cells.align,n,e),t.cellBorderWidth=w(t.calcdata.cells.line.width,n,e),t.font=i}))}(l),function(t){t.attr(\"width\",(function(t){return t.column.columnWidth})).attr(\"stroke-width\",(function(t){return t.cellBorderWidth})).each((function(t){var e=i.select(this);p.stroke(e,w(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),p.fill(e,w(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))}))}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",(function(){return\"auto\"})).on(\"mousedown\",(function(){i.event.stopPropagation()})),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each((function(t){o.font(i.select(this),t.font)}))}(c),b(c,e,s,t),z(l)}function b(t,e,r,a){t.text((function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var f,h,p=u?\"\":w(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":w(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:w(t.calcdata.cells.format,e,r)||null,m=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(f=_(m)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===f?_(m):f),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var v=(\" \"===n.wrapSplitCharacter?m.replace(/<a href=/gi,\"<a_href=\"):m).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?v.map((function(t){return t.replace(/<a_href=/gi,\"<a href=\")})):v;t.fragments=y.map((function(t){return{text:t,width:null}})),t.fragments.push({fragment:n.wrapSpacer,width:null}),h=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,h=m;return h})).attr(\"dy\",(function(t){return t.needsConvertToTspans?0:\"0.75em\"})).each((function(t){var o=i.select(this),l=t.wrappingNeeded?L:I;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",(function(t){return c(P(t),n.cellPad)})).attr(\"text-anchor\",(function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]}))}))}function _(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function w(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function T(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",c(e.x,r))}function k(t){return\"cells\"===t.type}function M(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce((function(t,e){return t+D(e,1/0)}),0)}function S(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=O(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),u=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l;e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===u.length&&(u[0]===i.length-1?u.unshift(u[0]-1):u.push(u[0]+1)),u[0]%2&&u.reverse(),e.each((function(t,e){t.page=u[e],t.scrollY=l})),e.attr(\"transform\",(function(t){var e=O(t.rowBlocks,t.page)-t.scrollY;return c(0,e)})),t&&(C(t,r,e,u,n.prevPages,n,0),C(t,r,e,u,n.prevPages,n,1),y(r,t))}}function E(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter((function(t){return s.key===t.key})),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var f=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return S(t,f,l),s.scrollY===u}}function C(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout((function(){var a=r.filter((function(t,e){return e===o&&n[e]!==i[e]}));x(t,e,a,r),i[o]=n[o]})))}function L(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each((function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each((function(t,r){e[r].width=this.getComputedTextLength()}));var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0})),o.selectAll(\"tspan.line\").remove(),b(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(z)}}function I(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=F(o),u=o.key-l.firstRowIndex,f=l.rows[u].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:f,p=Math.max(h,f);p-l.rows[u].rowHeight&&(l.rows[u].rowHeight=p,t.selectAll(\".\"+n.cn.columnCell).call(z),S(null,t.filter(k),0),y(r,a,!0)),s.attr(\"transform\",(function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return c(P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width),a)})),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function z(t){t.attr(\"transform\",(function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce((function(t,e){return t+D(e,1/0)}),0),r=D(F(t),t.key);return c(0,r+e)})).selectAll(\".\"+n.cn.cellRect).attr(\"height\",(function(t){return(e=F(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r}))}function O(t,e){for(var r=0,n=e-1;n>=0;n--)r+=R(t[n]);return r}function D(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function R(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function F(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map((function(e){var r=a.unwrap(e).trace;return f(t,r)})),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",(function(t){return t.width+t.size.l+t.size.r})).attr(\"height\",(function(t){return t.height+t.size.t+t.size.b})).attr(\"transform\",(function(t){return c(t.translateX,t.translateY)}));var p=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),b=p.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");if(r){var _=\"onwheel\"in document?\"wheel\":\"mousewheel\";b.on(\"mousemove\",(function(e){p.filter((function(t){return e===t})).call(y,t)})).on(_,(function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;E(t,p,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}})).call(y,t,!0)}p.attr(\"transform\",(function(t){return c(t.size.l,t.size.t)}));var w=p.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);w.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),w.attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),p.each((function(e){o.setClipUrl(i.select(this),g(t,e),t)}));var A=p.selectAll(\".\"+n.cn.yColumn).data((function(t){return t.columns}),a.keyFun);A.enter().append(\"g\").classed(n.cn.yColumn,!0),A.exit().remove(),A.attr(\"transform\",(function(t){return c(t.x,0)})),r&&A.call(i.behavior.drag().origin((function(e){return T(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,y(p.filter((function(t){return e.calcdata.key===t.key})),t),e})).on(\"drag\",(function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(A).filter((function(e){return e.calcdata.key===t.calcdata.key})).sort((function(t,e){return r(t)-r(e)})).forEach((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)})),A.filter((function(e){return t!==e})).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",(function(t){return c(t.x,0)})),e.call(u).attr(\"transform\",c(t.x,-n.uplift))})).on(\"dragend\",(function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,T(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort((function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]})),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map((function(t){return t.xIndex})))}))),A.each((function(e){o.setClipUrl(i.select(this),m(t,e),t)}));var C=A.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);C.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",(function(t){return t.key})),C.style(\"cursor\",(function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"}));var L=C.filter(M),I=C.filter(k);r&&I.call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t})).on(\"drag\",E(t,p,-1)).on(\"dragend\",(function(){}))),x(t,p,L,C),x(t,p,I,C);var P=p.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);P.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",(function(e){return g(t,e)}));var z=P.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),z.attr(\"width\",(function(t){return t.width+2*n.overdrag})).attr(\"height\",(function(t){return t.height+n.uplift})),A.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=A.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",(function(e){return m(t,e)}));var D=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);D.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),D.attr(\"width\",(function(t){return t.columnWidth+2*d(t)})).attr(\"height\",(function(t){return t.calcdata.height+2*d(t)+n.uplift})).attr(\"x\",(function(t){return-d(t)})).attr(\"y\",(function(t){return-d(t)})),S(null,I,p)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../lib/svg_text_utils\":803,\"./constants\":1319,\"./data_preparation_helper\":1320,\"./data_split_helpers\":1321,d3:169}],1325:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../pie/attributes\"),l=t(\"../sunburst/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{packing:{valType:\"enumerated\",values:[\"squarify\",\"binary\",\"dice\",\"slice\",\"slice-dice\",\"dice-slice\"],dflt:\"squarify\",editType:\"plot\"},squarifyratio:{valType:\"number\",min:1,dflt:1,editType:\"plot\"},flip:{valType:\"flaglist\",flags:[\"x\",\"y\"],dflt:\"\",editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:3,editType:\"plot\"},editType:\"calc\"},marker:u({pad:{t:{valType:\"number\",min:0,editType:\"plot\"},l:{valType:\"number\",min:0,editType:\"plot\"},r:{valType:\"number\",min:0,editType:\"plot\"},b:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\"},colors:l.marker.colors,depthfade:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],editType:\"style\"},line:l.marker.line,editType:\"calc\"},a(\"marker\",{colorAttr:\"colors\",anim:!1})),pathbar:{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},edgeshape:{valType:\"enumerated\",values:[\">\",\"<\",\"|\",\"/\",\"\\\\\"],dflt:\">\",editType:\"plot\"},thickness:{valType:\"number\",min:12,editType:\"plot\"},textfont:u({},s.textfont,{}),editType:\"calc\"},text:s.text,textinfo:l.textinfo,texttemplate:i({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:c.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:u({},s.outsidetextfont,{}),textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"top left\",editType:\"plot\"},sort:s.sort,root:l.root,domain:o({name:\"treemap\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161,\"../sunburst/attributes\":1299,\"./constants\":1328}],1326:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"treemap\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1327:[function(t,e,r){\"use strict\";var n=t(\"../sunburst/calc\");r.calc=function(t,e){return n.calc(t,e)},r.crossTraceCalc=function(t){return n._runCrossTraceCalc(\"treemap\",t)}},{\"../sunburst/calc\":1301}],1328:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"poly\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"],gapWithPathbar:1}},{}],1329:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText,l=t(\"../bar/constants\").TEXTPAD,c=t(\"../../components/colorscale\"),u=c.hasColorscale,f=c.handleDefaults;e.exports=function(t,e,r,c){function h(r,a){return n.coerce(t,e,i,r,a)}var p=h(\"labels\"),d=h(\"parents\");if(p&&p.length&&d&&d.length){var g=h(\"values\");g&&g.length?h(\"branchvalues\"):h(\"count\"),h(\"level\"),h(\"maxdepth\"),\"squarify\"===h(\"tiling.packing\")&&h(\"tiling.squarifyratio\"),h(\"tiling.flip\"),h(\"tiling.pad\");var m=h(\"text\");h(\"texttemplate\"),e.texttemplate||h(\"textinfo\",Array.isArray(m)?\"text+label\":\"label\"),h(\"hovertext\"),h(\"hovertemplate\");var v=h(\"pathbar.visible\");s(t,e,c,h,\"auto\",{hasPathbar:v,moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),h(\"textposition\");var y=-1!==e.textposition.indexOf(\"bottom\");h(\"marker.line.width\")&&h(\"marker.line.color\",c.paper_bgcolor);var x=h(\"marker.colors\"),b=e._hasColorscale=u(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;b?f(t,e,c,h,{prefix:\"marker.\",cLetter:\"c\"}):h(\"marker.depthfade\",!(x||[]).length);var _=2*e.textfont.size;h(\"marker.pad.t\",y?_/4:_),h(\"marker.pad.l\",_/4),h(\"marker.pad.r\",_/4),h(\"marker.pad.b\",y?_:_/4),b&&f(t,e,c,h,{prefix:\"marker.\",cLetter:\"c\"}),e._hovered={marker:{line:{width:2,color:a.contrast(c.paper_bgcolor)}}},v&&(h(\"pathbar.thickness\",e.pathbar.textfont.size+2*l),h(\"pathbar.side\"),h(\"pathbar.edgeshape\")),h(\"sort\"),h(\"root.color\"),o(e,c,h),e._length=null}else e.visible=!1}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../lib\":778,\"../../plots/domain\":855,\"../bar/constants\":923,\"../bar/defaults\":925,\"./attributes\":1325}],1330:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\");e.exports=function(t,e,r,h,p){var d=p.barDifY,g=p.width,m=p.height,v=p.viewX,y=p.viewY,x=p.pathSlice,b=p.toMoveInsideSlice,_=p.strTransform,w=p.hasTransition,T=p.handleSlicesExit,k=p.makeUpdateSliceInterpolator,M=p.makeUpdateTextInterpolator,A={},S=t._fullLayout,E=e[0],C=E.trace,L=E.hierarchy,I=g/C._entryDepth,P=u.listPath(r.data,\"id\"),z=s(L.copy(),[g,m],{packing:\"dice\",pad:{inner:0,top:0,left:0,right:0,bottom:0}}).descendants();(z=z.filter((function(t){var e=P.indexOf(t.data.id);return-1!==e&&(t.x0=I*e,t.x1=I*(e+1),t.y0=d,t.y1=d+m,t.onPathbar=!0,!0)}))).reverse(),(h=h.data(z,u.getPtId)).enter().append(\"g\").classed(\"pathbar\",!0),T(h,!0,A,[g,m],x),h.order();var O=h;w&&(O=O.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:!1})}))),O.each((function(s){s._hoverX=v(s.x1-Math.min(g,m)/2),s._hoverY=y(s.y1-m/2);var h=n.select(this),p=i.ensureSingle(h,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?p.transition().attrTween(\"d\",(function(t){var e=k(t,!0,A,[g,m]);return function(t){return x(e(t))}})):p.attr(\"d\",x),h.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:t._transitioning}),p.call(l,s,C,{hovered:!1}),s._text=(u.getPtLabel(s)||\"\").split(\"<br>\").join(\" \")||\"\";var d=i.ensureSingle(h,\"g\",\"slicetext\"),T=i.ensureSingle(d,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),E=i.ensureUniformFontSize(t,u.determineTextFont(C,s,S.font,{onPathbar:!0}));T.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",\"start\").call(a.font,E).call(o.convertToTspans,t),s.textBB=a.bBox(T.node()),s.transform=b(s,{fontSize:E.size,onPathbar:!0}),s.transform.fontSize=E.size,w?T.transition().attrTween(\"transform\",(function(t){var e=M(t,!0,A,[g,m]);return function(t){return _(e(t))}})):T.attr(\"transform\",_(s))}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../sunburst/fx\":1304,\"../sunburst/helpers\":1305,\"./constants\":1328,\"./partition\":1335,\"./style\":1337,d3:169}],1331:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\"),h=t(\"../sunburst/plot\").formatSliceLabel;e.exports=function(t,e,r,p,d){var g=d.width,m=d.height,v=d.viewX,y=d.viewY,x=d.pathSlice,b=d.toMoveInsideSlice,_=d.strTransform,w=d.hasTransition,T=d.handleSlicesExit,k=d.makeUpdateSliceInterpolator,M=d.makeUpdateTextInterpolator,A=d.prevEntry,S=t._fullLayout,E=e[0].trace,C=-1!==E.textposition.indexOf(\"left\"),L=-1!==E.textposition.indexOf(\"right\"),I=-1!==E.textposition.indexOf(\"bottom\"),P=!I&&!E.marker.pad.t||I&&!E.marker.pad.b,z=s(r,[g,m],{packing:E.tiling.packing,squarifyratio:E.tiling.squarifyratio,flipX:E.tiling.flip.indexOf(\"x\")>-1,flipY:E.tiling.flip.indexOf(\"y\")>-1,pad:{inner:E.tiling.pad,top:E.marker.pad.t,left:E.marker.pad.l,right:E.marker.pad.r,bottom:E.marker.pad.b}}).descendants(),O=1/0,D=-1/0;z.forEach((function(t){var e=t.depth;e>=E._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(O=Math.min(O,e),D=Math.max(D,e))})),p=p.data(z,u.getPtId),E._maxVisibleLayers=isFinite(D)?D-O+1:0,p.enter().append(\"g\").classed(\"slice\",!0),T(p,!1,{},[g,m],x),p.order();var R=null;if(w&&A){var F=u.getPtId(A);p.each((function(t){null===R&&u.getPtId(t)===F&&(R={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})}))}var B=function(){return R||{x0:0,x1:g,y0:0,y1:m}},N=p;return w&&(N=N.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})}))),N.each((function(s){var p=u.isHeader(s,E);s._hoverX=v(s.x1-E.marker.pad.r),s._hoverY=y(I?s.y1-E.marker.pad.b/2:s.y0+E.marker.pad.t/2);var d=n.select(this),T=i.ensureSingle(d,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?T.transition().attrTween(\"d\",(function(t){var e=k(t,!1,B(),[g,m]);return function(t){return x(e(t))}})):T.attr(\"d\",x),d.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),T.call(l,s,E,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text=\"\":s._text=p?P?\"\":u.getPtLabel(s)||\"\":h(s,r,E,e,S)||\"\";var A=i.ensureSingle(d,\"g\",\"slicetext\"),z=i.ensureSingle(A,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),O=i.ensureUniformFontSize(t,u.determineTextFont(E,s,S.font));z.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",L?\"end\":C||p?\"start\":\"middle\").call(a.font,O).call(o.convertToTspans,t),s.textBB=a.bBox(z.node()),s.transform=b(s,{fontSize:O.size,isHeader:p}),s.transform.fontSize=O.size,w?z.transition().attrTween(\"transform\",(function(t){var e=M(t,!1,B(),[g,m]);return function(t){return _(e(t))}})):z.attr(\"transform\",_(s))})),R}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../sunburst/fx\":1304,\"../sunburst/helpers\":1305,\"../sunburst/plot\":1309,\"./constants\":1328,\"./partition\":1335,\"./style\":1337,d3:169}],1332:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"treemap\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1205,\"./attributes\":1325,\"./base_plot\":1326,\"./calc\":1327,\"./defaults\":1329,\"./layout_attributes\":1333,\"./layout_defaults\":1334,\"./plot\":1336,\"./style\":1337}],1333:[function(t,e,r){\"use strict\";e.exports={treemapcolorway:{valType:\"colorlist\",editType:\"calc\"},extendtreemapcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1334:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"treemapcolorway\",e.colorway),r(\"extendtreemapcolors\")}},{\"../../lib\":778,\"./layout_attributes\":1333}],1335:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\");e.exports=function(t,e,r){var i,a=r.flipX,o=r.flipY,s=\"dice-slice\"===r.packing,l=r.pad[o?\"bottom\":\"top\"],c=r.pad[a?\"right\":\"left\"],u=r.pad[a?\"left\":\"right\"],f=r.pad[o?\"top\":\"bottom\"];s&&(i=c,c=l,l=i,i=u,u=f,f=i);var h=n.treemap().tile(function(t,e){switch(t){case\"squarify\":return n.treemapSquarify.ratio(e);case\"binary\":return n.treemapBinary;case\"dice\":return n.treemapDice;case\"slice\":return n.treemapSlice;default:return n.treemapSliceDice}}(r.packing,r.squarifyratio)).paddingInner(r.pad.inner).paddingLeft(c).paddingRight(u).paddingTop(l).paddingBottom(f).size(s?[e[1],e[0]]:e)(t);return(s||a||o)&&function t(e,r,n){var i;n.swapXY&&(i=e.x0,e.x0=e.y0,e.y0=i,i=e.x1,e.x1=e.y1,e.y1=i);n.flipX&&(i=e.x0,e.x0=r[0]-e.x1,e.x1=r[0]-i);n.flipY&&(i=e.y0,e.y0=r[1]-e.y1,e.y1=r[1]-i);var a=e.children;if(a)for(var o=0;o<a.length;o++)t(a[o],r,n)}(h,e,{swapXY:s,flipX:a,flipY:o}),h}},{\"d3-hierarchy\":161}],1336:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../sunburst/helpers\"),a=t(\"../../lib\"),o=t(\"../bar/constants\").TEXTPAD,s=t(\"../bar/plot\").toMoveInsideBar,l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,f=t(\"../bar/style\").resizeText,h=t(\"./constants\"),p=t(\"./draw_descendants\"),d=t(\"./draw_ancestors\");function g(t){return i.isHierarchyRoot(t)?\"\":i.getPtId(t)}function m(t,e,r,l){var u=t._fullLayout,f=e[0],m=f.trace,v=f.hierarchy,y=i.findEntryWithLevel(v,m.level),x=n.select(r),b=x.selectAll(\"g.pathbar\"),_=x.selectAll(\"g.slice\");if(!y)return b.remove(),void _.remove();var w=i.isHierarchyRoot(y),T=!u.uniformtext.mode&&i.hasTransition(l),k=i.getMaxDepth(m),M=u._size,A=m.domain,S=M.w*(A.x[1]-A.x[0]),E=M.h*(A.y[1]-A.y[0]),C=S,L=m.pathbar.thickness,I=m.marker.line.width+h.gapWithPathbar,P=m.pathbar.visible?m.pathbar.side.indexOf(\"bottom\")>-1?E+I:-(L+I):0,z={x0:C,x1:C,y0:P,y1:P+L},O=function(t,e,r){var n=m.tiling.pad,i=function(t){return t-n<=e.x0},a=function(t){return t+n>=e.x1},o=function(t){return t-n<=e.y0},s=function(t){return t+n>=e.y1};return{x0:i(t.x0-n)?0:a(t.x0-n)?r[0]:t.x0,x1:i(t.x1+n)?0:a(t.x1+n)?r[0]:t.x1,y0:o(t.y0-n)?0:s(t.y0-n)?r[1]:t.y0,y1:o(t.y1+n)?0:s(t.y1+n)?r[1]:t.y1}},D=null,R={},F={},B=null,N=function(t,e){return e?R[g(t)]:F[g(t)]},j=function(t,e,r,n){if(e)return R[g(v)]||z;var i=F[m.level]||r;return function(t){return t.data.depth-y.data.depth<k}(t)?O(t,i,n):{}};f.hasMultipleRoots&&w&&k++,m._maxDepth=k,m._backgroundColor=u.paper_bgcolor,m._entryDepth=y.data.depth,m._atRootLevel=w;var U=-S/2+M.l+M.w*(A.x[1]+A.x[0])/2,V=-E/2+M.t+M.h*(1-(A.y[1]+A.y[0])/2),q=function(t){return U+t},H=function(t){return V+t},G=H(0),Y=q(0),W=function(t){return Y+t},X=function(t){return G+t};function Z(t,e){return t+\",\"+e}var J=W(0),K=function(t){t.x=Math.max(J,t.x)},Q=m.pathbar.edgeshape,$=function(t,e){var r=t.x0,n=t.x1,i=t.y0,a=t.y1,l=t.textBB,f=function(t){return-1!==m.textposition.indexOf(t)},h=f(\"bottom\"),p=f(\"top\")||e.isHeader&&!h?\"start\":h?\"end\":\"middle\",d=f(\"right\"),g=f(\"left\")||e.onPathbar?-1:d?1:0,v=m.marker.pad;if(e.isHeader){if((r+=v.l-o)>=(n-=v.r-o)){var y=(r+n)/2;r=y,n=y}var x;h?i<(x=a-v.b)&&x<a&&(i=x):i<(x=i+v.t)&&x<a&&(a=x)}var b=s(r,n,i,a,l,{isHorizontal:!1,constrained:!0,angle:0,anchor:p,leftToRight:g});return b.fontSize=e.fontSize,b.targetX=q(b.targetX),b.targetY=H(b.targetY),isNaN(b.targetX)||isNaN(b.targetY)?{}:(r!==n&&i!==a&&c(m.type,b,u),{scale:b.scale,rotate:b.rotate,textX:b.textX,textY:b.textY,anchorX:b.anchorX,anchorY:b.anchorY,targetX:b.targetX,targetY:b.targetY})},tt=function(t,e){for(var r,n=0,i=t;!r&&n<k;)n++,(i=i.parent)?r=N(i,e):n=k;return r||{}},et=function(t,e,r,i){var o,s=N(t,e);if(s)o=s;else if(e)o=z;else if(D)if(t.parent){var l=B||r;l&&!e?o=O(t,l,i):(o={},a.extendFlat(o,tt(t,e)))}else o=t;else o={};return n.interpolate(o,{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})},rt=function(t,e,r,o){var s=N(t,e),l={},f=j(t,e,r,o);a.extendFlat(l,{transform:$({x0:f.x0,x1:f.x1,y0:f.y0,y1:f.y1,textBB:t.textBB,_text:t._text},{isHeader:i.isHeader(t,m)})}),s?l=s:t.parent&&a.extendFlat(l,tt(t,e));var h=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(m.type,h,u),n.interpolate(l,{transform:{scale:h.scale,rotate:h.rotate,textX:h.textX,textY:h.textY,anchorX:h.anchorX,anchorY:h.anchorY,targetX:h.targetX,targetY:h.targetY}})},nt=function(t,e,r,i,a){var o=i[0],s=i[1];T?t.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var r=function(t,e,r,i){var a,o=N(t,e);if(e)a=z;else{var s=N(y,e);a=s?O(t,s,i):{}}return n.interpolate(o,a)}(t,e,0,[o,s]);return function(t){return a(r(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():t.exit().remove()},it=function(t){var e=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(m.type,e,u),a.getTextTransform({textX:e.textX,textY:e.textY,anchorX:e.anchorX,anchorY:e.anchorY,targetX:e.targetX,targetY:e.targetY,scale:e.scale,rotate:e.rotate})};T&&(b.each((function(t){R[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(R[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate})})),_.each((function(t){F[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(F[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate}),!D&&i.isEntry(t)&&(D=t)}))),B=p(t,e,y,_,{width:S,height:E,viewX:q,viewY:H,pathSlice:function(t){var e=q(t.x0),r=q(t.x1),n=H(t.y0),i=H(t.y1),a=r-e,o=i-n;if(!a||!o)return\"\";return\"M\"+Z(e,n+0)+\"L\"+Z(r-0,n)+\"L\"+Z(r,i-0)+\"L\"+Z(e+0,i)+\"Z\"},toMoveInsideSlice:$,prevEntry:D,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:T,strTransform:it}),m.pathbar.visible?d(t,e,y,b,{barDifY:P,width:C,height:L,viewX:W,viewY:X,pathSlice:function(t){var e=W(Math.max(Math.min(t.x0,t.x0),0)),r=W(Math.min(Math.max(t.x1,t.x1),C)),n=X(t.y0),i=X(t.y1),a=L/2,o={},s={};o.x=e,s.x=r,o.y=s.y=(n+i)/2;var l={x:e,y:n},c={x:r,y:n},u={x:r,y:i},f={x:e,y:i};return\">\"===Q?(l.x-=a,c.x-=a,u.x-=a,f.x-=a):\"/\"===Q?(u.x-=a,f.x-=a,o.x-=a/2,s.x-=a/2):\"\\\\\"===Q?(l.x-=a,c.x-=a,o.x-=a/2,s.x-=a/2):\"<\"===Q&&(o.x-=a,s.x-=a),K(l),K(f),K(o),K(c),K(u),K(s),\"M\"+Z(l.x,l.y)+\"L\"+Z(c.x,c.y)+\"L\"+Z(s.x,s.y)+\"L\"+Z(u.x,u.y)+\"L\"+Z(f.x,f.y)+\"L\"+Z(o.x,o.y)+\"Z\"},toMoveInsideSlice:$,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:T,strTransform:it}):b.remove()}e.exports=function(t,e,r,a){var o,s,l=t._fullLayout,c=l._treemaplayer,h=!r;(u(\"treemap\",l),(o=c.selectAll(\"g.trace.treemap\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"treemap\",!0),o.order(),!l.uniformtext.mode&&i.hasTransition(r))?(a&&(s=a()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){s&&s()})).each(\"interrupt\",(function(){s&&s()})).each((function(){c.selectAll(\"g.trace\").each((function(e){m(t,e,this,r)}))}))):(o.each((function(e){m(t,e,this,r)})),l.uniformtext.mode&&f(t,l._treemaplayer.selectAll(\".trace\"),\"treemap\"));h&&o.exit().remove()}},{\"../../lib\":778,\"../bar/constants\":923,\"../bar/plot\":932,\"../bar/style\":935,\"../bar/uniform_text\":937,\"../sunburst/helpers\":1305,\"./constants\":1328,\"./draw_ancestors\":1330,\"./draw_descendants\":1331,d3:169}],1337:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../sunburst/helpers\"),s=t(\"../bar/uniform_text\").resizeText;function l(t,e,r,n){var s,l,c=(n||{}).hovered,u=e.data.data,f=u.i,h=u.color,p=o.isHierarchyRoot(e),d=1;if(c)s=r._hovered.marker.line.color,l=r._hovered.marker.line.width;else if(p&&h===r.root.color)d=100,s=\"rgba(0,0,0,0)\",l=0;else if(s=a.castOption(r,f,\"marker.line.color\")||i.defaultLine,l=a.castOption(r,f,\"marker.line.width\")||0,!r._hasColorscale&&!e.onPathbar){var g=r.marker.depthfade;if(g){var m,v=i.combine(i.addOpacity(r._backgroundColor,.75),h);if(!0===g){var y=o.getMaxDepth(r);m=isFinite(y)?o.isLeaf(e)?0:r._maxVisibleLayers-(e.data.depth-r._entryDepth):e.data.height+1}else m=e.data.depth-r._entryDepth,r._atRootLevel||m++;if(m>0)for(var x=0;x<m;x++){var b=.5*x/m;h=i.combine(i.addOpacity(v,b),h)}}}t.style(\"stroke-width\",l).call(i.fill,h).call(i.stroke,s).style(\"opacity\",d)}e.exports={style:function(t){var e=t._fullLayout._treemaplayer.selectAll(\".trace\");s(t,e,\"treemap\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(l,t,r,{hovered:!1})}))}))},styleOne:l}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/uniform_text\":937,\"../sunburst/helpers\":1305,d3:169}],1338:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":768,\"../box/attributes\":946}],1339:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function f(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var h={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[f(0),f(1)]};return i.setConvert(h),h.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),f=1/0,h=-1/0,p=0,d=0,g=0;g<r.length;g++){var m=r[g],v=m.pts.map(o.extractVal),y=m.bandwidth=l(e,m,v),x=m.span=c(e,m,u,y);if(m.min===m.max&&0===y)x=m.span=[m.min,m.max],m.density=[{v:1,t:x[0]}],m.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var T=o.makeKDE(m,e,v);m.density=new Array(_);for(var k=0,M=x[0];M<x[1]+w/2;k++,M+=w){var A=T(M);m.density[k]={v:A,t:M},p=Math.max(p,A)}}d=Math.max(d,v.length),f=Math.min(f,x[0]),h=Math.max(h,x[1])}var S=i.findExtremes(u,[f,h],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../box/calc\":947,\"./helpers\":1342}],1340:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(f)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":948}],1341:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,f=l(\"span\");Array.isArray(f)&&(u=\"manual\"),l(\"spanmode\",u);var h=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),m=c(\"box.fillcolor\",d),v=c(\"box.line.color\",h),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||m||v||y))||(e.box={visible:!1});var x=c(\"meanline.color\",h),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":643,\"../../lib\":778,\"../box/defaults\":949,\"./attributes\":1338}],1342:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":778}],1343:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,f=t.cd,h=f[0].trace,p=h.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),m=[];if(d||g){var v=a.hoverOnBoxes(t,e,r,s);if(g&&v.length>0){var y,x,b,_,w,T=t.xa,k=t.ya;\"h\"===h.orientation?(w=e,y=\"y\",b=k,x=\"x\",_=T):(w=r,y=\"x\",b=T,x=\"y\",_=k);var M=f[t.index];if(w>=M.span[0]&&w<=M.span[1]){var A=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(M,h,w),C=o.getPositionOnKdePath(M,h,S),L=b._offset,I=b._length;A[y+\"0\"]=C[0],A[y+\"1\"]=C[1],A[x+\"0\"]=A[x+\"1\"]=S,A[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+f[0].t.labels.kde+\" \"+E.toFixed(3),A.spikeDistance=v[0].spikeDistance;var P=y+\"Spike\";A[P]=v[0][P],v[0].spikeDistance=void 0,v[0][P]=void 0,A.hovertemplate=!1,m.push(A),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+I),u[y+\"2\"]=n.constrain(L+C[1],L,L+I),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(m=m.concat(v))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+h.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+h.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:m:c?(m.push(c),m):m}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../box/hover\":951,\"./helpers\":1342}],1344:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../box/defaults\":949,\"../box/select\":956,\"../scatter/style\":1211,\"./attributes\":1338,\"./calc\":1339,\"./cross_trace_calc\":1340,\"./defaults\":1341,\"./hover\":1343,\"./layout_attributes\":1345,\"./layout_defaults\":1346,\"./plot\":1347,\"./style\":1348}],1345:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":778,\"../box/layout_attributes\":953}],1346:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,(function(r,a){return n.coerce(t,e,i,r,a)}),\"violin\")}},{\"../../lib\":778,\"../box/layout_defaults\":954,\"./layout_attributes\":1345}],1347:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,f=e.xaxis,h=e.yaxis;function p(t){var e=s(t,{xaxis:f,yaxis:h,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0,linearized:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each((function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,m=e[s.valLetter+\"axis\"],v=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each((function(t){var e,r,i,a,o,l,f,h,_=n.select(this),w=t.density,T=w.length,k=v.c2l(t.pos+d,!0),M=v.l2p(k);if(c.width)e=s.maxKDE/g;else{var A=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?A.maxKDE/g*(A.maxCount/t.pts.length):A.maxKDE/g}if(x){for(f=new Array(T),o=0;o<T;o++)(h=f[o]={})[s.posLetter]=k+w[o].v/e,h[s.valLetter]=m.c2l(w[o].t,!0);r=p(f)}if(b){for(f=new Array(T),l=0,o=T-1;l<T;l++,o--)(h=f[l]={})[s.posLetter]=k-w[o].v/e,h[s.valLetter]=m.c2l(w[o].t,!0);i=p(f)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[M,m.c2p(w[0].t)],E=[M,m.c2p(w[T-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=M,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)}));var w,T,k,M=c.box,A=M.width,S=(M.line||{}).width;y?(w=g*A,T=0):x?(w=[0,g*A/2],T=S*{x:1,y:-1}[s.posLetter]):(w=[g*A/2,0],T=S*{x:-1,y:1}[s.posLetter]),o.plotBoxAndWhiskers(r,{pos:v,val:m},c,{bPos:d,bdPos:w,bPosPxOffset:T}),o.plotBoxMean(r,{pos:v,val:m},c,{bPos:d,bdPos:w,bPosPxOffset:T}),!c.box.visible&&c.meanline.visible&&(k=i.identity);var E=r.selectAll(\"path.meanline\").data(k||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each((function(t){var e=m.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])})),o.plotPoints(r,{x:f,y:h},c,s)}}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../box/plot\":955,\"../scatter/line_points\":1201,\"./helpers\":1342,d3:169}],1348:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var f={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(f).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(f).call(i.stroke,c.color),a(o,r,t)}))}},{\"../../components/color\":643,\"../scatter/style\":1211,d3:169}],1349:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll,c=e.exports=l(s({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:a.opacityscale,lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../isosurface/attributes\":1123,\"../surface/attributes\":1311}],1350:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=u.prototype;f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,f=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var h=this.data.hovertext||this.data.text;return Array.isArray(h)&&void 0!==h[f]?t.textLabel=h[f]:h&&(t.textLabel=h),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=c(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"../isosurface/convert\":1125,\"gl-mesh3d\":309}],1351:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults,o=t(\"../surface/defaults\").opacityscaleDefaults;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,s,l),o(t,e,s,l)}},{\"../../lib\":778,\"../isosurface/defaults\":1126,\"../surface/defaults\":1314,\"./attributes\":1349}],1352:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"../isosurface/calc\":1124,\"./attributes\":1349,\"./convert\":1350,\"./defaults\":1351}],1353:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../components/color\");function f(t){return{marker:{color:c({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:c({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:c({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:s({editType:\"plot\"},{keys:l.eventDataKeys.concat([\"label\"])}),text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:f(),decreasing:f(),totals:f(),connector:{line:{color:c({},i.color,{dflt:u.defaultLine}),width:c({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":643,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187,\"./constants\":1355}],1354:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"../../lib\").mergeArray,o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return\"a\"===t||\"absolute\"===t}function c(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,u,f,h,p=n.getFromId(t,e.xaxis||\"x\"),d=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=p.makeCalcdata(e,\"x\"),f=d.makeCalcdata(e,\"y\"),u=i(e,d,\"y\",f),h=!!e.yperiodalignment):(r=d.makeCalcdata(e,\"y\"),f=p.makeCalcdata(e,\"x\"),u=i(e,p,\"x\",f),h=!!e.xperiodalignment);for(var g,m=Math.min(u.length,r.length),v=new Array(m),y=0,x=!1,b=0;b<m;b++){var _=r[b]||0,w=!1;(r[b]!==s||c(e.measure[b])||l(e.measure[b]))&&b+1<m&&(r[b+1]!==s||c(e.measure[b+1])||l(e.measure[b+1]))&&(w=!0);var T=v[b]={i:b,p:u[b],s:_,rawS:_,cNext:w};l(e.measure[b])?(y=T.s,T.isSum=!0,T.dir=\"totals\",T.s=y):c(e.measure[b])?(T.isSum=!0,T.dir=\"totals\",T.s=y):(T.isSum=!1,T.dir=T.rawS<0?\"decreasing\":\"increasing\",g=T.s,T.s=y+g,y+=g),\"totals\"===T.dir&&(x=!0),h&&(v[b].orig_p=f[b]),e.ids&&(T.id=String(e.ids[b])),T.v=(e.base||0)+y}return v.length&&(v[0].hasTotals=x),a(e.text,v,\"tx\"),a(e.hovertext,v,\"htx\"),o(v,e),v}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189}],1355:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1356:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],f=[],h=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?h.push(r):f.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,f,d),n(t,c,l,h,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var m=r[g];!1===m.isSum&&(m.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":924}],1357:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\"),u=t(\"../../constants/delta.js\"),f=u.INCREASING.COLOR,h=u.DECREASING.COLOR;function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",c.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,c)){s(t,e,i,c),c(\"measure\"),c(\"orientation\",e.x&&!e.y?\"h\":\"v\"),c(\"base\"),c(\"offset\"),c(\"width\"),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var u=c(\"textposition\");if(a(t,e,i,c,u,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&(c(\"texttemplate\"),e.texttemplate||c(\"textinfo\")),p(c,\"increasing\",f),p(c,\"decreasing\",h),p(c,\"totals\",\"#4499FF\"),c(\"connector.visible\"))c(\"connector.mode\"),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.waterfallmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},{\"../../components/color\":643,\"../../constants/delta.js\":747,\"../../lib\":778,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":1353}],1358:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1359:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,f=u[0].trace,h=\"h\"===f.orientation,p=h?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var m=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+m+\")\":m,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var v=d.hi||f.hoverinfo,y=[];if(v&&\"none\"!==v&&\"skip\"!==v){var x=\"all\"===v,b=v.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(h?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(f,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":643,\"../../constants/delta.js\":747,\"../../plots/cartesian/axes\":828,\"../bar/hover\":928}],1360:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/select\":933,\"./attributes\":1353,\"./calc\":1354,\"./cross_trace_calc\":1356,\"./defaults\":1357,\"./event_data\":1358,\"./hover\":1359,\"./layout_attributes\":1361,\"./layout_defaults\":1362,\"./plot\":1363,\"./style\":1364}],1361:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1362:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":778,\"./layout_attributes\":1361}],1363:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;e.exports=function(t,e,r,c){var u=t._fullLayout;l(\"waterfall\",u),s.plot(t,e,r,c,{mode:u.waterfallmode,norm:u.waterfallmode,gap:u.waterfallgap,groupgap:u.waterfallgroupgap}),function(t,e,r,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),u=r[0].trace,f=i.ensureSingle(s,\"g\",\"lines\");if(u.connector&&u.connector.visible){var h=\"h\"===u.orientation,p=u.connector.mode,d=f.selectAll(\"g.line\").data(i.identity);d.enter().append(\"g\").classed(\"line\",!0),d.exit().remove();var g=d.size();d.each((function(r,s){if(s===g-1||r.cNext){var u=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,l,c,h),f=u[0],d=u[1],m=\"\";f[0]!==o&&d[0]!==o&&f[1]!==o&&d[1]!==o&&(\"spanning\"===p&&!r.isSum&&s>0&&(m+=h?\"M\"+f[0]+\",\"+d[1]+\"V\"+d[0]:\"M\"+f[1]+\",\"+d[0]+\"H\"+f[0]),\"between\"!==p&&(r.isSum||s<g-1)&&(m+=h?\"M\"+f[1]+\",\"+d[0]+\"V\"+d[1]:\"M\"+f[0]+\",\"+d[1]+\"H\"+f[1]),f[2]!==o&&d[2]!==o&&(m+=h?\"M\"+f[1]+\",\"+d[1]+\"V\"+d[2]:\"M\"+f[1]+\",\"+d[1]+\"H\"+f[2])),\"\"===m&&(m=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,c)}},{\"../../components/drawing\":665,\"../../constants/numerical\":753,\"../../lib\":778,\"../bar/plot\":932,\"../bar/uniform_text\":937,d3:169}],1364:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l(t,s,\"waterfall\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/interactions\":752,\"../bar/style\":935,\"../bar/uniform_text\":937,d3:169}],1365:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,a=e.c2d;switch(r){case\"count\":return f;case\"first\":return h;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r+=o)}return a(r)};case\"avg\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,i++)}return i?a(r/i):s};case\"min\":return function(t,e){for(var r=1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:a(r)};case\"max\":return function(t,e){for(var r=-1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:a(r)};case\"range\":return function(t,e){for(var r=1/0,i=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),i=Math.max(i,l))}return i===-1/0||r===1/0?s:a(i-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),i=n(t[e[e.length-1]]);return r===s||i===s?s:a(i-r)};case\"median\":return function(t,e){for(var r=[],o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&r.push(l)}if(!r.length)return s;r.sort(i.sorterAsc);var c=(r.length-1)/2;return a((r[Math.floor(c)]+r[Math.ceil(c)])/2)};case\"mode\":return function(t,e){for(var r={},i=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>i&&(i=u,o=c)}}return i?a(o):s};case\"rms\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,i++)}return i?a(Math.sqrt(r/i)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var f=u-c;a+=f,o+=f*f,l++}}var h=\"sample\"===t.funcmode?l-1:l;return h?Math.sqrt((o-a*a/l)/h):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function f(t,e){return e.length}function h(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var f=o(\"groups\");if(!Array.isArray(f)){if(!u[f])return n.enabled=!1,n;u[f]=0}var h,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],h,c,t,e)}for(r=0;r<p.length;r++){h={_index:r};var m=g(\"target\"),v=g(\"func\");g(\"enabled\")&&m&&(u[m]||\"count\"===v&&void 0===u[m])?(\"stddev\"===v&&g(\"funcmode\"),u[m]=0,d[r]=h):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,f,h={},p={},d=[],g=o(e.transforms,r),m=a.length;for(e._length&&(m=Math.min(m,e._length)),s=0;s<m;s++)void 0===(c=h[l=a[s]])?(h[l]=d.length,f=[s],d.push(f),p[h[l]]=g(s)):(d[c].push(s),p[h[l]]=(p[h[l]]||[]).concat(g(s)));r._indexToPoints=p;var v=r.aggregations;for(s=0;s<v.length;s++)u(t,e,d,v[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":753,\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plots/cartesian/axes\":828,\"./helpers\":1368}],1366:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,f=i.length;e._length&&(f=Math.min(f,e._length));var h=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(h=g)}var m,v,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,f=function(r){return e(r,0,t.valuecalendar)},h=function(t){return e(t,0,r)};o(l)?s=f(a?i[0]:i):o(c)?s=a?[f(i[0]),f(i[1])]:[f(i),f(i)]:o(u)&&(s=a?i.map(f):[f(i)]);switch(n){case\"=\":return function(t){return h(t)===s};case\"!=\":return function(t){return h(t)!==s};case\"<\":return function(t){return h(t)<s};case\"<=\":return function(t){return h(t)<=s};case\">\":return function(t){return h(t)>s};case\">=\":return function(t){return h(t)>=s};case\"[]\":return function(t){var e=h(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=h(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=h(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=h(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=h(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=h(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=h(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=h(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(h(t))};case\"}{\":return function(t){return-1===s.indexOf(h(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),h),x={},b={},_=0;d?(m=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(f))},v=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(m=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},v=function(t,e){var r=x[t.astr][e];t.get().push(r)}),k(m);for(var w=o(e.transforms,r),T=0;T<f;T++){y(i[T])?(k(v,T),b[_++]=w(T)):d&&_++}r._indexToPoints=b,e._length=_}}function k(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":749,\"../lib\":778,\"../plots/cartesian/axes\":828,\"../registry\":911,\"./helpers\":1368}],1367:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,f,h,p,d,g,m=e.transform,v=e.transformIndex,y=t.transforms[v].groups,x=o(t.transforms,m);if(!n.isArrayOrTypedArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,T=i.findArrayAttributes(t),k=m.styles||[],M={};for(r=0;r<k.length;r++)M[k[r].target]=k[r].value;m.styles&&(g=n.keyedContainer(m,\"styles\",\"target\",\"value.name\"));var A={},S={};for(r=0;r<b.length;r++){A[f=b[r]]=r,S[f]=0,(h=_[r]=n.extendDeepNoArrays({},t))._group=f,h.transforms[v]._indexToPoints={};var E=null;for(g&&(E=g.get(f)),h.name=E||\"\"===E?E:n.templateString(m.nameformat,{trace:t.name,group:f}),p=h.transforms,h.transforms=[],s=0;s<p.length;s++)h.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<T.length;s++)n.nestedProperty(h,T[s]).set([])}for(l=0;l<T.length;l++){for(c=T[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[A[y[s]]].push(u[s])}for(s=0;s<w;s++){(h=_[A[y[s]]]).transforms[v]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)f=b[r],h=_[r],a.clearExpandedTraceDefaultColors(h),h=n.extendDeepNoArrays(h,M[f]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var f=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(f)?u.value=n.extendDeep({},f):f&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plots/plots\":891,\"./helpers\":1368}],1368:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1369:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction,o=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var s=n.getTargetArray(e,r);if(s){var l=r.target,c=s.length;e._length&&(c=Math.min(c,e._length));var u,f,h=e._arrayAttrs,p=function(t,e,r,n){var i,a=new Array(n),s=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:n-i};case\"descending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:i-n}}}(t,r)),i=0;i<n;i++)s[i]=a[i].i;return s}(r,s,i.getDataToCoordFunc(t,e,l,s),c),d=a(e.transforms,r),g={};for(u=0;u<h.length;u++){var m=n.nestedProperty(e,h[u]),v=m.get(),y=new Array(c);for(f=0;f<c;f++)y[f]=v[p[f]];m.set(y)}for(f=0;f<c;f++)g[f]=d(p[f]);r._indexToPoints=g,e._length=c}}}},{\"../constants/numerical\":753,\"../lib\":778,\"../plots/cartesian/axes\":828,\"./helpers\":1368}],1370:[function(t,e,r){\"use strict\";r.version=\"1.58.4\"},{}]},{},[26])(26)}));</script>                <div id=\"bd18b47f-2b25-4184-bddb-f66e8a579e70\" class=\"plotly-graph-div\" style=\"height:640px; width:780px;\"></div>            <script type=\"text/javascript\">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"bd18b47f-2b25-4184-bddb-f66e8a579e70\")) {                    Plotly.newPlot(                        \"bd18b47f-2b25-4184-bddb-f66e8a579e70\",                        [{\"colorbar\": {\"title\": {\"text\": \"B<sub>0</sub> (Hz)\"}}, \"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.3333333333333333, \"rgb(230,0,0)\"], [0.6666666666666666, \"rgb(255,210,0)\"], [1.0, \"rgb(255,255,255)\"]], \"name\": \"comparison heatmap\", \"type\": \"heatmap\", \"visible\": true, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.087803363800049, -2.426593065261841, 0.0, -7.305730819702148, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.087803363800049, -2.426593065261841, 0.0, -7.305730819702148, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.118157863616943, 5.379171848297119, 0.0, 0.0, 0.0, 0.0, -4.221061706542969, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.118157863616943, 5.379171848297119, 0.0, 0.0, 0.0, 0.0, -4.221061706542969, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.1541134119033813, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.178466558456421, 3.2448856830596924, 4.271310806274414, 0.0, 0.0, 0.0, -2.232839822769165, -2.5523955821990967, -5.618098735809326, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.1541134119033813, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.178466558456421, 3.2448856830596924, 4.271310806274414, 0.0, 0.0, 0.0, -2.232839822769165, -2.5523955821990967, -5.618098735809326, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.813726007938385, -0.17689727246761322, 0.6927670240402222, 1.7436140775680542, 5.316542148590088, 7.897139072418213, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.46684455871582, 4.886863708496094, 3.753633737564087, 4.210861682891846, 0.0, 0.0, 0.0, -3.1667065620422363, -1.8339262008666992, -2.8259544372558594, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.813726007938385, -0.17689727246761322, 0.6927670240402222, 1.7436140775680542, 5.316542148590088, 7.897139072418213, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.46684455871582, 4.886863708496094, 3.753633737564087, 4.210861682891846, 0.0, 0.0, 0.0, -3.1667065620422363, -1.8339262008666992, -2.8259544372558594, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.515247821807861, -2.7338783740997314, 0.1792370080947876, 0.0, 0.0, 4.137482166290283, 4.4371724128723145, 7.655436038970947, 4.5086469650268555, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.271899223327637, 5.6681928634643555, 6.955719947814941, 9.534122467041016, 0.0, 6.9336724281311035, 4.9867377281188965, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.913353204727173, 1.078423261642456, 3.8286988735198975, 3.1810193061828613, 3.08546781539917, 0.0, 0.0, 0.0, -4.491750717163086, -5.671358108520508, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.515247821807861, -2.7338783740997314, 0.1792370080947876, 0.0, 0.0, 4.137482166290283, 4.4371724128723145, 7.655436038970947, 4.5086469650268555, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.271899223327637, 5.6681928634643555, 6.955719947814941, 9.534122467041016, 0.0, 6.9336724281311035, 4.9867377281188965, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.913353204727173, 1.078423261642456, 3.8286988735198975, 3.1810193061828613, 3.08546781539917, 0.0, 0.0, 0.0, -4.491750717163086, -5.671358108520508, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.75396728515625, -1.177873134613037, -1.0076459646224976, 3.964960813522339, 0.0, 6.612732887268066, 2.7914798259735107, 3.3324646949768066, 5.5138630867004395, 1.1111809015274048, 0.0, 0.0, 0.0, 0.0, 0.0, 4.464354991912842, 0.0, 3.6379458904266357, 0.27234309911727905, 4.111512660980225, 3.3781204223632812, 2.8775222301483154, 1.6192835569381714, 4.602302074432373, 3.049078941345215, 4.030014514923096, 4.1661882400512695, 5.435119152069092, 5.584183692932129, 4.52610969543457, 4.537086009979248, 6.020214080810547, 8.222932815551758, 7.750077247619629, 7.253428936004639, 6.76724100112915, 0.0, 2.348599433898926, 1.271418571472168, 3.706555128097534, 5.450841426849365, 3.7940611839294434, 0.0, -2.2773256301879883, -2.553067922592163, -4.201395511627197, -7.154326438903809, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.75396728515625, -1.177873134613037, -1.0076459646224976, 3.964960813522339, 0.0, 6.612732887268066, 2.7914798259735107, 3.3324646949768066, 5.5138630867004395, 1.1111809015274048, 0.0, 0.0, 0.0, 0.0, 0.0, 4.464354991912842, 0.0, 3.6379458904266357, 0.27234309911727905, 4.111512660980225, 3.3781204223632812, 2.8775222301483154, 1.6192835569381714, 4.602302074432373, 3.049078941345215, 4.030014514923096, 4.1661882400512695, 5.435119152069092, 5.584183692932129, 4.52610969543457, 4.537086009979248, 6.020214080810547, 8.222932815551758, 7.750077247619629, 7.253428936004639, 6.76724100112915, 0.0, 2.348599433898926, 1.271418571472168, 3.706555128097534, 5.450841426849365, 3.7940611839294434, 0.0, -2.2773256301879883, -2.553067922592163, -4.201395511627197, -7.154326438903809, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.6824666857719421, 2.366633415222168, 3.4318623542785645, 2.715230703353882, 0.0, 6.901504993438721, 3.742370128631592, 2.8226654529571533, 4.67970609664917, 3.6663362979888916, 4.101497173309326, 3.986469030380249, 4.712048530578613, 4.222833633422852, 3.4023008346557617, 2.781968116760254, 2.4498443603515625, 1.5269954204559326, 0.8492919206619263, 2.020108699798584, -0.2165418565273285, 3.5225327014923096, 4.653188228607178, 4.0085296630859375, 2.6554954051971436, 1.230735182762146, 3.7132174968719482, 4.784396171569824, 2.4899792671203613, 3.691448926925659, 5.427030563354492, 3.7510263919830322, 5.674305438995361, 3.708249568939209, 5.288050174713135, 3.9039158821105957, 0.0, 2.14190936088562, 4.895648956298828, 2.592298984527588, 2.1264090538024902, -0.8986506462097168, 0.0, -4.72628927230835, 0.0, -7.208812713623047, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.6824666857719421, 2.366633415222168, 3.4318623542785645, 2.715230703353882, 0.0, 6.901504993438721, 3.742370128631592, 2.8226654529571533, 4.67970609664917, 3.6663362979888916, 4.101497173309326, 3.986469030380249, 4.712048530578613, 4.222833633422852, 3.4023008346557617, 2.781968116760254, 2.4498443603515625, 1.5269954204559326, 0.8492919206619263, 2.020108699798584, -0.2165418565273285, 3.5225327014923096, 4.653188228607178, 4.0085296630859375, 2.6554954051971436, 1.230735182762146, 3.7132174968719482, 4.784396171569824, 2.4899792671203613, 3.691448926925659, 5.427030563354492, 3.7510263919830322, 5.674305438995361, 3.708249568939209, 5.288050174713135, 3.9039158821105957, 0.0, 2.14190936088562, 4.895648956298828, 2.592298984527588, 2.1264090538024902, -0.8986506462097168, 0.0, -4.72628927230835, 0.0, -7.208812713623047, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.23615837097168, 8.097911834716797, 8.450387001037598, 6.428805828094482, 5.027717590332031, 5.302314281463623, 4.59884786605835, 3.1397433280944824, 2.9413604736328125, 2.5153238773345947, 1.6299492120742798, 2.7066874504089355, 0.6029468774795532, 0.5477772951126099, 0.5061031579971313, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.921453475952148, 5.118689060211182, 0.0, 0.0, 7.572977542877197, 4.33583402633667, 4.079188823699951, 3.686509132385254, 4.0372419357299805, 5.970881462097168, 2.9955708980560303, 4.716954708099365, 3.317302703857422, -0.10157449543476105, -2.397568941116333, -3.8005239963531494, -3.618079662322998, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.23615837097168, 8.097911834716797, 8.450387001037598, 6.428805828094482, 5.027717590332031, 5.302314281463623, 4.59884786605835, 3.1397433280944824, 2.9413604736328125, 2.5153238773345947, 1.6299492120742798, 2.7066874504089355, 0.6029468774795532, 0.5477772951126099, 0.5061031579971313, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.921453475952148, 5.118689060211182, 0.0, 0.0, 7.572977542877197, 4.33583402633667, 4.079188823699951, 3.686509132385254, 4.0372419357299805, 5.970881462097168, 2.9955708980560303, 4.716954708099365, 3.317302703857422, -0.10157449543476105, -2.397568941116333, -3.8005239963531494, -3.618079662322998, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.450107097625732, 6.001450061798096, 6.8216423988342285, 4.518215179443359, 2.6565773487091064, 6.515960216522217, 3.4778528213500977, 2.3394720554351807, 0.3176685571670532, 0.0, 2.5721049308776855, 0.0, 3.23771071434021, 0.0, 0.3755593001842499, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.8509539365768433, 2.4150185585021973, 6.252331733703613, 4.242388725280762, 0.0, 0.0, 0.43903300166130066, 2.6424007415771484, 1.9723056554794312, 2.727975845336914, 3.6854166984558105, 2.2948315143585205, 1.1024333238601685, -0.9085654616355896, 0.6910502910614014, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.450107097625732, 6.001450061798096, 6.8216423988342285, 4.518215179443359, 2.6565773487091064, 6.515960216522217, 3.4778528213500977, 2.3394720554351807, 0.3176685571670532, 0.0, 2.5721049308776855, 0.0, 3.23771071434021, 0.0, 0.3755593001842499, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.8509539365768433, 2.4150185585021973, 6.252331733703613, 4.242388725280762, 0.0, 0.0, 0.43903300166130066, 2.6424007415771484, 1.9723056554794312, 2.727975845336914, 3.6854166984558105, 2.2948315143585205, 1.1024333238601685, -0.9085654616355896, 0.6910502910614014, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.218221187591553, 3.819054365158081, 3.4230635166168213, 3.0833792686462402, 5.896530628204346, 2.2987639904022217, 3.4015414714813232, 0.4781244397163391, 1.7845089435577393, 0.15819349884986877, 3.404644012451172, 3.21274733543396, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.9507361650466919, 0.0, 0.0, 0.0, 0.06907127797603607, 0.0, -0.4818741977214813, 1.7733217477798462, 6.214347839355469, 3.588656187057495, 3.1550827026367188, 1.9782453775405884, -1.118038296699524, -0.8819698095321655, -1.6615015268325806, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.218221187591553, 3.819054365158081, 3.4230635166168213, 3.0833792686462402, 5.896530628204346, 2.2987639904022217, 3.4015414714813232, 0.4781244397163391, 1.7845089435577393, 0.15819349884986877, 3.404644012451172, 3.21274733543396, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.9507361650466919, 0.0, 0.0, 0.0, 0.06907127797603607, 0.0, -0.4818741977214813, 1.7733217477798462, 6.214347839355469, 3.588656187057495, 3.1550827026367188, 1.9782453775405884, -1.118038296699524, -0.8819698095321655, -1.6615015268325806, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.365901231765747, 5.241902828216553, 2.7731986045837402, 2.8693597316741943, 3.5435256958007812, 0.0, -0.4578680396080017, 2.993088483810425, 1.771439552307129, 0.0, 2.8766653537750244, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.4080312252044678, -3.231390953063965, 0.0, 0.0, 0.0, 3.7803142070770264, 5.631789684295654, 3.3367412090301514, 0.08667406439781189, -0.0977039784193039, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.365901231765747, 5.241902828216553, 2.7731986045837402, 2.8693597316741943, 3.5435256958007812, 0.0, -0.4578680396080017, 2.993088483810425, 1.771439552307129, 0.0, 2.8766653537750244, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.4080312252044678, -3.231390953063965, 0.0, 0.0, 0.0, 3.7803142070770264, 5.631789684295654, 3.3367412090301514, 0.08667406439781189, -0.0977039784193039, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.566048622131348, 2.570016860961914, 2.9004416465759277, 2.741471767425537, 0.9407873749732971, 0.0, 0.0, -2.230384588241577, -2.1618363857269287, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.11209547519683838, 0.0, 0.0, -2.7582058906555176, -1.5043582916259766, -0.6872574687004089, -2.5511281490325928, 0.0, -4.672908306121826, -2.917351007461548, 0.0, -2.8296782970428467, -4.351561546325684, -1.1420819759368896, -0.32447391748428345, 0.0, 0.0, 0.0, 0.0, 0.0, 0.2117660641670227, 0.04694429412484169, 0.0, 0.0, 3.8397152423858643, 2.25124192237854, 4.46915864944458, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.566048622131348, 2.570016860961914, 2.9004416465759277, 2.741471767425537, 0.9407873749732971, 0.0, 0.0, -2.230384588241577, -2.1618363857269287, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.11209547519683838, 0.0, 0.0, -2.7582058906555176, -1.5043582916259766, -0.6872574687004089, -2.5511281490325928, 0.0, -4.672908306121826, -2.917351007461548, 0.0, -2.8296782970428467, -4.351561546325684, -1.1420819759368896, -0.32447391748428345, 0.0, 0.0, 0.0, 0.0, 0.0, 0.2117660641670227, 0.04694429412484169, 0.0, 0.0, 3.8397152423858643, 2.25124192237854, 4.46915864944458, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.25118792057037354, 1.182134985923767, 2.011335849761963, 2.2628090381622314, 5.338007926940918, 0.0, 0.0, -1.042432427406311, 0.13694451749324799, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.9811698794364929, -1.203900933265686, -2.47163462638855, -2.9546210765838623, -3.7769670486450195, -2.859713077545166, -2.807004928588867, -3.682506799697876, -2.7018165588378906, -2.711913585662842, -2.0291085243225098, -2.3588647842407227, -2.5907750129699707, -2.3628056049346924, -2.607150077819824, -1.3994051218032837, -1.6209518909454346, -1.8775886297225952, -2.3481154441833496, 0.19864170253276825, -1.3634034395217896, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.4508802890777588, 0.7414807081222534, 1.675443172454834, 1.9042314291000366, 2.704075336456299, 5.126998424530029, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.25118792057037354, 1.182134985923767, 2.011335849761963, 2.2628090381622314, 5.338007926940918, 0.0, 0.0, -1.042432427406311, 0.13694451749324799, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.9811698794364929, -1.203900933265686, -2.47163462638855, -2.9546210765838623, -3.7769670486450195, -2.859713077545166, -2.807004928588867, -3.682506799697876, -2.7018165588378906, -2.711913585662842, -2.0291085243225098, -2.3588647842407227, -2.5907750129699707, -2.3628056049346924, -2.607150077819824, -1.3994051218032837, -1.6209518909454346, -1.8775886297225952, -2.3481154441833496, 0.19864170253276825, -1.3634034395217896, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.4508802890777588, 0.7414807081222534, 1.675443172454834, 1.9042314291000366, 2.704075336456299, 5.126998424530029, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.282912015914917, 0.24079088866710663, -1.7058954238891602, 2.474684715270996, -0.6081165075302124, 4.801847457885742, 4.400485992431641, 4.523233890533447, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.09441613405942917, -0.8331688642501831, -1.9918286800384521, -5.3219804763793945, -2.961595058441162, -2.0970473289489746, -4.975368022918701, -5.789515495300293, -4.471806526184082, -4.139236927032471, 0.0, -2.350062370300293, -2.199601173400879, -2.6300597190856934, -1.9626604318618774, -1.9053046703338623, -2.01043701171875, -2.152254819869995, -1.3858790397644043, -1.246295690536499, -1.2008262872695923, -1.5155861377716064, -1.7134711742401123, -1.048924207687378, -1.5741188526153564, -0.9747920632362366, -0.4000692367553711, -1.1222320795059204, 0.0, 0.0, 0.0, 0.0, 1.6937717199325562, 2.3559517860412598, 0.0, 0.9294153451919556, 2.9568021297454834, 3.351128101348877, 2.543231248855591, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.282912015914917, 0.24079088866710663, -1.7058954238891602, 2.474684715270996, -0.6081165075302124, 4.801847457885742, 4.400485992431641, 4.523233890533447, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.09441613405942917, -0.8331688642501831, -1.9918286800384521, -5.3219804763793945, -2.961595058441162, -2.0970473289489746, -4.975368022918701, -5.789515495300293, -4.471806526184082, -4.139236927032471, 0.0, -2.350062370300293, -2.199601173400879, -2.6300597190856934, -1.9626604318618774, -1.9053046703338623, -2.01043701171875, -2.152254819869995, -1.3858790397644043, -1.246295690536499, -1.2008262872695923, -1.5155861377716064, -1.7134711742401123, -1.048924207687378, -1.5741188526153564, -0.9747920632362366, -0.4000692367553711, -1.1222320795059204, 0.0, 0.0, 0.0, 0.0, 1.6937717199325562, 2.3559517860412598, 0.0, 0.9294153451919556, 2.9568021297454834, 3.351128101348877, 2.543231248855591, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.2657299041748047, 0.849297046661377, 1.776932954788208, 3.0243079662323, -2.1481428146362305, -2.309828758239746, -3.0366785526275635, 0.0, 2.208608388900757, 0.0, 0.0, 0.0, 0.0, -5.030198574066162, -1.1230781078338623, -1.3517181873321533, -3.728379964828491, -3.026644468307495, -5.609962463378906, -2.184431314468384, -2.7451171875, -3.5601589679718018, -5.252130508422852, -4.199349880218506, -4.943298816680908, -5.163455009460449, -4.502029895782471, -2.990770101547241, -1.2698075771331787, -2.3932948112487793, -2.199845314025879, -1.7634954452514648, -2.681936740875244, -1.6640530824661255, -1.2337310314178467, -0.9327447414398193, -1.1471034288406372, -1.05095636844635, -1.067736268043518, -0.6942733526229858, -1.1806235313415527, -0.9676800966262817, -1.5523974895477295, -1.567204475402832, -1.308290958404541, -0.9255249500274658, 0.19019196927547455, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.380799770355225, 2.2703118324279785, 2.828200340270996, 4.52553653717041, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.2657299041748047, 0.849297046661377, 1.776932954788208, 3.0243079662323, -2.1481428146362305, -2.309828758239746, -3.0366785526275635, 0.0, 2.208608388900757, 0.0, 0.0, 0.0, 0.0, -5.030198574066162, -1.1230781078338623, -1.3517181873321533, -3.728379964828491, -3.026644468307495, -5.609962463378906, -2.184431314468384, -2.7451171875, -3.5601589679718018, -5.252130508422852, -4.199349880218506, -4.943298816680908, -5.163455009460449, -4.502029895782471, -2.990770101547241, -1.2698075771331787, -2.3932948112487793, -2.199845314025879, -1.7634954452514648, -2.681936740875244, -1.6640530824661255, -1.2337310314178467, -0.9327447414398193, -1.1471034288406372, -1.05095636844635, -1.067736268043518, -0.6942733526229858, -1.1806235313415527, -0.9676800966262817, -1.5523974895477295, -1.567204475402832, -1.308290958404541, -0.9255249500274658, 0.19019196927547455, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.380799770355225, 2.2703118324279785, 2.828200340270996, 4.52553653717041, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.3773467540740967, 1.5754276514053345, -0.059035852551460266, 0.09439502656459808, 0.0, -0.637557864189148, 1.9667936563491821, 0.0, 0.0, 0.0, 0.0, 0.0, -4.206582069396973, 0.0, -3.5575783252716064, -4.10037899017334, -3.524874448776245, -3.3368375301361084, -3.357998847961426, -3.8297009468078613, -3.2220821380615234, -3.5676722526550293, -1.460289478302002, -1.71517813205719, -5.456989765167236, -4.644258975982666, -4.285970687866211, -1.7088468074798584, -2.19394588470459, -1.5878121852874756, -2.0775794982910156, -1.918773889541626, -1.6530232429504395, -2.690251111984253, -1.542683482170105, -1.5400059223175049, -0.8980379104614258, -0.656095564365387, -0.8560919165611267, -1.4465466737747192, -1.3432320356369019, -1.0160433053970337, -0.6245558261871338, -0.40234410762786865, -0.7580675482749939, -0.7617490291595459, -1.3795002698898315, -0.809137761592865, -1.0399901866912842, 1.1893279552459717, 0.0, 0.0, 0.0, 4.861142158508301, 3.9841620922088623, 0.0, 4.0514984130859375, 3.4931788444519043, 2.9482955932617188, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.3773467540740967, 1.5754276514053345, -0.059035852551460266, 0.09439502656459808, 0.0, -0.637557864189148, 1.9667936563491821, 0.0, 0.0, 0.0, 0.0, 0.0, -4.206582069396973, 0.0, -3.5575783252716064, -4.10037899017334, -3.524874448776245, -3.3368375301361084, -3.357998847961426, -3.8297009468078613, -3.2220821380615234, -3.5676722526550293, -1.460289478302002, -1.71517813205719, -5.456989765167236, -4.644258975982666, -4.285970687866211, -1.7088468074798584, -2.19394588470459, -1.5878121852874756, -2.0775794982910156, -1.918773889541626, -1.6530232429504395, -2.690251111984253, -1.542683482170105, -1.5400059223175049, -0.8980379104614258, -0.656095564365387, -0.8560919165611267, -1.4465466737747192, -1.3432320356369019, -1.0160433053970337, -0.6245558261871338, -0.40234410762786865, -0.7580675482749939, -0.7617490291595459, -1.3795002698898315, -0.809137761592865, -1.0399901866912842, 1.1893279552459717, 0.0, 0.0, 0.0, 4.861142158508301, 3.9841620922088623, 0.0, 4.0514984130859375, 3.4931788444519043, 2.9482955932617188, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.4933278560638428, 0.2373627871274948, 1.6361411809921265, -0.9732471108436584, 2.736635446548462, 2.067880153656006, 1.9362637996673584, 0.0, 0.0, 0.0, 0.0, -6.398979663848877, -6.005181312561035, -3.331479787826538, -3.906270742416382, -4.413101673126221, -3.113050699234009, -3.48514461517334, -2.5811767578125, -2.61456036567688, -2.223585605621338, -2.902928590774536, -2.880607843399048, -2.9597220420837402, -2.5202860832214355, -0.7309703826904297, -0.8103417754173279, -2.258340358734131, -2.347628593444824, -1.5055701732635498, -1.2561970949172974, -1.3578382730484009, -1.495619535446167, -1.1977845430374146, -0.7001935839653015, -1.1579443216323853, -1.0232316255569458, -0.9223414659500122, -1.0239275693893433, -1.0894086360931396, -2.0576634407043457, -1.7986350059509277, -0.42574813961982727, -0.860656201839447, -0.9408626556396484, -0.8299286365509033, -1.0412403345108032, -0.45782971382141113, -1.0200965404510498, -1.258647084236145, -0.8850780725479126, 0.35376158356666565, 0.0, 0.9763133525848389, 0.0, 3.5396060943603516, 4.927621841430664, 0.0, 1.6774662733078003, 3.7065091133117676, 2.7670440673828125, 5.691627502441406, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.4933278560638428, 0.2373627871274948, 1.6361411809921265, -0.9732471108436584, 2.736635446548462, 2.067880153656006, 1.9362637996673584, 0.0, 0.0, 0.0, 0.0, -6.398979663848877, -6.005181312561035, -3.331479787826538, -3.906270742416382, -4.413101673126221, -3.113050699234009, -3.48514461517334, -2.5811767578125, -2.61456036567688, -2.223585605621338, -2.902928590774536, -2.880607843399048, -2.9597220420837402, -2.5202860832214355, -0.7309703826904297, -0.8103417754173279, -2.258340358734131, -2.347628593444824, -1.5055701732635498, -1.2561970949172974, -1.3578382730484009, -1.495619535446167, -1.1977845430374146, -0.7001935839653015, -1.1579443216323853, -1.0232316255569458, -0.9223414659500122, -1.0239275693893433, -1.0894086360931396, -2.0576634407043457, -1.7986350059509277, -0.42574813961982727, -0.860656201839447, -0.9408626556396484, -0.8299286365509033, -1.0412403345108032, -0.45782971382141113, -1.0200965404510498, -1.258647084236145, -0.8850780725479126, 0.35376158356666565, 0.0, 0.9763133525848389, 0.0, 3.5396060943603516, 4.927621841430664, 0.0, 1.6774662733078003, 3.7065091133117676, 2.7670440673828125, 5.691627502441406, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.148194670677185, -0.41068214178085327, -2.9647679328918457, -1.245980143547058, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.355095148086548, -4.975793361663818, -4.726435661315918, -4.0318145751953125, -3.410324811935425, -3.0716400146484375, -3.170644521713257, -2.3815526962280273, -2.477694034576416, -1.7822612524032593, -2.935637950897217, -2.9868316650390625, -2.518341064453125, -1.9637995958328247, -2.551755428314209, -2.5644993782043457, -2.672877550125122, -1.5441360473632812, -1.9209996461868286, -1.3111133575439453, -0.7937034368515015, -0.8880583643913269, -1.2145951986312866, -1.452574372291565, -1.5739145278930664, -1.656765341758728, -0.97435063123703, -1.2946581840515137, -0.6933057904243469, -1.4912759065628052, -2.377040386199951, -0.23554112017154694, -1.1813043355941772, 0.0768912136554718, -0.8245667219161987, -0.6541851758956909, -0.7084033489227295, -0.6124488711357117, -0.6039549112319946, -0.9802900552749634, -0.8191158771514893, -1.0134252309799194, 0.406328022480011, 0.6308944225311279, 0.0, 0.0, 4.922529220581055, 3.5824484825134277, 0.0, 2.7807934284210205, 2.85638689994812, 4.930503845214844, 4.5398759841918945, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.148194670677185, -0.41068214178085327, -2.9647679328918457, -1.245980143547058, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.355095148086548, -4.975793361663818, -4.726435661315918, -4.0318145751953125, -3.410324811935425, -3.0716400146484375, -3.170644521713257, -2.3815526962280273, -2.477694034576416, -1.7822612524032593, -2.935637950897217, -2.9868316650390625, -2.518341064453125, -1.9637995958328247, -2.551755428314209, -2.5644993782043457, -2.672877550125122, -1.5441360473632812, -1.9209996461868286, -1.3111133575439453, -0.7937034368515015, -0.8880583643913269, -1.2145951986312866, -1.452574372291565, -1.5739145278930664, -1.656765341758728, -0.97435063123703, -1.2946581840515137, -0.6933057904243469, -1.4912759065628052, -2.377040386199951, -0.23554112017154694, -1.1813043355941772, 0.0768912136554718, -0.8245667219161987, -0.6541851758956909, -0.7084033489227295, -0.6124488711357117, -0.6039549112319946, -0.9802900552749634, -0.8191158771514893, -1.0134252309799194, 0.406328022480011, 0.6308944225311279, 0.0, 0.0, 4.922529220581055, 3.5824484825134277, 0.0, 2.7807934284210205, 2.85638689994812, 4.930503845214844, 4.5398759841918945, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.7561004161834717, -0.6099308133125305, -1.113836646080017, 0.0, 2.6256983280181885, 0.7997660636901855, 0.0, 0.0, 0.0, 0.0, -4.778370380401611, -6.820331573486328, -4.88995885848999, -4.752219200134277, -4.358642101287842, -3.8864550590515137, -3.065744638442993, -3.0319900512695312, -3.2776384353637695, -2.6512348651885986, -2.857563018798828, -2.6283047199249268, -2.7295241355895996, -1.8331369161605835, -1.8811702728271484, -1.6728811264038086, -2.222323417663574, -1.318727731704712, -1.0659418106079102, -1.695866346359253, -1.499226450920105, -1.3911213874816895, -2.028995990753174, -1.3968929052352905, -1.017478585243225, -1.4101545810699463, -1.3282994031906128, -0.5529051423072815, -1.2308604717254639, -1.414504051208496, -0.8781961798667908, -0.4297832250595093, -0.22141769528388977, -1.2268877029418945, -0.02906065247952938, -0.8306405544281006, -0.31529149413108826, -0.4855138957500458, 0.2061762511730194, -1.1370060443878174, -1.0018287897109985, -0.6910718679428101, -1.4702826738357544, -1.1047600507736206, -1.4459447860717773, -0.5323565006256104, 0.0, 0.0, 0.0, 0.0, 2.0261964797973633, -0.02552853524684906, 1.9977188110351562, 4.8163981437683105, 3.4899914264678955, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.7561004161834717, -0.6099308133125305, -1.113836646080017, 0.0, 2.6256983280181885, 0.7997660636901855, 0.0, 0.0, 0.0, 0.0, -4.778370380401611, -6.820331573486328, -4.88995885848999, -4.752219200134277, -4.358642101287842, -3.8864550590515137, -3.065744638442993, -3.0319900512695312, -3.2776384353637695, -2.6512348651885986, -2.857563018798828, -2.6283047199249268, -2.7295241355895996, -1.8331369161605835, -1.8811702728271484, -1.6728811264038086, -2.222323417663574, -1.318727731704712, -1.0659418106079102, -1.695866346359253, -1.499226450920105, -1.3911213874816895, -2.028995990753174, -1.3968929052352905, -1.017478585243225, -1.4101545810699463, -1.3282994031906128, -0.5529051423072815, -1.2308604717254639, -1.414504051208496, -0.8781961798667908, -0.4297832250595093, -0.22141769528388977, -1.2268877029418945, -0.02906065247952938, -0.8306405544281006, -0.31529149413108826, -0.4855138957500458, 0.2061762511730194, -1.1370060443878174, -1.0018287897109985, -0.6910718679428101, -1.4702826738357544, -1.1047600507736206, -1.4459447860717773, -0.5323565006256104, 0.0, 0.0, 0.0, 0.0, 2.0261964797973633, -0.02552853524684906, 1.9977188110351562, 4.8163981437683105, 3.4899914264678955, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.4666602909564972, -0.5404475927352905, -0.12134233117103577, 0.0, 0.0, -0.3271993398666382, 0.0, 0.0, 0.0, 0.0, 0.0, -4.789229393005371, -5.193889617919922, -4.631153583526611, -4.31782341003418, -4.6352362632751465, -3.3762283325195312, -3.46404767036438, -2.2082388401031494, -2.530273199081421, -2.359023094177246, -3.332858085632324, -1.567881464958191, -2.039766311645508, -2.7909722328186035, -1.7456187009811401, -1.39030921459198, -1.5162603855133057, -1.6840399503707886, -1.0890841484069824, -2.2677435874938965, -1.8543143272399902, -1.0145472288131714, -0.9518067240715027, -0.6865171790122986, -1.5115547180175781, 0.08811233937740326, -0.9354957938194275, -0.8502369523048401, -0.6645901799201965, -1.095113754272461, -0.9400719404220581, -0.9302727580070496, -1.5347137451171875, -0.8455495834350586, -1.0594321489334106, -1.001011848449707, -0.0056409211829304695, -0.721633791923523, -0.8230020999908447, -0.9750484824180603, -0.28606241941452026, -1.0706636905670166, -0.8634374141693115, -1.4592841863632202, -0.7550901770591736, -0.9075756072998047, -0.6255465149879456, -1.134356141090393, 0.0, 0.0, 0.0, 2.2833704948425293, 0.27640992403030396, 1.0662938356399536, 3.340918779373169, 4.679320335388184, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.4666602909564972, -0.5404475927352905, -0.12134233117103577, 0.0, 0.0, -0.3271993398666382, 0.0, 0.0, 0.0, 0.0, 0.0, -4.789229393005371, -5.193889617919922, -4.631153583526611, -4.31782341003418, -4.6352362632751465, -3.3762283325195312, -3.46404767036438, -2.2082388401031494, -2.530273199081421, -2.359023094177246, -3.332858085632324, -1.567881464958191, -2.039766311645508, -2.7909722328186035, -1.7456187009811401, -1.39030921459198, -1.5162603855133057, -1.6840399503707886, -1.0890841484069824, -2.2677435874938965, -1.8543143272399902, -1.0145472288131714, -0.9518067240715027, -0.6865171790122986, -1.5115547180175781, 0.08811233937740326, -0.9354957938194275, -0.8502369523048401, -0.6645901799201965, -1.095113754272461, -0.9400719404220581, -0.9302727580070496, -1.5347137451171875, -0.8455495834350586, -1.0594321489334106, -1.001011848449707, -0.0056409211829304695, -0.721633791923523, -0.8230020999908447, -0.9750484824180603, -0.28606241941452026, -1.0706636905670166, -0.8634374141693115, -1.4592841863632202, -0.7550901770591736, -0.9075756072998047, -0.6255465149879456, -1.134356141090393, 0.0, 0.0, 0.0, 2.2833704948425293, 0.27640992403030396, 1.0662938356399536, 3.340918779373169, 4.679320335388184, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -3.389387845993042, -2.204883575439453, -2.6544454097747803, -2.5883688926696777, -5.345219612121582, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.913339614868164, -5.062413692474365, -4.8097004890441895, -4.034768581390381, -3.9249799251556396, -3.1793787479400635, -2.012622833251953, -2.908912181854248, -2.200078010559082, -2.490255355834961, -2.806285858154297, -2.352616310119629, -1.839316487312317, -2.119004726409912, -1.6391074657440186, -1.5230381488800049, -1.1615909337997437, -1.372084379196167, -0.773090660572052, -1.230244517326355, -1.2119131088256836, -1.6818374395370483, -0.6342265009880066, -1.2666285037994385, -0.9177520275115967, -0.8487218618392944, -0.9954178929328918, -1.607530951499939, -0.21321842074394226, -1.04746413230896, -1.650083303451538, -0.7089101076126099, -0.8747935891151428, -0.33634093403816223, -0.851875901222229, -1.0475788116455078, -0.08142486214637756, -0.2035766839981079, -0.9866490364074707, -0.5334559082984924, -0.37500256299972534, -1.0463510751724243, -0.7057294249534607, -0.7540704607963562, -1.4685828685760498, -1.5312182903289795, -0.5635188221931458, -0.2192997932434082, -0.5066062808036804, 1.9118107557296753, 0.0, 0.0, 0.0, 3.3434126377105713, 0.0, 2.867443799972534, 1.9779366254806519, 3.9314982891082764, 2.0471935272216797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.389387845993042, -2.204883575439453, -2.6544454097747803, -2.5883688926696777, -5.345219612121582, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.913339614868164, -5.062413692474365, -4.8097004890441895, -4.034768581390381, -3.9249799251556396, -3.1793787479400635, -2.012622833251953, -2.908912181854248, -2.200078010559082, -2.490255355834961, -2.806285858154297, -2.352616310119629, -1.839316487312317, -2.119004726409912, -1.6391074657440186, -1.5230381488800049, -1.1615909337997437, -1.372084379196167, -0.773090660572052, -1.230244517326355, -1.2119131088256836, -1.6818374395370483, -0.6342265009880066, -1.2666285037994385, -0.9177520275115967, -0.8487218618392944, -0.9954178929328918, -1.607530951499939, -0.21321842074394226, -1.04746413230896, -1.650083303451538, -0.7089101076126099, -0.8747935891151428, -0.33634093403816223, -0.851875901222229, -1.0475788116455078, -0.08142486214637756, -0.2035766839981079, -0.9866490364074707, -0.5334559082984924, -0.37500256299972534, -1.0463510751724243, -0.7057294249534607, -0.7540704607963562, -1.4685828685760498, -1.5312182903289795, -0.5635188221931458, -0.2192997932434082, -0.5066062808036804, 1.9118107557296753, 0.0, 0.0, 0.0, 3.3434126377105713, 0.0, 2.867443799972534, 1.9779366254806519, 3.9314982891082764, 2.0471935272216797, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -1.3156143426895142, -2.5988426208496094, -2.1811282634735107, 0.0, -5.453571796417236, -3.6375648975372314, 0.0, 0.0, 0.0, 0.0, 0.0, -5.6321539878845215, -5.280713081359863, -4.409215450286865, -3.9664878845214844, -3.4638373851776123, -3.565768003463745, -3.559471845626831, -2.407264232635498, -2.6634490489959717, -2.7274768352508545, -3.012730836868286, -2.6278796195983887, -1.9363359212875366, -1.9983783960342407, -2.213456392288208, -0.8237159848213196, -1.697569489479065, -1.707342267036438, -1.4083003997802734, -1.5987417697906494, -0.6340401768684387, -0.961264967918396, -0.7273479700088501, -2.0914735794067383, -0.6111298203468323, -0.8996849060058594, -0.8537337779998779, -0.3425140976905823, -0.6375919580459595, -0.3937379717826843, -0.7175227999687195, -0.0875278040766716, -1.435957670211792, -0.45993900299072266, -0.97982257604599, -0.731168270111084, -0.2138829082250595, -0.8067191243171692, -0.4883810877799988, -0.8641109466552734, -0.6609857082366943, -0.02697346918284893, -0.32494810223579407, -0.11188311129808426, -0.5936570167541504, -0.7022703886032104, -0.4715333878993988, -0.5892428159713745, -1.3720099925994873, -0.9803321361541748, -0.9067163467407227, 0.7812426090240479, 0.0, 0.0, 0.0, 0.0, 0.0, 0.9892002940177917, 3.821800947189331, 4.222301483154297, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.3156143426895142, -2.5988426208496094, -2.1811282634735107, 0.0, -5.453571796417236, -3.6375648975372314, 0.0, 0.0, 0.0, 0.0, 0.0, -5.6321539878845215, -5.280713081359863, -4.409215450286865, -3.9664878845214844, -3.4638373851776123, -3.565768003463745, -3.559471845626831, -2.407264232635498, -2.6634490489959717, -2.7274768352508545, -3.012730836868286, -2.6278796195983887, -1.9363359212875366, -1.9983783960342407, -2.213456392288208, -0.8237159848213196, -1.697569489479065, -1.707342267036438, -1.4083003997802734, -1.5987417697906494, -0.6340401768684387, -0.961264967918396, -0.7273479700088501, -2.0914735794067383, -0.6111298203468323, -0.8996849060058594, -0.8537337779998779, -0.3425140976905823, -0.6375919580459595, -0.3937379717826843, -0.7175227999687195, -0.0875278040766716, -1.435957670211792, -0.45993900299072266, -0.97982257604599, -0.731168270111084, -0.2138829082250595, -0.8067191243171692, -0.4883810877799988, -0.8641109466552734, -0.6609857082366943, -0.02697346918284893, -0.32494810223579407, -0.11188311129808426, -0.5936570167541504, -0.7022703886032104, -0.4715333878993988, -0.5892428159713745, -1.3720099925994873, -0.9803321361541748, -0.9067163467407227, 0.7812426090240479, 0.0, 0.0, 0.0, 0.0, 0.0, 0.9892002940177917, 3.821800947189331, 4.222301483154297, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -1.602412223815918, -1.491424798965454, -1.6706209182739258, 0.0, -5.455709457397461, 0.0, 0.0, 0.0, 0.0, -2.9822585582733154, -5.5527448654174805, -5.405561447143555, -4.715497970581055, -3.7335851192474365, -4.25306510925293, -3.017350435256958, -3.812385320663452, -3.23390793800354, -2.810788154602051, -2.7452049255371094, -2.616398811340332, -2.5703749656677246, -1.934294581413269, -1.4263845682144165, -2.992511749267578, -1.7261136770248413, -1.1432691812515259, -0.44373929500579834, -1.9393483400344849, -1.5255125761032104, -1.2127243280410767, -1.021433711051941, -1.168823480606079, -0.6820219159126282, -0.877955436706543, -1.133672833442688, -0.8907238245010376, -0.5953301191329956, -0.9703585505485535, -0.5659772753715515, -0.24524568021297455, 0.33677735924720764, -0.1351899802684784, -0.20890162885189056, -0.8849749565124512, -0.6506205797195435, -0.06831961870193481, 0.7788053154945374, -0.5769075751304626, -0.11436700820922852, -0.8913048505783081, -0.33933115005493164, -0.7051510214805603, -0.0019158723298460245, -0.4680160582065582, -0.9056797623634338, -0.21542388200759888, -0.8696972131729126, 0.2764061689376831, 0.201104536652565, -0.5304014086723328, -0.6358648538589478, 1.1533278226852417, -2.2955188751220703, 0.0, 0.0, 0.0, 4.683121681213379, 2.52064847946167, 3.4186694622039795, 2.86832332611084, 7.779939651489258, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.602412223815918, -1.491424798965454, -1.6706209182739258, 0.0, -5.455709457397461, 0.0, 0.0, 0.0, 0.0, -2.9822585582733154, -5.5527448654174805, -5.405561447143555, -4.715497970581055, -3.7335851192474365, -4.25306510925293, -3.017350435256958, -3.812385320663452, -3.23390793800354, -2.810788154602051, -2.7452049255371094, -2.616398811340332, -2.5703749656677246, -1.934294581413269, -1.4263845682144165, -2.992511749267578, -1.7261136770248413, -1.1432691812515259, -0.44373929500579834, -1.9393483400344849, -1.5255125761032104, -1.2127243280410767, -1.021433711051941, -1.168823480606079, -0.6820219159126282, -0.877955436706543, -1.133672833442688, -0.8907238245010376, -0.5953301191329956, -0.9703585505485535, -0.5659772753715515, -0.24524568021297455, 0.33677735924720764, -0.1351899802684784, -0.20890162885189056, -0.8849749565124512, -0.6506205797195435, -0.06831961870193481, 0.7788053154945374, -0.5769075751304626, -0.11436700820922852, -0.8913048505783081, -0.33933115005493164, -0.7051510214805603, -0.0019158723298460245, -0.4680160582065582, -0.9056797623634338, -0.21542388200759888, -0.8696972131729126, 0.2764061689376831, 0.201104536652565, -0.5304014086723328, -0.6358648538589478, 1.1533278226852417, -2.2955188751220703, 0.0, 0.0, 0.0, 4.683121681213379, 2.52064847946167, 3.4186694622039795, 2.86832332611084, 7.779939651489258, 0.0, 0.0], [0.0, 0.0, 0.0, -1.5964888334274292, -5.1398115158081055, 0.0, 0.0, -1.3283997774124146, 0.0, 0.0, 0.0, 0.0, 0.0, -4.265908718109131, -6.944316387176514, -5.677611827850342, -4.4649858474731445, -5.232649803161621, -4.136754512786865, -4.180442810058594, -2.965458869934082, -2.962423801422119, -1.6194583177566528, -1.7520986795425415, -1.9602059125900269, -2.4524261951446533, -1.3745956420898438, -1.8147969245910645, -2.047178268432617, -0.753772497177124, -0.9935222864151001, -0.9523038268089294, -1.3399451971054077, -1.5997776985168457, -1.0747663974761963, -1.020709753036499, -0.09694261848926544, -0.618770956993103, -0.8253880143165588, -1.1472430229187012, -1.7234888076782227, -0.8606019020080566, -0.8321630954742432, -1.3293826580047607, 0.05875646322965622, -1.3486634492874146, 0.07113157212734222, 0.10692910850048065, -0.43593427538871765, 0.0557035356760025, -0.48699113726615906, -0.11479050666093826, -0.3324209153652191, 0.451099157333374, -0.7431177496910095, -0.7832213044166565, -0.06325861811637878, -0.10527241230010986, -0.8784902691841125, -0.252273827791214, -0.27116528153419495, -0.4203624725341797, -0.907582700252533, -0.4142717719078064, -0.11264354735612869, -0.30113524198532104, 0.4052853286266327, -0.7106812000274658, 0.0, 0.0, 0.0, 0.0, 0.18798047304153442, 0.0, 4.4838104248046875, 5.427450656890869, 0.0, 0.0, 0.0, 0.0, 0.0, -1.5964888334274292, -5.1398115158081055, 0.0, 0.0, -1.3283997774124146, 0.0, 0.0, 0.0, 0.0, 0.0, -4.265908718109131, -6.944316387176514, -5.677611827850342, -4.4649858474731445, -5.232649803161621, -4.136754512786865, -4.180442810058594, -2.965458869934082, -2.962423801422119, -1.6194583177566528, -1.7520986795425415, -1.9602059125900269, -2.4524261951446533, -1.3745956420898438, -1.8147969245910645, -2.047178268432617, -0.753772497177124, -0.9935222864151001, -0.9523038268089294, -1.3399451971054077, -1.5997776985168457, -1.0747663974761963, -1.020709753036499, -0.09694261848926544, -0.618770956993103, -0.8253880143165588, -1.1472430229187012, -1.7234888076782227, -0.8606019020080566, -0.8321630954742432, -1.3293826580047607, 0.05875646322965622, -1.3486634492874146, 0.07113157212734222, 0.10692910850048065, -0.43593427538871765, 0.0557035356760025, -0.48699113726615906, -0.11479050666093826, -0.3324209153652191, 0.451099157333374, -0.7431177496910095, -0.7832213044166565, -0.06325861811637878, -0.10527241230010986, -0.8784902691841125, -0.252273827791214, -0.27116528153419495, -0.4203624725341797, -0.907582700252533, -0.4142717719078064, -0.11264354735612869, -0.30113524198532104, 0.4052853286266327, -0.7106812000274658, 0.0, 0.0, 0.0, 0.0, 0.18798047304153442, 0.0, 4.4838104248046875, 5.427450656890869, 0.0, 0.0], [0.0, 0.0, -0.7085674405097961, -2.623255729675293, -3.9465715885162354, 0.0, -1.32826828956604, 0.0, 0.0, 0.0, 0.0, -6.5666704177856445, -6.823080539703369, -6.010716915130615, -5.722445964813232, -5.263280391693115, -4.820990562438965, -3.6411120891571045, -3.239887237548828, -3.101736307144165, -3.212188720703125, -2.984454393386841, -3.1017234325408936, -2.48127818107605, -2.72940993309021, -1.5829393863677979, -1.367974042892456, -1.347947597503662, -2.030780076980591, -0.9853165745735168, -0.5816865563392639, -1.8946744203567505, -1.9522908926010132, -1.5936651229858398, -0.33919814229011536, -0.5930130481719971, -0.27286186814308167, -1.6786227226257324, -0.027001382783055305, -0.5962940454483032, -0.5898461937904358, -0.5125018358230591, 0.10915573686361313, -0.7693213820457458, -1.15524423122406, 0.1846119463443756, -0.8683289289474487, -0.4149746596813202, -0.5426807999610901, -0.2142152339220047, 1.0197523832321167, -0.03582724183797836, 0.5360174775123596, 0.23532895743846893, 0.08850819617509842, 0.8286341428756714, -0.6510589122772217, 0.7549813389778137, 1.8594110012054443, 0.04683011397719383, 0.23490965366363525, 0.10523075610399246, 0.6166724562644958, 0.3601284623146057, -0.08110009878873825, 0.03817359358072281, 0.157265305519104, -0.7049885392189026, -1.6459091901779175, 0.0, 0.0, 0.0, 0.0, 0.0, 5.491071701049805, 5.027410507202148, 3.3777225017547607, 0.0, 0.0, 0.0, -0.7085674405097961, -2.623255729675293, -3.9465715885162354, 0.0, -1.32826828956604, 0.0, 0.0, 0.0, 0.0, -6.5666704177856445, -6.823080539703369, -6.010716915130615, -5.722445964813232, -5.263280391693115, -4.820990562438965, -3.6411120891571045, -3.239887237548828, -3.101736307144165, -3.212188720703125, -2.984454393386841, -3.1017234325408936, -2.48127818107605, -2.72940993309021, -1.5829393863677979, -1.367974042892456, -1.347947597503662, -2.030780076980591, -0.9853165745735168, -0.5816865563392639, -1.8946744203567505, -1.9522908926010132, -1.5936651229858398, -0.33919814229011536, -0.5930130481719971, -0.27286186814308167, -1.6786227226257324, -0.027001382783055305, -0.5962940454483032, -0.5898461937904358, -0.5125018358230591, 0.10915573686361313, -0.7693213820457458, -1.15524423122406, 0.1846119463443756, -0.8683289289474487, -0.4149746596813202, -0.5426807999610901, -0.2142152339220047, 1.0197523832321167, -0.03582724183797836, 0.5360174775123596, 0.23532895743846893, 0.08850819617509842, 0.8286341428756714, -0.6510589122772217, 0.7549813389778137, 1.8594110012054443, 0.04683011397719383, 0.23490965366363525, 0.10523075610399246, 0.6166724562644958, 0.3601284623146057, -0.08110009878873825, 0.03817359358072281, 0.157265305519104, -0.7049885392189026, -1.6459091901779175, 0.0, 0.0, 0.0, 0.0, 0.0, 5.491071701049805, 5.027410507202148, 3.3777225017547607, 0.0], [0.0, -0.3749386966228485, 1.8750419616699219, 0.0, 0.0, 0.0, -2.610835313796997, 0.0, 0.0, 0.0, -5.154636859893799, -5.483408451080322, -6.22285795211792, -5.388968467712402, -5.362137794494629, -4.3919878005981445, -3.68131160736084, -3.721696138381958, -3.501919984817505, -3.5521740913391113, -2.4964065551757812, -2.8481028079986572, -2.3733749389648438, -2.6241884231567383, -2.115405559539795, -2.1530942916870117, -1.0026453733444214, -1.472469687461853, -1.0227150917053223, -1.521061897277832, -1.441460132598877, -0.2568144202232361, -0.511125385761261, -1.1650984287261963, -2.2430496215820312, -1.137756586074829, -0.43445345759391785, -0.25043484568595886, -0.7931580543518066, -0.08360597491264343, -0.10432776063680649, -1.2328720092773438, 0.10803547501564026, 0.23761942982673645, 0.16010984778404236, 0.05453857406973839, -0.19250693917274475, -0.10151026397943497, -0.14545883238315582, -0.6526802778244019, 0.5688043832778931, 0.7070325613021851, 1.2053685188293457, 0.09435929358005524, 0.17396418750286102, 0.15128007531166077, 0.7663013935089111, -0.019385959953069687, -0.21066096425056458, -0.06432905793190002, 0.35879746079444885, 0.31003135442733765, 0.3775176405906677, 0.18368735909461975, 1.1786324977874756, -0.650418758392334, -0.7581965327262878, -0.1825520247220993, -1.1986024379730225, -2.263206958770752, 0.0, 0.0, 0.0, 0.0, 0.0, 7.189102649688721, 2.829385280609131, 0.0, 0.0, -0.3749386966228485, 1.8750419616699219, 0.0, 0.0, 0.0, -2.610835313796997, 0.0, 0.0, 0.0, -5.154636859893799, -5.483408451080322, -6.22285795211792, -5.388968467712402, -5.362137794494629, -4.3919878005981445, -3.68131160736084, -3.721696138381958, -3.501919984817505, -3.5521740913391113, -2.4964065551757812, -2.8481028079986572, -2.3733749389648438, -2.6241884231567383, -2.115405559539795, -2.1530942916870117, -1.0026453733444214, -1.472469687461853, -1.0227150917053223, -1.521061897277832, -1.441460132598877, -0.2568144202232361, -0.511125385761261, -1.1650984287261963, -2.2430496215820312, -1.137756586074829, -0.43445345759391785, -0.25043484568595886, -0.7931580543518066, -0.08360597491264343, -0.10432776063680649, -1.2328720092773438, 0.10803547501564026, 0.23761942982673645, 0.16010984778404236, 0.05453857406973839, -0.19250693917274475, -0.10151026397943497, -0.14545883238315582, -0.6526802778244019, 0.5688043832778931, 0.7070325613021851, 1.2053685188293457, 0.09435929358005524, 0.17396418750286102, 0.15128007531166077, 0.7663013935089111, -0.019385959953069687, -0.21066096425056458, -0.06432905793190002, 0.35879746079444885, 0.31003135442733765, 0.3775176405906677, 0.18368735909461975, 1.1786324977874756, -0.650418758392334, -0.7581965327262878, -0.1825520247220993, -1.1986024379730225, -2.263206958770752, 0.0, 0.0, 0.0, 0.0, 0.0, 7.189102649688721, 2.829385280609131, 0.0], [0.0, -0.8181073069572449, -1.2445322275161743, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.867336750030518, -5.342780113220215, -5.438924312591553, -6.127384185791016, -4.992335796356201, -5.076482772827148, -4.670689582824707, -3.3923943042755127, -3.8820436000823975, -3.9895834922790527, -3.04011869430542, -3.0823214054107666, -1.9763842821121216, -2.7141361236572266, -2.4533815383911133, -1.4750378131866455, -1.4813368320465088, -0.7248762249946594, -1.8303180932998657, -0.6671462059020996, -1.2600457668304443, -0.8281183242797852, -0.504245936870575, -0.8016886115074158, -2.1186327934265137, 0.18071606755256653, -0.4982078969478607, -0.32498273253440857, -0.216263085603714, -0.7061777710914612, -0.001391329918988049, -0.27804335951805115, -0.21583954989910126, 0.24335719645023346, -0.007224996108561754, 0.5011060833930969, 0.15146204829216003, -0.25613343715667725, 0.27247774600982666, 0.1943989098072052, 0.19172179698944092, 0.41545695066452026, 0.23534393310546875, -0.5030390024185181, -0.3626631200313568, 0.5784996151924133, -0.08404619246721268, -0.05878576636314392, 0.20469136536121368, 1.085255742073059, 0.24316193163394928, 0.21838828921318054, -1.2623436450958252, 0.0741538554430008, 1.4333620071411133, -0.03207668289542198, -0.01707044057548046, -0.28378477692604065, -0.44394364953041077, -0.3536938428878784, 0.2090231031179428, 0.0, 0.0, 0.0, 0.0, 0.0, 4.04130744934082, 5.636340141296387, 8.324655532836914, 0.0, -0.8181073069572449, -1.2445322275161743, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.867336750030518, -5.342780113220215, -5.438924312591553, -6.127384185791016, -4.992335796356201, -5.076482772827148, -4.670689582824707, -3.3923943042755127, -3.8820436000823975, -3.9895834922790527, -3.04011869430542, -3.0823214054107666, -1.9763842821121216, -2.7141361236572266, -2.4533815383911133, -1.4750378131866455, -1.4813368320465088, -0.7248762249946594, -1.8303180932998657, -0.6671462059020996, -1.2600457668304443, -0.8281183242797852, -0.504245936870575, -0.8016886115074158, -2.1186327934265137, 0.18071606755256653, -0.4982078969478607, -0.32498273253440857, -0.216263085603714, -0.7061777710914612, -0.001391329918988049, -0.27804335951805115, -0.21583954989910126, 0.24335719645023346, -0.007224996108561754, 0.5011060833930969, 0.15146204829216003, -0.25613343715667725, 0.27247774600982666, 0.1943989098072052, 0.19172179698944092, 0.41545695066452026, 0.23534393310546875, -0.5030390024185181, -0.3626631200313568, 0.5784996151924133, -0.08404619246721268, -0.05878576636314392, 0.20469136536121368, 1.085255742073059, 0.24316193163394928, 0.21838828921318054, -1.2623436450958252, 0.0741538554430008, 1.4333620071411133, -0.03207668289542198, -0.01707044057548046, -0.28378477692604065, -0.44394364953041077, -0.3536938428878784, 0.2090231031179428, 0.0, 0.0, 0.0, 0.0, 0.0, 4.04130744934082, 5.636340141296387, 8.324655532836914], [-1.9517322778701782, -3.453021764755249, -4.0861616134643555, 0.0, 0.0, 0.0, 0.0, 0.0, -8.434080123901367, -6.107616901397705, -4.841644287109375, -5.018800735473633, -5.066346168518066, -4.977843284606934, -4.824601173400879, -4.2826995849609375, -3.5553674697875977, -3.6985528469085693, -2.711261034011841, -4.83436918258667, -2.720083713531494, -2.3273987770080566, -2.18048095703125, -1.4250236749649048, -2.369007110595703, -2.192748785018921, -1.527468204498291, -1.5651341676712036, -1.5472495555877686, -1.156072735786438, -0.025781581178307533, -1.0676226615905762, -0.6865079998970032, -1.1747692823410034, -0.1408962905406952, -0.5024664998054504, -0.5376109480857849, 0.13671092689037323, -0.7096214890480042, -0.8625864386558533, 0.2463691085577011, 0.06800968945026398, -0.040120601654052734, 0.5729148983955383, 0.3954404294490814, 0.34914496541023254, 0.347904235124588, 0.5837430953979492, 0.41583001613616943, 0.17266054451465607, -0.12966570258140564, 1.0885241031646729, 0.2670347988605499, 1.3840951919555664, 1.1719433069229126, 0.5740222334861755, -0.6048667430877686, -0.13571977615356445, 0.9068498611450195, 0.8921022415161133, -0.7522723078727722, -0.44020938873291016, 0.37332481145858765, 0.013497031293809414, 1.2285447120666504, -0.17723901569843292, 0.5773491859436035, 0.1797456443309784, 0.2944721579551697, 0.40198349952697754, -1.8468523025512695, 0.0, 0.0, 0.0, 0.0, 3.43184757232666, 4.151587963104248, 6.599128246307373, -1.9517322778701782, -3.453021764755249, -4.0861616134643555, 0.0, 0.0, 0.0, 0.0, 0.0, -8.434080123901367, -6.107616901397705, -4.841644287109375, -5.018800735473633, -5.066346168518066, -4.977843284606934, -4.824601173400879, -4.2826995849609375, -3.5553674697875977, -3.6985528469085693, -2.711261034011841, -4.83436918258667, -2.720083713531494, -2.3273987770080566, -2.18048095703125, -1.4250236749649048, -2.369007110595703, -2.192748785018921, -1.527468204498291, -1.5651341676712036, -1.5472495555877686, -1.156072735786438, -0.025781581178307533, -1.0676226615905762, -0.6865079998970032, -1.1747692823410034, -0.1408962905406952, -0.5024664998054504, -0.5376109480857849, 0.13671092689037323, -0.7096214890480042, -0.8625864386558533, 0.2463691085577011, 0.06800968945026398, -0.040120601654052734, 0.5729148983955383, 0.3954404294490814, 0.34914496541023254, 0.347904235124588, 0.5837430953979492, 0.41583001613616943, 0.17266054451465607, -0.12966570258140564, 1.0885241031646729, 0.2670347988605499, 1.3840951919555664, 1.1719433069229126, 0.5740222334861755, -0.6048667430877686, -0.13571977615356445, 0.9068498611450195, 0.8921022415161133, -0.7522723078727722, -0.44020938873291016, 0.37332481145858765, 0.013497031293809414, 1.2285447120666504, -0.17723901569843292, 0.5773491859436035, 0.1797456443309784, 0.2944721579551697, 0.40198349952697754, -1.8468523025512695, 0.0, 0.0, 0.0, 0.0, 3.43184757232666, 4.151587963104248, 6.599128246307373], [-1.8706670999526978, 0.037339381873607635, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.650053024291992, -5.533227443695068, -5.348769664764404, -5.047760009765625, -4.691861152648926, -4.912293910980225, -4.46517276763916, -4.375848293304443, -3.360968828201294, -3.012535810470581, -3.663304567337036, -2.811372756958008, -2.042789936065674, -4.53741979598999, -1.6216681003570557, -2.5028364658355713, -2.281477928161621, -1.7527180910110474, -1.674481987953186, -1.185124158859253, -0.534105658531189, -1.603920817375183, -0.9536111354827881, -1.428621768951416, -1.1073920726776123, -1.495519757270813, 0.0730867013335228, 0.5325261354446411, 0.14398357272148132, -0.197576105594635, 0.5221710205078125, -0.31973257660865784, 0.5282663702964783, 0.09767816960811615, -0.041942037642002106, -0.633895754814148, -0.08613984286785126, 1.4988292455673218, 0.28022947907447815, -0.6745419502258301, 0.3040561378002167, -0.1969282478094101, -0.15820200741291046, 1.1367204189300537, 0.1790965348482132, 0.254190057516098, 0.24403172731399536, 0.43276405334472656, 1.4894336462020874, 0.1027243509888649, 1.0634092092514038, 0.051704395562410355, 0.026499010622501373, 0.4591495394706726, 0.31423795223236084, 0.39758041501045227, 0.1488056480884552, 0.22355641424655914, 0.6668366193771362, 0.7998894453048706, 0.1503390520811081, -0.33350852131843567, 0.08444374799728394, 0.0, 0.0, 0.0, 0.0, 4.324313640594482, 5.418778419494629, 6.398793697357178, -1.8706670999526978, 0.037339381873607635, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.650053024291992, -5.533227443695068, -5.348769664764404, -5.047760009765625, -4.691861152648926, -4.912293910980225, -4.46517276763916, -4.375848293304443, -3.360968828201294, -3.012535810470581, -3.663304567337036, -2.811372756958008, -2.042789936065674, -4.53741979598999, -1.6216681003570557, -2.5028364658355713, -2.281477928161621, -1.7527180910110474, -1.674481987953186, -1.185124158859253, -0.534105658531189, -1.603920817375183, -0.9536111354827881, -1.428621768951416, -1.1073920726776123, -1.495519757270813, 0.0730867013335228, 0.5325261354446411, 0.14398357272148132, -0.197576105594635, 0.5221710205078125, -0.31973257660865784, 0.5282663702964783, 0.09767816960811615, -0.041942037642002106, -0.633895754814148, -0.08613984286785126, 1.4988292455673218, 0.28022947907447815, -0.6745419502258301, 0.3040561378002167, -0.1969282478094101, -0.15820200741291046, 1.1367204189300537, 0.1790965348482132, 0.254190057516098, 0.24403172731399536, 0.43276405334472656, 1.4894336462020874, 0.1027243509888649, 1.0634092092514038, 0.051704395562410355, 0.026499010622501373, 0.4591495394706726, 0.31423795223236084, 0.39758041501045227, 0.1488056480884552, 0.22355641424655914, 0.6668366193771362, 0.7998894453048706, 0.1503390520811081, -0.33350852131843567, 0.08444374799728394, 0.0, 0.0, 0.0, 0.0, 4.324313640594482, 5.418778419494629, 6.398793697357178], [-1.4336018562316895, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.709131717681885, -5.36865758895874, -5.457003593444824, -5.360965251922607, -4.9660539627075195, -4.542737007141113, -4.451332092285156, -3.1878297328948975, -3.7184743881225586, -3.5091278553009033, -3.7180001735687256, -2.932652711868286, -1.8714545965194702, -5.25332498550415, -2.125455856323242, -1.7121702432632446, -1.573150873184204, -1.5146405696868896, -1.2826321125030518, -1.3719944953918457, 0.20205767452716827, -0.8448318243026733, -1.449016809463501, -1.101509690284729, -0.6235929131507874, -0.5560007095336914, -0.45539626479148865, -0.9560210704803467, -0.0029743837658315897, 0.8668346405029297, 0.5721408128738403, -0.428169846534729, 0.1824267953634262, 0.9124249815940857, 0.37834447622299194, 0.39378854632377625, 0.6215669512748718, 0.2434266358613968, 0.05974392965435982, 0.35835886001586914, 0.3411635160446167, 0.466702401638031, -0.3892345428466797, 0.8310987949371338, -0.3740657567977905, 1.5622518062591553, 1.1675379276275635, 0.5089773535728455, 1.7246350049972534, 0.62620609998703, -0.25036951899528503, 0.2787986695766449, 0.34150832891464233, 0.22489550709724426, 0.328166127204895, 0.6950262784957886, 0.06704280525445938, 0.08174197375774384, 1.3196444511413574, 0.5480141043663025, -0.28265830874443054, -1.0987879037857056, -0.5365797281265259, 0.0, 0.0, 0.0, 6.890959739685059, 0.0, 0.0, 4.401675701141357, -1.4336018562316895, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.709131717681885, -5.36865758895874, -5.457003593444824, -5.360965251922607, -4.9660539627075195, -4.542737007141113, -4.451332092285156, -3.1878297328948975, -3.7184743881225586, -3.5091278553009033, -3.7180001735687256, -2.932652711868286, -1.8714545965194702, -5.25332498550415, -2.125455856323242, -1.7121702432632446, -1.573150873184204, -1.5146405696868896, -1.2826321125030518, -1.3719944953918457, 0.20205767452716827, -0.8448318243026733, -1.449016809463501, -1.101509690284729, -0.6235929131507874, -0.5560007095336914, -0.45539626479148865, -0.9560210704803467, -0.0029743837658315897, 0.8668346405029297, 0.5721408128738403, -0.428169846534729, 0.1824267953634262, 0.9124249815940857, 0.37834447622299194, 0.39378854632377625, 0.6215669512748718, 0.2434266358613968, 0.05974392965435982, 0.35835886001586914, 0.3411635160446167, 0.466702401638031, -0.3892345428466797, 0.8310987949371338, -0.3740657567977905, 1.5622518062591553, 1.1675379276275635, 0.5089773535728455, 1.7246350049972534, 0.62620609998703, -0.25036951899528503, 0.2787986695766449, 0.34150832891464233, 0.22489550709724426, 0.328166127204895, 0.6950262784957886, 0.06704280525445938, 0.08174197375774384, 1.3196444511413574, 0.5480141043663025, -0.28265830874443054, -1.0987879037857056, -0.5365797281265259, 0.0, 0.0, 0.0, 6.890959739685059, 0.0, 0.0, 4.401675701141357], [-0.7746953368186951, -1.9123414754867554, 0.0, 0.0, 0.0, 0.0, 0.0, -7.16736364364624, -5.224496364593506, -5.399454593658447, -4.90675687789917, -5.662519454956055, -4.486433506011963, -4.740433216094971, -4.162842750549316, -3.747251510620117, -3.4353690147399902, -2.7243010997772217, -2.7832117080688477, -1.7907854318618774, -2.5037970542907715, -2.336198329925537, -1.196757197380066, -1.251939058303833, -1.9195713996887207, -1.7400879859924316, -1.7318822145462036, -0.19991406798362732, -0.35936564207077026, -0.9196251630783081, -1.207441806793213, -0.9953570365905762, -0.9773752689361572, -1.125711441040039, -0.7652027010917664, -0.8046259880065918, 0.3392068147659302, 0.0, 0.2552157938480377, -0.2891070246696472, 0.518696665763855, 0.8395132422447205, 0.7997717261314392, 0.09730546921491623, 0.8245229125022888, 0.3394320607185364, 0.6951333284378052, 0.8797256350517273, 0.5363227128982544, 0.36978721618652344, 0.6626561284065247, 0.7452812194824219, -0.3447027802467346, 0.8829674124717712, 0.5562484860420227, 1.8292806148529053, 0.48565590381622314, 1.5175108909606934, 0.7799538969993591, 1.2002243995666504, 0.7503094673156738, 0.05550245940685272, 0.9297017455101013, 0.6485134363174438, 1.2817606925964355, 0.8533208966255188, 0.6698445677757263, 0.21185138821601868, 0.22040559351444244, -0.2188086211681366, -0.7049211263656616, -0.3777124583721161, 0.0, 0.0, 0.0, 0.0, 0.0, 3.4252514839172363, -0.7746953368186951, -1.9123414754867554, 0.0, 0.0, 0.0, 0.0, 0.0, -7.16736364364624, -5.224496364593506, -5.399454593658447, -4.90675687789917, -5.662519454956055, -4.486433506011963, -4.740433216094971, -4.162842750549316, -3.747251510620117, -3.4353690147399902, -2.7243010997772217, -2.7832117080688477, -1.7907854318618774, -2.5037970542907715, -2.336198329925537, -1.196757197380066, -1.251939058303833, -1.9195713996887207, -1.7400879859924316, -1.7318822145462036, -0.19991406798362732, -0.35936564207077026, -0.9196251630783081, -1.207441806793213, -0.9953570365905762, -0.9773752689361572, -1.125711441040039, -0.7652027010917664, -0.8046259880065918, 0.3392068147659302, 0.0, 0.2552157938480377, -0.2891070246696472, 0.518696665763855, 0.8395132422447205, 0.7997717261314392, 0.09730546921491623, 0.8245229125022888, 0.3394320607185364, 0.6951333284378052, 0.8797256350517273, 0.5363227128982544, 0.36978721618652344, 0.6626561284065247, 0.7452812194824219, -0.3447027802467346, 0.8829674124717712, 0.5562484860420227, 1.8292806148529053, 0.48565590381622314, 1.5175108909606934, 0.7799538969993591, 1.2002243995666504, 0.7503094673156738, 0.05550245940685272, 0.9297017455101013, 0.6485134363174438, 1.2817606925964355, 0.8533208966255188, 0.6698445677757263, 0.21185138821601868, 0.22040559351444244, -0.2188086211681366, -0.7049211263656616, -0.3777124583721161, 0.0, 0.0, 0.0, 0.0, 0.0, 3.4252514839172363], [-1.7915678024291992, 0.0, 0.0, 0.0, 0.0, 0.0, -6.970473289489746, -5.684185981750488, -5.498303413391113, -6.017238616943359, -4.378700256347656, -5.1477861404418945, -4.13691520690918, -5.004639625549316, -4.678762435913086, -4.478379249572754, -3.479818820953369, -2.4514803886413574, -3.1219186782836914, -2.9586071968078613, -2.484133243560791, -2.017815589904785, -1.3056362867355347, -2.2809128761291504, -1.0868312120437622, -1.656838059425354, -1.1558196544647217, -1.5110012292861938, -0.5673974752426147, -0.9596869945526123, -1.0013543367385864, -1.795414924621582, 0.08376121520996094, 0.20394712686538696, 0.10541718453168869, -0.1819826364517212, -0.253677636384964, 0.0, 0.0, 0.017984608188271523, 0.9084471464157104, 0.4494841992855072, 0.38296109437942505, 0.931118369102478, 0.47773295640945435, 0.5828080177307129, 0.4682008624076843, 0.4661160111427307, 0.9513016939163208, 1.9070297479629517, 0.5252062082290649, 1.147596836090088, -0.44210588932037354, 0.3296236991882324, 0.821673572063446, 0.5425638556480408, 0.7942089438438416, 0.3275623023509979, -0.6677972674369812, 0.40621262788772583, 0.16235898435115814, 0.578704833984375, 0.18970584869384766, 0.2092781960964203, 0.9095227718353271, 1.3155957460403442, 0.8644343018531799, 0.9423168897628784, 0.9837110638618469, -0.23843932151794434, -0.5524648427963257, -1.2172877788543701, 0.0, 0.0, 0.0, 3.3747894763946533, 0.0, 0.0, -1.7915678024291992, 0.0, 0.0, 0.0, 0.0, 0.0, -6.970473289489746, -5.684185981750488, -5.498303413391113, -6.017238616943359, -4.378700256347656, -5.1477861404418945, -4.13691520690918, -5.004639625549316, -4.678762435913086, -4.478379249572754, -3.479818820953369, -2.4514803886413574, -3.1219186782836914, -2.9586071968078613, -2.484133243560791, -2.017815589904785, -1.3056362867355347, -2.2809128761291504, -1.0868312120437622, -1.656838059425354, -1.1558196544647217, -1.5110012292861938, -0.5673974752426147, -0.9596869945526123, -1.0013543367385864, -1.795414924621582, 0.08376121520996094, 0.20394712686538696, 0.10541718453168869, -0.1819826364517212, -0.253677636384964, 0.0, 0.0, 0.017984608188271523, 0.9084471464157104, 0.4494841992855072, 0.38296109437942505, 0.931118369102478, 0.47773295640945435, 0.5828080177307129, 0.4682008624076843, 0.4661160111427307, 0.9513016939163208, 1.9070297479629517, 0.5252062082290649, 1.147596836090088, -0.44210588932037354, 0.3296236991882324, 0.821673572063446, 0.5425638556480408, 0.7942089438438416, 0.3275623023509979, -0.6677972674369812, 0.40621262788772583, 0.16235898435115814, 0.578704833984375, 0.18970584869384766, 0.2092781960964203, 0.9095227718353271, 1.3155957460403442, 0.8644343018531799, 0.9423168897628784, 0.9837110638618469, -0.23843932151794434, -0.5524648427963257, -1.2172877788543701, 0.0, 0.0, 0.0, 3.3747894763946533, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.587672233581543, -6.0140886306762695, -5.869172096252441, -5.786868095397949, -5.392704486846924, -4.68206787109375, -4.391471862792969, -4.467663764953613, -4.291077136993408, -3.6629602909088135, -3.779019355773926, -3.3307366371154785, -3.518083095550537, -2.2068111896514893, -2.0406107902526855, -3.061627149581909, -2.3749465942382812, -1.0613895654678345, -1.001523733139038, -1.3696974515914917, -0.9162409901618958, -0.717776894569397, 0.6513606905937195, -0.7498272657394409, -0.375429630279541, -0.7405744194984436, -0.8255608081817627, 0.3477233946323395, -0.25129368901252747, 0.30383339524269104, -0.04847409948706627, -1.6950953006744385, -1.8922401666641235, 0.3929136097431183, 0.7381153702735901, 0.7069165706634521, 0.7158766984939575, 0.28605666756629944, 0.4002402424812317, 0.47222474217414856, 0.32287487387657166, -0.311116099357605, 1.4014325141906738, 1.697609782218933, 0.8352063298225403, -0.13403914868831635, 0.4147031009197235, 0.7596524357795715, 1.0365698337554932, 0.555221676826477, 1.3444973230361938, 1.1629000902175903, 0.302508682012558, 0.09155005216598511, 0.46066349744796753, 0.5625497102737427, 0.8089673519134521, 1.0605111122131348, 2.7331013679504395, 0.7669302821159363, -0.08752834051847458, 0.5081542134284973, -0.35145434737205505, 0.584089457988739, 0.6215388178825378, -0.19309650361537933, 0.0, 0.0, 0.0, 0.0, -0.884543240070343, -0.7423288822174072, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.587672233581543, -6.0140886306762695, -5.869172096252441, -5.786868095397949, -5.392704486846924, -4.68206787109375, -4.391471862792969, -4.467663764953613, -4.291077136993408, -3.6629602909088135, -3.779019355773926, -3.3307366371154785, -3.518083095550537, -2.2068111896514893, -2.0406107902526855, -3.061627149581909, -2.3749465942382812, -1.0613895654678345, -1.001523733139038, -1.3696974515914917, -0.9162409901618958, -0.717776894569397, 0.6513606905937195, -0.7498272657394409, -0.375429630279541, -0.7405744194984436, -0.8255608081817627, 0.3477233946323395, -0.25129368901252747, 0.30383339524269104, -0.04847409948706627, -1.6950953006744385, -1.8922401666641235, 0.3929136097431183, 0.7381153702735901, 0.7069165706634521, 0.7158766984939575, 0.28605666756629944, 0.4002402424812317, 0.47222474217414856, 0.32287487387657166, -0.311116099357605, 1.4014325141906738, 1.697609782218933, 0.8352063298225403, -0.13403914868831635, 0.4147031009197235, 0.7596524357795715, 1.0365698337554932, 0.555221676826477, 1.3444973230361938, 1.1629000902175903, 0.302508682012558, 0.09155005216598511, 0.46066349744796753, 0.5625497102737427, 0.8089673519134521, 1.0605111122131348, 2.7331013679504395, 0.7669302821159363, -0.08752834051847458, 0.5081542134284973, -0.35145434737205505, 0.584089457988739, 0.6215388178825378, -0.19309650361537933, 0.0, 0.0, 0.0, 0.0, -0.884543240070343, -0.7423288822174072], [0.0, 0.0, 0.0, 0.0, 0.0, -9.093843460083008, -6.56293249130249, -5.469183921813965, -5.4423089027404785, -4.932447910308838, -5.55224084854126, -5.219784736633301, -4.204470157623291, -4.35420560836792, -3.6970393657684326, -2.7721335887908936, -3.6723601818084717, -4.394402027130127, -2.969879388809204, -2.6601004600524902, -2.1356029510498047, -1.9940251111984253, -1.3890347480773926, -1.056637167930603, -1.2547096014022827, -0.7833208441734314, -1.6975864171981812, -0.5077047944068909, -1.4540356397628784, -0.90613853931427, -1.0724010467529297, -0.40428638458251953, -0.8676313757896423, 0.3024716377258301, 0.6904838681221008, 0.07413175702095032, -0.10280746966600418, 0.34156617522239685, 0.09213021397590637, 1.2252990007400513, 0.7878484129905701, 0.7219205498695374, 0.9714041352272034, 0.5804706811904907, 0.6304260492324829, -0.27261272072792053, 0.5332486629486084, 0.9732957482337952, 0.8226322531700134, 1.4312458038330078, 0.2020762860774994, 0.0849817618727684, 1.1146330833435059, 1.1043983697891235, 1.3488175868988037, 0.9011907577514648, 3.5112550258636475, 0.6347730159759521, 0.7787281274795532, 0.12509606778621674, 0.989980161190033, 0.6827964186668396, 0.396348774433136, 0.9359567761421204, -0.700629472732544, 0.4294759929180145, 0.8322359919548035, 0.5846858620643616, 0.8114553689956665, 0.522146463394165, 0.5013302564620972, 0.21559368073940277, 0.03433685749769211, 0.0, 0.0, 0.0, 0.024741625413298607, -1.6590396165847778, 0.0, 0.0, 0.0, 0.0, 0.0, -9.093843460083008, -6.56293249130249, -5.469183921813965, -5.4423089027404785, -4.932447910308838, -5.55224084854126, -5.219784736633301, -4.204470157623291, -4.35420560836792, -3.6970393657684326, -2.7721335887908936, -3.6723601818084717, -4.394402027130127, -2.969879388809204, -2.6601004600524902, -2.1356029510498047, -1.9940251111984253, -1.3890347480773926, -1.056637167930603, -1.2547096014022827, -0.7833208441734314, -1.6975864171981812, -0.5077047944068909, -1.4540356397628784, -0.90613853931427, -1.0724010467529297, -0.40428638458251953, -0.8676313757896423, 0.3024716377258301, 0.6904838681221008, 0.07413175702095032, -0.10280746966600418, 0.34156617522239685, 0.09213021397590637, 1.2252990007400513, 0.7878484129905701, 0.7219205498695374, 0.9714041352272034, 0.5804706811904907, 0.6304260492324829, -0.27261272072792053, 0.5332486629486084, 0.9732957482337952, 0.8226322531700134, 1.4312458038330078, 0.2020762860774994, 0.0849817618727684, 1.1146330833435059, 1.1043983697891235, 1.3488175868988037, 0.9011907577514648, 3.5112550258636475, 0.6347730159759521, 0.7787281274795532, 0.12509606778621674, 0.989980161190033, 0.6827964186668396, 0.396348774433136, 0.9359567761421204, -0.700629472732544, 0.4294759929180145, 0.8322359919548035, 0.5846858620643616, 0.8114553689956665, 0.522146463394165, 0.5013302564620972, 0.21559368073940277, 0.03433685749769211, 0.0, 0.0, 0.0, 0.024741625413298607, -1.6590396165847778], [0.0, 0.0, 0.0, 0.0, 0.0, -6.713651180267334, -6.090236186981201, -5.794063568115234, -5.4882378578186035, -5.4661688804626465, -4.813931941986084, -5.043060302734375, -4.674327850341797, -3.985755443572998, -4.4765424728393555, -2.5672717094421387, -3.061910629272461, -1.599448800086975, -1.9760185480117798, -1.3663299083709717, -2.4777376651763916, -1.455073595046997, -1.1460211277008057, -0.3752368092536926, -0.11234535276889801, -0.7573027014732361, -0.7428790926933289, -1.6325016021728516, -0.7194936871528625, -0.6866827011108398, -0.19441603124141693, 0.07085695117712021, -0.9169452786445618, 0.06930505484342575, 0.004499002359807491, -0.4623786509037018, 0.1337830275297165, 0.7026223540306091, 0.7117617130279541, 0.06757235527038574, 1.1847552061080933, 1.0914334058761597, 4.04088830947876, 0.5532525777816772, 0.8879798054695129, 0.8286435008049011, 0.6646676659584045, 1.0207709074020386, 1.018826961517334, 3.4368813037872314, 0.23715662956237793, 0.6054002642631531, 1.2339881658554077, 1.2252459526062012, 1.0544931888580322, 1.4193602800369263, 0.7354294061660767, 1.947893500328064, 3.2832093238830566, 1.3498634099960327, 3.842956304550171, 0.378641813993454, 0.6076475381851196, 0.32694363594055176, 1.587677001953125, 3.127142906188965, 0.6160602569580078, 0.26943427324295044, 0.7122926712036133, 0.6927086114883423, 1.507413625717163, 0.3746066987514496, 0.2820965051651001, -0.22674661874771118, 0.0, 0.0, 0.14376920461654663, 2.083700180053711, 0.0, 0.0, 0.0, 0.0, 0.0, -6.713651180267334, -6.090236186981201, -5.794063568115234, -5.4882378578186035, -5.4661688804626465, -4.813931941986084, -5.043060302734375, -4.674327850341797, -3.985755443572998, -4.4765424728393555, -2.5672717094421387, -3.061910629272461, -1.599448800086975, -1.9760185480117798, -1.3663299083709717, -2.4777376651763916, -1.455073595046997, -1.1460211277008057, -0.3752368092536926, -0.11234535276889801, -0.7573027014732361, -0.7428790926933289, -1.6325016021728516, -0.7194936871528625, -0.6866827011108398, -0.19441603124141693, 0.07085695117712021, -0.9169452786445618, 0.06930505484342575, 0.004499002359807491, -0.4623786509037018, 0.1337830275297165, 0.7026223540306091, 0.7117617130279541, 0.06757235527038574, 1.1847552061080933, 1.0914334058761597, 4.04088830947876, 0.5532525777816772, 0.8879798054695129, 0.8286435008049011, 0.6646676659584045, 1.0207709074020386, 1.018826961517334, 3.4368813037872314, 0.23715662956237793, 0.6054002642631531, 1.2339881658554077, 1.2252459526062012, 1.0544931888580322, 1.4193602800369263, 0.7354294061660767, 1.947893500328064, 3.2832093238830566, 1.3498634099960327, 3.842956304550171, 0.378641813993454, 0.6076475381851196, 0.32694363594055176, 1.587677001953125, 3.127142906188965, 0.6160602569580078, 0.26943427324295044, 0.7122926712036133, 0.6927086114883423, 1.507413625717163, 0.3746066987514496, 0.2820965051651001, -0.22674661874771118, 0.0, 0.0, 0.14376920461654663, 2.083700180053711], [0.0, 0.0, 0.0, 0.0, -5.36279296875, -5.595897674560547, -6.28944206237793, -5.222421169281006, -5.884518146514893, -5.384179592132568, -5.348880290985107, -4.51777458190918, -3.8239285945892334, -4.131960391998291, -3.755686044692993, -3.745272636413574, -3.4862399101257324, -3.6206588745117188, -2.5957422256469727, -1.8645676374435425, -0.9307734370231628, -2.24092960357666, -1.9046374559402466, -1.9903496503829956, -0.5088614225387573, -1.2109975814819336, -1.5037282705307007, -0.19286222755908966, -0.9626877903938293, -0.2148578017950058, -0.7308087348937988, -0.8362671136856079, 1.2152519226074219, -0.3755362629890442, 0.2124253660440445, 0.02029639109969139, 1.070183515548706, 0.7324206233024597, 0.28016218543052673, 0.6398833990097046, 0.6941871643066406, -1.264148473739624, 2.098200798034668, 0.9193706512451172, 1.0720818042755127, 0.9850525856018066, 1.1750720739364624, 0.8363747000694275, 0.7175822257995605, 0.9699744582176208, 1.2829995155334473, 0.9921507835388184, 0.8491510152816772, 0.843825101852417, 0.9952144622802734, 0.9223019480705261, 1.1400264501571655, 0.9230242967605591, 0.12278064340353012, 0.361596018075943, 1.3308629989624023, -0.1309620887041092, 1.2449558973312378, 1.9655588865280151, 1.0969904661178589, 1.1075924634933472, 0.5550884008407593, 0.7542453408241272, 0.9915478825569153, 0.7520756125450134, 0.7054397463798523, 1.4076693058013916, 0.5092807412147522, 0.727946400642395, 0.0, 0.0, 2.4703640937805176, 1.1147586107254028, 0.0, 0.0, 0.0, 0.0, -5.36279296875, -5.595897674560547, -6.28944206237793, -5.222421169281006, -5.884518146514893, -5.384179592132568, -5.348880290985107, -4.51777458190918, -3.8239285945892334, -4.131960391998291, -3.755686044692993, -3.745272636413574, -3.4862399101257324, -3.6206588745117188, -2.5957422256469727, -1.8645676374435425, -0.9307734370231628, -2.24092960357666, -1.9046374559402466, -1.9903496503829956, -0.5088614225387573, -1.2109975814819336, -1.5037282705307007, -0.19286222755908966, -0.9626877903938293, -0.2148578017950058, -0.7308087348937988, -0.8362671136856079, 1.2152519226074219, -0.3755362629890442, 0.2124253660440445, 0.02029639109969139, 1.070183515548706, 0.7324206233024597, 0.28016218543052673, 0.6398833990097046, 0.6941871643066406, -1.264148473739624, 2.098200798034668, 0.9193706512451172, 1.0720818042755127, 0.9850525856018066, 1.1750720739364624, 0.8363747000694275, 0.7175822257995605, 0.9699744582176208, 1.2829995155334473, 0.9921507835388184, 0.8491510152816772, 0.843825101852417, 0.9952144622802734, 0.9223019480705261, 1.1400264501571655, 0.9230242967605591, 0.12278064340353012, 0.361596018075943, 1.3308629989624023, -0.1309620887041092, 1.2449558973312378, 1.9655588865280151, 1.0969904661178589, 1.1075924634933472, 0.5550884008407593, 0.7542453408241272, 0.9915478825569153, 0.7520756125450134, 0.7054397463798523, 1.4076693058013916, 0.5092807412147522, 0.727946400642395, 0.0, 0.0, 2.4703640937805176, 1.1147586107254028], [0.0, -10.099237442016602, 0.0, 0.0, -5.640933513641357, -5.3660783767700195, -5.398402214050293, -5.779526233673096, -6.464875221252441, -4.284679412841797, -5.7045464515686035, -4.146781921386719, -4.150189399719238, -2.3686680793762207, -4.660741806030273, -3.5211000442504883, -3.4315853118896484, -3.469731569290161, -2.4949324131011963, -2.6501779556274414, -1.7727941274642944, -1.8074185848236084, -1.725735068321228, -1.3463265895843506, -1.114119529724121, -0.5162829160690308, -0.8080576062202454, 0.03053440898656845, -0.9533723592758179, -0.48353415727615356, -0.38743093609809875, 0.2799736261367798, -0.6135854721069336, -0.7845141887664795, 0.6189231872558594, 0.3383735418319702, 0.5930721163749695, 0.018204351887106895, 1.015636920928955, 0.6360206604003906, 0.9712539315223694, 1.5706979036331177, 0.4452386498451233, 0.6972224712371826, 1.580332636833191, -0.1323648989200592, 0.4489579200744629, 2.269456624984741, 0.7839497923851013, 1.098039150238037, 1.1879768371582031, 0.1178845465183258, 1.0617905855178833, 0.997785747051239, 0.8267898559570312, 1.2707128524780273, 1.0143710374832153, 0.8299012780189514, 2.2079343795776367, 1.1043821573257446, 0.8447464108467102, 1.1735444068908691, 0.5082460641860962, 1.3823930025100708, 2.734471082687378, 0.6230410933494568, 0.6530126333236694, 1.1844234466552734, 1.4592632055282593, 0.39148885011672974, 1.8015612363815308, 0.6979727745056152, 1.3526803255081177, 0.7695941925048828, 0.09751340001821518, 0.0, 0.0, 1.2955663204193115, 0.0, -10.099237442016602, 0.0, 0.0, -5.640933513641357, -5.3660783767700195, -5.398402214050293, -5.779526233673096, -6.464875221252441, -4.284679412841797, -5.7045464515686035, -4.146781921386719, -4.150189399719238, -2.3686680793762207, -4.660741806030273, -3.5211000442504883, -3.4315853118896484, -3.469731569290161, -2.4949324131011963, -2.6501779556274414, -1.7727941274642944, -1.8074185848236084, -1.725735068321228, -1.3463265895843506, -1.114119529724121, -0.5162829160690308, -0.8080576062202454, 0.03053440898656845, -0.9533723592758179, -0.48353415727615356, -0.38743093609809875, 0.2799736261367798, -0.6135854721069336, -0.7845141887664795, 0.6189231872558594, 0.3383735418319702, 0.5930721163749695, 0.018204351887106895, 1.015636920928955, 0.6360206604003906, 0.9712539315223694, 1.5706979036331177, 0.4452386498451233, 0.6972224712371826, 1.580332636833191, -0.1323648989200592, 0.4489579200744629, 2.269456624984741, 0.7839497923851013, 1.098039150238037, 1.1879768371582031, 0.1178845465183258, 1.0617905855178833, 0.997785747051239, 0.8267898559570312, 1.2707128524780273, 1.0143710374832153, 0.8299012780189514, 2.2079343795776367, 1.1043821573257446, 0.8447464108467102, 1.1735444068908691, 0.5082460641860962, 1.3823930025100708, 2.734471082687378, 0.6230410933494568, 0.6530126333236694, 1.1844234466552734, 1.4592632055282593, 0.39148885011672974, 1.8015612363815308, 0.6979727745056152, 1.3526803255081177, 0.7695941925048828, 0.09751340001821518, 0.0, 0.0, 1.2955663204193115], [0.0, 0.0, 0.0, 0.0, -6.391586780548096, -6.047987937927246, -6.436451435089111, -5.637930393218994, -5.626845836639404, -5.039691925048828, -4.93963098526001, -5.219021797180176, -5.109745502471924, -3.910222053527832, -2.6558024883270264, -3.40096378326416, -3.5812289714813232, -2.190855026245117, -1.601893424987793, -2.966953992843628, -1.9471399784088135, -2.126295566558838, -1.611209511756897, -1.812060832977295, -0.9505360126495361, -2.7995002269744873, -0.7264481782913208, -1.2199828624725342, -0.48634466528892517, -0.43187829852104187, 0.03773622214794159, 0.37199804186820984, 0.517957866191864, -0.6094915866851807, 1.1427209377288818, 0.6973946690559387, 0.8523982763290405, 0.8380542993545532, 0.6161367893218994, 0.9753249883651733, 0.8704161643981934, 0.3608551025390625, 1.2181415557861328, 0.681982159614563, 0.9115182161331177, 2.7914671897888184, 0.808127224445343, 2.0780575275421143, 0.6208798289299011, 1.6586670875549316, 1.0616575479507446, 1.3521946668624878, 1.2199113368988037, 0.954137921333313, 1.2436535358428955, 1.1720378398895264, 0.8969622254371643, 1.5852895975112915, 0.40313059091567993, 1.8011906147003174, 0.24122735857963562, 1.230210781097412, 1.5354562997817993, 0.9411713480949402, 0.6385555267333984, 2.0811779499053955, 0.5916125178337097, 0.4580930173397064, 1.3841911554336548, 0.9835561513900757, 1.2437520027160645, 1.008934497833252, 1.457929015159607, 1.5558712482452393, 0.45655345916748047, 0.0, 0.0, 2.4582667350769043, 0.0, 0.0, 0.0, 0.0, -6.391586780548096, -6.047987937927246, -6.436451435089111, -5.637930393218994, -5.626845836639404, -5.039691925048828, -4.93963098526001, -5.219021797180176, -5.109745502471924, -3.910222053527832, -2.6558024883270264, -3.40096378326416, -3.5812289714813232, -2.190855026245117, -1.601893424987793, -2.966953992843628, -1.9471399784088135, -2.126295566558838, -1.611209511756897, -1.812060832977295, -0.9505360126495361, -2.7995002269744873, -0.7264481782913208, -1.2199828624725342, -0.48634466528892517, -0.43187829852104187, 0.03773622214794159, 0.37199804186820984, 0.517957866191864, -0.6094915866851807, 1.1427209377288818, 0.6973946690559387, 0.8523982763290405, 0.8380542993545532, 0.6161367893218994, 0.9753249883651733, 0.8704161643981934, 0.3608551025390625, 1.2181415557861328, 0.681982159614563, 0.9115182161331177, 2.7914671897888184, 0.808127224445343, 2.0780575275421143, 0.6208798289299011, 1.6586670875549316, 1.0616575479507446, 1.3521946668624878, 1.2199113368988037, 0.954137921333313, 1.2436535358428955, 1.1720378398895264, 0.8969622254371643, 1.5852895975112915, 0.40313059091567993, 1.8011906147003174, 0.24122735857963562, 1.230210781097412, 1.5354562997817993, 0.9411713480949402, 0.6385555267333984, 2.0811779499053955, 0.5916125178337097, 0.4580930173397064, 1.3841911554336548, 0.9835561513900757, 1.2437520027160645, 1.008934497833252, 1.457929015159607, 1.5558712482452393, 0.45655345916748047, 0.0, 0.0, 2.4582667350769043], [0.0, 0.0, 0.0, -9.369332313537598, -7.0643157958984375, -6.462048530578613, -5.90605354309082, -5.978270530700684, -5.79703426361084, -5.331462383270264, -5.758404731750488, -4.4429121017456055, -4.919914245605469, -4.218199729919434, -2.9317126274108887, -3.700608491897583, -2.79233980178833, -3.708822250366211, -2.895711898803711, -2.106156826019287, -2.0139851570129395, -1.820138931274414, -1.6604398488998413, -1.6855403184890747, -1.437940001487732, -1.223096489906311, -0.5414900183677673, -1.0633752346038818, -0.5793123841285706, -0.44390177726745605, -0.5650411248207092, 0.10124731808900833, 0.4604780375957489, -0.5455699563026428, -0.047391626983881, 0.3937040865421295, 0.4341515898704529, 0.5139483213424683, 0.07237040996551514, 0.7646262049674988, 1.0176448822021484, 0.8244765996932983, 0.6268173456192017, 0.9983367919921875, 0.6801846623420715, 0.8169494867324829, 1.1986725330352783, 0.9788516163825989, 1.3671003580093384, 1.79539954662323, 1.1459918022155762, 1.1661455631256104, 1.7979341745376587, 1.5599209070205688, 1.1007740497589111, 1.3125889301300049, 1.0036424398422241, 0.6695458889007568, 2.6551899909973145, 0.8553961515426636, -0.01757369190454483, 0.6774473786354065, 1.411820650100708, 0.959650456905365, 1.0795254707336426, 1.9128221273422241, 1.3815853595733643, 0.3971540629863739, 0.8236658573150635, 1.2559599876403809, -1.3586492538452148, 0.5494834780693054, 1.0784146785736084, 1.6240808963775635, 1.2834019660949707, 3.6596055030822754, 0.0, 2.312811851501465, 0.0, 0.0, 0.0, -9.369332313537598, -7.0643157958984375, -6.462048530578613, -5.90605354309082, -5.978270530700684, -5.79703426361084, -5.331462383270264, -5.758404731750488, -4.4429121017456055, -4.919914245605469, -4.218199729919434, -2.9317126274108887, -3.700608491897583, -2.79233980178833, -3.708822250366211, -2.895711898803711, -2.106156826019287, -2.0139851570129395, -1.820138931274414, -1.6604398488998413, -1.6855403184890747, -1.437940001487732, -1.223096489906311, -0.5414900183677673, -1.0633752346038818, -0.5793123841285706, -0.44390177726745605, -0.5650411248207092, 0.10124731808900833, 0.4604780375957489, -0.5455699563026428, -0.047391626983881, 0.3937040865421295, 0.4341515898704529, 0.5139483213424683, 0.07237040996551514, 0.7646262049674988, 1.0176448822021484, 0.8244765996932983, 0.6268173456192017, 0.9983367919921875, 0.6801846623420715, 0.8169494867324829, 1.1986725330352783, 0.9788516163825989, 1.3671003580093384, 1.79539954662323, 1.1459918022155762, 1.1661455631256104, 1.7979341745376587, 1.5599209070205688, 1.1007740497589111, 1.3125889301300049, 1.0036424398422241, 0.6695458889007568, 2.6551899909973145, 0.8553961515426636, -0.01757369190454483, 0.6774473786354065, 1.411820650100708, 0.959650456905365, 1.0795254707336426, 1.9128221273422241, 1.3815853595733643, 0.3971540629863739, 0.8236658573150635, 1.2559599876403809, -1.3586492538452148, 0.5494834780693054, 1.0784146785736084, 1.6240808963775635, 1.2834019660949707, 3.6596055030822754, 0.0, 2.312811851501465], [-5.9562273025512695, 0.0, 0.0, -6.85292387008667, -7.137126445770264, -6.57015323638916, -6.346471309661865, -5.675714492797852, -6.250663757324219, -5.570214748382568, -7.510933876037598, -5.66115140914917, -4.423041343688965, -4.258163928985596, -4.744382858276367, -3.2840845584869385, -3.8408005237579346, -4.314746379852295, -5.070947170257568, -2.262204170227051, -2.298447608947754, -1.921172022819519, -1.3747286796569824, -0.9746362566947937, -1.4096447229385376, -0.7955535054206848, -1.3342266082763672, -0.7018464803695679, -1.5830535888671875, -0.8702907562255859, -0.18358232080936432, 0.09397181123495102, -0.3230297863483429, 0.34722793102264404, 2.0067806243896484, 0.7397879362106323, 0.7465975284576416, 0.05739041045308113, -0.12192482501268387, 0.27246174216270447, 1.007515549659729, 1.182054042816162, 1.08008873462677, 1.0123122930526733, 1.7010055780410767, 1.6805403232574463, 2.0770814418792725, 1.903443694114685, 1.131935477256775, 0.9247517585754395, 0.8906800746917725, 1.135786533355713, 1.8028558492660522, 1.8910378217697144, 1.946100115776062, 2.2194411754608154, 1.0708374977111816, 1.5250128507614136, 0.26779288053512573, 1.3361408710479736, 1.3668476343154907, 0.04350369796156883, -0.8288815021514893, 1.5316945314407349, 0.5799251198768616, 1.284655213356018, 0.4088251292705536, 0.7104995250701904, 0.5091490149497986, 1.0617049932479858, 1.3363065719604492, 1.816987156867981, 0.7769657969474792, 1.865731120109558, 2.095262050628662, 2.461306571960449, 0.0, 2.26546049118042, -5.9562273025512695, 0.0, 0.0, -6.85292387008667, -7.137126445770264, -6.57015323638916, -6.346471309661865, -5.675714492797852, -6.250663757324219, -5.570214748382568, -7.510933876037598, -5.66115140914917, -4.423041343688965, -4.258163928985596, -4.744382858276367, -3.2840845584869385, -3.8408005237579346, -4.314746379852295, -5.070947170257568, -2.262204170227051, -2.298447608947754, -1.921172022819519, -1.3747286796569824, -0.9746362566947937, -1.4096447229385376, -0.7955535054206848, -1.3342266082763672, -0.7018464803695679, -1.5830535888671875, -0.8702907562255859, -0.18358232080936432, 0.09397181123495102, -0.3230297863483429, 0.34722793102264404, 2.0067806243896484, 0.7397879362106323, 0.7465975284576416, 0.05739041045308113, -0.12192482501268387, 0.27246174216270447, 1.007515549659729, 1.182054042816162, 1.08008873462677, 1.0123122930526733, 1.7010055780410767, 1.6805403232574463, 2.0770814418792725, 1.903443694114685, 1.131935477256775, 0.9247517585754395, 0.8906800746917725, 1.135786533355713, 1.8028558492660522, 1.8910378217697144, 1.946100115776062, 2.2194411754608154, 1.0708374977111816, 1.5250128507614136, 0.26779288053512573, 1.3361408710479736, 1.3668476343154907, 0.04350369796156883, -0.8288815021514893, 1.5316945314407349, 0.5799251198768616, 1.284655213356018, 0.4088251292705536, 0.7104995250701904, 0.5091490149497986, 1.0617049932479858, 1.3363065719604492, 1.816987156867981, 0.7769657969474792, 1.865731120109558, 2.095262050628662, 2.461306571960449, 0.0, 2.26546049118042], [-8.261013984680176, 0.0, -4.46396541595459, -6.487754821777344, -6.940851211547852, -6.7924723625183105, -6.528703689575195, -5.070561408996582, -6.1567277908325195, -5.454216480255127, -5.264655113220215, -3.550666332244873, -3.038957357406616, -5.064691543579102, -4.116787433624268, -4.376906394958496, -3.32413911819458, -2.128129482269287, -2.226267099380493, -2.194779634475708, -2.0906777381896973, -1.6523088216781616, -1.7626382112503052, -1.978469729423523, -1.9299372434616089, -2.204643487930298, 0.006115979980677366, -1.245444416999817, -0.02574486844241619, -0.6559953093528748, -0.4705756902694702, -0.9239514470100403, 0.3279598355293274, 0.7651879191398621, 0.7354457378387451, 1.3802658319473267, 3.9957053661346436, 0.7886824011802673, -0.6614804267883301, 0.7994298338890076, 1.1920886039733887, 1.5190635919570923, 1.393214464187622, 1.4950697422027588, 1.6700893640518188, 1.2018473148345947, 1.2155611515045166, 1.236566185951233, 1.9547311067581177, 1.4106512069702148, 2.002610206604004, 1.6741904020309448, 1.6165642738342285, 1.9851032495498657, 1.3532613515853882, 1.508590579032898, 0.8108036518096924, 1.0090075731277466, 1.4551211595535278, 1.2953872680664062, -0.3704966902732849, 1.429571270942688, 0.6821109652519226, 0.8437386751174927, 0.919185221195221, 0.7451431751251221, 0.5440187454223633, 0.001286512822844088, 0.44929468631744385, 1.6253817081451416, 3.7460596561431885, 0.9632827639579773, 1.2462184429168701, 2.0363306999206543, 1.5381507873535156, 1.953879952430725, 0.0, 3.437866449356079, -8.261013984680176, 0.0, -4.46396541595459, -6.487754821777344, -6.940851211547852, -6.7924723625183105, -6.528703689575195, -5.070561408996582, -6.1567277908325195, -5.454216480255127, -5.264655113220215, -3.550666332244873, -3.038957357406616, -5.064691543579102, -4.116787433624268, -4.376906394958496, -3.32413911819458, -2.128129482269287, -2.226267099380493, -2.194779634475708, -2.0906777381896973, -1.6523088216781616, -1.7626382112503052, -1.978469729423523, -1.9299372434616089, -2.204643487930298, 0.006115979980677366, -1.245444416999817, -0.02574486844241619, -0.6559953093528748, -0.4705756902694702, -0.9239514470100403, 0.3279598355293274, 0.7651879191398621, 0.7354457378387451, 1.3802658319473267, 3.9957053661346436, 0.7886824011802673, -0.6614804267883301, 0.7994298338890076, 1.1920886039733887, 1.5190635919570923, 1.393214464187622, 1.4950697422027588, 1.6700893640518188, 1.2018473148345947, 1.2155611515045166, 1.236566185951233, 1.9547311067581177, 1.4106512069702148, 2.002610206604004, 1.6741904020309448, 1.6165642738342285, 1.9851032495498657, 1.3532613515853882, 1.508590579032898, 0.8108036518096924, 1.0090075731277466, 1.4551211595535278, 1.2953872680664062, -0.3704966902732849, 1.429571270942688, 0.6821109652519226, 0.8437386751174927, 0.919185221195221, 0.7451431751251221, 0.5440187454223633, 0.001286512822844088, 0.44929468631744385, 1.6253817081451416, 3.7460596561431885, 0.9632827639579773, 1.2462184429168701, 2.0363306999206543, 1.5381507873535156, 1.953879952430725, 0.0, 3.437866449356079], [-7.16429328918457, 0.0, -8.25894832611084, -6.870509624481201, -6.4947829246521, -6.547784328460693, -5.890165328979492, -5.794102191925049, -6.111451148986816, -5.501437664031982, -5.95452356338501, -4.611376762390137, -4.639602184295654, -4.141533374786377, -4.501558303833008, -3.743405818939209, -4.092397689819336, -3.142338752746582, -3.0631415843963623, -1.6787155866622925, -2.037320137023926, -1.914415955543518, -1.8768459558486938, -1.4917521476745605, -1.415174126625061, 0.05607401207089424, -0.7211405038833618, -0.6525423526763916, -0.3862098157405853, -0.07903052866458893, -0.2136474996805191, 1.2287211418151855, 0.5978454351425171, 0.33496057987213135, -0.316697359085083, 1.812874436378479, 2.698624849319458, 1.5604698657989502, 0.6409181952476501, 0.8873164057731628, 1.0543403625488281, 1.6861796379089355, 1.3931411504745483, 1.2957007884979248, 1.257164478302002, 1.3265438079833984, 1.0149179697036743, 2.7809038162231445, 1.2434601783752441, 1.5424312353134155, 1.862876057624817, 1.1254674196243286, 1.1027841567993164, 1.0562430620193481, 1.2531942129135132, 1.138340711593628, 0.9919737577438354, 1.3518328666687012, 1.313884973526001, 0.1828487366437912, 1.2917673587799072, 0.5204765200614929, -0.011436047032475471, 1.2706124782562256, 0.9195570349693298, 0.6613695025444031, 0.5705867409706116, 0.9438101053237915, 0.8095611929893494, 0.2852025628089905, 1.343765139579773, 0.9494033455848694, 1.2939356565475464, 1.0984201431274414, 2.6319072246551514, 2.845606565475464, 0.0, 0.0, -7.16429328918457, 0.0, -8.25894832611084, -6.870509624481201, -6.4947829246521, -6.547784328460693, -5.890165328979492, -5.794102191925049, -6.111451148986816, -5.501437664031982, -5.95452356338501, -4.611376762390137, -4.639602184295654, -4.141533374786377, -4.501558303833008, -3.743405818939209, -4.092397689819336, -3.142338752746582, -3.0631415843963623, -1.6787155866622925, -2.037320137023926, -1.914415955543518, -1.8768459558486938, -1.4917521476745605, -1.415174126625061, 0.05607401207089424, -0.7211405038833618, -0.6525423526763916, -0.3862098157405853, -0.07903052866458893, -0.2136474996805191, 1.2287211418151855, 0.5978454351425171, 0.33496057987213135, -0.316697359085083, 1.812874436378479, 2.698624849319458, 1.5604698657989502, 0.6409181952476501, 0.8873164057731628, 1.0543403625488281, 1.6861796379089355, 1.3931411504745483, 1.2957007884979248, 1.257164478302002, 1.3265438079833984, 1.0149179697036743, 2.7809038162231445, 1.2434601783752441, 1.5424312353134155, 1.862876057624817, 1.1254674196243286, 1.1027841567993164, 1.0562430620193481, 1.2531942129135132, 1.138340711593628, 0.9919737577438354, 1.3518328666687012, 1.313884973526001, 0.1828487366437912, 1.2917673587799072, 0.5204765200614929, -0.011436047032475471, 1.2706124782562256, 0.9195570349693298, 0.6613695025444031, 0.5705867409706116, 0.9438101053237915, 0.8095611929893494, 0.2852025628089905, 1.343765139579773, 0.9494033455848694, 1.2939356565475464, 1.0984201431274414, 2.6319072246551514, 2.845606565475464, 0.0, 0.0], [-5.552942276000977, 0.0, -7.565060138702393, -6.768218040466309, -7.303192138671875, -6.26042366027832, -6.382656097412109, -6.0889434814453125, -5.5885515213012695, -5.830299377441406, -5.1414570808410645, -4.544590473175049, -3.80121111869812, -4.434136390686035, -4.663454532623291, -3.693291664123535, -4.094783782958984, -3.3855690956115723, -3.2650346755981445, -2.5059006214141846, -2.031439781188965, -2.2198450565338135, -2.3216140270233154, -1.7171508073806763, -0.5620113611221313, -0.950524628162384, -0.9720643758773804, -2.2086567878723145, -0.0727153867483139, -0.9482304453849792, -0.33020687103271484, -0.35183849930763245, 0.8946366310119629, 0.43837112188339233, -1.8011581897735596, -1.1214935779571533, 0.0, 1.0885990858078003, 1.3411270380020142, 0.936549186706543, 0.34650474786758423, -0.34076452255249023, -0.1283896416425705, 1.7994521856307983, 1.7847346067428589, 1.0124316215515137, 0.7008341550827026, 2.559058666229248, 1.0243020057678223, 2.011444568634033, 2.0758609771728516, 1.1640254259109497, 1.8539735078811646, 1.3415485620498657, 1.3370555639266968, 1.7495503425598145, -0.8676658868789673, 0.6085635423660278, 1.9907137155532837, 1.2591880559921265, 1.2830373048782349, 0.8104035258293152, -0.12470079958438873, 1.2042804956436157, 0.6279531121253967, 0.5305328369140625, 1.0947012901306152, 0.8215668201446533, 0.12011223286390305, 1.8306787014007568, 1.0787619352340698, 1.363163948059082, 1.2901294231414795, 2.262524127960205, 1.7882977724075317, 2.743868350982666, 0.0, 0.0, -5.552942276000977, 0.0, -7.565060138702393, -6.768218040466309, -7.303192138671875, -6.26042366027832, -6.382656097412109, -6.0889434814453125, -5.5885515213012695, -5.830299377441406, -5.1414570808410645, -4.544590473175049, -3.80121111869812, -4.434136390686035, -4.663454532623291, -3.693291664123535, -4.094783782958984, -3.3855690956115723, -3.2650346755981445, -2.5059006214141846, -2.031439781188965, -2.2198450565338135, -2.3216140270233154, -1.7171508073806763, -0.5620113611221313, -0.950524628162384, -0.9720643758773804, -2.2086567878723145, -0.0727153867483139, -0.9482304453849792, -0.33020687103271484, -0.35183849930763245, 0.8946366310119629, 0.43837112188339233, -1.8011581897735596, -1.1214935779571533, 0.0, 1.0885990858078003, 1.3411270380020142, 0.936549186706543, 0.34650474786758423, -0.34076452255249023, -0.1283896416425705, 1.7994521856307983, 1.7847346067428589, 1.0124316215515137, 0.7008341550827026, 2.559058666229248, 1.0243020057678223, 2.011444568634033, 2.0758609771728516, 1.1640254259109497, 1.8539735078811646, 1.3415485620498657, 1.3370555639266968, 1.7495503425598145, -0.8676658868789673, 0.6085635423660278, 1.9907137155532837, 1.2591880559921265, 1.2830373048782349, 0.8104035258293152, -0.12470079958438873, 1.2042804956436157, 0.6279531121253967, 0.5305328369140625, 1.0947012901306152, 0.8215668201446533, 0.12011223286390305, 1.8306787014007568, 1.0787619352340698, 1.363163948059082, 1.2901294231414795, 2.262524127960205, 1.7882977724075317, 2.743868350982666, 0.0, 0.0], [0.0, 0.0, -7.566123008728027, -7.031012535095215, -6.431532859802246, -6.591085433959961, -6.571557521820068, -6.309863567352295, -5.972165107727051, -5.445249557495117, -5.259843349456787, -5.721146583557129, -5.9685492515563965, -4.621431350708008, -4.51439905166626, -3.9552805423736572, -3.4389450550079346, -3.222945213317871, -4.008881092071533, -3.7078981399536133, -2.3199567794799805, -1.750137209892273, -0.32490935921669006, -2.03607439994812, -1.298992395401001, -0.9543060064315796, -0.7745124697685242, -0.8390708565711975, -0.4440475106239319, -0.10196396708488464, 0.9344016909599304, -0.17703309655189514, 2.705582618713379, 0.9688250422477722, 1.6092437505722046, 1.142665147781372, 1.559200406074524, 0.9866344928741455, 0.3003261685371399, 0.6989457607269287, 1.2887284755706787, 0.8922065496444702, 0.7997015118598938, 0.9712202548980713, 1.2976455688476562, 1.4051085710525513, 0.7254797220230103, 0.8316685557365417, 1.9627573490142822, 1.7615183591842651, 1.0216652154922485, 1.3838025331497192, 1.0961439609527588, 1.486128330230713, 1.6013256311416626, 1.553829312324524, 1.538116216659546, 2.6796717643737793, 0.9936885237693787, 1.8058669567108154, 0.3340533971786499, 0.6347397565841675, 1.7520723342895508, 1.3140593767166138, 3.3900041580200195, 0.3654133081436157, 0.9012064337730408, 0.7677234411239624, 0.7447248101234436, 0.9967519044876099, 1.3298754692077637, 0.8736687302589417, 1.2795063257217407, 1.8474786281585693, 1.712964415550232, 2.288012981414795, 0.0, 0.0, 0.0, 0.0, -7.566123008728027, -7.031012535095215, -6.431532859802246, -6.591085433959961, -6.571557521820068, -6.309863567352295, -5.972165107727051, -5.445249557495117, -5.259843349456787, -5.721146583557129, -5.9685492515563965, -4.621431350708008, -4.51439905166626, -3.9552805423736572, -3.4389450550079346, -3.222945213317871, -4.008881092071533, -3.7078981399536133, -2.3199567794799805, -1.750137209892273, -0.32490935921669006, -2.03607439994812, -1.298992395401001, -0.9543060064315796, -0.7745124697685242, -0.8390708565711975, -0.4440475106239319, -0.10196396708488464, 0.9344016909599304, -0.17703309655189514, 2.705582618713379, 0.9688250422477722, 1.6092437505722046, 1.142665147781372, 1.559200406074524, 0.9866344928741455, 0.3003261685371399, 0.6989457607269287, 1.2887284755706787, 0.8922065496444702, 0.7997015118598938, 0.9712202548980713, 1.2976455688476562, 1.4051085710525513, 0.7254797220230103, 0.8316685557365417, 1.9627573490142822, 1.7615183591842651, 1.0216652154922485, 1.3838025331497192, 1.0961439609527588, 1.486128330230713, 1.6013256311416626, 1.553829312324524, 1.538116216659546, 2.6796717643737793, 0.9936885237693787, 1.8058669567108154, 0.3340533971786499, 0.6347397565841675, 1.7520723342895508, 1.3140593767166138, 3.3900041580200195, 0.3654133081436157, 0.9012064337730408, 0.7677234411239624, 0.7447248101234436, 0.9967519044876099, 1.3298754692077637, 0.8736687302589417, 1.2795063257217407, 1.8474786281585693, 1.712964415550232, 2.288012981414795, 0.0, 0.0], [0.0, 0.0, -7.014796257019043, -7.514228343963623, -7.037868499755859, -6.532268524169922, -7.291738986968994, -6.231338024139404, -6.434367656707764, -5.8258867263793945, -5.711191177368164, -5.086219310760498, -5.081461429595947, -4.825118541717529, -3.924330234527588, -4.8359503746032715, -3.3159866333007812, -3.3095245361328125, -2.9859249591827393, -2.2039175033569336, -2.475602149963379, -1.8417022228240967, -1.0844402313232422, 0.7882699966430664, -1.917480707168579, -1.188326358795166, -0.7332494258880615, -0.5101792216300964, 2.153865098953247, -1.0488718748092651, 0.12821920216083527, 0.04484285041689873, -0.07651808112859726, 0.5614071488380432, 1.9849380254745483, 0.0, 1.342500925064087, 0.7025664448738098, -0.25761473178863525, 0.5337281823158264, 1.5485979318618774, 1.3747880458831787, 1.354103684425354, 0.6166421175003052, 0.9520314335823059, 1.0379921197891235, 1.6875462532043457, 1.8160252571105957, 1.496530294418335, 1.485497236251831, 1.6468669176101685, 1.5695607662200928, 1.092076301574707, 1.183424949645996, 0.3885631561279297, 1.1916996240615845, -0.15511475503444672, 0.3768901526927948, 1.13373601436615, 1.6920756101608276, 0.6405994892120361, 1.2302000522613525, -0.20224358141422272, 0.6230987906455994, 0.4686730206012726, -0.5087392926216125, -1.7904314994812012, 0.33108094334602356, 0.6885581016540527, 1.0223602056503296, 1.8833521604537964, 1.768035888671875, 1.4440163373947144, 0.950921893119812, 1.7997413873672485, 1.0881845951080322, 0.0, 0.0, 0.0, 0.0, -7.014796257019043, -7.514228343963623, -7.037868499755859, -6.532268524169922, -7.291738986968994, -6.231338024139404, -6.434367656707764, -5.8258867263793945, -5.711191177368164, -5.086219310760498, -5.081461429595947, -4.825118541717529, -3.924330234527588, -4.8359503746032715, -3.3159866333007812, -3.3095245361328125, -2.9859249591827393, -2.2039175033569336, -2.475602149963379, -1.8417022228240967, -1.0844402313232422, 0.7882699966430664, -1.917480707168579, -1.188326358795166, -0.7332494258880615, -0.5101792216300964, 2.153865098953247, -1.0488718748092651, 0.12821920216083527, 0.04484285041689873, -0.07651808112859726, 0.5614071488380432, 1.9849380254745483, 0.0, 1.342500925064087, 0.7025664448738098, -0.25761473178863525, 0.5337281823158264, 1.5485979318618774, 1.3747880458831787, 1.354103684425354, 0.6166421175003052, 0.9520314335823059, 1.0379921197891235, 1.6875462532043457, 1.8160252571105957, 1.496530294418335, 1.485497236251831, 1.6468669176101685, 1.5695607662200928, 1.092076301574707, 1.183424949645996, 0.3885631561279297, 1.1916996240615845, -0.15511475503444672, 0.3768901526927948, 1.13373601436615, 1.6920756101608276, 0.6405994892120361, 1.2302000522613525, -0.20224358141422272, 0.6230987906455994, 0.4686730206012726, -0.5087392926216125, -1.7904314994812012, 0.33108094334602356, 0.6885581016540527, 1.0223602056503296, 1.8833521604537964, 1.768035888671875, 1.4440163373947144, 0.950921893119812, 1.7997413873672485, 1.0881845951080322, 0.0, 0.0], [0.0, -5.412473678588867, -7.2542548179626465, -7.5837249755859375, -7.578117370605469, -7.547021865844727, -7.245001316070557, -6.458077430725098, -6.849835395812988, -6.21885871887207, -5.679545879364014, -5.432552814483643, -4.514139652252197, -5.325057506561279, -4.533636093139648, -5.316837310791016, -3.9402904510498047, -2.7914466857910156, -3.124667167663574, -2.3437957763671875, -2.077144145965576, -1.8767821788787842, -1.6509699821472168, -2.360795021057129, -1.716145634651184, -1.5757176876068115, -1.724645733833313, -1.1016125679016113, -0.6086265444755554, -0.9909693598747253, -0.17993660271167755, -1.482650876045227, 1.0960280895233154, 0.6542113423347473, 0.5950170755386353, 1.5564827919006348, 1.0468816757202148, 0.27037134766578674, -0.2004268318414688, -0.14140170812606812, 1.1039605140686035, 0.7363684773445129, 0.5756375789642334, 2.376856803894043, 1.0161521434783936, 1.5732276439666748, 1.0586556196212769, 1.1613452434539795, 0.941275417804718, 1.9204506874084473, 1.9675499200820923, 1.1131690740585327, 1.0997744798660278, 1.2214372158050537, 1.005147099494934, 1.3040236234664917, 0.5195261240005493, 1.1052190065383911, 1.3043601512908936, -0.16366560757160187, 0.48535022139549255, 1.1518999338150024, -0.2868580222129822, -0.8004171252250671, 0.5739635229110718, 1.9982761144638062, -0.0962894931435585, -0.6560080051422119, 1.2787048816680908, 0.20213128626346588, 0.3100701868534088, -0.0653219148516655, 1.365710973739624, 0.8292248845100403, 1.2144389152526855, 1.7733110189437866, 2.483510971069336, 0.0, 0.0, -5.412473678588867, -7.2542548179626465, -7.5837249755859375, -7.578117370605469, -7.547021865844727, -7.245001316070557, -6.458077430725098, -6.849835395812988, -6.21885871887207, -5.679545879364014, -5.432552814483643, -4.514139652252197, -5.325057506561279, -4.533636093139648, -5.316837310791016, -3.9402904510498047, -2.7914466857910156, -3.124667167663574, -2.3437957763671875, -2.077144145965576, -1.8767821788787842, -1.6509699821472168, -2.360795021057129, -1.716145634651184, -1.5757176876068115, -1.724645733833313, -1.1016125679016113, -0.6086265444755554, -0.9909693598747253, -0.17993660271167755, -1.482650876045227, 1.0960280895233154, 0.6542113423347473, 0.5950170755386353, 1.5564827919006348, 1.0468816757202148, 0.27037134766578674, -0.2004268318414688, -0.14140170812606812, 1.1039605140686035, 0.7363684773445129, 0.5756375789642334, 2.376856803894043, 1.0161521434783936, 1.5732276439666748, 1.0586556196212769, 1.1613452434539795, 0.941275417804718, 1.9204506874084473, 1.9675499200820923, 1.1131690740585327, 1.0997744798660278, 1.2214372158050537, 1.005147099494934, 1.3040236234664917, 0.5195261240005493, 1.1052190065383911, 1.3043601512908936, -0.16366560757160187, 0.48535022139549255, 1.1518999338150024, -0.2868580222129822, -0.8004171252250671, 0.5739635229110718, 1.9982761144638062, -0.0962894931435585, -0.6560080051422119, 1.2787048816680908, 0.20213128626346588, 0.3100701868534088, -0.0653219148516655, 1.365710973739624, 0.8292248845100403, 1.2144389152526855, 1.7733110189437866, 2.483510971069336, 0.0], [0.0, -9.243880271911621, -8.192251205444336, -8.132597923278809, -6.909965991973877, -6.61444091796875, -7.063071250915527, -6.876638412475586, -6.897530555725098, -6.2210283279418945, -6.2058820724487305, -5.536466121673584, -5.204539775848389, -5.741027355194092, -4.887796878814697, -4.822907447814941, -3.985044479370117, -3.259526491165161, -3.3886048793792725, -3.2413597106933594, -2.4504454135894775, -3.0226759910583496, -2.56211519241333, -1.9803295135498047, -1.5204112529754639, -2.997124671936035, -1.8342524766921997, -1.0307154655456543, -0.7324765920639038, -1.6916331052780151, -0.6081817150115967, 0.2391863465309143, 0.6340796947479248, 2.301730155944824, -0.8374189734458923, 0.3188745081424713, 1.0438802242279053, -0.8823623061180115, -0.7473562359809875, -0.5975826382637024, 0.22160248458385468, 0.8251730799674988, 1.1417131423950195, 1.0901083946228027, 1.2835991382598877, 1.6533983945846558, 0.9238236546516418, 0.7267044186592102, 1.6071527004241943, 1.1503338813781738, 0.3101290166378021, 1.3947393894195557, 1.6023366451263428, 1.0852031707763672, 2.165050983428955, 0.8706253170967102, 0.5056123733520508, -0.9342362880706787, 0.06095065549015999, 1.3909047842025757, 0.1346377283334732, 0.673051118850708, 1.6186023950576782, 1.517148494720459, 0.7577128410339355, 0.7742642164230347, 0.5661701560020447, 0.41406145691871643, 0.8807113170623779, -0.1268170326948166, -0.5601437091827393, 0.7523118853569031, 0.7257726192474365, 1.0117229223251343, 1.558219075202942, 1.5142449140548706, 1.7799766063690186, 0.0, 0.0, -9.243880271911621, -8.192251205444336, -8.132597923278809, -6.909965991973877, -6.61444091796875, -7.063071250915527, -6.876638412475586, -6.897530555725098, -6.2210283279418945, -6.2058820724487305, -5.536466121673584, -5.204539775848389, -5.741027355194092, -4.887796878814697, -4.822907447814941, -3.985044479370117, -3.259526491165161, -3.3886048793792725, -3.2413597106933594, -2.4504454135894775, -3.0226759910583496, -2.56211519241333, -1.9803295135498047, -1.5204112529754639, -2.997124671936035, -1.8342524766921997, -1.0307154655456543, -0.7324765920639038, -1.6916331052780151, -0.6081817150115967, 0.2391863465309143, 0.6340796947479248, 2.301730155944824, -0.8374189734458923, 0.3188745081424713, 1.0438802242279053, -0.8823623061180115, -0.7473562359809875, -0.5975826382637024, 0.22160248458385468, 0.8251730799674988, 1.1417131423950195, 1.0901083946228027, 1.2835991382598877, 1.6533983945846558, 0.9238236546516418, 0.7267044186592102, 1.6071527004241943, 1.1503338813781738, 0.3101290166378021, 1.3947393894195557, 1.6023366451263428, 1.0852031707763672, 2.165050983428955, 0.8706253170967102, 0.5056123733520508, -0.9342362880706787, 0.06095065549015999, 1.3909047842025757, 0.1346377283334732, 0.673051118850708, 1.6186023950576782, 1.517148494720459, 0.7577128410339355, 0.7742642164230347, 0.5661701560020447, 0.41406145691871643, 0.8807113170623779, -0.1268170326948166, -0.5601437091827393, 0.7523118853569031, 0.7257726192474365, 1.0117229223251343, 1.558219075202942, 1.5142449140548706, 1.7799766063690186, 0.0], [0.0, -9.161845207214355, -8.10926628112793, -7.670139789581299, -8.356636047363281, -6.832672595977783, -7.376380920410156, -7.532762050628662, -7.477263450622559, -7.11285400390625, -6.4221954345703125, -6.320727825164795, -5.649777412414551, -4.604282855987549, -5.322144508361816, -4.442859649658203, -3.6009700298309326, -4.412180423736572, -3.7879295349121094, -3.4202351570129395, -2.44328236579895, -2.417506694793701, -2.1559202671051025, -2.111210346221924, -1.1620696783065796, -1.3537817001342773, -1.3356419801712036, -0.7047678828239441, -0.0008163897437043488, -1.3910375833511353, -0.15597160160541534, 0.555094838142395, 0.9402761459350586, 1.5849266052246094, -0.2659977078437805, 0.6430158019065857, -0.822640061378479, -1.7974387407302856, -2.131657123565674, -0.19457383453845978, -0.5157546997070312, 0.6605913639068604, 0.6381040811538696, 0.9914352297782898, 1.2139158248901367, 0.9622993469238281, 0.3312995433807373, 1.2404518127441406, 1.1823139190673828, 1.192134141921997, 1.2984850406646729, 0.9580910205841064, 1.0180609226226807, 0.9188168048858643, 1.4156628847122192, 1.0697499513626099, 0.38740232586860657, 0.6322769522666931, 0.7020095586776733, 0.8296121954917908, 1.0653399229049683, 0.7610531449317932, 0.07153166085481644, -0.43809062242507935, -0.18589302897453308, -0.009546495042741299, 0.3298914134502411, 0.668621838092804, 1.6626144647598267, -0.14570285379886627, 0.7907721400260925, 0.4012162983417511, 0.13834434747695923, 0.7849595546722412, 0.42309921979904175, 0.18269412219524384, 1.9060921669006348, 0.0, 0.0, -9.161845207214355, -8.10926628112793, -7.670139789581299, -8.356636047363281, -6.832672595977783, -7.376380920410156, -7.532762050628662, -7.477263450622559, -7.11285400390625, -6.4221954345703125, -6.320727825164795, -5.649777412414551, -4.604282855987549, -5.322144508361816, -4.442859649658203, -3.6009700298309326, -4.412180423736572, -3.7879295349121094, -3.4202351570129395, -2.44328236579895, -2.417506694793701, -2.1559202671051025, -2.111210346221924, -1.1620696783065796, -1.3537817001342773, -1.3356419801712036, -0.7047678828239441, -0.0008163897437043488, -1.3910375833511353, -0.15597160160541534, 0.555094838142395, 0.9402761459350586, 1.5849266052246094, -0.2659977078437805, 0.6430158019065857, -0.822640061378479, -1.7974387407302856, -2.131657123565674, -0.19457383453845978, -0.5157546997070312, 0.6605913639068604, 0.6381040811538696, 0.9914352297782898, 1.2139158248901367, 0.9622993469238281, 0.3312995433807373, 1.2404518127441406, 1.1823139190673828, 1.192134141921997, 1.2984850406646729, 0.9580910205841064, 1.0180609226226807, 0.9188168048858643, 1.4156628847122192, 1.0697499513626099, 0.38740232586860657, 0.6322769522666931, 0.7020095586776733, 0.8296121954917908, 1.0653399229049683, 0.7610531449317932, 0.07153166085481644, -0.43809062242507935, -0.18589302897453308, -0.009546495042741299, 0.3298914134502411, 0.668621838092804, 1.6626144647598267, -0.14570285379886627, 0.7907721400260925, 0.4012162983417511, 0.13834434747695923, 0.7849595546722412, 0.42309921979904175, 0.18269412219524384, 1.9060921669006348, 0.0], [0.0, -8.484947204589844, -8.219344139099121, -8.205972671508789, -7.927215576171875, -7.59365701675415, -6.5897088050842285, -7.330934524536133, -7.518918991088867, -7.831132888793945, -6.538292407989502, -4.828634262084961, -6.472289562225342, -5.043080806732178, -5.215035915374756, -5.446506977081299, -5.158386707305908, -2.840904474258423, -3.609893798828125, -2.310737133026123, -3.1023898124694824, -1.9373632669448853, -1.7059071063995361, -2.1633715629577637, -2.402387857437134, -2.220315933227539, -1.545271396636963, -0.44462665915489197, -0.23226222395896912, 0.3623408079147339, 0.05382876470685005, 0.8455762267112732, -0.11344174295663834, -2.0355348587036133, 1.2874727249145508, -0.08116171509027481, -0.4320947825908661, -3.0762150287628174, 0.0, 0.0, -0.8842894434928894, 0.2924971282482147, 1.0496164560317993, 0.5104787349700928, 1.9440008401870728, 0.8820226788520813, 1.7848751544952393, 0.06296224147081375, 1.4308576583862305, 1.175254225730896, 1.0862444639205933, 1.0014604330062866, 1.3004846572875977, 0.9892758131027222, 0.2542378604412079, -0.06935471296310425, 0.3895840644836426, 1.3406243324279785, 0.3515077829360962, 0.4632241129875183, 0.7566476464271545, -0.6632907390594482, -2.6362452507019043, 0.5208561420440674, 0.646835207939148, 0.347687691450119, 0.12970386445522308, -1.3275301456451416, -0.20108184218406677, -0.4065541625022888, -0.25851860642433167, 0.5470513105392456, 0.4256720244884491, 0.7348653078079224, -0.3170223832130432, 0.2980916500091553, 0.14210794866085052, 0.0, 0.0, -8.484947204589844, -8.219344139099121, -8.205972671508789, -7.927215576171875, -7.59365701675415, -6.5897088050842285, -7.330934524536133, -7.518918991088867, -7.831132888793945, -6.538292407989502, -4.828634262084961, -6.472289562225342, -5.043080806732178, -5.215035915374756, -5.446506977081299, -5.158386707305908, -2.840904474258423, -3.609893798828125, -2.310737133026123, -3.1023898124694824, -1.9373632669448853, -1.7059071063995361, -2.1633715629577637, -2.402387857437134, -2.220315933227539, -1.545271396636963, -0.44462665915489197, -0.23226222395896912, 0.3623408079147339, 0.05382876470685005, 0.8455762267112732, -0.11344174295663834, -2.0355348587036133, 1.2874727249145508, -0.08116171509027481, -0.4320947825908661, -3.0762150287628174, 0.0, 0.0, -0.8842894434928894, 0.2924971282482147, 1.0496164560317993, 0.5104787349700928, 1.9440008401870728, 0.8820226788520813, 1.7848751544952393, 0.06296224147081375, 1.4308576583862305, 1.175254225730896, 1.0862444639205933, 1.0014604330062866, 1.3004846572875977, 0.9892758131027222, 0.2542378604412079, -0.06935471296310425, 0.3895840644836426, 1.3406243324279785, 0.3515077829360962, 0.4632241129875183, 0.7566476464271545, -0.6632907390594482, -2.6362452507019043, 0.5208561420440674, 0.646835207939148, 0.347687691450119, 0.12970386445522308, -1.3275301456451416, -0.20108184218406677, -0.4065541625022888, -0.25851860642433167, 0.5470513105392456, 0.4256720244884491, 0.7348653078079224, -0.3170223832130432, 0.2980916500091553, 0.14210794866085052, 0.0], [0.0, -8.354467391967773, -8.868300437927246, -8.479194641113281, -8.922694206237793, -8.2073335647583, -7.923600196838379, -8.201678276062012, -7.554165840148926, -7.391841411590576, -6.915677547454834, -7.272099494934082, -6.151771068572998, -5.755982398986816, -4.899083137512207, -4.607082366943359, -4.669196605682373, -2.918161153793335, -2.8384265899658203, -5.66533088684082, -2.7096006870269775, -2.417886734008789, -2.503894805908203, -1.5090065002441406, -1.3741060495376587, -1.1112793684005737, -0.8993842005729675, -1.3720951080322266, -1.2026911973953247, 0.03856099024415016, -0.3719395101070404, 0.002085361396893859, -1.4061636924743652, -0.15782462060451508, 0.3718411922454834, -0.3078748881816864, -0.7766191363334656, 1.134637475013733, 5.229090213775635, 2.8786251544952393, -0.8754451870918274, 0.6444132924079895, 1.2151447534561157, 1.8008815050125122, 0.8213536739349365, -0.134894460439682, 1.4135388135910034, 0.4954221248626709, 1.1299242973327637, 2.3092265129089355, 0.9308484792709351, 0.3807674050331116, 3.0963783264160156, 0.32026511430740356, 0.9773455858230591, 0.623436450958252, 0.3090807795524597, 0.8168957233428955, -0.5454923510551453, -1.6644773483276367, 2.119828462600708, 1.6947412490844727, 0.3026086390018463, -0.045608293265104294, 1.938949465751648, -0.2602666914463043, 0.37305042147636414, -0.34274905920028687, -1.5390911102294922, -0.9516766667366028, -1.0309035778045654, -0.5017644166946411, -0.09782592207193375, 0.2906678318977356, -0.08910718560218811, 0.4542892575263977, 1.3156746625900269, 0.0, 0.0, -8.354467391967773, -8.868300437927246, -8.479194641113281, -8.922694206237793, -8.2073335647583, -7.923600196838379, -8.201678276062012, -7.554165840148926, -7.391841411590576, -6.915677547454834, -7.272099494934082, -6.151771068572998, -5.755982398986816, -4.899083137512207, -4.607082366943359, -4.669196605682373, -2.918161153793335, -2.8384265899658203, -5.66533088684082, -2.7096006870269775, -2.417886734008789, -2.503894805908203, -1.5090065002441406, -1.3741060495376587, -1.1112793684005737, -0.8993842005729675, -1.3720951080322266, -1.2026911973953247, 0.03856099024415016, -0.3719395101070404, 0.002085361396893859, -1.4061636924743652, -0.15782462060451508, 0.3718411922454834, -0.3078748881816864, -0.7766191363334656, 1.134637475013733, 5.229090213775635, 2.8786251544952393, -0.8754451870918274, 0.6444132924079895, 1.2151447534561157, 1.8008815050125122, 0.8213536739349365, -0.134894460439682, 1.4135388135910034, 0.4954221248626709, 1.1299242973327637, 2.3092265129089355, 0.9308484792709351, 0.3807674050331116, 3.0963783264160156, 0.32026511430740356, 0.9773455858230591, 0.623436450958252, 0.3090807795524597, 0.8168957233428955, -0.5454923510551453, -1.6644773483276367, 2.119828462600708, 1.6947412490844727, 0.3026086390018463, -0.045608293265104294, 1.938949465751648, -0.2602666914463043, 0.37305042147636414, -0.34274905920028687, -1.5390911102294922, -0.9516766667366028, -1.0309035778045654, -0.5017644166946411, -0.09782592207193375, 0.2906678318977356, -0.08910718560218811, 0.4542892575263977, 1.3156746625900269, 0.0], [0.0, -9.177613258361816, -9.150391578674316, -9.759490013122559, -8.824555397033691, -9.518867492675781, -7.745303153991699, -8.442728996276855, -7.631931781768799, -8.069925308227539, -6.969172477722168, -6.897911548614502, -6.484655857086182, -5.815464019775391, -5.870404243469238, -5.391446113586426, -4.611326217651367, -4.681792736053467, -4.495628833770752, -3.968750476837158, -4.548412322998047, -2.325288772583008, -4.777246952056885, -2.3736443519592285, -0.8124991655349731, -2.179525375366211, -0.872422456741333, -2.4902381896972656, -1.3167316913604736, -0.4807341396808624, 0.05522730574011803, 0.5096904635429382, -0.126907616853714, -0.12398691475391388, 0.798045814037323, -0.4472583532333374, -1.3015415668487549, 0.028317902237176895, 2.313990831375122, 1.4801476001739502, -0.5693365931510925, 0.987820029258728, 0.8822210431098938, 0.41149720549583435, 0.5958676338195801, 1.720327615737915, 1.1895880699157715, 1.6241639852523804, 1.4038667678833008, 1.396916151046753, 1.3520623445510864, 1.0514055490493774, 0.6579300165176392, 3.8547725677490234, 0.022290127351880074, 1.250281572341919, 1.4611568450927734, 0.9922474026679993, -0.10373087227344513, 1.2452247142791748, -0.034555960446596146, 0.43122994899749756, -0.5324862003326416, 0.2732040286064148, 0.9250017404556274, -3.328779935836792, -1.5748193264007568, -1.0212738513946533, -1.2272067070007324, -0.48032277822494507, -0.7660053372383118, -0.6962427496910095, 0.047988180071115494, 0.023193923756480217, 0.682482123374939, -0.17697946727275848, 0.48556575179100037, 0.0, 0.0, -9.177613258361816, -9.150391578674316, -9.759490013122559, -8.824555397033691, -9.518867492675781, -7.745303153991699, -8.442728996276855, -7.631931781768799, -8.069925308227539, -6.969172477722168, -6.897911548614502, -6.484655857086182, -5.815464019775391, -5.870404243469238, -5.391446113586426, -4.611326217651367, -4.681792736053467, -4.495628833770752, -3.968750476837158, -4.548412322998047, -2.325288772583008, -4.777246952056885, -2.3736443519592285, -0.8124991655349731, -2.179525375366211, -0.872422456741333, -2.4902381896972656, -1.3167316913604736, -0.4807341396808624, 0.05522730574011803, 0.5096904635429382, -0.126907616853714, -0.12398691475391388, 0.798045814037323, -0.4472583532333374, -1.3015415668487549, 0.028317902237176895, 2.313990831375122, 1.4801476001739502, -0.5693365931510925, 0.987820029258728, 0.8822210431098938, 0.41149720549583435, 0.5958676338195801, 1.720327615737915, 1.1895880699157715, 1.6241639852523804, 1.4038667678833008, 1.396916151046753, 1.3520623445510864, 1.0514055490493774, 0.6579300165176392, 3.8547725677490234, 0.022290127351880074, 1.250281572341919, 1.4611568450927734, 0.9922474026679993, -0.10373087227344513, 1.2452247142791748, -0.034555960446596146, 0.43122994899749756, -0.5324862003326416, 0.2732040286064148, 0.9250017404556274, -3.328779935836792, -1.5748193264007568, -1.0212738513946533, -1.2272067070007324, -0.48032277822494507, -0.7660053372383118, -0.6962427496910095, 0.047988180071115494, 0.023193923756480217, 0.682482123374939, -0.17697946727275848, 0.48556575179100037, 0.0], [0.0, -9.584936141967773, -10.265020370483398, -7.695870399475098, -8.785557746887207, -8.374113082885742, -8.704556465148926, -9.07459831237793, -8.440434455871582, -7.673798561096191, -6.485191345214844, -7.240242958068848, -6.937724590301514, -6.265515327453613, -6.157434463500977, -4.891968727111816, -5.638556480407715, -4.788544178009033, -1.3556209802627563, -3.6837573051452637, -3.458192825317383, -2.8309082984924316, -1.9037107229232788, -1.286001443862915, -2.373718023300171, -1.692101001739502, -1.48665452003479, -4.187341690063477, -1.6533002853393555, -0.2642551064491272, -0.5844658017158508, -1.513957142829895, 0.3622286915779114, 0.5443103313446045, -0.3127487897872925, -0.9110528230667114, -0.5940598249435425, -0.7958199381828308, 0.5457825660705566, 0.758675754070282, 1.4751360416412354, 1.389101505279541, 1.1185195446014404, 1.4891411066055298, 1.1917225122451782, 2.8892056941986084, 0.8290197253227234, 0.9588468074798584, 0.6611193418502808, 1.3093301057815552, 0.7326797246932983, 0.9164323806762695, 0.591405987739563, 1.6850377321243286, 1.8460358381271362, 1.8783247470855713, 0.8235717415809631, -0.04144563525915146, 0.4227098822593689, 2.1228926181793213, 0.26874664425849915, -0.04606533423066139, -0.38699647784233093, 0.7113039493560791, -1.178044080734253, -0.825904130935669, 0.36536097526550293, -1.3654805421829224, -0.40183842182159424, 0.32874801754951477, -0.3289423882961273, 0.20897626876831055, -0.22635000944137573, -0.7966622710227966, -0.3963901400566101, -0.27072933316230774, -0.052486222237348557, 0.0, 0.0, -9.584936141967773, -10.265020370483398, -7.695870399475098, -8.785557746887207, -8.374113082885742, -8.704556465148926, -9.07459831237793, -8.440434455871582, -7.673798561096191, -6.485191345214844, -7.240242958068848, -6.937724590301514, -6.265515327453613, -6.157434463500977, -4.891968727111816, -5.638556480407715, -4.788544178009033, -1.3556209802627563, -3.6837573051452637, -3.458192825317383, -2.8309082984924316, -1.9037107229232788, -1.286001443862915, -2.373718023300171, -1.692101001739502, -1.48665452003479, -4.187341690063477, -1.6533002853393555, -0.2642551064491272, -0.5844658017158508, -1.513957142829895, 0.3622286915779114, 0.5443103313446045, -0.3127487897872925, -0.9110528230667114, -0.5940598249435425, -0.7958199381828308, 0.5457825660705566, 0.758675754070282, 1.4751360416412354, 1.389101505279541, 1.1185195446014404, 1.4891411066055298, 1.1917225122451782, 2.8892056941986084, 0.8290197253227234, 0.9588468074798584, 0.6611193418502808, 1.3093301057815552, 0.7326797246932983, 0.9164323806762695, 0.591405987739563, 1.6850377321243286, 1.8460358381271362, 1.8783247470855713, 0.8235717415809631, -0.04144563525915146, 0.4227098822593689, 2.1228926181793213, 0.26874664425849915, -0.04606533423066139, -0.38699647784233093, 0.7113039493560791, -1.178044080734253, -0.825904130935669, 0.36536097526550293, -1.3654805421829224, -0.40183842182159424, 0.32874801754951477, -0.3289423882961273, 0.20897626876831055, -0.22635000944137573, -0.7966622710227966, -0.3963901400566101, -0.27072933316230774, -0.052486222237348557, 0.0], [0.0, -11.691939353942871, -9.493038177490234, -9.414140701293945, -9.15782642364502, -8.804123878479004, -9.262043952941895, -9.226948738098145, -8.430906295776367, -6.318821907043457, -7.85158634185791, -6.830227375030518, -6.934271335601807, -6.241396427154541, -6.089528560638428, -5.339277744293213, -4.877939224243164, -4.804159641265869, -3.835618734359741, -3.5434787273406982, -2.7049400806427, -2.0329933166503906, -3.1215031147003174, -0.8511911034584045, -1.9935402870178223, -1.0329076051712036, -1.3874690532684326, -1.3049713373184204, -0.9812853336334229, -2.353400230407715, -0.4955264627933502, -0.9012563824653625, -0.8737452626228333, 0.02659333311021328, 0.1316903680562973, 0.31941142678260803, 0.6154369711875916, 0.280906081199646, -1.2999627590179443, 0.5195240378379822, 0.05791321396827698, 2.599954605102539, 1.1087098121643066, 0.9363025426864624, 0.6033469438552856, 0.8764684200286865, 0.2863348722457886, 1.2982861995697021, 2.423532009124756, 0.5903582572937012, 1.7864397764205933, -0.7929017543792725, 2.641512393951416, -0.0833158791065216, 3.9788129329681396, 0.6260762214660645, 1.6244407892227173, 0.42940884828567505, -0.5728803277015686, -0.12369094789028168, 0.33427268266677856, -0.4774489998817444, -0.801537811756134, -0.8376483917236328, -0.7088626623153687, 0.684551477432251, -0.050305090844631195, -0.9742256999015808, -1.600876808166504, 0.13456226885318756, -0.09441737085580826, 1.3884774446487427, -0.710788369178772, -0.23999769985675812, -0.9113421440124512, -0.7981410026550293, -2.046110153198242, 0.0, 0.0, -11.691939353942871, -9.493038177490234, -9.414140701293945, -9.15782642364502, -8.804123878479004, -9.262043952941895, -9.226948738098145, -8.430906295776367, -6.318821907043457, -7.85158634185791, -6.830227375030518, -6.934271335601807, -6.241396427154541, -6.089528560638428, -5.339277744293213, -4.877939224243164, -4.804159641265869, -3.835618734359741, -3.5434787273406982, -2.7049400806427, -2.0329933166503906, -3.1215031147003174, -0.8511911034584045, -1.9935402870178223, -1.0329076051712036, -1.3874690532684326, -1.3049713373184204, -0.9812853336334229, -2.353400230407715, -0.4955264627933502, -0.9012563824653625, -0.8737452626228333, 0.02659333311021328, 0.1316903680562973, 0.31941142678260803, 0.6154369711875916, 0.280906081199646, -1.2999627590179443, 0.5195240378379822, 0.05791321396827698, 2.599954605102539, 1.1087098121643066, 0.9363025426864624, 0.6033469438552856, 0.8764684200286865, 0.2863348722457886, 1.2982861995697021, 2.423532009124756, 0.5903582572937012, 1.7864397764205933, -0.7929017543792725, 2.641512393951416, -0.0833158791065216, 3.9788129329681396, 0.6260762214660645, 1.6244407892227173, 0.42940884828567505, -0.5728803277015686, -0.12369094789028168, 0.33427268266677856, -0.4774489998817444, -0.801537811756134, -0.8376483917236328, -0.7088626623153687, 0.684551477432251, -0.050305090844631195, -0.9742256999015808, -1.600876808166504, 0.13456226885318756, -0.09441737085580826, 1.3884774446487427, -0.710788369178772, -0.23999769985675812, -0.9113421440124512, -0.7981410026550293, -2.046110153198242, 0.0], [0.0, -10.764739990234375, -10.324376106262207, -9.886802673339844, -9.816926956176758, -10.11599063873291, -9.800628662109375, -9.266343116760254, -8.981996536254883, -7.699080467224121, -7.697093963623047, -7.956436634063721, -7.094203948974609, -7.043259620666504, -5.5715837478637695, -5.629724025726318, -5.209850788116455, -4.926290988922119, -4.343167781829834, -1.837978720664978, -3.0192980766296387, -2.4430346488952637, -2.6597514152526855, -2.164508581161499, -2.0569000244140625, 1.3652029037475586, -1.3914703130722046, -1.4904407262802124, -0.9544704556465149, -1.096055269241333, -0.9774766564369202, -0.5623098015785217, 0.23404109477996826, 0.27657827734947205, -0.9144689440727234, 0.7227303981781006, -0.6516032218933105, 0.278273344039917, 0.7125864028930664, 1.1146161556243896, 1.008029580116272, 1.6538900136947632, 0.38152316212654114, 1.0611122846603394, 1.3442966938018799, 1.6599215269088745, 1.6800340414047241, 1.3635287284851074, 1.022918701171875, 0.191867396235466, 1.2487599849700928, 0.9397431015968323, 1.7506636381149292, 0.848427414894104, 2.8857669830322266, 0.13044151663780212, 1.1904513835906982, 0.6469496488571167, -0.3009723424911499, -0.11642121523618698, -0.030405323952436447, -0.47236964106559753, -0.1353103667497635, -0.767625093460083, -1.6440002918243408, -1.3560125827789307, -1.6667473316192627, -0.9333854913711548, -1.463803768157959, -0.6468821167945862, -0.9968430995941162, -0.7466402649879456, -1.1683429479599, -0.782978892326355, -1.153489351272583, -2.141810894012451, -1.8304321765899658, 0.0, 0.0, -10.764739990234375, -10.324376106262207, -9.886802673339844, -9.816926956176758, -10.11599063873291, -9.800628662109375, -9.266343116760254, -8.981996536254883, -7.699080467224121, -7.697093963623047, -7.956436634063721, -7.094203948974609, -7.043259620666504, -5.5715837478637695, -5.629724025726318, -5.209850788116455, -4.926290988922119, -4.343167781829834, -1.837978720664978, -3.0192980766296387, -2.4430346488952637, -2.6597514152526855, -2.164508581161499, -2.0569000244140625, 1.3652029037475586, -1.3914703130722046, -1.4904407262802124, -0.9544704556465149, -1.096055269241333, -0.9774766564369202, -0.5623098015785217, 0.23404109477996826, 0.27657827734947205, -0.9144689440727234, 0.7227303981781006, -0.6516032218933105, 0.278273344039917, 0.7125864028930664, 1.1146161556243896, 1.008029580116272, 1.6538900136947632, 0.38152316212654114, 1.0611122846603394, 1.3442966938018799, 1.6599215269088745, 1.6800340414047241, 1.3635287284851074, 1.022918701171875, 0.191867396235466, 1.2487599849700928, 0.9397431015968323, 1.7506636381149292, 0.848427414894104, 2.8857669830322266, 0.13044151663780212, 1.1904513835906982, 0.6469496488571167, -0.3009723424911499, -0.11642121523618698, -0.030405323952436447, -0.47236964106559753, -0.1353103667497635, -0.767625093460083, -1.6440002918243408, -1.3560125827789307, -1.6667473316192627, -0.9333854913711548, -1.463803768157959, -0.6468821167945862, -0.9968430995941162, -0.7466402649879456, -1.1683429479599, -0.782978892326355, -1.153489351272583, -2.141810894012451, -1.8304321765899658, 0.0], [0.0, -11.377140045166016, -10.580568313598633, -10.880471229553223, -10.240413665771484, -10.656465530395508, -9.716827392578125, -8.443851470947266, -9.148194313049316, -8.886359214782715, -8.138908386230469, -7.71143913269043, -7.364774227142334, -7.164237022399902, -6.154930114746094, -5.788563251495361, -5.8797993659973145, -5.0953755378723145, -4.900664806365967, -1.9462858438491821, -3.5964667797088623, -3.4622747898101807, -2.01900053024292, -2.613476514816284, -2.500854015350342, -1.5777268409729004, -1.5783650875091553, -0.6630232334136963, -0.9796547889709473, -1.1582567691802979, 1.1120193004608154, -0.522838294506073, 1.4766205549240112, 0.24131998419761658, 0.4573729336261749, -1.5545499324798584, 1.3946114778518677, 0.30761268734931946, 0.9314072728157043, 0.8544423580169678, 1.0756328105926514, 0.9450827240943909, -1.5512194633483887, 1.6794353723526, 1.829813838005066, 1.6344422101974487, 1.3582568168640137, 2.6511542797088623, -1.3186911344528198, -0.04600561410188675, 1.5958484411239624, 0.830299973487854, 0.5501644015312195, 0.9041943550109863, 0.2974761426448822, 1.726757287979126, 0.3057458698749542, 0.1926642805337906, -1.2698036432266235, -0.6949207782745361, -0.4730493128299713, 0.8049793243408203, 0.14900219440460205, -0.9297521114349365, 0.35993772745132446, -1.1126821041107178, -1.3701951503753662, -1.4209831953048706, -0.7810509204864502, -2.1043238639831543, -1.6032272577285767, -1.0878061056137085, -0.8496307730674744, -0.5635989308357239, -0.6641985177993774, -0.7430437803268433, -3.1975202560424805, 0.0, 0.0, -11.377140045166016, -10.580568313598633, -10.880471229553223, -10.240413665771484, -10.656465530395508, -9.716827392578125, -8.443851470947266, -9.148194313049316, -8.886359214782715, -8.138908386230469, -7.71143913269043, -7.364774227142334, -7.164237022399902, -6.154930114746094, -5.788563251495361, -5.8797993659973145, -5.0953755378723145, -4.900664806365967, -1.9462858438491821, -3.5964667797088623, -3.4622747898101807, -2.01900053024292, -2.613476514816284, -2.500854015350342, -1.5777268409729004, -1.5783650875091553, -0.6630232334136963, -0.9796547889709473, -1.1582567691802979, 1.1120193004608154, -0.522838294506073, 1.4766205549240112, 0.24131998419761658, 0.4573729336261749, -1.5545499324798584, 1.3946114778518677, 0.30761268734931946, 0.9314072728157043, 0.8544423580169678, 1.0756328105926514, 0.9450827240943909, -1.5512194633483887, 1.6794353723526, 1.829813838005066, 1.6344422101974487, 1.3582568168640137, 2.6511542797088623, -1.3186911344528198, -0.04600561410188675, 1.5958484411239624, 0.830299973487854, 0.5501644015312195, 0.9041943550109863, 0.2974761426448822, 1.726757287979126, 0.3057458698749542, 0.1926642805337906, -1.2698036432266235, -0.6949207782745361, -0.4730493128299713, 0.8049793243408203, 0.14900219440460205, -0.9297521114349365, 0.35993772745132446, -1.1126821041107178, -1.3701951503753662, -1.4209831953048706, -0.7810509204864502, -2.1043238639831543, -1.6032272577285767, -1.0878061056137085, -0.8496307730674744, -0.5635989308357239, -0.6641985177993774, -0.7430437803268433, -3.1975202560424805, 0.0], [0.0, -11.593354225158691, -11.423067092895508, -10.435574531555176, -10.15639591217041, -10.737401962280273, -10.065990447998047, -9.742020606994629, -9.567849159240723, -10.24274730682373, -8.357702255249023, -7.119746685028076, -7.404335021972656, -7.827888011932373, -5.959296226501465, -6.417610168457031, -5.7148284912109375, -5.555558204650879, -4.070709228515625, -3.3852291107177734, -3.4682297706604004, -2.7546589374542236, -1.4721697568893433, 0.7315507531166077, -2.4558093547821045, -1.8628956079483032, -0.45081081986427307, -3.731170654296875, -2.876929759979248, -0.7170401811599731, -1.504323959350586, 0.04311750829219818, 0.12901532649993896, 0.16915307939052582, 0.4522317349910736, 1.1309514045715332, -0.5340431928634644, 0.9082922339439392, 0.4793001115322113, 1.0744518041610718, 0.8139222860336304, 3.3654003143310547, 1.0779881477355957, 1.1805243492126465, 1.9648008346557617, 1.0570454597473145, 1.853469967842102, 0.8613467812538147, 0.4768977761268616, 1.3795230388641357, 1.398498296737671, 1.7272976636886597, 2.1166749000549316, 0.8997694253921509, -0.15297242999076843, -0.9583940505981445, -0.276099294424057, -0.37704548239707947, -0.5170670747756958, 0.27762845158576965, -0.04253866523504257, -0.180680513381958, -0.1334296464920044, -1.2724063396453857, -1.4491678476333618, -1.4168564081192017, -0.803692102432251, -1.158394455909729, -1.0439562797546387, -1.2889164686203003, -1.3265933990478516, -1.3804388046264648, -0.4584645926952362, -0.514748215675354, 0.6397907733917236, -0.1389157921075821, -1.767184853553772, 0.0, 0.0, -11.593354225158691, -11.423067092895508, -10.435574531555176, -10.15639591217041, -10.737401962280273, -10.065990447998047, -9.742020606994629, -9.567849159240723, -10.24274730682373, -8.357702255249023, -7.119746685028076, -7.404335021972656, -7.827888011932373, -5.959296226501465, -6.417610168457031, -5.7148284912109375, -5.555558204650879, -4.070709228515625, -3.3852291107177734, -3.4682297706604004, -2.7546589374542236, -1.4721697568893433, 0.7315507531166077, -2.4558093547821045, -1.8628956079483032, -0.45081081986427307, -3.731170654296875, -2.876929759979248, -0.7170401811599731, -1.504323959350586, 0.04311750829219818, 0.12901532649993896, 0.16915307939052582, 0.4522317349910736, 1.1309514045715332, -0.5340431928634644, 0.9082922339439392, 0.4793001115322113, 1.0744518041610718, 0.8139222860336304, 3.3654003143310547, 1.0779881477355957, 1.1805243492126465, 1.9648008346557617, 1.0570454597473145, 1.853469967842102, 0.8613467812538147, 0.4768977761268616, 1.3795230388641357, 1.398498296737671, 1.7272976636886597, 2.1166749000549316, 0.8997694253921509, -0.15297242999076843, -0.9583940505981445, -0.276099294424057, -0.37704548239707947, -0.5170670747756958, 0.27762845158576965, -0.04253866523504257, -0.180680513381958, -0.1334296464920044, -1.2724063396453857, -1.4491678476333618, -1.4168564081192017, -0.803692102432251, -1.158394455909729, -1.0439562797546387, -1.2889164686203003, -1.3265933990478516, -1.3804388046264648, -0.4584645926952362, -0.514748215675354, 0.6397907733917236, -0.1389157921075821, -1.767184853553772, 0.0], [0.0, -11.673303604125977, -12.009238243103027, -10.581323623657227, -11.171278953552246, -10.773091316223145, -10.309179306030273, -9.840822219848633, -10.090051651000977, -8.622932434082031, -9.323735237121582, -8.733795166015625, -8.190773010253906, -7.195577621459961, -6.812128067016602, -6.383209705352783, -6.236340522766113, -5.49520206451416, -4.649698257446289, -4.730006217956543, -3.2277538776397705, -4.347014904022217, -3.2244064807891846, 0.18087300658226013, -1.7761633396148682, -3.80181622505188, -1.562532901763916, -0.4614408612251282, -0.6528348922729492, -0.41469818353652954, -1.1474493741989136, -0.37970471382141113, -0.1486966758966446, 0.7303907871246338, 0.043818507343530655, 0.07669307291507721, -0.17903289198875427, 0.6708694696426392, 1.6959177255630493, 0.49211376905441284, 0.9274703860282898, -0.2602681517601013, -0.6075944900512695, 1.2288768291473389, -0.016769500449299812, 0.9270721077919006, 3.29459810256958, 1.1159261465072632, 0.589976966381073, -0.8908588290214539, 0.9203968048095703, 1.584872841835022, 1.0584348440170288, 0.5258515477180481, -0.1774529069662094, -0.7383607029914856, 1.1558741331100464, 0.5403093099594116, -0.12692971527576447, -0.29264214634895325, 0.2210378497838974, -1.4543145895004272, 0.38716140389442444, -0.5936782956123352, -0.8674783110618591, -1.4127262830734253, -1.2604035139083862, -1.3849505186080933, -1.1721646785736084, -1.3108532428741455, -0.7389504909515381, -1.3700566291809082, -1.2650201320648193, -0.9593995809555054, 0.3907703757286072, -0.8670604228973389, -1.4356275796890259, -1.4316800832748413, 0.0, -11.673303604125977, -12.009238243103027, -10.581323623657227, -11.171278953552246, -10.773091316223145, -10.309179306030273, -9.840822219848633, -10.090051651000977, -8.622932434082031, -9.323735237121582, -8.733795166015625, -8.190773010253906, -7.195577621459961, -6.812128067016602, -6.383209705352783, -6.236340522766113, -5.49520206451416, -4.649698257446289, -4.730006217956543, -3.2277538776397705, -4.347014904022217, -3.2244064807891846, 0.18087300658226013, -1.7761633396148682, -3.80181622505188, -1.562532901763916, -0.4614408612251282, -0.6528348922729492, -0.41469818353652954, -1.1474493741989136, -0.37970471382141113, -0.1486966758966446, 0.7303907871246338, 0.043818507343530655, 0.07669307291507721, -0.17903289198875427, 0.6708694696426392, 1.6959177255630493, 0.49211376905441284, 0.9274703860282898, -0.2602681517601013, -0.6075944900512695, 1.2288768291473389, -0.016769500449299812, 0.9270721077919006, 3.29459810256958, 1.1159261465072632, 0.589976966381073, -0.8908588290214539, 0.9203968048095703, 1.584872841835022, 1.0584348440170288, 0.5258515477180481, -0.1774529069662094, -0.7383607029914856, 1.1558741331100464, 0.5403093099594116, -0.12692971527576447, -0.29264214634895325, 0.2210378497838974, -1.4543145895004272, 0.38716140389442444, -0.5936782956123352, -0.8674783110618591, -1.4127262830734253, -1.2604035139083862, -1.3849505186080933, -1.1721646785736084, -1.3108532428741455, -0.7389504909515381, -1.3700566291809082, -1.2650201320648193, -0.9593995809555054, 0.3907703757286072, -0.8670604228973389, -1.4356275796890259, -1.4316800832748413], [-14.238969802856445, -12.051715850830078, -11.760245323181152, -11.06611156463623, -11.952720642089844, -10.69140338897705, -10.513060569763184, -10.438494682312012, -10.109326362609863, -8.892359733581543, -8.822165489196777, -8.622581481933594, -8.042972564697266, -7.528074264526367, -6.3544816970825195, -7.449170112609863, -5.758773326873779, -4.794198513031006, -5.739172458648682, -4.351577281951904, -3.4633984565734863, -2.3832664489746094, -3.979722261428833, -3.1251533031463623, -2.530958652496338, -1.441816806793213, -1.6232895851135254, -3.0750858783721924, -1.2639083862304688, -1.6386077404022217, -0.013546817004680634, 0.5950817465782166, -0.7247831225395203, 0.08232143521308899, 0.01893937960267067, 0.3181072175502777, -1.6785812377929688, -3.7749011516571045, 0.22918900847434998, 1.1243356466293335, 0.33270207047462463, 0.24080733954906464, -0.10442382097244263, 3.9085609912872314, 1.5366226434707642, 0.44428446888923645, 1.1923398971557617, 1.425467610359192, 1.1550893783569336, 1.4935133457183838, 1.2449733018875122, -0.34730446338653564, 2.848674774169922, 0.8072864413261414, 1.5495351552963257, 0.4774876832962036, -0.5059875845909119, -0.0011062802514061332, -0.9827379584312439, -0.2851976752281189, -0.40141820907592773, -0.5126549005508423, -0.1025119423866272, 0.24554775655269623, -1.0271046161651611, -1.1322954893112183, -1.9204853773117065, -1.3140555620193481, -2.3472564220428467, -2.0230603218078613, -1.845630407333374, -0.22919996082782745, -1.0393601655960083, -1.3616458177566528, -1.107622742652893, -1.9817806482315063, -1.2176525592803955, 2.2489640712738037, -14.238969802856445, -12.051715850830078, -11.760245323181152, -11.06611156463623, -11.952720642089844, -10.69140338897705, -10.513060569763184, -10.438494682312012, -10.109326362609863, -8.892359733581543, -8.822165489196777, -8.622581481933594, -8.042972564697266, -7.528074264526367, -6.3544816970825195, -7.449170112609863, -5.758773326873779, -4.794198513031006, -5.739172458648682, -4.351577281951904, -3.4633984565734863, -2.3832664489746094, -3.979722261428833, -3.1251533031463623, -2.530958652496338, -1.441816806793213, -1.6232895851135254, -3.0750858783721924, -1.2639083862304688, -1.6386077404022217, -0.013546817004680634, 0.5950817465782166, -0.7247831225395203, 0.08232143521308899, 0.01893937960267067, 0.3181072175502777, -1.6785812377929688, -3.7749011516571045, 0.22918900847434998, 1.1243356466293335, 0.33270207047462463, 0.24080733954906464, -0.10442382097244263, 3.9085609912872314, 1.5366226434707642, 0.44428446888923645, 1.1923398971557617, 1.425467610359192, 1.1550893783569336, 1.4935133457183838, 1.2449733018875122, -0.34730446338653564, 2.848674774169922, 0.8072864413261414, 1.5495351552963257, 0.4774876832962036, -0.5059875845909119, -0.0011062802514061332, -0.9827379584312439, -0.2851976752281189, -0.40141820907592773, -0.5126549005508423, -0.1025119423866272, 0.24554775655269623, -1.0271046161651611, -1.1322954893112183, -1.9204853773117065, -1.3140555620193481, -2.3472564220428467, -2.0230603218078613, -1.845630407333374, -0.22919996082782745, -1.0393601655960083, -1.3616458177566528, -1.107622742652893, -1.9817806482315063, -1.2176525592803955, 2.2489640712738037], [-12.336322784423828, -11.60444450378418, -11.542243003845215, -11.718880653381348, -11.722939491271973, -11.330473899841309, -10.44672966003418, -10.361766815185547, -10.22154426574707, -10.213390350341797, -9.357767105102539, -9.198164939880371, -8.468856811523438, -7.877450466156006, -7.496587753295898, -6.8509674072265625, -6.52981424331665, -2.5470001697540283, -4.321841716766357, -5.90596342086792, -5.373638153076172, -5.181140899658203, -3.58963942527771, -3.2372829914093018, -2.796039342880249, -2.0603742599487305, -2.0912668704986572, -0.9483883380889893, -2.098191499710083, -0.847408652305603, -0.26219362020492554, -0.9024172425270081, 1.0102818012237549, -0.589921236038208, -0.3622486889362335, -1.7492032051086426, -0.13278034329414368, -1.3109445571899414, -0.917725682258606, -0.7021138668060303, 0.7842171788215637, 0.7649263739585876, 1.3094687461853027, 1.7188489437103271, 1.2750890254974365, 1.2481858730316162, 1.1741820573806763, 0.06569447368383408, 0.7601165771484375, 0.7179259061813354, 0.6603490114212036, 1.8922473192214966, 0.32177311182022095, 0.9697586894035339, -0.32761478424072266, -0.1640571653842926, -1.1716817617416382, -0.06086341664195061, 0.3699960708618164, -0.966026246547699, -0.45603182911872864, -1.6477525234222412, -1.150285005569458, -0.06633053719997406, -1.0235233306884766, -0.4487742483615875, -2.043626070022583, -1.3470927476882935, -1.0902642011642456, -2.431567668914795, -1.742769718170166, -1.653258204460144, -0.5733476281166077, -1.1414891481399536, -1.0798391103744507, -1.1183527708053589, -0.9086011648178101, 3.392266273498535, -12.336322784423828, -11.60444450378418, -11.542243003845215, -11.718880653381348, -11.722939491271973, -11.330473899841309, -10.44672966003418, -10.361766815185547, -10.22154426574707, -10.213390350341797, -9.357767105102539, -9.198164939880371, -8.468856811523438, -7.877450466156006, -7.496587753295898, -6.8509674072265625, -6.52981424331665, -2.5470001697540283, -4.321841716766357, -5.90596342086792, -5.373638153076172, -5.181140899658203, -3.58963942527771, -3.2372829914093018, -2.796039342880249, -2.0603742599487305, -2.0912668704986572, -0.9483883380889893, -2.098191499710083, -0.847408652305603, -0.26219362020492554, -0.9024172425270081, 1.0102818012237549, -0.589921236038208, -0.3622486889362335, -1.7492032051086426, -0.13278034329414368, -1.3109445571899414, -0.917725682258606, -0.7021138668060303, 0.7842171788215637, 0.7649263739585876, 1.3094687461853027, 1.7188489437103271, 1.2750890254974365, 1.2481858730316162, 1.1741820573806763, 0.06569447368383408, 0.7601165771484375, 0.7179259061813354, 0.6603490114212036, 1.8922473192214966, 0.32177311182022095, 0.9697586894035339, -0.32761478424072266, -0.1640571653842926, -1.1716817617416382, -0.06086341664195061, 0.3699960708618164, -0.966026246547699, -0.45603182911872864, -1.6477525234222412, -1.150285005569458, -0.06633053719997406, -1.0235233306884766, -0.4487742483615875, -2.043626070022583, -1.3470927476882935, -1.0902642011642456, -2.431567668914795, -1.742769718170166, -1.653258204460144, -0.5733476281166077, -1.1414891481399536, -1.0798391103744507, -1.1183527708053589, -0.9086011648178101, 3.392266273498535], [-11.087982177734375, -11.76352310180664, -12.200423240661621, -12.203113555908203, -11.167159080505371, -13.49413013458252, -11.514374732971191, -11.183778762817383, -10.58885669708252, -9.73564338684082, -9.481553077697754, -7.861195087432861, -9.193456649780273, -8.661316871643066, -6.623584747314453, -7.186995983123779, -5.584329605102539, -5.079361438751221, -5.250768184661865, -4.252197742462158, -3.699241876602173, -5.2932047843933105, -3.902059555053711, -2.584256410598755, -2.4751906394958496, -2.9108641147613525, -2.0641591548919678, -2.0054612159729004, -1.699397087097168, -0.8753645420074463, -1.4514182806015015, -1.136390209197998, -0.6689255833625793, -0.2421015053987503, -0.5366033315658569, 0.2578233778476715, 0.3116735816001892, -0.14086775481700897, -0.013035610318183899, -0.046597905457019806, 1.1523723602294922, -0.4432094991207123, 0.7933154106140137, 2.465466260910034, 0.3262118101119995, -0.9459018707275391, 1.4792934656143188, -1.392545223236084, 0.5656919479370117, 3.3565096855163574, 1.3852639198303223, 1.1971995830535889, 0.7482268214225769, 0.37463393807411194, -0.6795859336853027, -0.515095591545105, 2.444037675857544, -0.498393714427948, 0.35018253326416016, 1.102171540260315, 0.05925103276968002, -1.3193541765213013, -1.553317666053772, -0.6219391226768494, -1.269620656967163, -0.7824813723564148, -1.8419039249420166, -1.2979953289031982, -1.218084454536438, -1.9683464765548706, -0.20193791389465332, -1.0914167165756226, -1.6986459493637085, -1.1104214191436768, -1.2654067277908325, -0.4020024538040161, 1.5368434190750122, 2.7070183753967285, -11.087982177734375, -11.76352310180664, -12.200423240661621, -12.203113555908203, -11.167159080505371, -13.49413013458252, -11.514374732971191, -11.183778762817383, -10.58885669708252, -9.73564338684082, -9.481553077697754, -7.861195087432861, -9.193456649780273, -8.661316871643066, -6.623584747314453, -7.186995983123779, -5.584329605102539, -5.079361438751221, -5.250768184661865, -4.252197742462158, -3.699241876602173, -5.2932047843933105, -3.902059555053711, -2.584256410598755, -2.4751906394958496, -2.9108641147613525, -2.0641591548919678, -2.0054612159729004, -1.699397087097168, -0.8753645420074463, -1.4514182806015015, -1.136390209197998, -0.6689255833625793, -0.2421015053987503, -0.5366033315658569, 0.2578233778476715, 0.3116735816001892, -0.14086775481700897, -0.013035610318183899, -0.046597905457019806, 1.1523723602294922, -0.4432094991207123, 0.7933154106140137, 2.465466260910034, 0.3262118101119995, -0.9459018707275391, 1.4792934656143188, -1.392545223236084, 0.5656919479370117, 3.3565096855163574, 1.3852639198303223, 1.1971995830535889, 0.7482268214225769, 0.37463393807411194, -0.6795859336853027, -0.515095591545105, 2.444037675857544, -0.498393714427948, 0.35018253326416016, 1.102171540260315, 0.05925103276968002, -1.3193541765213013, -1.553317666053772, -0.6219391226768494, -1.269620656967163, -0.7824813723564148, -1.8419039249420166, -1.2979953289031982, -1.218084454536438, -1.9683464765548706, -0.20193791389465332, -1.0914167165756226, -1.6986459493637085, -1.1104214191436768, -1.2654067277908325, -0.4020024538040161, 1.5368434190750122, 2.7070183753967285], [0.0, -10.557575225830078, -12.10400390625, -12.267868995666504, -11.882389068603516, -11.414763450622559, -11.525155067443848, -10.916766166687012, -10.369986534118652, -9.781610488891602, -8.996145248413086, -8.418088912963867, -8.615138053894043, -8.490033149719238, -7.37259578704834, -5.969110488891602, -6.345205783843994, -6.262834548950195, -5.688472747802734, -4.724997520446777, -3.3290281295776367, -4.063454627990723, -5.008404731750488, -4.575507640838623, -3.468879222869873, -2.0468931198120117, -1.8327105045318604, -0.8694559931755066, -1.6894183158874512, -1.2036842107772827, -1.5333713293075562, -0.6982272863388062, -1.0542500019073486, -1.7110350131988525, 0.3943963646888733, -0.5552566051483154, -1.2118991613388062, 0.34496769309043884, -0.48913121223449707, -0.32265523076057434, -0.8225215077400208, -0.6762059926986694, 0.3776697814464569, -0.43385252356529236, 0.099298395216465, 0.33277085423469543, 0.7923279404640198, 1.0833467245101929, 1.8800172805786133, 0.9577233195304871, -0.11147434264421463, -0.5861337780952454, 0.4784068167209625, 0.08170770853757858, 0.8476216197013855, -0.2977205216884613, -0.9032253623008728, 0.20804741978645325, -0.1978418380022049, -1.7545185089111328, -0.8674848675727844, -1.082218050956726, -1.0097849369049072, -0.6812865138053894, -1.4306434392929077, -1.8294143676757812, -1.262474536895752, -1.1395326852798462, -0.7407045364379883, -1.6140172481536865, -1.1495119333267212, -1.1880195140838623, -0.748347818851471, -0.8533961176872253, -1.0702269077301025, -0.3584691882133484, 1.617514967918396, 2.1961934566497803, 0.0, -10.557575225830078, -12.10400390625, -12.267868995666504, -11.882389068603516, -11.414763450622559, -11.525155067443848, -10.916766166687012, -10.369986534118652, -9.781610488891602, -8.996145248413086, -8.418088912963867, -8.615138053894043, -8.490033149719238, -7.37259578704834, -5.969110488891602, -6.345205783843994, -6.262834548950195, -5.688472747802734, -4.724997520446777, -3.3290281295776367, -4.063454627990723, -5.008404731750488, -4.575507640838623, -3.468879222869873, -2.0468931198120117, -1.8327105045318604, -0.8694559931755066, -1.6894183158874512, -1.2036842107772827, -1.5333713293075562, -0.6982272863388062, -1.0542500019073486, -1.7110350131988525, 0.3943963646888733, -0.5552566051483154, -1.2118991613388062, 0.34496769309043884, -0.48913121223449707, -0.32265523076057434, -0.8225215077400208, -0.6762059926986694, 0.3776697814464569, -0.43385252356529236, 0.099298395216465, 0.33277085423469543, 0.7923279404640198, 1.0833467245101929, 1.8800172805786133, 0.9577233195304871, -0.11147434264421463, -0.5861337780952454, 0.4784068167209625, 0.08170770853757858, 0.8476216197013855, -0.2977205216884613, -0.9032253623008728, 0.20804741978645325, -0.1978418380022049, -1.7545185089111328, -0.8674848675727844, -1.082218050956726, -1.0097849369049072, -0.6812865138053894, -1.4306434392929077, -1.8294143676757812, -1.262474536895752, -1.1395326852798462, -0.7407045364379883, -1.6140172481536865, -1.1495119333267212, -1.1880195140838623, -0.748347818851471, -0.8533961176872253, -1.0702269077301025, -0.3584691882133484, 1.617514967918396, 2.1961934566497803], [0.0, -10.670563697814941, -11.780448913574219, -11.743611335754395, -11.147700309753418, -11.051513671875, -11.460771560668945, -10.80867862701416, -10.46975326538086, -10.101530075073242, -8.96558952331543, -10.024255752563477, -9.400516510009766, -7.740398406982422, -7.914981365203857, -7.696774005889893, -5.296664237976074, -6.0352277755737305, -6.043966770172119, -5.625864028930664, -3.69461727142334, -4.634382247924805, -4.214236736297607, -6.727595329284668, -4.5176100730896, -2.0815563201904297, -2.5289528369903564, -3.1135365962982178, -2.265207290649414, -2.1729207038879395, -0.6611104011535645, -0.7405033111572266, -0.34037333726882935, -2.9517204761505127, -0.7214796543121338, -0.8832773566246033, -0.6557738780975342, -1.0667661428451538, -1.1122148036956787, -1.0069645643234253, -0.4867948591709137, -1.4801656007766724, -1.4939053058624268, -2.2797913551330566, 0.06773301959037781, -0.3549438714981079, 0.6099158525466919, 1.4748929738998413, 0.8147107362747192, 0.23182864487171173, 0.018120305612683296, -0.8435696959495544, -0.25392982363700867, 0.2717166244983673, 0.08912748843431473, -0.5833119750022888, 0.04826721176505089, 0.4891335368156433, -0.13666903972625732, 0.02963198721408844, -1.4147303104400635, -1.3353486061096191, -1.3656277656555176, -0.9193381071090698, -1.5404911041259766, -2.1954715251922607, -1.8155804872512817, -1.417320728302002, -1.2409948110580444, -1.5830591917037964, -2.7328484058380127, -1.157697319984436, -1.2769017219543457, -1.0935838222503662, 0.9793341755867004, -0.632035493850708, 0.4085107147693634, 1.6978217363357544, 0.0, -10.670563697814941, -11.780448913574219, -11.743611335754395, -11.147700309753418, -11.051513671875, -11.460771560668945, -10.80867862701416, -10.46975326538086, -10.101530075073242, -8.96558952331543, -10.024255752563477, -9.400516510009766, -7.740398406982422, -7.914981365203857, -7.696774005889893, -5.296664237976074, -6.0352277755737305, -6.043966770172119, -5.625864028930664, -3.69461727142334, -4.634382247924805, -4.214236736297607, -6.727595329284668, -4.5176100730896, -2.0815563201904297, -2.5289528369903564, -3.1135365962982178, -2.265207290649414, -2.1729207038879395, -0.6611104011535645, -0.7405033111572266, -0.34037333726882935, -2.9517204761505127, -0.7214796543121338, -0.8832773566246033, -0.6557738780975342, -1.0667661428451538, -1.1122148036956787, -1.0069645643234253, -0.4867948591709137, -1.4801656007766724, -1.4939053058624268, -2.2797913551330566, 0.06773301959037781, -0.3549438714981079, 0.6099158525466919, 1.4748929738998413, 0.8147107362747192, 0.23182864487171173, 0.018120305612683296, -0.8435696959495544, -0.25392982363700867, 0.2717166244983673, 0.08912748843431473, -0.5833119750022888, 0.04826721176505089, 0.4891335368156433, -0.13666903972625732, 0.02963198721408844, -1.4147303104400635, -1.3353486061096191, -1.3656277656555176, -0.9193381071090698, -1.5404911041259766, -2.1954715251922607, -1.8155804872512817, -1.417320728302002, -1.2409948110580444, -1.5830591917037964, -2.7328484058380127, -1.157697319984436, -1.2769017219543457, -1.0935838222503662, 0.9793341755867004, -0.632035493850708, 0.4085107147693634, 1.6978217363357544], [0.0, -10.482580184936523, -11.560831069946289, -11.271870613098145, -12.43435287475586, -12.239171028137207, -11.453895568847656, -10.752062797546387, -10.821483612060547, -9.84358024597168, -9.553640365600586, -10.600095748901367, -7.250148773193359, -8.304523468017578, -8.165664672851562, -7.197486400604248, -6.6769208908081055, -6.0724005699157715, -5.234301567077637, -5.625650882720947, -1.5898276567459106, -4.3954010009765625, -3.246941328048706, -4.762835502624512, -3.939636468887329, -3.568359613418579, -1.1896398067474365, -2.244684934616089, -3.1119139194488525, -2.8218653202056885, -1.0513489246368408, -1.8613189458847046, -1.375265121459961, -4.96380615234375, -0.1522323191165924, -1.5509146451950073, -1.1059465408325195, -1.7065538167953491, -2.140439987182617, -1.4266610145568848, -0.8464621305465698, -1.9185847043991089, 1.3221185207366943, -0.6324712038040161, -0.5866764187812805, -3.0599019527435303, -0.8378787040710449, -3.0077266693115234, -1.048431396484375, -1.5236238241195679, -0.5247119665145874, -0.938238263130188, 1.794203758239746, -0.4460286498069763, -0.6668739914894104, -2.2220327854156494, -0.7112330794334412, -0.18382319808006287, 0.22298428416252136, 0.7315434813499451, 0.25093916058540344, -0.7006320357322693, -1.0519853830337524, -1.1977481842041016, -0.5563995838165283, 1.014559268951416, -0.9468594193458557, -1.3777364492416382, -1.6144105195999146, -1.4777464866638184, -2.3160929679870605, -1.8622424602508545, -1.7430107593536377, -1.0427372455596924, -0.9674344658851624, -0.8824828863143921, 1.0665905475616455, 0.6987473964691162, 0.0, -10.482580184936523, -11.560831069946289, -11.271870613098145, -12.43435287475586, -12.239171028137207, -11.453895568847656, -10.752062797546387, -10.821483612060547, -9.84358024597168, -9.553640365600586, -10.600095748901367, -7.250148773193359, -8.304523468017578, -8.165664672851562, -7.197486400604248, -6.6769208908081055, -6.0724005699157715, -5.234301567077637, -5.625650882720947, -1.5898276567459106, -4.3954010009765625, -3.246941328048706, -4.762835502624512, -3.939636468887329, -3.568359613418579, -1.1896398067474365, -2.244684934616089, -3.1119139194488525, -2.8218653202056885, -1.0513489246368408, -1.8613189458847046, -1.375265121459961, -4.96380615234375, -0.1522323191165924, -1.5509146451950073, -1.1059465408325195, -1.7065538167953491, -2.140439987182617, -1.4266610145568848, -0.8464621305465698, -1.9185847043991089, 1.3221185207366943, -0.6324712038040161, -0.5866764187812805, -3.0599019527435303, -0.8378787040710449, -3.0077266693115234, -1.048431396484375, -1.5236238241195679, -0.5247119665145874, -0.938238263130188, 1.794203758239746, -0.4460286498069763, -0.6668739914894104, -2.2220327854156494, -0.7112330794334412, -0.18382319808006287, 0.22298428416252136, 0.7315434813499451, 0.25093916058540344, -0.7006320357322693, -1.0519853830337524, -1.1977481842041016, -0.5563995838165283, 1.014559268951416, -0.9468594193458557, -1.3777364492416382, -1.6144105195999146, -1.4777464866638184, -2.3160929679870605, -1.8622424602508545, -1.7430107593536377, -1.0427372455596924, -0.9674344658851624, -0.8824828863143921, 1.0665905475616455, 0.6987473964691162], [0.0, -10.49825382232666, -11.356956481933594, -11.681902885437012, -11.6539888381958, -11.478848457336426, -10.927058219909668, -10.633784294128418, -9.268192291259766, -10.538052558898926, -11.671679496765137, -8.051583290100098, -8.920650482177734, -5.9258856773376465, -8.516287803649902, -7.380185604095459, -6.999535083770752, -5.845778465270996, -5.848552703857422, -4.737575531005859, -4.306205749511719, -4.528041839599609, -4.007707118988037, -4.386752605438232, -4.151501655578613, -3.5933969020843506, -3.7886810302734375, -2.8642964363098145, -3.321343183517456, -3.1950159072875977, -1.242027997970581, -0.37048351764678955, -2.17417573928833, -1.8923107385635376, -2.809405565261841, -0.3140299618244171, -1.555353045463562, -2.431779146194458, -2.034336805343628, -2.6794087886810303, -1.135089635848999, -0.12961263954639435, -2.1084940433502197, -1.9520493745803833, -1.4142634868621826, 0.7797651290893555, -0.08931531012058258, -1.5304614305496216, 1.6499441862106323, -0.2615728974342346, -1.2726109027862549, -0.47694313526153564, -0.5825840830802917, -0.122440867125988, -0.7150201797485352, -0.8150355815887451, -1.2691559791564941, -0.18386626243591309, -0.6914909482002258, 0.7098398208618164, -2.427821159362793, -0.7010604739189148, -1.866729974746704, -0.9239639043807983, -1.0495331287384033, -0.7512304186820984, -0.2124132364988327, -1.038773775100708, -1.1407830715179443, -1.4168951511383057, -0.6889097690582275, -0.9886455535888672, -0.9768748879432678, -0.38759464025497437, -1.1012260913848877, -0.4310215711593628, 0.9218758344650269, 0.0, 0.0, -10.49825382232666, -11.356956481933594, -11.681902885437012, -11.6539888381958, -11.478848457336426, -10.927058219909668, -10.633784294128418, -9.268192291259766, -10.538052558898926, -11.671679496765137, -8.051583290100098, -8.920650482177734, -5.9258856773376465, -8.516287803649902, -7.380185604095459, -6.999535083770752, -5.845778465270996, -5.848552703857422, -4.737575531005859, -4.306205749511719, -4.528041839599609, -4.007707118988037, -4.386752605438232, -4.151501655578613, -3.5933969020843506, -3.7886810302734375, -2.8642964363098145, -3.321343183517456, -3.1950159072875977, -1.242027997970581, -0.37048351764678955, -2.17417573928833, -1.8923107385635376, -2.809405565261841, -0.3140299618244171, -1.555353045463562, -2.431779146194458, -2.034336805343628, -2.6794087886810303, -1.135089635848999, -0.12961263954639435, -2.1084940433502197, -1.9520493745803833, -1.4142634868621826, 0.7797651290893555, -0.08931531012058258, -1.5304614305496216, 1.6499441862106323, -0.2615728974342346, -1.2726109027862549, -0.47694313526153564, -0.5825840830802917, -0.122440867125988, -0.7150201797485352, -0.8150355815887451, -1.2691559791564941, -0.18386626243591309, -0.6914909482002258, 0.7098398208618164, -2.427821159362793, -0.7010604739189148, -1.866729974746704, -0.9239639043807983, -1.0495331287384033, -0.7512304186820984, -0.2124132364988327, -1.038773775100708, -1.1407830715179443, -1.4168951511383057, -0.6889097690582275, -0.9886455535888672, -0.9768748879432678, -0.38759464025497437, -1.1012260913848877, -0.4310215711593628, 0.9218758344650269, 0.0], [-10.421984672546387, -10.975603103637695, -11.180838584899902, -10.869367599487305, -11.2791166305542, -11.581533432006836, -11.562716484069824, -11.3855619430542, -10.341552734375, -10.208792686462402, -9.619746208190918, -8.542401313781738, -8.989921569824219, -7.298920154571533, -7.431335926055908, -6.802830696105957, -7.0308756828308105, -6.072381973266602, -5.759246826171875, -5.926407814025879, -4.882877349853516, -4.643535614013672, -3.831411838531494, -4.948571681976318, -3.4406275749206543, -3.6471211910247803, -3.7428228855133057, -3.0304114818573, -4.10897970199585, -2.2486820220947266, -0.6117659211158752, -2.1197333335876465, -0.675248920917511, -1.4888296127319336, -1.9049280881881714, -2.532487630844116, -2.642017364501953, -3.0774292945861816, -3.000697612762451, -3.1577134132385254, -2.9627859592437744, -3.3433923721313477, -3.920740842819214, -2.6778225898742676, -2.2108724117279053, -1.929469108581543, -2.5498952865600586, -1.864133596420288, -2.518894672393799, -3.751950263977051, -2.0187456607818604, -0.9249157905578613, -0.6648817658424377, -0.8325278162956238, 1.1602250337600708, -1.2417291402816772, -0.07964213192462921, -0.6826484203338623, -0.6410185098648071, -0.05921852961182594, -1.616965413093567, -0.8338600993156433, -0.8746145367622375, -1.2800309658050537, -1.1967008113861084, -2.243755340576172, -0.7133477926254272, -0.8080748319625854, -1.2794522047042847, -1.5321259498596191, -1.5913729667663574, -1.4469830989837646, -1.3636292219161987, -1.4513894319534302, -2.1028494834899902, -0.40819552540779114, 1.517937421798706, 0.0, -10.421984672546387, -10.975603103637695, -11.180838584899902, -10.869367599487305, -11.2791166305542, -11.581533432006836, -11.562716484069824, -11.3855619430542, -10.341552734375, -10.208792686462402, -9.619746208190918, -8.542401313781738, -8.989921569824219, -7.298920154571533, -7.431335926055908, -6.802830696105957, -7.0308756828308105, -6.072381973266602, -5.759246826171875, -5.926407814025879, -4.882877349853516, -4.643535614013672, -3.831411838531494, -4.948571681976318, -3.4406275749206543, -3.6471211910247803, -3.7428228855133057, -3.0304114818573, -4.10897970199585, -2.2486820220947266, -0.6117659211158752, -2.1197333335876465, -0.675248920917511, -1.4888296127319336, -1.9049280881881714, -2.532487630844116, -2.642017364501953, -3.0774292945861816, -3.000697612762451, -3.1577134132385254, -2.9627859592437744, -3.3433923721313477, -3.920740842819214, -2.6778225898742676, -2.2108724117279053, -1.929469108581543, -2.5498952865600586, -1.864133596420288, -2.518894672393799, -3.751950263977051, -2.0187456607818604, -0.9249157905578613, -0.6648817658424377, -0.8325278162956238, 1.1602250337600708, -1.2417291402816772, -0.07964213192462921, -0.6826484203338623, -0.6410185098648071, -0.05921852961182594, -1.616965413093567, -0.8338600993156433, -0.8746145367622375, -1.2800309658050537, -1.1967008113861084, -2.243755340576172, -0.7133477926254272, -0.8080748319625854, -1.2794522047042847, -1.5321259498596191, -1.5913729667663574, -1.4469830989837646, -1.3636292219161987, -1.4513894319534302, -2.1028494834899902, -0.40819552540779114, 1.517937421798706, 0.0], [0.0, -11.149820327758789, -10.798294067382812, -11.421904563903809, -11.340672492980957, -10.872844696044922, -10.51163101196289, -10.569826126098633, -10.254965782165527, -10.14552116394043, -10.079319953918457, -8.962181091308594, -5.630580425262451, -8.476810455322266, -8.15590763092041, -6.746637344360352, -7.28378438949585, -6.758200168609619, -6.282851696014404, -5.0889739990234375, -3.81606125831604, -4.489478588104248, -4.1366071701049805, -4.287135601043701, -4.641989231109619, -3.624558448791504, -3.4829933643341064, -3.515489339828491, -2.7049405574798584, -3.4983348846435547, -2.652878522872925, -1.8826419115066528, -3.3011481761932373, -3.513305425643921, -3.6354100704193115, -3.4756860733032227, -3.045755386352539, -3.3007609844207764, -3.3560218811035156, -3.9260287284851074, -4.018787384033203, -1.4259308576583862, -2.4091837406158447, -3.9498798847198486, -4.079158306121826, -3.644925355911255, -2.372098445892334, -2.7379586696624756, -2.7797389030456543, -3.9673030376434326, -2.383824586868286, -0.669497013092041, -0.865032434463501, -0.06843502819538116, -0.5902218222618103, 0.11535932123661041, -1.2136635780334473, -0.8320950269699097, -0.8240619897842407, -1.2225415706634521, 0.02373988926410675, -0.4383295476436615, -0.8319649696350098, -0.926343560218811, 0.26175397634506226, -1.0752509832382202, -1.3641979694366455, 0.01632668264210224, -0.6797971129417419, -1.4043914079666138, -1.1336644887924194, -1.0337944030761719, -1.140961766242981, -1.3870973587036133, -1.0581245422363281, -1.6733078956604004, 0.9832292795181274, 0.0, 0.0, -11.149820327758789, -10.798294067382812, -11.421904563903809, -11.340672492980957, -10.872844696044922, -10.51163101196289, -10.569826126098633, -10.254965782165527, -10.14552116394043, -10.079319953918457, -8.962181091308594, -5.630580425262451, -8.476810455322266, -8.15590763092041, -6.746637344360352, -7.28378438949585, -6.758200168609619, -6.282851696014404, -5.0889739990234375, -3.81606125831604, -4.489478588104248, -4.1366071701049805, -4.287135601043701, -4.641989231109619, -3.624558448791504, -3.4829933643341064, -3.515489339828491, -2.7049405574798584, -3.4983348846435547, -2.652878522872925, -1.8826419115066528, -3.3011481761932373, -3.513305425643921, -3.6354100704193115, -3.4756860733032227, -3.045755386352539, -3.3007609844207764, -3.3560218811035156, -3.9260287284851074, -4.018787384033203, -1.4259308576583862, -2.4091837406158447, -3.9498798847198486, -4.079158306121826, -3.644925355911255, -2.372098445892334, -2.7379586696624756, -2.7797389030456543, -3.9673030376434326, -2.383824586868286, -0.669497013092041, -0.865032434463501, -0.06843502819538116, -0.5902218222618103, 0.11535932123661041, -1.2136635780334473, -0.8320950269699097, -0.8240619897842407, -1.2225415706634521, 0.02373988926410675, -0.4383295476436615, -0.8319649696350098, -0.926343560218811, 0.26175397634506226, -1.0752509832382202, -1.3641979694366455, 0.01632668264210224, -0.6797971129417419, -1.4043914079666138, -1.1336644887924194, -1.0337944030761719, -1.140961766242981, -1.3870973587036133, -1.0581245422363281, -1.6733078956604004, 0.9832292795181274, 0.0], [0.0, -10.752768516540527, -10.696348190307617, -11.261143684387207, -11.204262733459473, -11.482023239135742, -10.341470718383789, -10.617024421691895, -9.918365478515625, -9.728841781616211, -9.699320793151855, -9.09584903717041, -8.900518417358398, -7.322549343109131, -7.171748161315918, -7.083913803100586, -7.396291255950928, -6.0025177001953125, -4.703066825866699, -4.494154930114746, -5.651670455932617, -5.732599258422852, -4.366061687469482, -4.210421562194824, -4.201245307922363, -4.058380603790283, -3.7978439331054688, -4.443753242492676, -4.046844959259033, -3.327728509902954, -3.2964248657226562, -2.9954233169555664, -3.505064010620117, -3.5627095699310303, -3.3627889156341553, -3.3849692344665527, -4.01479434967041, -5.1105637550354, -5.013216495513916, -4.585365295410156, -4.440792083740234, -3.7712650299072266, -4.472726345062256, -4.124177932739258, -4.872037410736084, -2.1047146320343018, -2.2579472064971924, -3.9631705284118652, -2.7992801666259766, -5.151243209838867, -3.2815451622009277, -1.2248210906982422, -0.5879692435264587, -2.3915438652038574, -0.4533156156539917, 1.2637640237808228, -0.7697360515594482, -3.693575382232666, -1.7541191577911377, 0.3838397264480591, -0.33820992708206177, -0.5406474471092224, -0.7918084263801575, -0.9991186261177063, 1.2608110904693604, -1.172062635421753, -1.0021668672561646, -1.5360891819000244, -0.9141905903816223, -1.7785922288894653, -1.4527831077575684, -1.4603495597839355, -1.2333340644836426, -1.7439154386520386, -1.1508561372756958, -1.4714921712875366, -0.47612640261650085, 0.0, 0.0, -10.752768516540527, -10.696348190307617, -11.261143684387207, -11.204262733459473, -11.482023239135742, -10.341470718383789, -10.617024421691895, -9.918365478515625, -9.728841781616211, -9.699320793151855, -9.09584903717041, -8.900518417358398, -7.322549343109131, -7.171748161315918, -7.083913803100586, -7.396291255950928, -6.0025177001953125, -4.703066825866699, -4.494154930114746, -5.651670455932617, -5.732599258422852, -4.366061687469482, -4.210421562194824, -4.201245307922363, -4.058380603790283, -3.7978439331054688, -4.443753242492676, -4.046844959259033, -3.327728509902954, -3.2964248657226562, -2.9954233169555664, -3.505064010620117, -3.5627095699310303, -3.3627889156341553, -3.3849692344665527, -4.01479434967041, -5.1105637550354, -5.013216495513916, -4.585365295410156, -4.440792083740234, -3.7712650299072266, -4.472726345062256, -4.124177932739258, -4.872037410736084, -2.1047146320343018, -2.2579472064971924, -3.9631705284118652, -2.7992801666259766, -5.151243209838867, -3.2815451622009277, -1.2248210906982422, -0.5879692435264587, -2.3915438652038574, -0.4533156156539917, 1.2637640237808228, -0.7697360515594482, -3.693575382232666, -1.7541191577911377, 0.3838397264480591, -0.33820992708206177, -0.5406474471092224, -0.7918084263801575, -0.9991186261177063, 1.2608110904693604, -1.172062635421753, -1.0021668672561646, -1.5360891819000244, -0.9141905903816223, -1.7785922288894653, -1.4527831077575684, -1.4603495597839355, -1.2333340644836426, -1.7439154386520386, -1.1508561372756958, -1.4714921712875366, -0.47612640261650085, 0.0], [0.0, 0.0, -10.617183685302734, -10.398908615112305, -10.986281394958496, -11.889376640319824, -10.754966735839844, -10.57083511352539, -9.428926467895508, -9.017236709594727, -9.72751235961914, -9.057611465454102, -9.045740127563477, -8.298090934753418, -7.6277265548706055, -7.2583723068237305, -6.36767053604126, -6.113999366760254, -6.281904697418213, -5.160317420959473, -4.976372718811035, -4.164589881896973, -4.6200971603393555, -4.297359943389893, -4.79433536529541, -4.130652904510498, -4.053437232971191, -1.7342050075531006, -4.985416412353516, -3.7987513542175293, -4.089779853820801, -3.815762519836426, -4.40354585647583, -4.25236701965332, -4.761026859283447, -5.594522476196289, -4.931704044342041, -5.286154747009277, -5.865050792694092, -7.593605041503906, -5.690052509307861, -6.1371002197265625, -6.890866279602051, -6.462484836578369, -5.283405780792236, -4.181836128234863, -4.721529483795166, -3.394991159439087, -2.8408377170562744, -2.6823391914367676, -1.6738961935043335, -2.465268135070801, -2.203139066696167, -1.7065669298171997, 0.7900684475898743, -0.7301828265190125, 0.5025097131729126, -0.18415327370166779, -0.7937176823616028, -1.3102047443389893, -0.07465777546167374, -0.7101074457168579, -1.1599485874176025, -0.3942986726760864, -1.039984107017517, -2.264064311981201, -0.8054078221321106, -0.7419849634170532, -0.6064854860305786, -0.2821867763996124, -0.9606195092201233, -0.7978038191795349, -1.0047712326049805, -1.3776990175247192, -1.7326724529266357, -1.5562080144882202, 0.0, 0.0, 0.0, 0.0, -10.617183685302734, -10.398908615112305, -10.986281394958496, -11.889376640319824, -10.754966735839844, -10.57083511352539, -9.428926467895508, -9.017236709594727, -9.72751235961914, -9.057611465454102, -9.045740127563477, -8.298090934753418, -7.6277265548706055, -7.2583723068237305, -6.36767053604126, -6.113999366760254, -6.281904697418213, -5.160317420959473, -4.976372718811035, -4.164589881896973, -4.6200971603393555, -4.297359943389893, -4.79433536529541, -4.130652904510498, -4.053437232971191, -1.7342050075531006, -4.985416412353516, -3.7987513542175293, -4.089779853820801, -3.815762519836426, -4.40354585647583, -4.25236701965332, -4.761026859283447, -5.594522476196289, -4.931704044342041, -5.286154747009277, -5.865050792694092, -7.593605041503906, -5.690052509307861, -6.1371002197265625, -6.890866279602051, -6.462484836578369, -5.283405780792236, -4.181836128234863, -4.721529483795166, -3.394991159439087, -2.8408377170562744, -2.6823391914367676, -1.6738961935043335, -2.465268135070801, -2.203139066696167, -1.7065669298171997, 0.7900684475898743, -0.7301828265190125, 0.5025097131729126, -0.18415327370166779, -0.7937176823616028, -1.3102047443389893, -0.07465777546167374, -0.7101074457168579, -1.1599485874176025, -0.3942986726760864, -1.039984107017517, -2.264064311981201, -0.8054078221321106, -0.7419849634170532, -0.6064854860305786, -0.2821867763996124, -0.9606195092201233, -0.7978038191795349, -1.0047712326049805, -1.3776990175247192, -1.7326724529266357, -1.5562080144882202, 0.0, 0.0], [-12.971758842468262, 0.0, -10.340189933776855, -10.51301097869873, -11.082408905029297, -12.205119132995605, -10.572707176208496, -10.509615898132324, -9.708434104919434, -9.779261589050293, -9.963505744934082, -9.410646438598633, -8.904783248901367, -8.48931884765625, -7.232151985168457, -7.385293006896973, -6.846092224121094, -6.228173732757568, -6.7516021728515625, -5.4387407302856445, -6.056835651397705, -4.835388660430908, -4.892282485961914, -4.4733147621154785, -4.866023063659668, -4.936524868011475, -3.6046342849731445, -4.77523946762085, -4.185115814208984, -5.009042739868164, -4.800178527832031, -4.469336986541748, -5.154819965362549, -5.02502965927124, -6.0746636390686035, -6.1179022789001465, -5.033677577972412, -7.163298606872559, -7.508796691894531, -8.120129585266113, -7.222500801086426, -7.949609279632568, -6.958858013153076, -6.71950626373291, -8.575291633605957, -4.763983726501465, -3.2645602226257324, -5.066239356994629, -4.330724716186523, -3.985748291015625, -3.024798631668091, -2.7141432762145996, -2.827828884124756, -1.39254891872406, -2.156675338745117, -1.4812428951263428, -0.4922831952571869, -1.4787510633468628, -0.7258227467536926, -0.986149251461029, -0.887713611125946, -0.4635695815086365, -0.9844108819961548, -0.5719300508499146, 1.4386016130447388, -0.4077441692352295, -1.4716548919677734, -1.0261873006820679, -1.1674333810806274, -1.2193858623504639, -1.8236677646636963, -0.7621525526046753, -2.3801076412200928, -1.8131663799285889, -1.9967669248580933, -2.83781099319458, 0.0, 3.002213954925537, -12.971758842468262, 0.0, -10.340189933776855, -10.51301097869873, -11.082408905029297, -12.205119132995605, -10.572707176208496, -10.509615898132324, -9.708434104919434, -9.779261589050293, -9.963505744934082, -9.410646438598633, -8.904783248901367, -8.48931884765625, -7.232151985168457, -7.385293006896973, -6.846092224121094, -6.228173732757568, -6.7516021728515625, -5.4387407302856445, -6.056835651397705, -4.835388660430908, -4.892282485961914, -4.4733147621154785, -4.866023063659668, -4.936524868011475, -3.6046342849731445, -4.77523946762085, -4.185115814208984, -5.009042739868164, -4.800178527832031, -4.469336986541748, -5.154819965362549, -5.02502965927124, -6.0746636390686035, -6.1179022789001465, -5.033677577972412, -7.163298606872559, -7.508796691894531, -8.120129585266113, -7.222500801086426, -7.949609279632568, -6.958858013153076, -6.71950626373291, -8.575291633605957, -4.763983726501465, -3.2645602226257324, -5.066239356994629, -4.330724716186523, -3.985748291015625, -3.024798631668091, -2.7141432762145996, -2.827828884124756, -1.39254891872406, -2.156675338745117, -1.4812428951263428, -0.4922831952571869, -1.4787510633468628, -0.7258227467536926, -0.986149251461029, -0.887713611125946, -0.4635695815086365, -0.9844108819961548, -0.5719300508499146, 1.4386016130447388, -0.4077441692352295, -1.4716548919677734, -1.0261873006820679, -1.1674333810806274, -1.2193858623504639, -1.8236677646636963, -0.7621525526046753, -2.3801076412200928, -1.8131663799285889, -1.9967669248580933, -2.83781099319458, 0.0, 3.002213954925537], [-11.691462516784668, 0.0, -11.027059555053711, -10.600751876831055, -11.814855575561523, -11.38936996459961, -10.452032089233398, -10.139979362487793, -10.442855834960938, -9.251951217651367, -9.379433631896973, -8.806375503540039, -8.971366882324219, -7.998898506164551, -8.382706642150879, -7.3707170486450195, -7.357274532318115, -6.095534801483154, -5.579334735870361, -5.724516868591309, -4.737397193908691, -4.877376079559326, -5.281422138214111, -4.139866352081299, -5.44189977645874, -4.32293176651001, -2.88822078704834, -4.327208042144775, -4.9127020835876465, -5.434384346008301, -5.258157253265381, -5.605942249298096, -6.231685161590576, -7.018243789672852, -6.996950626373291, -6.533397674560547, -9.838214874267578, -7.164155006408691, -8.811654090881348, -9.473837852478027, -8.871657371520996, -9.176843643188477, -7.315817356109619, -7.5769219398498535, -6.9633049964904785, -5.587789058685303, -5.201629638671875, -5.225545406341553, -4.6663594245910645, -2.826620101928711, -4.480259418487549, -6.04932975769043, -4.43576192855835, -3.5461854934692383, -0.5034088492393494, -1.1362476348876953, -0.788507878780365, -1.5533313751220703, -1.2213855981826782, -0.7883623838424683, -0.3270943760871887, -0.45518139004707336, -0.6472474932670593, -0.4902489185333252, 0.04375530779361725, -0.5846165418624878, -1.2569366693496704, -1.3827263116836548, -0.39066171646118164, -1.2444391250610352, -0.9944353103637695, -0.906949520111084, -1.7153054475784302, -1.615456461906433, -1.9807095527648926, -1.1226392984390259, 0.0, 0.417997270822525, -11.691462516784668, 0.0, -11.027059555053711, -10.600751876831055, -11.814855575561523, -11.38936996459961, -10.452032089233398, -10.139979362487793, -10.442855834960938, -9.251951217651367, -9.379433631896973, -8.806375503540039, -8.971366882324219, -7.998898506164551, -8.382706642150879, -7.3707170486450195, -7.357274532318115, -6.095534801483154, -5.579334735870361, -5.724516868591309, -4.737397193908691, -4.877376079559326, -5.281422138214111, -4.139866352081299, -5.44189977645874, -4.32293176651001, -2.88822078704834, -4.327208042144775, -4.9127020835876465, -5.434384346008301, -5.258157253265381, -5.605942249298096, -6.231685161590576, -7.018243789672852, -6.996950626373291, -6.533397674560547, -9.838214874267578, -7.164155006408691, -8.811654090881348, -9.473837852478027, -8.871657371520996, -9.176843643188477, -7.315817356109619, -7.5769219398498535, -6.9633049964904785, -5.587789058685303, -5.201629638671875, -5.225545406341553, -4.6663594245910645, -2.826620101928711, -4.480259418487549, -6.04932975769043, -4.43576192855835, -3.5461854934692383, -0.5034088492393494, -1.1362476348876953, -0.788507878780365, -1.5533313751220703, -1.2213855981826782, -0.7883623838424683, -0.3270943760871887, -0.45518139004707336, -0.6472474932670593, -0.4902489185333252, 0.04375530779361725, -0.5846165418624878, -1.2569366693496704, -1.3827263116836548, -0.39066171646118164, -1.2444391250610352, -0.9944353103637695, -0.906949520111084, -1.7153054475784302, -1.615456461906433, -1.9807095527648926, -1.1226392984390259, 0.0, 0.417997270822525], [-15.091606140136719, 0.0, -12.114255905151367, -10.841151237487793, -11.275829315185547, -11.133111000061035, -10.45246410369873, -10.558460235595703, -9.729591369628906, -9.278260231018066, -9.442121505737305, -8.057120323181152, -6.8632612228393555, -9.005962371826172, -8.846467018127441, -6.94175910949707, -6.814018726348877, -6.078975677490234, -6.21340799331665, -5.67082405090332, -4.841028213500977, -4.614654541015625, -4.1652703285217285, -4.806725025177002, -5.135364055633545, -4.867403984069824, -5.526804447174072, -5.518387317657471, -6.2982001304626465, -5.862057209014893, -5.452486515045166, -5.958994388580322, -6.649714469909668, -6.962296485900879, -7.740530490875244, -10.614978790283203, -10.658275604248047, -9.153457641601562, -9.99730396270752, -10.389187812805176, -12.318353652954102, -10.403523445129395, -9.852529525756836, -9.080229759216309, -8.118758201599121, -8.177754402160645, -7.048797607421875, 0.0, -2.8931093215942383, -5.645891189575195, -5.176621437072754, -5.916029930114746, -2.751969814300537, -2.0212466716766357, -2.0799875259399414, -1.1546334028244019, -1.1803066730499268, -1.2127361297607422, -0.4584512412548065, -1.2500426769256592, -0.2666090130805969, -0.49241089820861816, -1.3487184047698975, -0.045441996306180954, -0.7984380722045898, -0.7539985775947571, -0.37701696157455444, -0.7333675622940063, -0.8246238231658936, -1.2789196968078613, -2.258763313293457, -1.5895652770996094, -1.5328874588012695, -1.821771264076233, -1.7660101652145386, 0.0, 0.0, 2.7192442417144775, -15.091606140136719, 0.0, -12.114255905151367, -10.841151237487793, -11.275829315185547, -11.133111000061035, -10.45246410369873, -10.558460235595703, -9.729591369628906, -9.278260231018066, -9.442121505737305, -8.057120323181152, -6.8632612228393555, -9.005962371826172, -8.846467018127441, -6.94175910949707, -6.814018726348877, -6.078975677490234, -6.21340799331665, -5.67082405090332, -4.841028213500977, -4.614654541015625, -4.1652703285217285, -4.806725025177002, -5.135364055633545, -4.867403984069824, -5.526804447174072, -5.518387317657471, -6.2982001304626465, -5.862057209014893, -5.452486515045166, -5.958994388580322, -6.649714469909668, -6.962296485900879, -7.740530490875244, -10.614978790283203, -10.658275604248047, -9.153457641601562, -9.99730396270752, -10.389187812805176, -12.318353652954102, -10.403523445129395, -9.852529525756836, -9.080229759216309, -8.118758201599121, -8.177754402160645, -7.048797607421875, 0.0, -2.8931093215942383, -5.645891189575195, -5.176621437072754, -5.916029930114746, -2.751969814300537, -2.0212466716766357, -2.0799875259399414, -1.1546334028244019, -1.1803066730499268, -1.2127361297607422, -0.4584512412548065, -1.2500426769256592, -0.2666090130805969, -0.49241089820861816, -1.3487184047698975, -0.045441996306180954, -0.7984380722045898, -0.7539985775947571, -0.37701696157455444, -0.7333675622940063, -0.8246238231658936, -1.2789196968078613, -2.258763313293457, -1.5895652770996094, -1.5328874588012695, -1.821771264076233, -1.7660101652145386, 0.0, 0.0, 2.7192442417144775], [-13.050131797790527, 0.0, -11.25323486328125, -10.17546272277832, -10.37985897064209, -10.601943016052246, -9.977649688720703, -9.506413459777832, -9.494364738464355, -9.059769630432129, -9.546916007995605, -8.305663108825684, -8.236281394958496, -8.59627628326416, -7.092021942138672, -7.289525032043457, -6.404066562652588, -6.443942546844482, -6.094044208526611, -5.5302629470825195, -5.283776760101318, -5.571991443634033, -5.962745189666748, -7.11983060836792, -5.254026889801025, -5.487407207489014, -5.812545299530029, -5.809579372406006, -6.8751091957092285, -6.2112884521484375, -7.145725727081299, -6.820478916168213, -7.628232002258301, -8.12232780456543, -11.532022476196289, -10.535829544067383, -10.088117599487305, -10.687152862548828, -11.423409461975098, -11.5708646774292, -11.60551929473877, -11.603487968444824, -10.05140209197998, -10.690428733825684, -10.638187408447266, -9.258578300476074, -7.61538028717041, 0.0, -5.129245758056641, -4.929347515106201, -4.816032886505127, -4.887313365936279, -4.195190906524658, -3.5350143909454346, -3.155348539352417, -1.8217412233352661, -1.5037785768508911, -1.2692606449127197, -1.2485971450805664, -0.9523248672485352, -0.8459109663963318, -0.40216201543807983, 0.20108641684055328, -0.3794872760772705, -0.5579066872596741, -0.8073424100875854, -0.15512385964393616, -0.38428765535354614, -0.616290807723999, -2.462991237640381, -0.6629612445831299, -2.401376724243164, -1.5684468746185303, -1.966688871383667, -2.6218152046203613, 0.0, 0.0, 0.9033079743385315, -13.050131797790527, 0.0, -11.25323486328125, -10.17546272277832, -10.37985897064209, -10.601943016052246, -9.977649688720703, -9.506413459777832, -9.494364738464355, -9.059769630432129, -9.546916007995605, -8.305663108825684, -8.236281394958496, -8.59627628326416, -7.092021942138672, -7.289525032043457, -6.404066562652588, -6.443942546844482, -6.094044208526611, -5.5302629470825195, -5.283776760101318, -5.571991443634033, -5.962745189666748, -7.11983060836792, -5.254026889801025, -5.487407207489014, -5.812545299530029, -5.809579372406006, -6.8751091957092285, -6.2112884521484375, -7.145725727081299, -6.820478916168213, -7.628232002258301, -8.12232780456543, -11.532022476196289, -10.535829544067383, -10.088117599487305, -10.687152862548828, -11.423409461975098, -11.5708646774292, -11.60551929473877, -11.603487968444824, -10.05140209197998, -10.690428733825684, -10.638187408447266, -9.258578300476074, -7.61538028717041, 0.0, -5.129245758056641, -4.929347515106201, -4.816032886505127, -4.887313365936279, -4.195190906524658, -3.5350143909454346, -3.155348539352417, -1.8217412233352661, -1.5037785768508911, -1.2692606449127197, -1.2485971450805664, -0.9523248672485352, -0.8459109663963318, -0.40216201543807983, 0.20108641684055328, -0.3794872760772705, -0.5579066872596741, -0.8073424100875854, -0.15512385964393616, -0.38428765535354614, -0.616290807723999, -2.462991237640381, -0.6629612445831299, -2.401376724243164, -1.5684468746185303, -1.966688871383667, -2.6218152046203613, 0.0, 0.0, 0.9033079743385315], [-12.490434646606445, -12.586653709411621, 0.0, -9.82557487487793, -9.886090278625488, -10.134620666503906, -9.950425148010254, -9.755898475646973, -9.604253768920898, -9.352672576904297, -8.654778480529785, -9.019915580749512, -8.599102973937988, -8.425729751586914, -7.937105178833008, -7.237392902374268, -6.480930328369141, -6.616830348968506, -6.529678821563721, -5.761117935180664, -6.814215660095215, -4.429330825805664, -5.9097700119018555, -5.519715309143066, -4.876770973205566, -6.056034088134766, -6.182760715484619, -6.996206283569336, -6.5807271003723145, -6.550314426422119, -7.3425774574279785, -8.14750862121582, -7.824209690093994, -10.64738941192627, 0.0, -11.40121078491211, -11.546977996826172, -12.116436958312988, -12.667474746704102, -13.752381324768066, -13.297738075256348, -12.374261856079102, -11.657881736755371, -10.820487022399902, -10.763278007507324, -10.633576393127441, -9.066729545593262, -9.025163650512695, -7.298251152038574, -7.1920247077941895, -5.315245628356934, -5.260045528411865, -4.814976215362549, -4.193431377410889, -4.005566120147705, -2.5728845596313477, -1.5390238761901855, -1.4493117332458496, -1.274527668952942, -1.7986825704574585, -0.13764791190624237, -1.5152384042739868, -0.13482773303985596, -0.5341148376464844, -0.2565167248249054, -0.838120698928833, -0.18773870170116425, -0.3689742386341095, -0.7032115459442139, -1.657172441482544, -0.9891201257705688, -1.7033792734146118, -1.3602864742279053, -1.1857911348342896, 0.0, 0.0, 0.0, 2.709406614303589, -12.490434646606445, -12.586653709411621, 0.0, -9.82557487487793, -9.886090278625488, -10.134620666503906, -9.950425148010254, -9.755898475646973, -9.604253768920898, -9.352672576904297, -8.654778480529785, -9.019915580749512, -8.599102973937988, -8.425729751586914, -7.937105178833008, -7.237392902374268, -6.480930328369141, -6.616830348968506, -6.529678821563721, -5.761117935180664, -6.814215660095215, -4.429330825805664, -5.9097700119018555, -5.519715309143066, -4.876770973205566, -6.056034088134766, -6.182760715484619, -6.996206283569336, -6.5807271003723145, -6.550314426422119, -7.3425774574279785, -8.14750862121582, -7.824209690093994, -10.64738941192627, 0.0, -11.40121078491211, -11.546977996826172, -12.116436958312988, -12.667474746704102, -13.752381324768066, -13.297738075256348, -12.374261856079102, -11.657881736755371, -10.820487022399902, -10.763278007507324, -10.633576393127441, -9.066729545593262, -9.025163650512695, -7.298251152038574, -7.1920247077941895, -5.315245628356934, -5.260045528411865, -4.814976215362549, -4.193431377410889, -4.005566120147705, -2.5728845596313477, -1.5390238761901855, -1.4493117332458496, -1.274527668952942, -1.7986825704574585, -0.13764791190624237, -1.5152384042739868, -0.13482773303985596, -0.5341148376464844, -0.2565167248249054, -0.838120698928833, -0.18773870170116425, -0.3689742386341095, -0.7032115459442139, -1.657172441482544, -0.9891201257705688, -1.7033792734146118, -1.3602864742279053, -1.1857911348342896, 0.0, 0.0, 0.0, 2.709406614303589], [-13.686424255371094, -11.507148742675781, 0.0, 0.0, -9.442100524902344, -9.242541313171387, -9.916872024536133, -9.000886917114258, -9.354828834533691, -9.300341606140137, -8.994518280029297, -8.729904174804688, -7.862091541290283, -8.415899276733398, -7.356677532196045, -6.671298503875732, -6.880257606506348, -7.446447372436523, -5.815620422363281, -6.145517349243164, -5.811764717102051, -5.50307559967041, -5.721534252166748, -6.455532073974609, -5.072732448577881, -5.916470527648926, -6.589442253112793, -6.767110347747803, -7.71267557144165, -7.95756196975708, 0.0, 0.0, 0.0, -14.056931495666504, -14.227331161499023, -13.02430248260498, -13.334765434265137, -13.320425987243652, -14.610469818115234, -14.371652603149414, -14.174947738647461, -14.718697547912598, -11.60576343536377, -12.067549705505371, -10.366314888000488, -10.1463623046875, -10.027837753295898, -8.726970672607422, -8.38654613494873, -6.310031414031982, -5.47614049911499, -6.860607624053955, -5.795771598815918, -4.756984233856201, -4.467613220214844, -3.362726926803589, -2.8586552143096924, -2.2046072483062744, -2.236130952835083, -1.9951449632644653, -1.2156028747558594, -0.44460758566856384, -0.5609183311462402, -1.0963366031646729, -0.11154821515083313, -0.9247891902923584, -0.009431996382772923, -0.690067708492279, 0.5383189916610718, -0.6843558549880981, -0.9299288392066956, -1.071798324584961, -1.5135613679885864, -1.6559017896652222, 0.0, 0.0, 2.680539608001709, 2.401711940765381, -13.686424255371094, -11.507148742675781, 0.0, 0.0, -9.442100524902344, -9.242541313171387, -9.916872024536133, -9.000886917114258, -9.354828834533691, -9.300341606140137, -8.994518280029297, -8.729904174804688, -7.862091541290283, -8.415899276733398, -7.356677532196045, -6.671298503875732, -6.880257606506348, -7.446447372436523, -5.815620422363281, -6.145517349243164, -5.811764717102051, -5.50307559967041, -5.721534252166748, -6.455532073974609, -5.072732448577881, -5.916470527648926, -6.589442253112793, -6.767110347747803, -7.71267557144165, -7.95756196975708, 0.0, 0.0, 0.0, -14.056931495666504, -14.227331161499023, -13.02430248260498, -13.334765434265137, -13.320425987243652, -14.610469818115234, -14.371652603149414, -14.174947738647461, -14.718697547912598, -11.60576343536377, -12.067549705505371, -10.366314888000488, -10.1463623046875, -10.027837753295898, -8.726970672607422, -8.38654613494873, -6.310031414031982, -5.47614049911499, -6.860607624053955, -5.795771598815918, -4.756984233856201, -4.467613220214844, -3.362726926803589, -2.8586552143096924, -2.2046072483062744, -2.236130952835083, -1.9951449632644653, -1.2156028747558594, -0.44460758566856384, -0.5609183311462402, -1.0963366031646729, -0.11154821515083313, -0.9247891902923584, -0.009431996382772923, -0.690067708492279, 0.5383189916610718, -0.6843558549880981, -0.9299288392066956, -1.071798324584961, -1.5135613679885864, -1.6559017896652222, 0.0, 0.0, 2.680539608001709, 2.401711940765381], [-12.237131118774414, -11.489928245544434, -8.771513938903809, 0.0, -9.200369834899902, -9.948600769042969, -9.720149040222168, -8.958091735839844, -9.522643089294434, -9.042621612548828, -8.75832748413086, -8.434714317321777, -7.362646579742432, -8.351226806640625, -7.056821823120117, -6.557685852050781, -6.697470664978027, -6.631183624267578, -6.82179594039917, -6.278522491455078, -6.65868616104126, -6.287982940673828, -6.835808753967285, -6.1526713371276855, -5.728060722351074, -5.515531539916992, -6.51584529876709, -7.521674633026123, -7.211216926574707, 0.0, 0.0, -10.927891731262207, -11.52243709564209, -11.360363006591797, -15.642763137817383, -13.969924926757812, -14.085681915283203, -15.859338760375977, -16.10641860961914, -16.0853271484375, -16.113256454467773, -15.7719087600708, -12.705178260803223, -16.58392906188965, -12.965615272521973, -12.08243465423584, -14.534764289855957, -10.83232593536377, -7.863250255584717, -8.864171028137207, -10.318058013916016, -5.953491687774658, -5.754086017608643, -5.084969520568848, -4.560234069824219, -3.7021121978759766, -4.082836151123047, -2.4535646438598633, 0.0, -1.0638468265533447, -1.0572081804275513, -1.2608757019042969, -0.44964611530303955, -0.9774079322814941, -0.8694596290588379, -0.8352091908454895, -0.5530307292938232, -0.9180536866188049, -1.477645754814148, -0.08687329292297363, -0.9150669574737549, -1.0627572536468506, -0.688451886177063, 0.0, 0.0, 0.0, 2.6176233291625977, 1.9256618022918701, -12.237131118774414, -11.489928245544434, -8.771513938903809, 0.0, -9.200369834899902, -9.948600769042969, -9.720149040222168, -8.958091735839844, -9.522643089294434, -9.042621612548828, -8.75832748413086, -8.434714317321777, -7.362646579742432, -8.351226806640625, -7.056821823120117, -6.557685852050781, -6.697470664978027, -6.631183624267578, -6.82179594039917, -6.278522491455078, -6.65868616104126, -6.287982940673828, -6.835808753967285, -6.1526713371276855, -5.728060722351074, -5.515531539916992, -6.51584529876709, -7.521674633026123, -7.211216926574707, 0.0, 0.0, -10.927891731262207, -11.52243709564209, -11.360363006591797, -15.642763137817383, -13.969924926757812, -14.085681915283203, -15.859338760375977, -16.10641860961914, -16.0853271484375, -16.113256454467773, -15.7719087600708, -12.705178260803223, -16.58392906188965, -12.965615272521973, -12.08243465423584, -14.534764289855957, -10.83232593536377, -7.863250255584717, -8.864171028137207, -10.318058013916016, -5.953491687774658, -5.754086017608643, -5.084969520568848, -4.560234069824219, -3.7021121978759766, -4.082836151123047, -2.4535646438598633, 0.0, -1.0638468265533447, -1.0572081804275513, -1.2608757019042969, -0.44964611530303955, -0.9774079322814941, -0.8694596290588379, -0.8352091908454895, -0.5530307292938232, -0.9180536866188049, -1.477645754814148, -0.08687329292297363, -0.9150669574737549, -1.0627572536468506, -0.688451886177063, 0.0, 0.0, 0.0, 2.6176233291625977, 1.9256618022918701], [-14.433103561401367, -11.313392639160156, -10.350700378417969, 0.0, 0.0, -9.913887023925781, -9.99330997467041, -9.692988395690918, -9.22402286529541, -8.669485092163086, -8.936981201171875, -8.726806640625, -8.312756538391113, -7.666484355926514, -7.221917629241943, -7.849625110626221, 0.0, -8.37645435333252, -6.422115325927734, -6.416087627410889, -6.075827598571777, -4.785433769226074, -5.954720497131348, -5.489483833312988, -5.9893107414245605, -7.155494689941406, -6.920096397399902, -7.19209623336792, -7.158693313598633, -12.074552536010742, -13.609573364257812, -10.935938835144043, -11.984333038330078, 0.0, -15.97963809967041, 0.0, -16.051050186157227, -16.449012756347656, -17.369508743286133, -17.82522201538086, -16.98103904724121, -16.91197395324707, -17.14145278930664, -17.401575088500977, -14.112381935119629, -13.865315437316895, -12.47525405883789, -11.081663131713867, -11.116048812866211, -10.053296089172363, -8.896594047546387, -6.829094886779785, -6.568667411804199, -5.600517749786377, -4.874035358428955, -4.663085460662842, -3.448655843734741, -3.0295283794403076, -2.2949204444885254, -1.284466028213501, -1.775607705116272, -1.559390902519226, -1.4236369132995605, -1.3518097400665283, -0.8692368865013123, -1.3893388509750366, -0.9308100938796997, -0.7297286987304688, -0.31848403811454773, -1.93177330493927, -1.0256555080413818, -0.3298720717430115, -0.044427540153265, 0.0, 0.0, 0.0, 2.28670072555542, 2.1158955097198486, -14.433103561401367, -11.313392639160156, -10.350700378417969, 0.0, 0.0, -9.913887023925781, -9.99330997467041, -9.692988395690918, -9.22402286529541, -8.669485092163086, -8.936981201171875, -8.726806640625, -8.312756538391113, -7.666484355926514, -7.221917629241943, -7.849625110626221, 0.0, -8.37645435333252, -6.422115325927734, -6.416087627410889, -6.075827598571777, -4.785433769226074, -5.954720497131348, -5.489483833312988, -5.9893107414245605, -7.155494689941406, -6.920096397399902, -7.19209623336792, -7.158693313598633, -12.074552536010742, -13.609573364257812, -10.935938835144043, -11.984333038330078, 0.0, -15.97963809967041, 0.0, -16.051050186157227, -16.449012756347656, -17.369508743286133, -17.82522201538086, -16.98103904724121, -16.91197395324707, -17.14145278930664, -17.401575088500977, -14.112381935119629, -13.865315437316895, -12.47525405883789, -11.081663131713867, -11.116048812866211, -10.053296089172363, -8.896594047546387, -6.829094886779785, -6.568667411804199, -5.600517749786377, -4.874035358428955, -4.663085460662842, -3.448655843734741, -3.0295283794403076, -2.2949204444885254, -1.284466028213501, -1.775607705116272, -1.559390902519226, -1.4236369132995605, -1.3518097400665283, -0.8692368865013123, -1.3893388509750366, -0.9308100938796997, -0.7297286987304688, -0.31848403811454773, -1.93177330493927, -1.0256555080413818, -0.3298720717430115, -0.044427540153265, 0.0, 0.0, 0.0, 2.28670072555542, 2.1158955097198486], [-15.056103706359863, -13.376530647277832, -11.024374961853027, 0.0, 0.0, -9.251042366027832, -9.683370590209961, -9.749540328979492, -9.449358940124512, -9.084029197692871, -9.305855751037598, -9.366602897644043, -8.304988861083984, -7.787092685699463, -7.646040439605713, -7.409071445465088, -6.660865306854248, -8.612773895263672, -6.501821994781494, -6.4015069007873535, -6.34005069732666, -5.647412300109863, -5.408939361572266, -6.605691909790039, -4.564193248748779, -6.3213019371032715, -8.315320014953613, -8.967275619506836, -9.015949249267578, -8.825851440429688, -11.604809761047363, -11.55627727508545, -14.828662872314453, -13.414763450622559, -13.368407249450684, 0.0, -17.746335983276367, -18.732641220092773, -16.787405014038086, -19.702754974365234, -20.346290588378906, -17.62901496887207, -18.276714324951172, -17.331201553344727, -16.32053565979004, -16.132823944091797, -14.145023345947266, -13.537192344665527, -11.605111122131348, -10.835644721984863, -8.752779006958008, -8.890801429748535, -8.632479667663574, -6.314372539520264, -4.627647876739502, -5.465548515319824, -3.671265125274658, -2.898324728012085, -3.9318594932556152, -2.056488513946533, -1.4865992069244385, -2.031205177307129, -1.8248542547225952, -1.0597645044326782, -1.1403703689575195, -1.4859352111816406, -1.5421899557113647, -1.565261721611023, -0.6659514904022217, -0.8641889691352844, -0.41868066787719727, 0.9168469309806824, 2.004765033721924, 0.0, 0.0, 3.244900941848755, 3.3764536380767822, 2.4414305686950684, -15.056103706359863, -13.376530647277832, -11.024374961853027, 0.0, 0.0, -9.251042366027832, -9.683370590209961, -9.749540328979492, -9.449358940124512, -9.084029197692871, -9.305855751037598, -9.366602897644043, -8.304988861083984, -7.787092685699463, -7.646040439605713, -7.409071445465088, -6.660865306854248, -8.612773895263672, -6.501821994781494, -6.4015069007873535, -6.34005069732666, -5.647412300109863, -5.408939361572266, -6.605691909790039, -4.564193248748779, -6.3213019371032715, -8.315320014953613, -8.967275619506836, -9.015949249267578, -8.825851440429688, -11.604809761047363, -11.55627727508545, -14.828662872314453, -13.414763450622559, -13.368407249450684, 0.0, -17.746335983276367, -18.732641220092773, -16.787405014038086, -19.702754974365234, -20.346290588378906, -17.62901496887207, -18.276714324951172, -17.331201553344727, -16.32053565979004, -16.132823944091797, -14.145023345947266, -13.537192344665527, -11.605111122131348, -10.835644721984863, -8.752779006958008, -8.890801429748535, -8.632479667663574, -6.314372539520264, -4.627647876739502, -5.465548515319824, -3.671265125274658, -2.898324728012085, -3.9318594932556152, -2.056488513946533, -1.4865992069244385, -2.031205177307129, -1.8248542547225952, -1.0597645044326782, -1.1403703689575195, -1.4859352111816406, -1.5421899557113647, -1.565261721611023, -0.6659514904022217, -0.8641889691352844, -0.41868066787719727, 0.9168469309806824, 2.004765033721924, 0.0, 0.0, 3.244900941848755, 3.3764536380767822, 2.4414305686950684], [-13.657269477844238, -14.212027549743652, -13.943021774291992, -10.555830955505371, 0.0, -11.02554988861084, -10.22536849975586, -9.635327339172363, -9.554046630859375, -8.951912879943848, -9.04034423828125, -8.698434829711914, -9.344321250915527, -8.429720878601074, -8.001296997070312, -7.8433451652526855, -7.457479476928711, -5.6793928146362305, -7.121081829071045, -6.643673419952393, -6.600395202636719, -6.4029669761657715, -6.541974067687988, -7.140434265136719, -7.505499839782715, 0.0, -7.781794548034668, -9.01515007019043, -9.622029304504395, -10.373851776123047, -11.152060508728027, -13.467511177062988, -13.6673002243042, -15.657269477844238, -15.661212921142578, -19.623485565185547, -19.27461051940918, -19.254552841186523, -20.537227630615234, -22.495529174804688, -20.043798446655273, -20.3284854888916, 0.0, -19.36351203918457, -18.071346282958984, -14.294189453125, -15.385082244873047, -14.68118953704834, -14.263104438781738, -11.7880277633667, -11.941829681396484, -10.359153747558594, -9.248322486877441, -7.465469837188721, -7.095997333526611, -4.304783821105957, -4.886674880981445, -3.5900206565856934, -4.006884574890137, -2.095459222793579, -2.682265281677246, -2.359060287475586, -2.456480026245117, -1.979163408279419, -2.142347812652588, -0.9659523963928223, -1.4673296213150024, -2.152494192123413, -0.9860435724258423, -0.7949433326721191, -0.26941290497779846, 0.05382895842194557, 0.0, 0.0, 6.554276466369629, 4.778913974761963, 2.8230960369110107, 3.9748265743255615, -13.657269477844238, -14.212027549743652, -13.943021774291992, -10.555830955505371, 0.0, -11.02554988861084, -10.22536849975586, -9.635327339172363, -9.554046630859375, -8.951912879943848, -9.04034423828125, -8.698434829711914, -9.344321250915527, -8.429720878601074, -8.001296997070312, -7.8433451652526855, -7.457479476928711, -5.6793928146362305, -7.121081829071045, -6.643673419952393, -6.600395202636719, -6.4029669761657715, -6.541974067687988, -7.140434265136719, -7.505499839782715, 0.0, -7.781794548034668, -9.01515007019043, -9.622029304504395, -10.373851776123047, -11.152060508728027, -13.467511177062988, -13.6673002243042, -15.657269477844238, -15.661212921142578, -19.623485565185547, -19.27461051940918, -19.254552841186523, -20.537227630615234, -22.495529174804688, -20.043798446655273, -20.3284854888916, 0.0, -19.36351203918457, -18.071346282958984, -14.294189453125, -15.385082244873047, -14.68118953704834, -14.263104438781738, -11.7880277633667, -11.941829681396484, -10.359153747558594, -9.248322486877441, -7.465469837188721, -7.095997333526611, -4.304783821105957, -4.886674880981445, -3.5900206565856934, -4.006884574890137, -2.095459222793579, -2.682265281677246, -2.359060287475586, -2.456480026245117, -1.979163408279419, -2.142347812652588, -0.9659523963928223, -1.4673296213150024, -2.152494192123413, -0.9860435724258423, -0.7949433326721191, -0.26941290497779846, 0.05382895842194557, 0.0, 0.0, 6.554276466369629, 4.778913974761963, 2.8230960369110107, 3.9748265743255615], [-14.702488899230957, -14.536216735839844, -13.307474136352539, -12.574888229370117, 0.0, -11.586098670959473, -10.841004371643066, -10.123263359069824, -9.9979887008667, -9.72025203704834, -9.890036582946777, -8.933320999145508, -9.639535903930664, -8.554612159729004, -8.096684455871582, -7.151540279388428, -8.21118450164795, -7.485959529876709, -8.35888671875, -6.725808143615723, -7.689611911773682, -7.566492080688477, -7.0110626220703125, -10.796510696411133, 0.0, -10.12962532043457, -8.957335472106934, -9.979264259338379, -9.668542861938477, -11.083173751831055, -12.585538864135742, -13.827619552612305, -16.175222396850586, -16.4630069732666, -18.73146629333496, -19.071481704711914, -19.457197189331055, -21.47289276123047, -23.97893714904785, -22.796161651611328, -21.899869918823242, -24.450960159301758, -22.09409523010254, -20.250703811645508, -20.25971031188965, -18.615150451660156, -15.30612564086914, -15.619461059570312, -15.339174270629883, -13.489384651184082, -12.276782035827637, -9.645865440368652, -9.12315845489502, -8.71121883392334, -6.370455741882324, -6.8552727699279785, -5.8009233474731445, -4.492249965667725, -4.03756046295166, -3.7123377323150635, -3.015103578567505, -2.3536157608032227, -2.1477084159851074, -2.0500969886779785, -1.2606781721115112, -2.153663396835327, -2.01259708404541, -1.7077375650405884, -0.7908449172973633, -0.9497378468513489, -0.1643228828907013, 0.12179133296012878, 0.0, 0.0, 3.2555038928985596, 4.171017169952393, 3.532942056655884, 2.808877944946289, -14.702488899230957, -14.536216735839844, -13.307474136352539, -12.574888229370117, 0.0, -11.586098670959473, -10.841004371643066, -10.123263359069824, -9.9979887008667, -9.72025203704834, -9.890036582946777, -8.933320999145508, -9.639535903930664, -8.554612159729004, -8.096684455871582, -7.151540279388428, -8.21118450164795, -7.485959529876709, -8.35888671875, -6.725808143615723, -7.689611911773682, -7.566492080688477, -7.0110626220703125, -10.796510696411133, 0.0, -10.12962532043457, -8.957335472106934, -9.979264259338379, -9.668542861938477, -11.083173751831055, -12.585538864135742, -13.827619552612305, -16.175222396850586, -16.4630069732666, -18.73146629333496, -19.071481704711914, -19.457197189331055, -21.47289276123047, -23.97893714904785, -22.796161651611328, -21.899869918823242, -24.450960159301758, -22.09409523010254, -20.250703811645508, -20.25971031188965, -18.615150451660156, -15.30612564086914, -15.619461059570312, -15.339174270629883, -13.489384651184082, -12.276782035827637, -9.645865440368652, -9.12315845489502, -8.71121883392334, -6.370455741882324, -6.8552727699279785, -5.8009233474731445, -4.492249965667725, -4.03756046295166, -3.7123377323150635, -3.015103578567505, -2.3536157608032227, -2.1477084159851074, -2.0500969886779785, -1.2606781721115112, -2.153663396835327, -2.01259708404541, -1.7077375650405884, -0.7908449172973633, -0.9497378468513489, -0.1643228828907013, 0.12179133296012878, 0.0, 0.0, 3.2555038928985596, 4.171017169952393, 3.532942056655884, 2.808877944946289], [-15.816248893737793, -15.06155776977539, -15.010383605957031, -12.177766799926758, 0.0, 0.0, -11.847064018249512, -10.639148712158203, -10.140054702758789, -10.093612670898438, -9.171936988830566, -9.54473876953125, -8.269673347473145, -7.613037109375, -8.275553703308105, -7.218432903289795, -7.602886199951172, -7.414071559906006, -7.888392448425293, -7.566335678100586, -7.68184757232666, -7.309403419494629, -7.317698001861572, -8.922508239746094, -7.943276405334473, -8.32526683807373, -10.39511489868164, -10.503265380859375, -12.06838607788086, -12.067220687866211, -15.473993301391602, -14.927802085876465, -17.316497802734375, -18.55229949951172, -19.825233459472656, -19.097230911254883, -22.47254180908203, -22.596067428588867, -23.273813247680664, -21.282686233520508, -22.924009323120117, -23.457700729370117, -22.322397232055664, -22.12299156188965, -22.29604148864746, -21.322919845581055, -19.160858154296875, -18.58356475830078, -15.917694091796875, -14.969314575195312, -13.006024360656738, -9.097062110900879, -8.349995613098145, -8.19737720489502, -7.255997180938721, -6.286500453948975, -5.740711688995361, -3.5882511138916016, -4.2452592849731445, -4.430838584899902, -3.9232394695281982, -2.7838168144226074, -2.6674962043762207, -2.2982184886932373, -2.3105828762054443, -1.747931718826294, -1.539254903793335, -0.7995598912239075, -1.2116196155548096, -0.45275649428367615, 0.3761101961135864, 0.0, 0.0, 6.301385879516602, 4.570422172546387, 4.055581569671631, 3.3064048290252686, 1.7640084028244019, -15.816248893737793, -15.06155776977539, -15.010383605957031, -12.177766799926758, 0.0, 0.0, -11.847064018249512, -10.639148712158203, -10.140054702758789, -10.093612670898438, -9.171936988830566, -9.54473876953125, -8.269673347473145, -7.613037109375, -8.275553703308105, -7.218432903289795, -7.602886199951172, -7.414071559906006, -7.888392448425293, -7.566335678100586, -7.68184757232666, -7.309403419494629, -7.317698001861572, -8.922508239746094, -7.943276405334473, -8.32526683807373, -10.39511489868164, -10.503265380859375, -12.06838607788086, -12.067220687866211, -15.473993301391602, -14.927802085876465, -17.316497802734375, -18.55229949951172, -19.825233459472656, -19.097230911254883, -22.47254180908203, -22.596067428588867, -23.273813247680664, -21.282686233520508, -22.924009323120117, -23.457700729370117, -22.322397232055664, -22.12299156188965, -22.29604148864746, -21.322919845581055, -19.160858154296875, -18.58356475830078, -15.917694091796875, -14.969314575195312, -13.006024360656738, -9.097062110900879, -8.349995613098145, -8.19737720489502, -7.255997180938721, -6.286500453948975, -5.740711688995361, -3.5882511138916016, -4.2452592849731445, -4.430838584899902, -3.9232394695281982, -2.7838168144226074, -2.6674962043762207, -2.2982184886932373, -2.3105828762054443, -1.747931718826294, -1.539254903793335, -0.7995598912239075, -1.2116196155548096, -0.45275649428367615, 0.3761101961135864, 0.0, 0.0, 6.301385879516602, 4.570422172546387, 4.055581569671631, 3.3064048290252686, 1.7640084028244019], [-19.36632537841797, -15.74630355834961, -14.613920211791992, -13.429494857788086, -13.41792106628418, 0.0, -14.16490650177002, -11.510601043701172, -11.10363483428955, -9.849525451660156, -10.007891654968262, -8.561473846435547, -8.097158432006836, -8.659951210021973, -8.291849136352539, -7.899254322052002, -9.018058776855469, -7.813187122344971, -7.570287704467773, -7.854179382324219, -7.571714878082275, -8.00973129272461, -7.889759540557861, -8.142667770385742, -8.74553108215332, -11.745291709899902, -10.918294906616211, -11.593355178833008, -12.944594383239746, -14.955453872680664, -17.886554718017578, -18.474916458129883, -16.944334030151367, -20.698410034179688, -20.385103225708008, -23.890193939208984, -24.158767700195312, -24.29954719543457, -25.21259880065918, -25.97437858581543, 0.0, -23.140350341796875, -26.611064910888672, -23.84198760986328, -22.255245208740234, -22.638294219970703, -20.178625106811523, -21.090740203857422, -16.11237144470215, -15.482020378112793, -14.82734203338623, -12.438359260559082, -10.758796691894531, -9.133172035217285, -7.655701637268066, -7.532876014709473, -6.025641441345215, -6.105332374572754, -5.957108974456787, -5.567904949188232, -4.196159839630127, -4.1043381690979, -3.1044399738311768, -2.572258234024048, -2.12406063079834, -1.9805845022201538, -1.638914942741394, -1.2489984035491943, -0.7703561782836914, -0.6851224899291992, -0.28927865624427795, 0.0, 4.4153971672058105, 5.719132423400879, 4.035456657409668, 3.8878235816955566, 2.7388861179351807, 1.3137378692626953, -19.36632537841797, -15.74630355834961, -14.613920211791992, -13.429494857788086, -13.41792106628418, 0.0, -14.16490650177002, -11.510601043701172, -11.10363483428955, -9.849525451660156, -10.007891654968262, -8.561473846435547, -8.097158432006836, -8.659951210021973, -8.291849136352539, -7.899254322052002, -9.018058776855469, -7.813187122344971, -7.570287704467773, -7.854179382324219, -7.571714878082275, -8.00973129272461, -7.889759540557861, -8.142667770385742, -8.74553108215332, -11.745291709899902, -10.918294906616211, -11.593355178833008, -12.944594383239746, -14.955453872680664, -17.886554718017578, -18.474916458129883, -16.944334030151367, -20.698410034179688, -20.385103225708008, -23.890193939208984, -24.158767700195312, -24.29954719543457, -25.21259880065918, -25.97437858581543, 0.0, -23.140350341796875, -26.611064910888672, -23.84198760986328, -22.255245208740234, -22.638294219970703, -20.178625106811523, -21.090740203857422, -16.11237144470215, -15.482020378112793, -14.82734203338623, -12.438359260559082, -10.758796691894531, -9.133172035217285, -7.655701637268066, -7.532876014709473, -6.025641441345215, -6.105332374572754, -5.957108974456787, -5.567904949188232, -4.196159839630127, -4.1043381690979, -3.1044399738311768, -2.572258234024048, -2.12406063079834, -1.9805845022201538, -1.638914942741394, -1.2489984035491943, -0.7703561782836914, -0.6851224899291992, -0.28927865624427795, 0.0, 4.4153971672058105, 5.719132423400879, 4.035456657409668, 3.8878235816955566, 2.7388861179351807, 1.3137378692626953], [-15.923014640808105, -16.046220779418945, -15.06629753112793, -13.411242485046387, -13.434345245361328, 0.0, 0.0, -11.456746101379395, -11.166253089904785, -9.684934616088867, -9.648795127868652, -9.29140853881836, -7.707053184509277, -7.699768543243408, -7.255137920379639, -8.45522689819336, -8.123167991638184, -7.851357936859131, -8.055046081542969, -7.885061740875244, -7.708147048950195, -7.965302467346191, -7.9142279624938965, -9.16769790649414, -8.953422546386719, -13.776790618896484, -11.730436325073242, -12.370044708251953, -13.647746086120605, -15.163476943969727, -16.84737205505371, -18.23894691467285, -21.659852981567383, -22.01991844177246, -25.050779342651367, -24.590017318725586, -25.180452346801758, -27.67753791809082, -26.410673141479492, -29.254150390625, -28.1543025970459, -25.80414390563965, -27.447391510009766, -27.345096588134766, -26.949113845825195, -25.11514663696289, -23.204944610595703, -21.916122436523438, -19.506376266479492, -18.06309700012207, -16.368589401245117, -14.655081748962402, -12.204574584960938, -8.517889976501465, -7.420579433441162, -6.123668670654297, -4.998010158538818, -5.658302307128906, -6.653149604797363, -4.7088847160339355, -5.200660228729248, -3.7899301052093506, -3.200704336166382, -2.293765068054199, -2.8831663131713867, -2.245831251144409, -1.3113899230957031, -0.8716082572937012, -0.3213423192501068, -0.058824289590120316, 2.3116214275360107, 0.0, 4.799849510192871, 4.433538913726807, 3.3940863609313965, 3.3953263759613037, 3.142021656036377, 3.007124185562134, -15.923014640808105, -16.046220779418945, -15.06629753112793, -13.411242485046387, -13.434345245361328, 0.0, 0.0, -11.456746101379395, -11.166253089904785, -9.684934616088867, -9.648795127868652, -9.29140853881836, -7.707053184509277, -7.699768543243408, -7.255137920379639, -8.45522689819336, -8.123167991638184, -7.851357936859131, -8.055046081542969, -7.885061740875244, -7.708147048950195, -7.965302467346191, -7.9142279624938965, -9.16769790649414, -8.953422546386719, -13.776790618896484, -11.730436325073242, -12.370044708251953, -13.647746086120605, -15.163476943969727, -16.84737205505371, -18.23894691467285, -21.659852981567383, -22.01991844177246, -25.050779342651367, -24.590017318725586, -25.180452346801758, -27.67753791809082, -26.410673141479492, -29.254150390625, -28.1543025970459, -25.80414390563965, -27.447391510009766, -27.345096588134766, -26.949113845825195, -25.11514663696289, -23.204944610595703, -21.916122436523438, -19.506376266479492, -18.06309700012207, -16.368589401245117, -14.655081748962402, -12.204574584960938, -8.517889976501465, -7.420579433441162, -6.123668670654297, -4.998010158538818, -5.658302307128906, -6.653149604797363, -4.7088847160339355, -5.200660228729248, -3.7899301052093506, -3.200704336166382, -2.293765068054199, -2.8831663131713867, -2.245831251144409, -1.3113899230957031, -0.8716082572937012, -0.3213423192501068, -0.058824289590120316, 2.3116214275360107, 0.0, 4.799849510192871, 4.433538913726807, 3.3940863609313965, 3.3953263759613037, 3.142021656036377, 3.007124185562134], [-16.604515075683594, -16.254852294921875, -16.015380859375, -14.706069946289062, -14.0247163772583, 0.0, 0.0, 0.0, -10.99161148071289, -10.029112815856934, -10.008886337280273, -9.286434173583984, -9.2337064743042, -8.82334041595459, -7.929994583129883, -7.7907023429870605, -8.521929740905762, -8.080111503601074, -9.311746597290039, -7.512762069702148, -9.537079811096191, -8.588298797607422, -9.040854454040527, -9.344664573669434, -9.408465385437012, -10.966062545776367, -12.654251098632812, -14.801936149597168, -13.115525245666504, -14.749406814575195, -17.550952911376953, -21.100000381469727, -25.248306274414062, -22.875951766967773, -27.726219177246094, -27.261396408081055, -29.855831146240234, -30.421018600463867, -29.743221282958984, -30.92989158630371, -31.54254722595215, -26.420764923095703, -24.63457489013672, -25.62550926208496, -27.961898803710938, -27.14859962463379, -24.554523468017578, -22.487707138061523, -21.938020706176758, -21.811437606811523, -18.90325355529785, -14.472164154052734, -12.566131591796875, -8.558196067810059, -8.72035026550293, -9.809693336486816, -7.136385917663574, -7.827393054962158, -8.389619827270508, -6.875665664672852, -8.197138786315918, -8.545498847961426, -2.510175943374634, -2.329627513885498, -2.6846237182617188, -1.996981143951416, -1.0120775699615479, -1.5072717666625977, -0.8984269499778748, 0.12639927864074707, 0.0, 1.7973625659942627, 5.979179859161377, 4.522497177124023, 3.5588314533233643, 3.906351327896118, 0.0, -0.9332597255706787, -16.604515075683594, -16.254852294921875, -16.015380859375, -14.706069946289062, -14.0247163772583, 0.0, 0.0, 0.0, -10.99161148071289, -10.029112815856934, -10.008886337280273, -9.286434173583984, -9.2337064743042, -8.82334041595459, -7.929994583129883, -7.7907023429870605, -8.521929740905762, -8.080111503601074, -9.311746597290039, -7.512762069702148, -9.537079811096191, -8.588298797607422, -9.040854454040527, -9.344664573669434, -9.408465385437012, -10.966062545776367, -12.654251098632812, -14.801936149597168, -13.115525245666504, -14.749406814575195, -17.550952911376953, -21.100000381469727, -25.248306274414062, -22.875951766967773, -27.726219177246094, -27.261396408081055, -29.855831146240234, -30.421018600463867, -29.743221282958984, -30.92989158630371, -31.54254722595215, -26.420764923095703, -24.63457489013672, -25.62550926208496, -27.961898803710938, -27.14859962463379, -24.554523468017578, -22.487707138061523, -21.938020706176758, -21.811437606811523, -18.90325355529785, -14.472164154052734, -12.566131591796875, -8.558196067810059, -8.72035026550293, -9.809693336486816, -7.136385917663574, -7.827393054962158, -8.389619827270508, -6.875665664672852, -8.197138786315918, -8.545498847961426, -2.510175943374634, -2.329627513885498, -2.6846237182617188, -1.996981143951416, -1.0120775699615479, -1.5072717666625977, -0.8984269499778748, 0.12639927864074707, 0.0, 1.7973625659942627, 5.979179859161377, 4.522497177124023, 3.5588314533233643, 3.906351327896118, 0.0, -0.9332597255706787], [-18.922887802124023, -17.89287567138672, -16.455066680908203, -15.913934707641602, -13.740263938903809, -13.395722389221191, 0.0, 0.0, -10.817666053771973, -9.93337631225586, -9.891045570373535, -9.580044746398926, -9.121779441833496, -8.56795883178711, -8.626171112060547, -8.470658302307129, -8.494117736816406, -8.443912506103516, -9.42400074005127, -9.184722900390625, -8.672280311584473, -7.438533306121826, -9.884032249450684, -9.57204532623291, -9.868123054504395, -10.407889366149902, -12.68681812286377, -13.92340087890625, -15.216819763183594, -18.04534149169922, 0.0, -23.12986183166504, -25.693370819091797, -27.1827335357666, -26.508541107177734, -24.479305267333984, -24.75604248046875, -26.45644187927246, -29.738122940063477, -31.74964714050293, -27.02693748474121, -27.853357315063477, -26.013181686401367, -25.760086059570312, -24.911083221435547, -21.63564109802246, -20.736347198486328, -24.122224807739258, -22.313764572143555, -21.45308494567871, -19.785850524902344, -15.793543815612793, -10.241626739501953, -11.303641319274902, -9.544962882995605, -8.062589645385742, -8.13270378112793, -7.936779499053955, -5.659648418426514, -8.780740737915039, -9.207749366760254, -7.673711776733398, -2.0336475372314453, -3.056209087371826, -2.058927059173584, -1.6879774332046509, -1.5458072423934937, -1.8067307472229004, -3.15944504737854, 0.0, 3.365095376968384, 4.093210220336914, 5.5741753578186035, 3.724876642227173, 3.5635290145874023, 2.809246301651001, -0.5730255842208862, 0.0, -18.922887802124023, -17.89287567138672, -16.455066680908203, -15.913934707641602, -13.740263938903809, -13.395722389221191, 0.0, 0.0, -10.817666053771973, -9.93337631225586, -9.891045570373535, -9.580044746398926, -9.121779441833496, -8.56795883178711, -8.626171112060547, -8.470658302307129, -8.494117736816406, -8.443912506103516, -9.42400074005127, -9.184722900390625, -8.672280311584473, -7.438533306121826, -9.884032249450684, -9.57204532623291, -9.868123054504395, -10.407889366149902, -12.68681812286377, -13.92340087890625, -15.216819763183594, -18.04534149169922, 0.0, -23.12986183166504, -25.693370819091797, -27.1827335357666, -26.508541107177734, -24.479305267333984, -24.75604248046875, -26.45644187927246, -29.738122940063477, -31.74964714050293, -27.02693748474121, -27.853357315063477, -26.013181686401367, -25.760086059570312, -24.911083221435547, -21.63564109802246, -20.736347198486328, -24.122224807739258, -22.313764572143555, -21.45308494567871, -19.785850524902344, -15.793543815612793, -10.241626739501953, -11.303641319274902, -9.544962882995605, -8.062589645385742, -8.13270378112793, -7.936779499053955, -5.659648418426514, -8.780740737915039, -9.207749366760254, -7.673711776733398, -2.0336475372314453, -3.056209087371826, -2.058927059173584, -1.6879774332046509, -1.5458072423934937, -1.8067307472229004, -3.15944504737854, 0.0, 3.365095376968384, 4.093210220336914, 5.5741753578186035, 3.724876642227173, 3.5635290145874023, 2.809246301651001, -0.5730255842208862, 0.0], [-18.086116790771484, -17.11934471130371, -14.680954933166504, -15.102315902709961, -14.282781600952148, -11.12248420715332, -13.1168851852417, -10.176597595214844, 0.0, -10.24567985534668, -9.214895248413086, -9.992886543273926, -8.933728218078613, -8.894630432128906, -8.551430702209473, -8.724546432495117, -9.127729415893555, -9.022563934326172, -9.03650951385498, -9.058507919311523, -9.276412010192871, -9.110471725463867, -10.170062065124512, -10.558133125305176, -10.983964920043945, -11.528409004211426, -11.492107391357422, -13.650036811828613, -13.984660148620605, 0.0, 0.0, -26.61156463623047, -25.228864669799805, -23.767274856567383, -25.096691131591797, -25.88921546936035, -28.38153076171875, -27.05717658996582, -28.776329040527344, -30.58333396911621, -29.34835433959961, -29.068286895751953, -27.584505081176758, -24.357988357543945, -22.077505111694336, -23.852638244628906, -20.162334442138672, -20.399524688720703, -19.188812255859375, -18.61760902404785, -19.470754623413086, -14.252030372619629, -12.9402437210083, -10.487709999084473, -11.333843231201172, -10.190242767333984, -9.069924354553223, -9.106074333190918, -9.764781951904297, -11.104791641235352, -10.17640495300293, -4.057666778564453, -2.4016878604888916, -2.1189026832580566, -2.072835922241211, -1.4168304204940796, -1.6207762956619263, -3.5616135597229004, 0.0, 0.0, 4.003432273864746, 4.168593406677246, 2.264307737350464, 3.300858736038208, 2.4843790531158447, 2.8495774269104004, 0.6211045384407043, 0.0, -18.086116790771484, -17.11934471130371, -14.680954933166504, -15.102315902709961, -14.282781600952148, -11.12248420715332, -13.1168851852417, -10.176597595214844, 0.0, -10.24567985534668, -9.214895248413086, -9.992886543273926, -8.933728218078613, -8.894630432128906, -8.551430702209473, -8.724546432495117, -9.127729415893555, -9.022563934326172, -9.03650951385498, -9.058507919311523, -9.276412010192871, -9.110471725463867, -10.170062065124512, -10.558133125305176, -10.983964920043945, -11.528409004211426, -11.492107391357422, -13.650036811828613, -13.984660148620605, 0.0, 0.0, -26.61156463623047, -25.228864669799805, -23.767274856567383, -25.096691131591797, -25.88921546936035, -28.38153076171875, -27.05717658996582, -28.776329040527344, -30.58333396911621, -29.34835433959961, -29.068286895751953, -27.584505081176758, -24.357988357543945, -22.077505111694336, -23.852638244628906, -20.162334442138672, -20.399524688720703, -19.188812255859375, -18.61760902404785, -19.470754623413086, -14.252030372619629, -12.9402437210083, -10.487709999084473, -11.333843231201172, -10.190242767333984, -9.069924354553223, -9.106074333190918, -9.764781951904297, -11.104791641235352, -10.17640495300293, -4.057666778564453, -2.4016878604888916, -2.1189026832580566, -2.072835922241211, -1.4168304204940796, -1.6207762956619263, -3.5616135597229004, 0.0, 0.0, 4.003432273864746, 4.168593406677246, 2.264307737350464, 3.300858736038208, 2.4843790531158447, 2.8495774269104004, 0.6211045384407043, 0.0], [-18.801837921142578, -18.745222091674805, -17.16141128540039, -16.09757423400879, -15.71151351928711, -13.97486686706543, -13.076141357421875, -12.464847564697266, -9.016349792480469, 0.0, -9.305730819702148, -9.555285453796387, -9.455209732055664, -9.588656425476074, -9.061970710754395, -9.399303436279297, -9.631628036499023, -8.868183135986328, -9.705513000488281, -10.165360450744629, -9.549392700195312, -10.868866920471191, -10.347881317138672, -10.895522117614746, -11.141708374023438, -10.440888404846191, 0.0, -17.73394775390625, -14.436172485351562, 0.0, 0.0, 0.0, -23.498456954956055, -25.732452392578125, -28.529138565063477, -28.55059242248535, -30.405071258544922, -30.7396183013916, -31.535335540771484, -27.127788543701172, -28.80455207824707, -27.321374893188477, -26.422754287719727, -23.4842472076416, -22.699758529663086, -23.936443328857422, -23.163955688476562, -23.192228317260742, -20.312015533447266, -20.472082138061523, -20.71103286743164, -19.1435604095459, -13.843000411987305, -14.630908966064453, -16.129573822021484, -13.933388710021973, -11.079203605651855, 0.0, -8.478409767150879, -5.599388122558594, -6.323175430297852, -3.486393451690674, -1.7970479726791382, -2.844923496246338, -2.7257351875305176, -1.6335093975067139, 0.0, 0.0, 0.0, 4.875019073486328, 4.372586250305176, 4.599595546722412, 5.368802547454834, 3.893663167953491, 3.975832939147949, 1.895387887954712, 0.0, 0.0, -18.801837921142578, -18.745222091674805, -17.16141128540039, -16.09757423400879, -15.71151351928711, -13.97486686706543, -13.076141357421875, -12.464847564697266, -9.016349792480469, 0.0, -9.305730819702148, -9.555285453796387, -9.455209732055664, -9.588656425476074, -9.061970710754395, -9.399303436279297, -9.631628036499023, -8.868183135986328, -9.705513000488281, -10.165360450744629, -9.549392700195312, -10.868866920471191, -10.347881317138672, -10.895522117614746, -11.141708374023438, -10.440888404846191, 0.0, -17.73394775390625, -14.436172485351562, 0.0, 0.0, 0.0, -23.498456954956055, -25.732452392578125, -28.529138565063477, -28.55059242248535, -30.405071258544922, -30.7396183013916, -31.535335540771484, -27.127788543701172, -28.80455207824707, -27.321374893188477, -26.422754287719727, -23.4842472076416, -22.699758529663086, -23.936443328857422, -23.163955688476562, -23.192228317260742, -20.312015533447266, -20.472082138061523, -20.71103286743164, -19.1435604095459, -13.843000411987305, -14.630908966064453, -16.129573822021484, -13.933388710021973, -11.079203605651855, 0.0, -8.478409767150879, -5.599388122558594, -6.323175430297852, -3.486393451690674, -1.7970479726791382, -2.844923496246338, -2.7257351875305176, -1.6335093975067139, 0.0, 0.0, 0.0, 4.875019073486328, 4.372586250305176, 4.599595546722412, 5.368802547454834, 3.893663167953491, 3.975832939147949, 1.895387887954712, 0.0, 0.0], [0.0, -18.8227481842041, -16.61130142211914, -15.767354011535645, -14.324515342712402, -12.82861042022705, -13.239988327026367, -12.352560043334961, -10.783720970153809, -8.178169250488281, 0.0, -11.347118377685547, -9.155746459960938, -9.615259170532227, -9.396074295043945, -9.518904685974121, -9.68764877319336, -9.839189529418945, -11.283204078674316, -10.418055534362793, -10.575443267822266, -11.747108459472656, -11.801430702209473, -11.615400314331055, -11.468768119812012, 0.0, 0.0, -15.227275848388672, -16.76907730102539, -16.15554428100586, 0.0, 0.0, -26.432876586914062, -25.154361724853516, -28.96969985961914, -27.30811309814453, -25.97342300415039, -28.78902244567871, -28.692380905151367, -29.33315086364746, -29.790264129638672, -30.23799705505371, -31.070817947387695, -27.793014526367188, -24.289180755615234, -23.29396629333496, -23.387107849121094, -25.10000991821289, -23.639875411987305, -20.3724422454834, -19.880823135375977, -18.70836639404297, -18.92547607421875, -15.079781532287598, -12.849143981933594, -15.080229759216309, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.098898410797119, 0.0, 0.0, 0.0, 4.158181190490723, 4.9224348068237305, 3.8650035858154297, 4.379242897033691, 3.6696577072143555, 1.0086201429367065, 2.690030574798584, -0.00374787044711411, 0.0, 0.0, 0.0, -18.8227481842041, -16.61130142211914, -15.767354011535645, -14.324515342712402, -12.82861042022705, -13.239988327026367, -12.352560043334961, -10.783720970153809, -8.178169250488281, 0.0, -11.347118377685547, -9.155746459960938, -9.615259170532227, -9.396074295043945, -9.518904685974121, -9.68764877319336, -9.839189529418945, -11.283204078674316, -10.418055534362793, -10.575443267822266, -11.747108459472656, -11.801430702209473, -11.615400314331055, -11.468768119812012, 0.0, 0.0, -15.227275848388672, -16.76907730102539, -16.15554428100586, 0.0, 0.0, -26.432876586914062, -25.154361724853516, -28.96969985961914, -27.30811309814453, -25.97342300415039, -28.78902244567871, -28.692380905151367, -29.33315086364746, -29.790264129638672, -30.23799705505371, -31.070817947387695, -27.793014526367188, -24.289180755615234, -23.29396629333496, -23.387107849121094, -25.10000991821289, -23.639875411987305, -20.3724422454834, -19.880823135375977, -18.70836639404297, -18.92547607421875, -15.079781532287598, -12.849143981933594, -15.080229759216309, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.098898410797119, 0.0, 0.0, 0.0, 4.158181190490723, 4.9224348068237305, 3.8650035858154297, 4.379242897033691, 3.6696577072143555, 1.0086201429367065, 2.690030574798584, -0.00374787044711411, 0.0, 0.0], [0.0, 0.0, -14.68898868560791, -16.205060958862305, -16.59916114807129, -13.718644142150879, -14.416254997253418, -11.5667085647583, -11.647852897644043, -10.437666893005371, -10.11777114868164, -9.105402946472168, 0.0, -9.254496574401855, -10.216391563415527, -9.245842933654785, -9.454070091247559, -10.985140800476074, -10.44870662689209, -11.163216590881348, -10.937427520751953, -10.973167419433594, -12.194478034973145, -13.127193450927734, 0.0, 0.0, 0.0, 0.0, -15.757965087890625, -18.915830612182617, 0.0, 0.0, 0.0, -28.09556770324707, -25.568851470947266, -28.1650447845459, -31.002779006958008, -28.842735290527344, -31.741695404052734, -31.06337547302246, -30.286823272705078, -31.459850311279297, -29.41099739074707, -30.46000099182129, -28.247730255126953, -25.240314483642578, -23.95184326171875, -27.5072021484375, -25.375349044799805, -21.126527786254883, -19.539783477783203, 0.0, -15.715415000915527, 0.0, 0.0, -18.204360961914062, -19.472183227539062, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.3348114490509033, 3.7045559883117676, 6.384570121765137, 3.798459768295288, 4.645539283752441, 3.6398041248321533, 1.857323408126831, 1.2616424560546875, 0.0, 0.0, 0.0, 0.0, -14.68898868560791, -16.205060958862305, -16.59916114807129, -13.718644142150879, -14.416254997253418, -11.5667085647583, -11.647852897644043, -10.437666893005371, -10.11777114868164, -9.105402946472168, 0.0, -9.254496574401855, -10.216391563415527, -9.245842933654785, -9.454070091247559, -10.985140800476074, -10.44870662689209, -11.163216590881348, -10.937427520751953, -10.973167419433594, -12.194478034973145, -13.127193450927734, 0.0, 0.0, 0.0, 0.0, -15.757965087890625, -18.915830612182617, 0.0, 0.0, 0.0, -28.09556770324707, -25.568851470947266, -28.1650447845459, -31.002779006958008, -28.842735290527344, -31.741695404052734, -31.06337547302246, -30.286823272705078, -31.459850311279297, -29.41099739074707, -30.46000099182129, -28.247730255126953, -25.240314483642578, -23.95184326171875, -27.5072021484375, -25.375349044799805, -21.126527786254883, -19.539783477783203, 0.0, -15.715415000915527, 0.0, 0.0, -18.204360961914062, -19.472183227539062, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.3348114490509033, 3.7045559883117676, 6.384570121765137, 3.798459768295288, 4.645539283752441, 3.6398041248321533, 1.857323408126831, 1.2616424560546875, 0.0, 0.0], [0.0, 0.0, -14.173910140991211, -16.604543685913086, -16.302845001220703, -11.68591594696045, -13.014711380004883, -12.762059211730957, -12.867862701416016, -10.204488754272461, -10.546693801879883, -10.80838394165039, -9.856836318969727, -10.259666442871094, -11.800539016723633, -10.54312801361084, -11.66948127746582, -11.273386001586914, -11.798105239868164, -12.380105972290039, -12.2544527053833, -13.247979164123535, 0.0, 0.0, 0.0, 0.0, 0.0, -17.548765182495117, 0.0, 0.0, 0.0, 0.0, 0.0, -29.185710906982422, -29.862199783325195, -30.373870849609375, -28.001543045043945, -27.368465423583984, -29.724336624145508, -34.183494567871094, -34.763465881347656, -33.95246887207031, -33.0134162902832, -32.151588439941406, -31.52432632446289, -28.400331497192383, -27.155330657958984, -24.773637771606445, -23.520158767700195, -21.190683364868164, -19.677019119262695, -20.026500701904297, 0.0, 0.0, 0.0, -18.878978729248047, -17.505390167236328, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.5158114433288574, 4.5314788818359375, 2.277662754058838, 4.762075424194336, 4.5312323570251465, 3.2730233669281006, 2.928455352783203, 1.2498042583465576, 0.0, 0.0, 0.0, 0.0, 0.0, -14.173910140991211, -16.604543685913086, -16.302845001220703, -11.68591594696045, -13.014711380004883, -12.762059211730957, -12.867862701416016, -10.204488754272461, -10.546693801879883, -10.80838394165039, -9.856836318969727, -10.259666442871094, -11.800539016723633, -10.54312801361084, -11.66948127746582, -11.273386001586914, -11.798105239868164, -12.380105972290039, -12.2544527053833, -13.247979164123535, 0.0, 0.0, 0.0, 0.0, 0.0, -17.548765182495117, 0.0, 0.0, 0.0, 0.0, 0.0, -29.185710906982422, -29.862199783325195, -30.373870849609375, -28.001543045043945, -27.368465423583984, -29.724336624145508, -34.183494567871094, -34.763465881347656, -33.95246887207031, -33.0134162902832, -32.151588439941406, -31.52432632446289, -28.400331497192383, -27.155330657958984, -24.773637771606445, -23.520158767700195, -21.190683364868164, -19.677019119262695, -20.026500701904297, 0.0, 0.0, 0.0, -18.878978729248047, -17.505390167236328, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.5158114433288574, 4.5314788818359375, 2.277662754058838, 4.762075424194336, 4.5312323570251465, 3.2730233669281006, 2.928455352783203, 1.2498042583465576, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, -21.0902099609375, -18.305864334106445, -15.23560905456543, -13.687651634216309, -12.100504875183105, -13.251358032226562, -11.226465225219727, -11.253560066223145, -10.711320877075195, -9.599509239196777, -9.618481636047363, 0.0, -12.909192085266113, -11.062474250793457, -12.373832702636719, -12.945982933044434, -14.191070556640625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.631284713745117, -19.673513412475586, -21.100629806518555, 0.0, 0.0, 0.0, 0.0, -26.0131893157959, -27.674571990966797, -26.21343994140625, -30.163082122802734, 0.0, 0.0, 0.0, 0.0, 0.0, -34.70266342163086, -32.39757537841797, -30.874088287353516, -28.631847381591797, -25.27919578552246, -23.011154174804688, -21.724225997924805, 0.0, 0.0, 0.0, -16.610904693603516, -18.114477157592773, -15.008012771606445, -13.043845176696777, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.7251343727111816, 4.410250663757324, 5.230818748474121, 3.860980749130249, 2.9755334854125977, 2.7978031635284424, 2.1702194213867188, 1.1365466117858887, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -21.0902099609375, -18.305864334106445, -15.23560905456543, -13.687651634216309, -12.100504875183105, -13.251358032226562, -11.226465225219727, -11.253560066223145, -10.711320877075195, -9.599509239196777, -9.618481636047363, 0.0, -12.909192085266113, -11.062474250793457, -12.373832702636719, -12.945982933044434, -14.191070556640625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.631284713745117, -19.673513412475586, -21.100629806518555, 0.0, 0.0, 0.0, 0.0, -26.0131893157959, -27.674571990966797, -26.21343994140625, -30.163082122802734, 0.0, 0.0, 0.0, 0.0, 0.0, -34.70266342163086, -32.39757537841797, -30.874088287353516, -28.631847381591797, -25.27919578552246, -23.011154174804688, -21.724225997924805, 0.0, 0.0, 0.0, -16.610904693603516, -18.114477157592773, -15.008012771606445, -13.043845176696777, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.7251343727111816, 4.410250663757324, 5.230818748474121, 3.860980749130249, 2.9755334854125977, 2.7978031635284424, 2.1702194213867188, 1.1365466117858887, 0.0, 0.0, 0.0], [-22.803234100341797, 0.0, 0.0, 0.0, -17.602209091186523, -14.511078834533691, -13.391409873962402, -13.446287155151367, -13.128915786743164, -11.243329048156738, -12.096373558044434, -10.896421432495117, -11.713408470153809, -10.54800033569336, -12.16485595703125, 0.0, 0.0, 0.0, -12.595202445983887, -16.852537155151367, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.447845458984375, -21.747844696044922, 0.0, 0.0, 0.0, 0.0, 0.0, -27.891855239868164, -30.90373420715332, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.309236526489258, -29.58983612060547, -25.388111114501953, -24.1170654296875, -25.175832748413086, 0.0, 0.0, -19.410877227783203, -19.342491149902344, -15.154364585876465, -14.8793363571167, -16.31245994567871, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.601170539855957, 2.1710548400878906, 1.6757519245147705, 5.1298346519470215, 0.9563760757446289, 2.3613529205322266, 1.3794234991073608, 0.0, 2.200901508331299, 0.0, -22.803234100341797, 0.0, 0.0, 0.0, -17.602209091186523, -14.511078834533691, -13.391409873962402, -13.446287155151367, -13.128915786743164, -11.243329048156738, -12.096373558044434, -10.896421432495117, -11.713408470153809, -10.54800033569336, -12.16485595703125, 0.0, 0.0, 0.0, -12.595202445983887, -16.852537155151367, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.447845458984375, -21.747844696044922, 0.0, 0.0, 0.0, 0.0, 0.0, -27.891855239868164, -30.90373420715332, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.309236526489258, -29.58983612060547, -25.388111114501953, -24.1170654296875, -25.175832748413086, 0.0, 0.0, -19.410877227783203, -19.342491149902344, -15.154364585876465, -14.8793363571167, -16.31245994567871, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.601170539855957, 2.1710548400878906, 1.6757519245147705, 5.1298346519470215, 0.9563760757446289, 2.3613529205322266, 1.3794234991073608, 0.0, 2.200901508331299, 0.0], [-23.893590927124023, -23.419313430786133, -21.55776596069336, -20.189266204833984, 0.0, -16.212989807128906, -15.4923734664917, -13.64630126953125, -12.170599937438965, -13.032013893127441, -11.84476375579834, -11.155072212219238, -10.650824546813965, -11.906061172485352, -10.008831024169922, 0.0, 0.0, 0.0, -12.793187141418457, -14.230323791503906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.353090286254883, 0.0, -25.477968215942383, -28.884611129760742, 0.0, 0.0, 0.0, 0.0, 0.0, -30.183969497680664, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.303678512573242, -27.863794326782227, -25.734235763549805, 0.0, 0.0, 0.0, 0.0, -19.10326385498047, -14.55715560913086, -16.137617111206055, -15.186408042907715, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.914950370788574, 2.204339027404785, 0.830301821231842, 2.2150309085845947, 2.4607834815979004, 0.0, 3.5713894367218018, 1.5145609378814697, 0.0, -23.893590927124023, -23.419313430786133, -21.55776596069336, -20.189266204833984, 0.0, -16.212989807128906, -15.4923734664917, -13.64630126953125, -12.170599937438965, -13.032013893127441, -11.84476375579834, -11.155072212219238, -10.650824546813965, -11.906061172485352, -10.008831024169922, 0.0, 0.0, 0.0, -12.793187141418457, -14.230323791503906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.353090286254883, 0.0, -25.477968215942383, -28.884611129760742, 0.0, 0.0, 0.0, 0.0, 0.0, -30.183969497680664, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.303678512573242, -27.863794326782227, -25.734235763549805, 0.0, 0.0, 0.0, 0.0, -19.10326385498047, -14.55715560913086, -16.137617111206055, -15.186408042907715, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.914950370788574, 2.204339027404785, 0.830301821231842, 2.2150309085845947, 2.4607834815979004, 0.0, 3.5713894367218018, 1.5145609378814697, 0.0], [-25.645368576049805, -23.634780883789062, -22.083555221557617, 0.0, 0.0, -14.775457382202148, -14.489081382751465, -14.006665229797363, -13.156414985656738, -10.343241691589355, -12.850032806396484, -11.53995132446289, -12.118966102600098, -12.8387451171875, -10.951244354248047, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.359573364257812, -27.713134765625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.761770248413086, -30.776531219482422, -28.486764907836914, -29.712440490722656, -26.4844970703125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.126012802124023, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.383988618850708, 2.5876426696777344, 2.8899848461151123, 2.711751699447632, 2.774998188018799, 1.558376669883728, 0.0, 0.0, 0.0, 0.0, -25.645368576049805, -23.634780883789062, -22.083555221557617, 0.0, 0.0, -14.775457382202148, -14.489081382751465, -14.006665229797363, -13.156414985656738, -10.343241691589355, -12.850032806396484, -11.53995132446289, -12.118966102600098, -12.8387451171875, -10.951244354248047, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.359573364257812, -27.713134765625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.761770248413086, -30.776531219482422, -28.486764907836914, -29.712440490722656, -26.4844970703125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.126012802124023, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.383988618850708, 2.5876426696777344, 2.8899848461151123, 2.711751699447632, 2.774998188018799, 1.558376669883728, 0.0, 0.0, 0.0, 0.0], [-28.17190933227539, 0.0, -21.054853439331055, 0.0, 0.0, 0.0, -16.949750900268555, -14.816654205322266, -13.54492473602295, -12.449457168579102, -13.057198524475098, -11.57171630859375, -13.371586799621582, -13.027118682861328, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.708213806152344, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.425521850585938, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -31.91651153564453, -31.06846809387207, -31.85643768310547, -31.037912368774414, -30.63083267211914, 0.0, 0.0, 0.0, 0.0, 0.0, -19.00046157836914, 0.0, 0.0, -16.682456970214844, 0.0, 0.0, 0.0, 0.0, -14.065646171569824, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.857743740081787, 3.9725828170776367, 2.42885684967041, 3.057023048400879, 1.8320562839508057, 0.0, 0.0, -3.739678144454956, 0.0, -28.17190933227539, 0.0, -21.054853439331055, 0.0, 0.0, 0.0, -16.949750900268555, -14.816654205322266, -13.54492473602295, -12.449457168579102, -13.057198524475098, -11.57171630859375, -13.371586799621582, -13.027118682861328, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.708213806152344, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.425521850585938, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -31.91651153564453, -31.06846809387207, -31.85643768310547, -31.037912368774414, -30.63083267211914, 0.0, 0.0, 0.0, 0.0, 0.0, -19.00046157836914, 0.0, 0.0, -16.682456970214844, 0.0, 0.0, 0.0, 0.0, -14.065646171569824, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.857743740081787, 3.9725828170776367, 2.42885684967041, 3.057023048400879, 1.8320562839508057, 0.0, 0.0, -3.739678144454956, 0.0], [0.0, 0.0, -18.03476333618164, -20.223791122436523, 0.0, 0.0, 0.0, -12.722201347351074, -13.072876930236816, -12.357739448547363, -12.660554885864258, -10.892260551452637, -12.063106536865234, -11.628137588500977, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.88504409790039, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.455747604370117, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.707435607910156, 0.0, 0.0, 0.0, 0.0, -29.729766845703125, -29.545455932617188, -28.300907135009766, -25.748790740966797, 0.0, 0.0, -28.14640998840332, 0.0, 0.0, 0.0, -20.17741584777832, 0.0, -16.667619705200195, -16.30592918395996, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -4.513970851898193, 0.0, 0.0, 0.0, 4.399117946624756, 2.0431265830993652, 0.0, 0.0, 0.6072479486465454, 0.0, 6.4775800704956055, 0.0, 0.0, -18.03476333618164, -20.223791122436523, 0.0, 0.0, 0.0, -12.722201347351074, -13.072876930236816, -12.357739448547363, -12.660554885864258, -10.892260551452637, -12.063106536865234, -11.628137588500977, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.88504409790039, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.455747604370117, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.707435607910156, 0.0, 0.0, 0.0, 0.0, -29.729766845703125, -29.545455932617188, -28.300907135009766, -25.748790740966797, 0.0, 0.0, -28.14640998840332, 0.0, 0.0, 0.0, -20.17741584777832, 0.0, -16.667619705200195, -16.30592918395996, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -4.513970851898193, 0.0, 0.0, 0.0, 4.399117946624756, 2.0431265830993652, 0.0, 0.0, 0.6072479486465454, 0.0, 6.4775800704956055], [0.0, 0.0, 0.0, -21.369415283203125, -20.961183547973633, 0.0, 0.0, -12.506232261657715, -12.7247314453125, -11.870806694030762, -13.351570129394531, -10.521926879882812, -12.364730834960938, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.381916046142578, -24.29895782470703, -26.44965171813965, 0.0, 0.0, 0.0, 0.0, 0.0, -30.597505569458008, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -31.90364646911621, 0.0, -27.141706466674805, -26.751222610473633, -30.138675689697266, -29.581703186035156, -25.111167907714844, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.92365074157715, -19.407350540161133, -17.495317459106445, -16.890016555786133, -15.431313514709473, -12.13765811920166, -13.506155967712402, -12.905556678771973, -10.621408462524414, 0.0, 0.0, 0.0, -5.992918968200684, -4.906120300292969, 0.0, -1.1203575134277344, 0.5424465537071228, 2.1136631965637207, 0.0, -1.4928654432296753, 1.9722687005996704, 5.4514875411987305, 4.9472856521606445, 0.0, 0.0, 0.0, -21.369415283203125, -20.961183547973633, 0.0, 0.0, -12.506232261657715, -12.7247314453125, -11.870806694030762, -13.351570129394531, -10.521926879882812, -12.364730834960938, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.381916046142578, -24.29895782470703, -26.44965171813965, 0.0, 0.0, 0.0, 0.0, 0.0, -30.597505569458008, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -31.90364646911621, 0.0, -27.141706466674805, -26.751222610473633, -30.138675689697266, -29.581703186035156, -25.111167907714844, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.92365074157715, -19.407350540161133, -17.495317459106445, -16.890016555786133, -15.431313514709473, -12.13765811920166, -13.506155967712402, -12.905556678771973, -10.621408462524414, 0.0, 0.0, 0.0, -5.992918968200684, -4.906120300292969, 0.0, -1.1203575134277344, 0.5424465537071228, 2.1136631965637207, 0.0, -1.4928654432296753, 1.9722687005996704, 5.4514875411987305, 4.9472856521606445], [0.0, 0.0, 0.0, -20.678129196166992, 0.0, -23.08024024963379, 0.0, 0.0, -12.409070014953613, -12.75684642791748, -11.69178295135498, -13.072097778320312, 0.0, -9.577621459960938, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.9705810546875, -26.240636825561523, -26.286195755004883, 0.0, 0.0, 0.0, 0.0, 0.0, -30.885150909423828, 0.0, -33.17222595214844, 0.0, 0.0, 0.0, 0.0, 0.0, -33.20131301879883, 0.0, 0.0, -31.432613372802734, 0.0, 0.0, -27.94588279724121, -27.71794319152832, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.215606689453125, -18.723587036132812, -16.7034969329834, -16.453556060791016, -15.145498275756836, -14.16573715209961, -12.937121391296387, -12.28902530670166, -13.62606430053711, -14.806384086608887, 0.0, 0.0, -8.871454238891602, -9.870813369750977, 0.0, 0.0, 0.0, 0.0, -2.947448253631592, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.678129196166992, 0.0, -23.08024024963379, 0.0, 0.0, -12.409070014953613, -12.75684642791748, -11.69178295135498, -13.072097778320312, 0.0, -9.577621459960938, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.9705810546875, -26.240636825561523, -26.286195755004883, 0.0, 0.0, 0.0, 0.0, 0.0, -30.885150909423828, 0.0, -33.17222595214844, 0.0, 0.0, 0.0, 0.0, 0.0, -33.20131301879883, 0.0, 0.0, -31.432613372802734, 0.0, 0.0, -27.94588279724121, -27.71794319152832, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.215606689453125, -18.723587036132812, -16.7034969329834, -16.453556060791016, -15.145498275756836, -14.16573715209961, -12.937121391296387, -12.28902530670166, -13.62606430053711, -14.806384086608887, 0.0, 0.0, -8.871454238891602, -9.870813369750977, 0.0, 0.0, 0.0, 0.0, -2.947448253631592, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -20.12431526184082, -18.734256744384766, -14.815567970275879, -13.267729759216309, -13.304787635803223, 0.0, -13.931727409362793, 0.0, -11.62570858001709, -15.27784252166748, -15.351702690124512, 0.0, 0.0, -16.01005744934082, -19.998798370361328, -20.0247859954834, -21.478731155395508, -24.76702308654785, -26.96469497680664, -27.65302085876465, -27.832605361938477, 0.0, 0.0, 0.0, 0.0, -34.6430549621582, 0.0, 0.0, -34.240875244140625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.167543411254883, 0.0, -29.446165084838867, -29.024147033691406, -28.47645378112793, -27.83514404296875, -29.735992431640625, 0.0, 0.0, 0.0, 0.0, -22.613574981689453, -21.98221778869629, 0.0, -21.811504364013672, -20.136022567749023, -20.08272933959961, -17.694303512573242, -18.065753936767578, -16.889230728149414, -15.265731811523438, -14.909441947937012, -13.475198745727539, -12.11398983001709, -11.462477684020996, -10.575750350952148, -8.173328399658203, 0.0, -10.210051536560059, 0.0, 0.0, 0.0, 0.0, 0.0, -3.7654008865356445, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.12431526184082, -18.734256744384766, -14.815567970275879, -13.267729759216309, -13.304787635803223, 0.0, -13.931727409362793, 0.0, -11.62570858001709, -15.27784252166748, -15.351702690124512, 0.0, 0.0, -16.01005744934082, -19.998798370361328, -20.0247859954834, -21.478731155395508, -24.76702308654785, -26.96469497680664, -27.65302085876465, -27.832605361938477, 0.0, 0.0, 0.0, 0.0, -34.6430549621582, 0.0, 0.0, -34.240875244140625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.167543411254883, 0.0, -29.446165084838867, -29.024147033691406, -28.47645378112793, -27.83514404296875, -29.735992431640625, 0.0, 0.0, 0.0, 0.0, -22.613574981689453, -21.98221778869629, 0.0, -21.811504364013672, -20.136022567749023, -20.08272933959961, -17.694303512573242, -18.065753936767578, -16.889230728149414, -15.265731811523438, -14.909441947937012, -13.475198745727539, -12.11398983001709, -11.462477684020996, -10.575750350952148, -8.173328399658203, 0.0, -10.210051536560059, 0.0, 0.0, 0.0, 0.0, 0.0, -3.7654008865356445, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -20.21233558654785, -20.16263198852539, -16.002134323120117, -15.305403709411621, 0.0, -14.508560180664062, 0.0, 0.0, -10.486135482788086, -13.272603988647461, -14.902587890625, -13.893182754516602, -17.608806610107422, -17.976381301879883, -18.60282325744629, -19.596540451049805, -21.079639434814453, -22.718687057495117, -25.5664119720459, -27.5790958404541, -27.683046340942383, -28.47366714477539, 0.0, -32.99625778198242, -34.805816650390625, -35.29485321044922, -32.72464370727539, -35.206703186035156, -31.815153121948242, 0.0, -29.049182891845703, 0.0, 0.0, 0.0, 0.0, 0.0, -29.47865867614746, -31.80055046081543, -29.511661529541016, -32.32572937011719, -30.939125061035156, -28.306428909301758, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.993654251098633, 0.0, -19.722885131835938, -20.165428161621094, -20.82481575012207, -19.743242263793945, -18.4455509185791, -17.938037872314453, -16.44158935546875, -15.122944831848145, -14.356903076171875, -12.85706615447998, -11.831649780273438, -10.453605651855469, -8.738042831420898, -6.615896701812744, -5.4514851570129395, -0.994382917881012, 0.0, -1.651167869567871, 0.0, 0.0, -1.9457721710205078, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.21233558654785, -20.16263198852539, -16.002134323120117, -15.305403709411621, 0.0, -14.508560180664062, 0.0, 0.0, -10.486135482788086, -13.272603988647461, -14.902587890625, -13.893182754516602, -17.608806610107422, -17.976381301879883, -18.60282325744629, -19.596540451049805, -21.079639434814453, -22.718687057495117, -25.5664119720459, -27.5790958404541, -27.683046340942383, -28.47366714477539, 0.0, -32.99625778198242, -34.805816650390625, -35.29485321044922, -32.72464370727539, -35.206703186035156, -31.815153121948242, 0.0, -29.049182891845703, 0.0, 0.0, 0.0, 0.0, 0.0, -29.47865867614746, -31.80055046081543, -29.511661529541016, -32.32572937011719, -30.939125061035156, -28.306428909301758, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.993654251098633, 0.0, -19.722885131835938, -20.165428161621094, -20.82481575012207, -19.743242263793945, -18.4455509185791, -17.938037872314453, -16.44158935546875, -15.122944831848145, -14.356903076171875, -12.85706615447998, -11.831649780273438, -10.453605651855469, -8.738042831420898, -6.615896701812744, -5.4514851570129395, -0.994382917881012, 0.0, -1.651167869567871, 0.0, 0.0, -1.9457721710205078, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.965641021728516, -14.990466117858887, 0.0, 0.0, -14.735671997070312, -13.96543025970459, -9.827815055847168, -9.27583122253418, -12.594202041625977, -13.893196105957031, -15.801759719848633, -17.719066619873047, -18.04542350769043, -20.34878158569336, -21.667314529418945, -22.56199836730957, -24.452186584472656, -27.027385711669922, -29.004446029663086, -30.355167388916016, 0.0, 0.0, -34.87063980102539, -35.927574157714844, -33.13161087036133, 0.0, -28.9654541015625, -28.125234603881836, -31.224117279052734, -31.859237670898438, 0.0, 0.0, 0.0, -32.84247589111328, -28.184146881103516, -29.89691162109375, 0.0, -33.312896728515625, 0.0, -25.442323684692383, 0.0, 0.0, 0.0, 0.0, 0.0, -20.766746520996094, -23.037052154541016, -25.30167579650879, -20.836009979248047, -21.56534194946289, -20.787338256835938, -19.90956687927246, -19.605180740356445, -18.252613067626953, -16.822887420654297, -16.191333770751953, -14.98734188079834, -13.640534400939941, -11.760534286499023, -10.050450325012207, -8.828012466430664, -7.453139781951904, -5.623966217041016, -2.0741000175476074, -1.4235503673553467, -1.1742132902145386, 0.0, -3.3946728706359863, -2.495086669921875, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.965641021728516, -14.990466117858887, 0.0, 0.0, -14.735671997070312, -13.96543025970459, -9.827815055847168, -9.27583122253418, -12.594202041625977, -13.893196105957031, -15.801759719848633, -17.719066619873047, -18.04542350769043, -20.34878158569336, -21.667314529418945, -22.56199836730957, -24.452186584472656, -27.027385711669922, -29.004446029663086, -30.355167388916016, 0.0, 0.0, -34.87063980102539, -35.927574157714844, -33.13161087036133, 0.0, -28.9654541015625, -28.125234603881836, -31.224117279052734, -31.859237670898438, 0.0, 0.0, 0.0, -32.84247589111328, -28.184146881103516, -29.89691162109375, 0.0, -33.312896728515625, 0.0, -25.442323684692383, 0.0, 0.0, 0.0, 0.0, 0.0, -20.766746520996094, -23.037052154541016, -25.30167579650879, -20.836009979248047, -21.56534194946289, -20.787338256835938, -19.90956687927246, -19.605180740356445, -18.252613067626953, -16.822887420654297, -16.191333770751953, -14.98734188079834, -13.640534400939941, -11.760534286499023, -10.050450325012207, -8.828012466430664, -7.453139781951904, -5.623966217041016, -2.0741000175476074, -1.4235503673553467, -1.1742132902145386, 0.0, -3.3946728706359863, -2.495086669921875, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.604596138000488, -16.734113693237305, 0.0, -17.665599822998047, -14.759275436401367, 0.0, 0.0, 0.0, -10.715678215026855, -12.442525863647461, -14.910562515258789, -16.26108741760254, -18.258541107177734, -20.41957664489746, -21.467052459716797, -23.02462387084961, -25.335681915283203, -27.40789222717285, -28.449533462524414, -30.453603744506836, -30.413169860839844, -27.603382110595703, 0.0, -32.78498077392578, -32.0609130859375, -34.33816909790039, 0.0, 0.0, 0.0, -32.663814544677734, -35.95984649658203, 0.0, 0.0, -31.446388244628906, -31.690486907958984, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.150949478149414, -23.099159240722656, -23.242536544799805, -20.907888412475586, -21.242530822753906, -20.965198516845703, -20.55167579650879, -19.41524314880371, -18.477672576904297, -17.08422088623047, -15.763442993164062, -15.077011108398438, -13.295849800109863, -11.422419548034668, -9.873764991760254, -8.220736503601074, -6.489818096160889, -4.718323230743408, -4.481984615325928, -2.828721523284912, -2.3008575439453125, 0.0, 0.0, -5.388415336608887, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.604596138000488, -16.734113693237305, 0.0, -17.665599822998047, -14.759275436401367, 0.0, 0.0, 0.0, -10.715678215026855, -12.442525863647461, -14.910562515258789, -16.26108741760254, -18.258541107177734, -20.41957664489746, -21.467052459716797, -23.02462387084961, -25.335681915283203, -27.40789222717285, -28.449533462524414, -30.453603744506836, -30.413169860839844, -27.603382110595703, 0.0, -32.78498077392578, -32.0609130859375, -34.33816909790039, 0.0, 0.0, 0.0, -32.663814544677734, -35.95984649658203, 0.0, 0.0, -31.446388244628906, -31.690486907958984, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.150949478149414, -23.099159240722656, -23.242536544799805, -20.907888412475586, -21.242530822753906, -20.965198516845703, -20.55167579650879, -19.41524314880371, -18.477672576904297, -17.08422088623047, -15.763442993164062, -15.077011108398438, -13.295849800109863, -11.422419548034668, -9.873764991760254, -8.220736503601074, -6.489818096160889, -4.718323230743408, -4.481984615325928, -2.828721523284912, -2.3008575439453125, 0.0, 0.0, -5.388415336608887, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.280973434448242, -13.563105583190918, 0.0, -15.234066009521484, -14.92629337310791, 0.0, -9.29564094543457, -8.576098442077637, -11.309992790222168, -13.033336639404297, -15.328346252441406, -17.46881675720215, -19.484375, -21.944780349731445, -23.500782012939453, -24.839534759521484, -27.052461624145508, -28.585981369018555, -29.37734603881836, -31.226356506347656, -32.092864990234375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -33.450138092041016, 0.0, -29.063007354736328, -30.295547485351562, 0.0, -23.295114517211914, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.526945114135742, -21.789920806884766, -21.755802154541016, -21.494808197021484, -20.89106559753418, -19.97437858581543, -19.412887573242188, -17.96725082397461, -16.962528228759766, -16.046279907226562, -14.029932975769043, -12.7461576461792, -11.374375343322754, -10.161308288574219, -8.281023025512695, -6.363582611083984, -5.113450050354004, -4.552170276641846, -4.6399383544921875, -5.319599151611328, -2.7264206409454346, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.280973434448242, -13.563105583190918, 0.0, -15.234066009521484, -14.92629337310791, 0.0, -9.29564094543457, -8.576098442077637, -11.309992790222168, -13.033336639404297, -15.328346252441406, -17.46881675720215, -19.484375, -21.944780349731445, -23.500782012939453, -24.839534759521484, -27.052461624145508, -28.585981369018555, -29.37734603881836, -31.226356506347656, -32.092864990234375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -33.450138092041016, 0.0, -29.063007354736328, -30.295547485351562, 0.0, -23.295114517211914, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.526945114135742, -21.789920806884766, -21.755802154541016, -21.494808197021484, -20.89106559753418, -19.97437858581543, -19.412887573242188, -17.96725082397461, -16.962528228759766, -16.046279907226562, -14.029932975769043, -12.7461576461792, -11.374375343322754, -10.161308288574219, -8.281023025512695, -6.363582611083984, -5.113450050354004, -4.552170276641846, -4.6399383544921875, -5.319599151611328, -2.7264206409454346, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.497608184814453, 0.0, -15.608692169189453, -15.737442016601562, 0.0, 0.0, -10.919572830200195, -8.056525230407715, -10.026253700256348, -12.700368881225586, -16.219039916992188, -18.567493438720703, -21.127405166625977, -22.807300567626953, -25.305389404296875, -26.811460494995117, -28.92547607421875, -30.41964340209961, -32.225711822509766, -33.596275329589844, -32.412750244140625, -31.827028274536133, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.61677360534668, 0.0, 0.0, -30.512361526489258, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.738191604614258, -20.5131893157959, -22.076526641845703, -21.604106903076172, -20.88074493408203, -19.773120880126953, -19.217967987060547, -17.817289352416992, -16.62037467956543, -15.31664752960205, -13.728212356567383, -12.315085411071777, -10.272138595581055, -8.971077919006348, -7.447502613067627, -6.59161901473999, -5.607529163360596, -5.78439998626709, -8.579188346862793, -4.925991058349609, -4.76192569732666, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.497608184814453, 0.0, -15.608692169189453, -15.737442016601562, 0.0, 0.0, -10.919572830200195, -8.056525230407715, -10.026253700256348, -12.700368881225586, -16.219039916992188, -18.567493438720703, -21.127405166625977, -22.807300567626953, -25.305389404296875, -26.811460494995117, -28.92547607421875, -30.41964340209961, -32.225711822509766, -33.596275329589844, -32.412750244140625, -31.827028274536133, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.61677360534668, 0.0, 0.0, -30.512361526489258, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.738191604614258, -20.5131893157959, -22.076526641845703, -21.604106903076172, -20.88074493408203, -19.773120880126953, -19.217967987060547, -17.817289352416992, -16.62037467956543, -15.31664752960205, -13.728212356567383, -12.315085411071777, -10.272138595581055, -8.971077919006348, -7.447502613067627, -6.59161901473999, -5.607529163360596, -5.78439998626709, -8.579188346862793, -4.925991058349609, -4.76192569732666, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.680965423583984, -16.683090209960938, -17.840843200683594, -13.971700668334961, -15.689717292785645, -13.211795806884766, -13.53056526184082, -13.51699447631836, -11.848602294921875, -15.449252128601074, -18.030195236206055, -19.85577964782715, -22.04738426208496, -24.591978073120117, -26.18461036682129, -28.410823822021484, -29.817434310913086, -31.285696029663086, -33.05381774902344, -31.76494026184082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.547748565673828, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.815793991088867, -21.6671199798584, -21.06511116027832, -20.624534606933594, -19.760955810546875, -19.301578521728516, -17.83465003967285, -17.044763565063477, -15.120221138000488, -13.967533111572266, -12.829376220703125, -10.688389778137207, -9.242280006408691, -7.887556552886963, -7.091202259063721, -6.243161678314209, -6.419064998626709, -10.007868766784668, 0.0, -7.157095909118652, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.680965423583984, -16.683090209960938, -17.840843200683594, -13.971700668334961, -15.689717292785645, -13.211795806884766, -13.53056526184082, -13.51699447631836, -11.848602294921875, -15.449252128601074, -18.030195236206055, -19.85577964782715, -22.04738426208496, -24.591978073120117, -26.18461036682129, -28.410823822021484, -29.817434310913086, -31.285696029663086, -33.05381774902344, -31.76494026184082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.547748565673828, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.815793991088867, -21.6671199798584, -21.06511116027832, -20.624534606933594, -19.760955810546875, -19.301578521728516, -17.83465003967285, -17.044763565063477, -15.120221138000488, -13.967533111572266, -12.829376220703125, -10.688389778137207, -9.242280006408691, -7.887556552886963, -7.091202259063721, -6.243161678314209, -6.419064998626709, -10.007868766784668, 0.0, -7.157095909118652, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.072053909301758, -14.528739929199219, 0.0, 0.0, -15.72965145111084, -11.424029350280762, -13.924980163574219, -13.498512268066406, -15.442458152770996, -17.949697494506836, -20.84678077697754, -23.66350555419922, -25.44955825805664, -27.89152717590332, -29.048521041870117, -31.056310653686523, -33.02455520629883, -32.53455352783203, -31.127593994140625, 0.0, 0.0, 0.0, 0.0, 0.0, -30.592741012573242, -28.256620407104492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.467226028442383, -27.67805290222168, 0.0, 0.0, 0.0, 0.0, -22.701702117919922, -20.227813720703125, -19.88519859313965, -19.23762321472168, -18.65076446533203, -16.601459503173828, -15.332590103149414, -14.726365089416504, -12.828195571899414, -11.94450569152832, -10.268762588500977, -8.611076354980469, -8.597759246826172, -7.413997650146484, -7.5092854499816895, -5.960134029388428, -7.398899555206299, -11.045610427856445, 0.0, -6.772065162658691, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.072053909301758, -14.528739929199219, 0.0, 0.0, -15.72965145111084, -11.424029350280762, -13.924980163574219, -13.498512268066406, -15.442458152770996, -17.949697494506836, -20.84678077697754, -23.66350555419922, -25.44955825805664, -27.89152717590332, -29.048521041870117, -31.056310653686523, -33.02455520629883, -32.53455352783203, -31.127593994140625, 0.0, 0.0, 0.0, 0.0, 0.0, -30.592741012573242, -28.256620407104492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.467226028442383, -27.67805290222168, 0.0, 0.0, 0.0, 0.0, -22.701702117919922, -20.227813720703125, -19.88519859313965, -19.23762321472168, -18.65076446533203, -16.601459503173828, -15.332590103149414, -14.726365089416504, -12.828195571899414, -11.94450569152832, -10.268762588500977, -8.611076354980469, -8.597759246826172, -7.413997650146484, -7.5092854499816895, -5.960134029388428, -7.398899555206299, -11.045610427856445, 0.0, -6.772065162658691, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.598444938659668, 0.0, -13.422513008117676, -12.847822189331055, -14.136606216430664, -12.89444351196289, -13.276463508605957, -13.809892654418945, -18.248186111450195, -18.47989845275879, -22.42049217224121, -23.46870231628418, -26.78729820251465, -28.732200622558594, -30.03301429748535, -30.415979385375977, -30.626949310302734, -31.27220344543457, -33.386417388916016, 0.0, 0.0, 0.0, 0.0, -29.476505279541016, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.680702209472656, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.073505401611328, -18.511287689208984, -17.742523193359375, -15.371012687683105, -16.040008544921875, -12.773333549499512, -12.63627815246582, -11.649258613586426, -10.12175178527832, -8.465751647949219, -7.348471164703369, -7.673967361450195, -8.36800479888916, -8.270343780517578, -7.202925205230713, -10.11837100982666, -10.854777336120605, 0.0, -8.038429260253906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.598444938659668, 0.0, -13.422513008117676, -12.847822189331055, -14.136606216430664, -12.89444351196289, -13.276463508605957, -13.809892654418945, -18.248186111450195, -18.47989845275879, -22.42049217224121, -23.46870231628418, -26.78729820251465, -28.732200622558594, -30.03301429748535, -30.415979385375977, -30.626949310302734, -31.27220344543457, -33.386417388916016, 0.0, 0.0, 0.0, 0.0, -29.476505279541016, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.680702209472656, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.073505401611328, -18.511287689208984, -17.742523193359375, -15.371012687683105, -16.040008544921875, -12.773333549499512, -12.63627815246582, -11.649258613586426, -10.12175178527832, -8.465751647949219, -7.348471164703369, -7.673967361450195, -8.36800479888916, -8.270343780517578, -7.202925205230713, -10.11837100982666, -10.854777336120605, 0.0, -8.038429260253906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.101197242736816, 0.0, -10.11043930053711, -10.58353042602539, 0.0, -14.094658851623535, -16.233983993530273, -16.351879119873047, -19.38924217224121, -20.43170166015625, -20.81295394897461, -20.123388290405273, -23.767532348632812, -26.563140869140625, -28.06373405456543, -26.363685607910156, -30.39688491821289, -29.994651794433594, -32.71018600463867, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.69537925720215, -18.035152435302734, -14.088846206665039, -12.204913139343262, -15.071394920349121, -11.671163558959961, -8.663260459899902, -8.051379203796387, -7.391909599304199, -5.677183151245117, -7.023983001708984, -7.351027011871338, -9.521353721618652, -9.06946849822998, -8.998453140258789, -10.843310356140137, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.101197242736816, 0.0, -10.11043930053711, -10.58353042602539, 0.0, -14.094658851623535, -16.233983993530273, -16.351879119873047, -19.38924217224121, -20.43170166015625, -20.81295394897461, -20.123388290405273, -23.767532348632812, -26.563140869140625, -28.06373405456543, -26.363685607910156, -30.39688491821289, -29.994651794433594, -32.71018600463867, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.69537925720215, -18.035152435302734, -14.088846206665039, -12.204913139343262, -15.071394920349121, -11.671163558959961, -8.663260459899902, -8.051379203796387, -7.391909599304199, -5.677183151245117, -7.023983001708984, -7.351027011871338, -9.521353721618652, -9.06946849822998, -8.998453140258789, -10.843310356140137, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.205945014953613, 0.0, 0.0, -15.06186580657959, 0.0, -19.46072006225586, -21.497753143310547, -17.179405212402344, 0.0, 0.0, 0.0, 0.0, 0.0, -26.774520874023438, -30.37763214111328, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.063241958618164, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.59552764892578, -18.089399337768555, -12.85246753692627, -10.006977081298828, -14.564718246459961, -14.117673873901367, -13.13991928100586, -9.232625961303711, -9.813349723815918, -6.922438144683838, -7.292791843414307, -10.983173370361328, -11.127729415893555, -8.632213592529297, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.205945014953613, 0.0, 0.0, -15.06186580657959, 0.0, -19.46072006225586, -21.497753143310547, -17.179405212402344, 0.0, 0.0, 0.0, 0.0, 0.0, -26.774520874023438, -30.37763214111328, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.063241958618164, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.59552764892578, -18.089399337768555, -12.85246753692627, -10.006977081298828, -14.564718246459961, -14.117673873901367, -13.13991928100586, -9.232625961303711, -9.813349723815918, -6.922438144683838, -7.292791843414307, -10.983173370361328, -11.127729415893555, -8.632213592529297, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.373699188232422, 0.0, 0.0, 0.0, 0.0, -20.938852310180664, 0.0, 0.0, -12.428013801574707, 0.0, -16.563121795654297, 0.0, 0.0, -22.768911361694336, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.412221908569336, -27.91585350036621, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.860876083374023, -8.904999732971191, -11.56413745880127, -13.645454406738281, 0.0, -12.098305702209473, -9.268716812133789, 0.0, 0.0, 0.0, -13.709268569946289, -13.8999605178833, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.373699188232422, 0.0, 0.0, 0.0, 0.0, -20.938852310180664, 0.0, 0.0, -12.428013801574707, 0.0, -16.563121795654297, 0.0, 0.0, -22.768911361694336, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.412221908569336, -27.91585350036621, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.860876083374023, -8.904999732971191, -11.56413745880127, -13.645454406738281, 0.0, -12.098305702209473, -9.268716812133789, 0.0, 0.0, 0.0, -13.709268569946289, -13.8999605178833, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.509833335876465, 0.0, 0.0, 0.0, 0.0, 0.0, -11.24201774597168, 0.0, 0.0, 0.0, -13.571137428283691, 0.0, 0.0, -20.65463638305664, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.36595916748047, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.2889404296875, 0.0, 0.0, 0.0, 0.0, 0.0, -10.720049858093262, 0.0, 0.0, 0.0, -14.225383758544922, -12.807125091552734, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.509833335876465, 0.0, 0.0, 0.0, 0.0, 0.0, -11.24201774597168, 0.0, 0.0, 0.0, -13.571137428283691, 0.0, 0.0, -20.65463638305664, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.36595916748047, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.2889404296875, 0.0, 0.0, 0.0, 0.0, 0.0, -10.720049858093262, 0.0, 0.0, 0.0, -14.225383758544922, -12.807125091552734, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.363285064697266, 0.0, 0.0, 0.0, 0.0, 0.0, -10.275032997131348, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.99415397644043, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.285324096679688, -24.48419189453125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.798433303833008, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.363285064697266, 0.0, 0.0, 0.0, 0.0, 0.0, -10.275032997131348, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.99415397644043, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.285324096679688, -24.48419189453125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.798433303833008, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.422715187072754, 0.0, 0.0, 0.0, 0.0, -19.377716064453125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.419530868530273, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.422715187072754, 0.0, 0.0, 0.0, 0.0, -19.377716064453125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.419530868530273, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.943737030029297, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.943737030029297, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.18449592590332, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.18449592590332, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.1439266204834, -22.25124168395996, 0.0, 0.0, 0.0, -29.491058349609375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.1439266204834, -22.25124168395996, 0.0, 0.0, 0.0, -29.491058349609375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.682422637939453, -23.992700576782227, 0.0, 0.0, -25.01064109802246, -25.580537796020508, -26.763206481933594, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.682422637939453, -23.992700576782227, 0.0, 0.0, -25.01064109802246, -25.580537796020508, -26.763206481933594, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.978147506713867, 0.0, -22.517663955688477, -25.16257667541504, -23.08565902709961, -21.820676803588867, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.978147506713867, 0.0, -22.517663955688477, -25.16257667541504, -23.08565902709961, -21.820676803588867, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.25322151184082, -26.439260482788086, -22.64897346496582, -22.3233642578125, -24.134309768676758, -24.27831268310547, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.25322151184082, -26.439260482788086, -22.64897346496582, -22.3233642578125, -24.134309768676758, -24.27831268310547, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.875158309936523, -25.40766716003418, -24.905208587646484, -21.005800247192383, -20.44029426574707, -18.98810577392578, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.875158309936523, -25.40766716003418, -24.905208587646484, -21.005800247192383, -20.44029426574707, -18.98810577392578, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.00953483581543, -22.542572021484375, -23.03889274597168, -23.995960235595703, -22.851573944091797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.00953483581543, -22.542572021484375, -23.03889274597168, -23.995960235595703, -22.851573944091797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.470129013061523, -25.190753936767578, -26.59723663330078, -24.43080711364746, -24.452716827392578, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.470129013061523, -25.190753936767578, -26.59723663330078, -24.43080711364746, -24.452716827392578, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.64651107788086, -27.12965202331543, -28.661787033081055, -27.049583435058594, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.64651107788086, -27.12965202331543, -28.661787033081055, -27.049583435058594, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.114377975463867, -25.05306053161621, -26.34955596923828, -27.30466079711914, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.114377975463867, -25.05306053161621, -26.34955596923828, -27.30466079711914, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]]}, {\"colorbar\": {\"title\": {\"text\": \"B<sub>0</sub> (Hz)\"}}, \"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.3333333333333333, \"rgb(230,0,0)\"], [0.6666666666666666, \"rgb(255,210,0)\"], [1.0, \"rgb(255,255,255)\"]], \"name\": \"comparison heatmap\", \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.186505675315857, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.186505675315857, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.5032926797866821, -2.5763065814971924, -4.349231719970703, -6.338567733764648, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.5032926797866821, -2.5763065814971924, -4.349231719970703, -6.338567733764648, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.9471405744552612, -1.8285934925079346, 0.0, 6.943681716918945, 5.043417930603027, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.4587974548339844, 0.0, 6.985881328582764, 0.0, 1.8454101085662842, 0.0, -2.2791032791137695, 0.0, -4.499988555908203, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.9471405744552612, -1.8285934925079346, 0.0, 6.943681716918945, 5.043417930603027, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.4587974548339844, 0.0, 6.985881328582764, 0.0, 1.8454101085662842, -0.0, -2.2791032791137695, -0.0, -4.499988555908203, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.752416968345642, -1.3192558288574219, 0.0, 4.251728534698486, 2.5733606815338135, 5.866727828979492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.752416968345642, -1.3192558288574219, 0.0, 4.251728534698486, 2.5733606815338135, 5.866727828979492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.6274124383926392, -2.340719223022461, 0.0, 6.799569129943848, 5.439270973205566, 8.507064819335938, 5.668610572814941, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.383766174316406, 8.028093338012695, 9.881113052368164, 7.940657138824463, 6.848191738128662, 7.842790603637695, 3.4295895099639893, 4.651692867279053, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.6274124383926392, -2.340719223022461, 0.0, 6.799569129943848, 5.439270973205566, 8.507064819335938, 5.668610572814941, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.383766174316406, 8.028093338012695, 9.881113052368164, 7.940657138824463, 6.848191738128662, 7.842790603637695, 3.4295895099639893, 4.651692867279053, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.5809041261672974, 0.3486100137233734, 0.5881845355033875, 1.1852679252624512, 0.0, 7.878321170806885, 6.391805171966553, 6.265022277832031, 4.659230709075928, 3.191171884536743, 2.1035408973693848, 0.0, 0.0, 0.0, 0.0, 6.389889240264893, 4.166909694671631, 2.666306972503662, 1.0354642868041992, 2.7003519535064697, 3.2822768688201904, 2.458528757095337, 2.63631010055542, 4.132320880889893, 3.1621198654174805, 2.4699299335479736, 6.1427812576293945, 5.372417449951172, 6.413280963897705, 6.687460422515869, 6.201344966888428, 6.971407413482666, 7.537319660186768, 6.074188232421875, 7.520042419433594, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.5018730759620667, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.5809041261672974, 0.3486100137233734, 0.5881845355033875, 1.1852679252624512, 0.0, 7.878321170806885, 6.391805171966553, 6.265022277832031, 4.659230709075928, 3.191171884536743, 2.1035408973693848, 0.0, 0.0, 0.0, 0.0, 6.389889240264893, 4.166909694671631, 2.666306972503662, 1.0354642868041992, 2.7003519535064697, 3.2822768688201904, 2.458528757095337, 2.63631010055542, 4.132320880889893, 3.1621198654174805, 2.4699299335479736, 6.1427812576293945, 5.372417449951172, 6.413280963897705, 6.687460422515869, 6.201344966888428, 6.971407413482666, 7.537319660186768, 6.074188232421875, 7.520042419433594, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.5018730759620667, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.789966106414795, 4.203035831451416, 5.749379634857178, 5.105056285858154, 3.167285680770874, 5.2018866539001465, 6.548154354095459, 4.9681525230407715, 5.514098167419434, 4.319634437561035, 5.055574417114258, 2.877556324005127, 3.297595977783203, 1.7116135358810425, 1.7273049354553223, 2.3905439376831055, 1.3902548551559448, 1.5920400619506836, -0.2454531490802765, 2.34409236907959, 3.2447261810302734, 2.2238569259643555, 2.1982805728912354, 3.1477668285369873, 2.8110909461975098, 3.1621899604797363, 6.4604620933532715, 4.8865509033203125, 5.150174617767334, 4.639875888824463, 5.097816467285156, 5.419427394866943, 5.372796535491943, 6.0625176429748535, 0.0, 0.0, 2.1709985733032227, 3.884937286376953, 0.5700372457504272, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 3.789966106414795, 4.203035831451416, 5.749379634857178, 5.105056285858154, 3.167285680770874, 5.2018866539001465, 6.548154354095459, 4.9681525230407715, 5.514098167419434, 4.319634437561035, 5.055574417114258, 2.877556324005127, 3.297595977783203, 1.7116135358810425, 1.7273049354553223, 2.3905439376831055, 1.3902548551559448, 1.5920400619506836, -0.2454531490802765, 2.34409236907959, 3.2447261810302734, 2.2238569259643555, 2.1982805728912354, 3.1477668285369873, 2.8110909461975098, 3.1621899604797363, 6.4604620933532715, 4.8865509033203125, 5.150174617767334, 4.639875888824463, 5.097816467285156, 5.419427394866943, 5.372796535491943, 6.0625176429748535, 0.0, 0.0, 2.1709985733032227, 3.884937286376953, 0.5700372457504272, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.6808860301971436, 5.391678333282471, 6.927667617797852, 6.7032670974731445, 2.6195104122161865, 7.477264881134033, 5.0606584548950195, 6.810686111450195, 4.00112771987915, 4.917933940887451, 5.964178085327148, 4.901930809020996, 1.1441280841827393, 3.023163080215454, 2.0384881496429443, 0.19259005784988403, 0.9186851382255554, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.540077209472656, 5.836215019226074, 2.4406278133392334, 4.0754313468933105, 2.511597156524658, 4.072282791137695, 4.4683122634887695, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 1.6808860301971436, 5.391678333282471, 6.927667617797852, 6.7032670974731445, 2.6195104122161865, 7.477264881134033, 5.0606584548950195, 6.810686111450195, 4.00112771987915, 4.917933940887451, 5.964178085327148, 4.901930809020996, 1.1441280841827393, 3.023163080215454, 2.0384881496429443, 0.19259005784988403, 0.9186851382255554, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.540077209472656, 5.836215019226074, 2.4406278133392334, 4.0754313468933105, 2.511597156524658, 4.072282791137695, 4.4683122634887695, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.7301175594329834, 5.7039794921875, 5.886866569519043, 5.1213178634643555, 2.597228527069092, 4.817926406860352, 4.025817394256592, 1.714875340461731, 3.0650107860565186, 2.4655604362487793, 0.0, 3.024427890777588, 0.01248754933476448, 0.0, 0.0, 2.7042160034179688, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.9784586429595947, 0.09844760596752167, 3.4113807678222656, 4.359027862548828, 4.487122535705566, 0.0, 0.0, 1.370481252670288, 0.15422654151916504, 1.1984713077545166, 3.9556167125701904, 3.8216001987457275, 4.805600643157959, 0.42462068796157837, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.7301175594329834, 5.7039794921875, 5.886866569519043, 5.1213178634643555, 2.597228527069092, 4.817926406860352, 4.025817394256592, 1.714875340461731, 3.0650107860565186, 2.4655604362487793, 0.0, 3.024427890777588, 0.01248754933476448, 0.0, 0.0, 2.7042160034179688, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -1.9784586429595947, 0.09844760596752167, 3.4113807678222656, 4.359027862548828, 4.487122535705566, 0.0, 0.0, 1.370481252670288, 0.15422654151916504, 1.1984713077545166, 3.9556167125701904, 3.8216001987457275, 4.805600643157959, 0.42462068796157837, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.043808937072754, 4.2074713706970215, 3.538562059402466, 3.1509132385253906, 6.1056132316589355, 7.266987323760986, 6.29949426651001, 6.986950874328613, 5.107562065124512, 6.024742603302002, 5.250579833984375, 6.36238431930542, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.47682636976242065, 1.7040126323699951, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.8475944995880127, 6.618042469024658, 1.5442414283752441, 1.9075723886489868, 4.254687309265137, 4.212575912475586, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.043808937072754, 4.2074713706970215, 3.538562059402466, 3.1509132385253906, 6.1056132316589355, 7.266987323760986, 6.29949426651001, 6.986950874328613, 5.107562065124512, 6.024742603302002, 5.250579833984375, 6.36238431930542, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.47682636976242065, 1.7040126323699951, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.8475944995880127, 6.618042469024658, 1.5442414283752441, 1.9075723886489868, 4.254687309265137, 4.212575912475586, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.2736685276031494, 5.5723700523376465, 3.1069459915161133, 2.5638222694396973, 2.4050376415252686, 2.1652915477752686, 0.0, 0.0, 5.3944902420043945, 4.202508449554443, 3.5553932189941406, 3.774864673614502, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.543878436088562, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.9588968753814697, 5.042593955993652, 4.430384635925293, 1.7088910341262817, 2.8770322799682617, 2.57700252532959, -0.00830974243581295, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 2.2736685276031494, 5.5723700523376465, 3.1069459915161133, 2.5638222694396973, 2.4050376415252686, 2.1652915477752686, 0.0, 0.0, 5.3944902420043945, 4.202508449554443, 3.5553932189941406, 3.774864673614502, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, -1.543878436088562, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 3.9588968753814697, 5.042593955993652, 4.430384635925293, 1.7088910341262817, 2.8770322799682617, 2.57700252532959, -0.00830974243581295, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5234381556510925, 3.6212334632873535, 3.014435052871704, 2.5011463165283203, 3.012637138366699, 1.1877983808517456, -0.9243454933166504, -2.175529718399048, -3.607938766479492, -3.42293119430542, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.15629243850708, -3.207636594772339, 0.0, 0.0, 0.0, -0.04173273593187332, -0.8419401049613953, 0.0, 0.0, -0.7583578824996948, -0.1450454145669937, 0.3509072959423065, -4.304912090301514, -3.46592116355896, 0.0, 2.4765663146972656, -2.676407814025879, 0.0, 0.0, 0.0, 0.0, 2.2003366947174072, 2.274893283843994, 0.0, 0.0, 4.557300567626953, 2.9431583881378174, 0.9383355975151062, 3.6619677543640137, 6.249272346496582, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.5234381556510925, 3.6212334632873535, 3.014435052871704, 2.5011463165283203, 3.012637138366699, 1.1877983808517456, -0.9243454933166504, -2.175529718399048, -3.607938766479492, -3.42293119430542, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -2.15629243850708, -3.207636594772339, -0.0, -0.0, -0.0, -0.04173273593187332, -0.8419401049613953, -0.0, -0.0, -0.7583578824996948, -0.1450454145669937, 0.3509072959423065, -4.304912090301514, -3.46592116355896, 0.0, 2.4765663146972656, -2.676407814025879, -0.0, 0.0, 0.0, 0.0, 2.2003366947174072, 2.274893283843994, 0.0, 0.0, 4.557300567626953, 2.9431583881378174, 0.9383355975151062, 3.6619677543640137, 6.249272346496582, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.7889164090156555, 1.4229761362075806, 2.4492149353027344, 2.4237730503082275, 0.5876403450965881, 0.0, 2.9353268146514893, -1.5838406085968018, 1.330585241317749, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.3323568105697632, -2.1726996898651123, -2.403822898864746, -1.6788086891174316, -1.5335668325424194, -3.1806640625, -2.3442447185516357, -2.7275400161743164, -1.7015719413757324, -2.0246124267578125, -1.7421743869781494, -2.0496654510498047, -2.5827276706695557, -2.49674916267395, -1.4453015327453613, -1.2829498052597046, -0.941395103931427, -1.0975371599197388, -0.057670265436172485, -2.9250006675720215, 0.04254721850156784, 0.0, 0.0, 0.0, 0.0, 0.0, 2.8908960819244385, 1.7729063034057617, 2.9665231704711914, 2.936662435531616, 3.229536294937134, 4.72446346282959, 5.34417200088501, 5.183478832244873, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.7889164090156555, 1.4229761362075806, 2.4492149353027344, 2.4237730503082275, 0.5876403450965881, 0.0, 2.9353268146514893, -1.5838406085968018, 1.330585241317749, 0.0, -0.0, -0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.3323568105697632, -2.1726996898651123, -2.403822898864746, -1.6788086891174316, -1.5335668325424194, -3.1806640625, -2.3442447185516357, -2.7275400161743164, -1.7015719413757324, -2.0246124267578125, -1.7421743869781494, -2.0496654510498047, -2.5827276706695557, -2.49674916267395, -1.4453015327453613, -1.2829498052597046, -0.941395103931427, -1.0975371599197388, -0.057670265436172485, -2.9250006675720215, 0.04254721850156784, 0.0, -0.0, -0.0, 0.0, 0.0, 2.8908960819244385, 1.7729063034057617, 2.9665231704711914, 2.936662435531616, 3.229536294937134, 4.72446346282959, 5.34417200088501, 5.183478832244873, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.1538281440734863, 1.5402109622955322, 0.6263494491577148, -0.45603641867637634, 0.0, 4.141025066375732, 2.902641534805298, 0.6805849075317383, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.7365992069244385, -0.6232227683067322, 1.3056167364120483, -2.5841755867004395, -3.093475818634033, -2.2027950286865234, -4.229057312011719, -3.837993621826172, -5.20969295501709, -4.885866641998291, 0.0, -1.7712764739990234, -1.3558181524276733, -2.2899081707000732, -1.6400470733642578, -2.264145612716675, -2.1787362098693848, -1.2326160669326782, -1.5008575916290283, -1.2988474369049072, -0.8090239763259888, -1.4517674446105957, -0.9439239501953125, -0.6180257797241211, -1.3122698068618774, -0.8809151649475098, -1.9043561220169067, -0.874016523361206, -3.275226593017578, 0.0, 0.0, 0.0, 1.5425753593444824, 0.0, 1.4475350379943848, 0.0, 1.7161929607391357, 3.6169943809509277, 5.256185531616211, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.1538281440734863, 1.5402109622955322, 0.6263494491577148, -0.45603641867637634, 0.0, 4.141025066375732, 2.902641534805298, 0.6805849075317383, -0.0, 0.0, 0.0, -0.0, 0.0, -0.0, -0.0, -0.7365992069244385, -0.6232227683067322, 1.3056167364120483, -2.5841755867004395, -3.093475818634033, -2.2027950286865234, -4.229057312011719, -3.837993621826172, -5.20969295501709, -4.885866641998291, -0.0, -1.7712764739990234, -1.3558181524276733, -2.2899081707000732, -1.6400470733642578, -2.264145612716675, -2.1787362098693848, -1.2326160669326782, -1.5008575916290283, -1.2988474369049072, -0.8090239763259888, -1.4517674446105957, -0.9439239501953125, -0.6180257797241211, -1.3122698068618774, -0.8809151649475098, -1.9043561220169067, -0.874016523361206, -3.275226593017578, -0.0, 0.0, 0.0, 1.5425753593444824, 0.0, 1.4475350379943848, 0.0, 1.7161929607391357, 3.6169943809509277, 5.256185531616211, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.4343141317367554, 1.1730914115905762, 0.789745032787323, -1.5057047605514526, -2.3661813735961914, -3.830148696899414, 1.4158740043640137, 0.0, 0.0, 0.0, -6.771113872528076, 0.0, -2.5064852237701416, 0.8121249079704285, -2.4281110763549805, -0.9788857102394104, -2.1182804107666016, -3.155428409576416, -2.540926694869995, -1.8628270626068115, -3.562962293624878, -0.290705144405365, -3.1728017330169678, -3.1891024112701416, -3.5114357471466064, -5.80565881729126, -2.277780055999756, -1.7519525289535522, -1.1843616962432861, -1.3240891695022583, -1.7614774703979492, -1.3803476095199585, -1.1072319746017456, -1.058347463607788, -1.0721248388290405, -1.4939931631088257, -1.532311201095581, -0.41502249240875244, -1.2443164587020874, -0.6267445087432861, -0.8415822386741638, -1.2954447269439697, -1.3545132875442505, -1.4890013933181763, -1.323354959487915, 0.8195697069168091, 3.344029426574707, 0.0, 0.0, 0.0, 0.0, 4.096247673034668, 0.0, 2.853161096572876, 5.652196884155273, 5.723629474639893, 7.542617321014404, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 1.4343141317367554, 1.1730914115905762, 0.789745032787323, -1.5057047605514526, -2.3661813735961914, -3.830148696899414, 1.4158740043640137, 0.0, 0.0, -0.0, -6.771113872528076, -0.0, -2.5064852237701416, 0.8121249079704285, -2.4281110763549805, -0.9788857102394104, -2.1182804107666016, -3.155428409576416, -2.540926694869995, -1.8628270626068115, -3.562962293624878, -0.290705144405365, -3.1728017330169678, -3.1891024112701416, -3.5114357471466064, -5.80565881729126, -2.277780055999756, -1.7519525289535522, -1.1843616962432861, -1.3240891695022583, -1.7614774703979492, -1.3803476095199585, -1.1072319746017456, -1.058347463607788, -1.0721248388290405, -1.4939931631088257, -1.532311201095581, -0.41502249240875244, -1.2443164587020874, -0.6267445087432861, -0.8415822386741638, -1.2954447269439697, -1.3545132875442505, -1.4890013933181763, -1.323354959487915, 0.8195697069168091, 3.344029426574707, 0.0, 0.0, 0.0, 0.0, 4.096247673034668, 0.0, 2.853161096572876, 5.652196884155273, 5.723629474639893, 7.542617321014404, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.492971420288086, -0.3914841115474701, 1.6313717365264893, 0.41990697383880615, -1.8804885149002075, 0.0, -0.35320988297462463, 0.0, 0.0, 0.0, 0.0, 0.0, -5.128454208374023, -2.649858236312866, -4.7659807205200195, -1.8932584524154663, -2.99145770072937, -2.863734245300293, -3.019843816757202, -2.7332990169525146, -2.445199489593506, -2.173947811126709, -2.3799712657928467, -1.4246759414672852, -5.871410846710205, -1.8985369205474854, -3.9188098907470703, -1.3055682182312012, -1.0312201976776123, -1.2453622817993164, -1.6799936294555664, -1.9133049249649048, -1.4476666450500488, -2.059447765350342, -1.822806477546692, -0.7986703515052795, -0.6652000546455383, -1.1127073764801025, -0.6519263982772827, -0.9493597149848938, -0.9327770471572876, -0.7742776274681091, -0.600679337978363, -1.319872498512268, -0.777032732963562, -1.2929904460906982, -1.1225407123565674, -0.8642637133598328, -1.3057823181152344, 2.6478562355041504, 0.0, 0.0, 0.0, 0.0, 5.958338737487793, 1.956032633781433, 4.152500152587891, 4.498101711273193, 4.805032253265381, 2.2364320755004883, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 2.492971420288086, -0.3914841115474701, 1.6313717365264893, 0.41990697383880615, -1.8804885149002075, -0.0, -0.35320988297462463, -0.0, 0.0, 0.0, 0.0, -0.0, -5.128454208374023, -2.649858236312866, -4.7659807205200195, -1.8932584524154663, -2.99145770072937, -2.863734245300293, -3.019843816757202, -2.7332990169525146, -2.445199489593506, -2.173947811126709, -2.3799712657928467, -1.4246759414672852, -5.871410846710205, -1.8985369205474854, -3.9188098907470703, -1.3055682182312012, -1.0312201976776123, -1.2453622817993164, -1.6799936294555664, -1.9133049249649048, -1.4476666450500488, -2.059447765350342, -1.822806477546692, -0.7986703515052795, -0.6652000546455383, -1.1127073764801025, -0.6519263982772827, -0.9493597149848938, -0.9327770471572876, -0.7742776274681091, -0.600679337978363, -1.319872498512268, -0.777032732963562, -1.2929904460906982, -1.1225407123565674, -0.8642637133598328, -1.3057823181152344, 2.6478562355041504, 0.0, 0.0, 0.0, 0.0, 5.958338737487793, 1.956032633781433, 4.152500152587891, 4.498101711273193, 4.805032253265381, 2.2364320755004883, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.03614462539553642, 0.9270843863487244, 4.132969856262207, -0.32990744709968567, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.890686511993408, -3.400153398513794, -3.536015272140503, -2.8230443000793457, -3.0334584712982178, -2.727463960647583, -2.1258225440979004, -2.810319662094116, -2.2473526000976562, -1.9689098596572876, -1.9898655414581299, -1.8902076482772827, -1.1113301515579224, 0.01770472340285778, -1.458127498626709, -1.6967430114746094, -2.4047834873199463, -1.1695702075958252, -0.7129619717597961, -0.8305953741073608, -1.2744724750518799, -0.3826991617679596, -0.6169376969337463, -1.3584688901901245, -0.5481099486351013, -1.2671983242034912, -1.5913108587265015, -0.8379204273223877, -1.8821814060211182, -0.7367178201675415, -0.5386881232261658, -0.9096426963806152, -0.9548219442367554, -0.42807185649871826, -0.08154921233654022, -0.8050687909126282, -1.293066143989563, 0.5339416265487671, 0.9327716827392578, 0.0, 0.0, 0.0, 0.0, 5.281719207763672, 7.03428316116333, 3.475632429122925, 4.616518020629883, 5.173827171325684, 6.198547840118408, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.03614462539553642, 0.9270843863487244, 4.132969856262207, -0.32990744709968567, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -3.890686511993408, -3.400153398513794, -3.536015272140503, -2.8230443000793457, -3.0334584712982178, -2.727463960647583, -2.1258225440979004, -2.810319662094116, -2.2473526000976562, -1.9689098596572876, -1.9898655414581299, -1.8902076482772827, -1.1113301515579224, 0.01770472340285778, -1.458127498626709, -1.6967430114746094, -2.4047834873199463, -1.1695702075958252, -0.7129619717597961, -0.8305953741073608, -1.2744724750518799, -0.3826991617679596, -0.6169376969337463, -1.3584688901901245, -0.5481099486351013, -1.2671983242034912, -1.5913108587265015, -0.8379204273223877, -1.8821814060211182, -0.7367178201675415, -0.5386881232261658, -0.9096426963806152, -0.9548219442367554, -0.42807185649871826, -0.08154921233654022, -0.8050687909126282, -1.293066143989563, 0.5339416265487671, 0.9327716827392578, 0.0, -0.0, 0.0, 0.0, 5.281719207763672, 7.03428316116333, 3.475632429122925, 4.616518020629883, 5.173827171325684, 6.198547840118408, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.06215335428714752, 0.18608753383159637, -0.3131234347820282, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -4.55311393737793, -0.8877962231636047, -4.698091983795166, -3.799186944961548, -3.968114137649536, -3.2986209392547607, -2.5241684913635254, -3.4989545345306396, -2.977674722671509, -2.040536403656006, -2.3696064949035645, -2.1923234462738037, -1.9061046838760376, -1.7598365545272827, -1.9653700590133667, -1.7846088409423828, -1.7525347471237183, -0.514807939529419, -1.1219838857650757, -1.3869487047195435, -1.681559443473816, -0.9016976952552795, -1.2649314403533936, -1.158709168434143, -0.7034210562705994, -1.4829931259155273, 0.6720095872879028, -0.38246646523475647, -0.6610345244407654, -0.4695325195789337, -0.623098611831665, -0.7719956636428833, -0.2528946101665497, -0.6631460785865784, -0.4431665539741516, -0.2977930009365082, -0.2988796532154083, -0.5712172985076904, -0.5651152729988098, -0.6684749126434326, -0.8438856601715088, 0.019057607278227806, -0.21158550679683685, -2.5028510093688965, -1.5778417587280273, 0.0, 0.0, 0.0, 5.366196632385254, 1.2777371406555176, 2.3719379901885986, 2.598973035812378, 5.409738063812256, 6.701544761657715, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.06215335428714752, 0.18608753383159637, -0.3131234347820282, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -4.55311393737793, -0.8877962231636047, -4.698091983795166, -3.799186944961548, -3.968114137649536, -3.2986209392547607, -2.5241684913635254, -3.4989545345306396, -2.977674722671509, -2.040536403656006, -2.3696064949035645, -2.1923234462738037, -1.9061046838760376, -1.7598365545272827, -1.9653700590133667, -1.7846088409423828, -1.7525347471237183, -0.514807939529419, -1.1219838857650757, -1.3869487047195435, -1.681559443473816, -0.9016976952552795, -1.2649314403533936, -1.158709168434143, -0.7034210562705994, -1.4829931259155273, 0.6720095872879028, -0.38246646523475647, -0.6610345244407654, -0.4695325195789337, -0.623098611831665, -0.7719956636428833, -0.2528946101665497, -0.6631460785865784, -0.4431665539741516, -0.2977930009365082, -0.2988796532154083, -0.5712172985076904, -0.5651152729988098, -0.6684749126434326, -0.8438856601715088, 0.019057607278227806, -0.21158550679683685, -2.5028510093688965, -1.5778417587280273, -0.0, 0.0, 0.0, 5.366196632385254, 1.2777371406555176, 2.3719379901885986, 2.598973035812378, 5.409738063812256, 6.701544761657715, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.6284911632537842, 0.21479211747646332, -0.6480427980422974, -0.8612010478973389, 0.0, -0.5268964767456055, 0.0, 0.0, 0.0, 0.0, 0.0, -3.429871082305908, -4.955667018890381, -4.566162109375, -4.285249710083008, -3.9562504291534424, -2.9065191745758057, -2.9325368404388428, -2.7306506633758545, -2.4053103923797607, -2.923893928527832, -2.412834882736206, -2.00614595413208, -2.3850722312927246, -1.180712103843689, -1.5248565673828125, -1.7773889303207397, -1.2508248090744019, -1.1539934873580933, -1.1724833250045776, -0.8275558352470398, -1.014399766921997, -1.1140894889831543, -1.1882708072662354, -0.2710351347923279, -0.866298496723175, -0.5092074871063232, -0.9346381425857544, -0.8731460571289062, -0.6889345645904541, 0.9324942827224731, -0.7905669212341309, 0.16384638845920563, -0.4975826144218445, -1.054703712463379, -0.34383076429367065, -0.8408195972442627, -0.616023063659668, -0.91407310962677, -0.19031335413455963, -0.6460021734237671, -0.9652783870697021, -0.4383024275302887, -0.09902163594961166, -0.5380939841270447, 1.0884944200515747, 3.54567289352417, 0.0, 0.0, 0.0, 5.21725606918335, 0.0, 0.0, 4.612019062042236, 5.024860382080078, 5.702908515930176, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.6284911632537842, 0.21479211747646332, -0.6480427980422974, -0.8612010478973389, -0.0, -0.5268964767456055, -0.0, -0.0, -0.0, -0.0, -0.0, -3.429871082305908, -4.955667018890381, -4.566162109375, -4.285249710083008, -3.9562504291534424, -2.9065191745758057, -2.9325368404388428, -2.7306506633758545, -2.4053103923797607, -2.923893928527832, -2.412834882736206, -2.00614595413208, -2.3850722312927246, -1.180712103843689, -1.5248565673828125, -1.7773889303207397, -1.2508248090744019, -1.1539934873580933, -1.1724833250045776, -0.8275558352470398, -1.014399766921997, -1.1140894889831543, -1.1882708072662354, -0.2710351347923279, -0.866298496723175, -0.5092074871063232, -0.9346381425857544, -0.8731460571289062, -0.6889345645904541, 0.9324942827224731, -0.7905669212341309, 0.16384638845920563, -0.4975826144218445, -1.054703712463379, -0.34383076429367065, -0.8408195972442627, -0.616023063659668, -0.91407310962677, -0.19031335413455963, -0.6460021734237671, -0.9652783870697021, -0.4383024275302887, -0.09902163594961166, -0.5380939841270447, 1.0884944200515747, 3.54567289352417, 0.0, 0.0, 0.0, 5.21725606918335, 0.0, 0.0, 4.612019062042236, 5.024860382080078, 5.702908515930176, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.6879029273986816, -0.9405971765518188, -0.6885648369789124, 0.0, -0.6039880514144897, -2.501699924468994, 0.0, 0.0, 0.0, 0.0, -4.384241104125977, -4.993409633636475, -4.454137802124023, -4.318040370941162, -4.437841892242432, -4.19407320022583, -3.349419593811035, -3.129058361053467, -2.8733034133911133, -2.346817970275879, -2.4489505290985107, -3.6174042224884033, -2.2061243057250977, -1.7421482801437378, -1.3715208768844604, -0.8599839806556702, -1.2226307392120361, -1.0332344770431519, -1.7086387872695923, -1.703011155128479, -1.5518914461135864, -1.7630501985549927, -1.2443878650665283, -0.9410447478294373, -1.2387932538986206, 0.012967485934495926, -0.8780117630958557, -0.16471734642982483, -0.6243359446525574, -0.8308538198471069, -0.039973463863134384, 0.027133839204907417, -0.49819880723953247, -0.8574398756027222, -0.5708228349685669, -0.642114520072937, -0.4006314277648926, -1.0502536296844482, -0.676243782043457, 0.14937637746334076, -0.7788102626800537, 0.08744626492261887, 0.2189103662967682, 0.367920845746994, -0.7008313536643982, -0.2038259506225586, 0.5325483083724976, 0.7580287456512451, 1.2721240520477295, 0.0, 0.0, 0.0, 3.670438528060913, 0.0, 3.266549587249756, 3.5353291034698486, 5.3618268966674805, 6.800267696380615, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -2.6879029273986816, -0.9405971765518188, -0.6885648369789124, -0.0, -0.6039880514144897, -2.501699924468994, -0.0, -0.0, -0.0, -0.0, -4.384241104125977, -4.993409633636475, -4.454137802124023, -4.318040370941162, -4.437841892242432, -4.19407320022583, -3.349419593811035, -3.129058361053467, -2.8733034133911133, -2.346817970275879, -2.4489505290985107, -3.6174042224884033, -2.2061243057250977, -1.7421482801437378, -1.3715208768844604, -0.8599839806556702, -1.2226307392120361, -1.0332344770431519, -1.7086387872695923, -1.703011155128479, -1.5518914461135864, -1.7630501985549927, -1.2443878650665283, -0.9410447478294373, -1.2387932538986206, 0.012967485934495926, -0.8780117630958557, -0.16471734642982483, -0.6243359446525574, -0.8308538198471069, -0.039973463863134384, 0.027133839204907417, -0.49819880723953247, -0.8574398756027222, -0.5708228349685669, -0.642114520072937, -0.4006314277648926, -1.0502536296844482, -0.676243782043457, 0.14937637746334076, -0.7788102626800537, 0.08744626492261887, 0.2189103662967682, 0.367920845746994, -0.7008313536643982, -0.2038259506225586, 0.5325483083724976, 0.7580287456512451, 1.2721240520477295, 0.0, 0.0, 0.0, 3.670438528060913, 0.0, 3.266549587249756, 3.5353291034698486, 5.3618268966674805, 6.800267696380615, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.02819561958313, -2.1869635581970215, -3.2577807903289795, -4.733762741088867, -5.6458353996276855, 0.0, 0.0, 0.0, 0.0, -5.0383501052856445, -5.0728044509887695, -4.738857746124268, -4.455273628234863, -4.028163909912109, -3.2625551223754883, -3.5540151596069336, -3.264866590499878, -2.3849332332611084, -1.963362455368042, -2.474177598953247, -1.4869108200073242, -1.940552830696106, -2.2688629627227783, -3.0828771591186523, -1.6530309915542603, -1.6101199388504028, -1.6084730625152588, -1.3140273094177246, -1.6512408256530762, -1.9533312320709229, 0.9510764479637146, -1.6911698579788208, -1.2694851160049438, -0.4302906095981598, -1.030358910560608, -0.9610832929611206, -0.9170506596565247, -0.7432792782783508, -0.20339518785476685, -0.0276802871376276, -0.2906818985939026, -0.4065822660923004, 0.3595866858959198, -0.00023469282314181328, -0.18621325492858887, 0.12328396737575531, -0.45715728402137756, -0.8610490560531616, -0.4964907467365265, -0.2876383364200592, 0.23598167300224304, 0.08637122064828873, -0.7361852526664734, 0.3621518611907959, 0.04742912948131561, -0.5791667699813843, -0.33077141642570496, 0.1177888959646225, -0.26299822330474854, 2.1401970386505127, 2.3078067302703857, 0.0, 0.0, 0.0, 0.0, 1.8874233961105347, 3.6809585094451904, 5.291200637817383, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -3.02819561958313, -2.1869635581970215, -3.2577807903289795, -4.733762741088867, -5.6458353996276855, -0.0, -0.0, -0.0, -0.0, -5.0383501052856445, -5.0728044509887695, -4.738857746124268, -4.455273628234863, -4.028163909912109, -3.2625551223754883, -3.5540151596069336, -3.264866590499878, -2.3849332332611084, -1.963362455368042, -2.474177598953247, -1.4869108200073242, -1.940552830696106, -2.2688629627227783, -3.0828771591186523, -1.6530309915542603, -1.6101199388504028, -1.6084730625152588, -1.3140273094177246, -1.6512408256530762, -1.9533312320709229, 0.9510764479637146, -1.6911698579788208, -1.2694851160049438, -0.4302906095981598, -1.030358910560608, -0.9610832929611206, -0.9170506596565247, -0.7432792782783508, -0.20339518785476685, -0.0276802871376276, -0.2906818985939026, -0.4065822660923004, 0.3595866858959198, -0.00023469282314181328, -0.18621325492858887, 0.12328396737575531, -0.45715728402137756, -0.8610490560531616, -0.4964907467365265, -0.2876383364200592, 0.23598167300224304, 0.08637122064828873, -0.7361852526664734, 0.3621518611907959, 0.04742912948131561, -0.5791667699813843, -0.33077141642570496, 0.1177888959646225, -0.26299822330474854, 2.1401970386505127, 2.3078067302703857, 0.0, 0.0, 0.0, 0.0, 1.8874233961105347, 3.6809585094451904, 5.291200637817383, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -4.227005958557129, -2.708876371383667, -1.1964538097381592, -4.471495151519775, -2.1472365856170654, 0.0, 0.0, 0.0, -4.218255996704102, -4.160297870635986, -5.172310829162598, -4.4348578453063965, -4.5702104568481445, -3.929692268371582, -4.169825077056885, -3.4535298347473145, -3.1410443782806396, -2.8932642936706543, -1.9666868448257446, -2.146164894104004, -2.232405662536621, -2.2334280014038086, -2.2417187690734863, -1.8284574747085571, -2.549307346343994, -1.165557861328125, -1.4155994653701782, -1.232482671737671, -3.189223527908325, -1.9045459032058716, -0.5526684522628784, -0.07349564135074615, -1.410201907157898, -1.4942631721496582, -0.4286041557788849, -0.785682737827301, -0.9706451892852783, -0.857955276966095, -0.27069610357284546, 0.004533019848167896, -0.2671026885509491, -0.2978008985519409, -0.06184655800461769, -0.4140240550041199, 0.025104809552431107, -0.6410590410232544, -0.5468940734863281, -0.496453195810318, -0.5314961671829224, -0.5356577634811401, -0.504143476486206, -0.20347917079925537, -0.7224430441856384, -0.7248459458351135, 0.2307833433151245, 0.2938797175884247, -0.38963931798934937, 0.17430643737316132, -0.020170003175735474, -0.13516147434711456, 0.5725680589675903, 0.9382146000862122, 0.0, 0.0, 0.0, 0.0, 2.2713375091552734, 0.0, 3.790877342224121, 5.903478622436523, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -4.227005958557129, -2.708876371383667, -1.1964538097381592, -4.471495151519775, -2.1472365856170654, -0.0, -0.0, -0.0, -4.218255996704102, -4.160297870635986, -5.172310829162598, -4.4348578453063965, -4.5702104568481445, -3.929692268371582, -4.169825077056885, -3.4535298347473145, -3.1410443782806396, -2.8932642936706543, -1.9666868448257446, -2.146164894104004, -2.232405662536621, -2.2334280014038086, -2.2417187690734863, -1.8284574747085571, -2.549307346343994, -1.165557861328125, -1.4155994653701782, -1.232482671737671, -3.189223527908325, -1.9045459032058716, -0.5526684522628784, -0.07349564135074615, -1.410201907157898, -1.4942631721496582, -0.4286041557788849, -0.785682737827301, -0.9706451892852783, -0.857955276966095, -0.27069610357284546, 0.004533019848167896, -0.2671026885509491, -0.2978008985519409, -0.06184655800461769, -0.4140240550041199, 0.025104809552431107, -0.6410590410232544, -0.5468940734863281, -0.496453195810318, -0.5314961671829224, -0.5356577634811401, -0.504143476486206, -0.20347917079925537, -0.7224430441856384, -0.7248459458351135, 0.2307833433151245, 0.2938797175884247, -0.38963931798934937, 0.17430643737316132, -0.020170003175735474, -0.13516147434711456, 0.5725680589675903, 0.9382146000862122, 0.0, -0.0, 0.0, 0.0, 2.2713375091552734, 0.0, 3.790877342224121, 5.903478622436523, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -2.5956809520721436, 0.09601357579231262, -1.3411908149719238, 0.0, -5.5487518310546875, 0.0, 0.0, 0.0, 0.0, -3.8810436725616455, -4.399397373199463, -4.55009651184082, -4.8967509269714355, -4.213883876800537, -4.011163711547852, -3.172396421432495, -3.6288888454437256, -2.3898308277130127, -3.1608328819274902, -1.851770281791687, -1.849279522895813, -2.2316205501556396, -2.1601178646087646, -2.207214832305908, -1.5221754312515259, -0.49771565198898315, -1.229052186012268, -0.26411172747612, -0.8245986700057983, -1.0181490182876587, -1.374283790588379, -1.3230574131011963, -1.1021074056625366, -1.073161244392395, -0.5654520988464355, 0.6718038320541382, -0.8496483564376831, -1.1456128358840942, -1.247485637664795, -0.6365724205970764, -0.4712791442871094, -0.4758242666721344, -0.3082321584224701, -0.03028772957623005, 0.08630137145519257, -0.5702626705169678, 0.2827318608760834, -0.92386794090271, 0.012997107580304146, -0.2889159321784973, 0.0774153470993042, -0.21846938133239746, -0.3743187487125397, 0.4433227479457855, 0.25683677196502686, -0.03944578021764755, -0.5684950351715088, -1.3344926834106445, -0.3841654062271118, 0.05159352719783783, 0.2673015594482422, -0.8714771270751953, -0.2951403856277466, -1.2794883251190186, 0.0, 0.0, 0.0, 4.099859237670898, 0.0, 0.0, 4.804418563842773, 6.9082512855529785, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -2.5956809520721436, 0.09601357579231262, -1.3411908149719238, -0.0, -5.5487518310546875, -0.0, -0.0, -0.0, -0.0, -3.8810436725616455, -4.399397373199463, -4.55009651184082, -4.8967509269714355, -4.213883876800537, -4.011163711547852, -3.172396421432495, -3.6288888454437256, -2.3898308277130127, -3.1608328819274902, -1.851770281791687, -1.849279522895813, -2.2316205501556396, -2.1601178646087646, -2.207214832305908, -1.5221754312515259, -0.49771565198898315, -1.229052186012268, -0.26411172747612, -0.8245986700057983, -1.0181490182876587, -1.374283790588379, -1.3230574131011963, -1.1021074056625366, -1.073161244392395, -0.5654520988464355, 0.6718038320541382, -0.8496483564376831, -1.1456128358840942, -1.247485637664795, -0.6365724205970764, -0.4712791442871094, -0.4758242666721344, -0.3082321584224701, -0.03028772957623005, 0.08630137145519257, -0.5702626705169678, 0.2827318608760834, -0.92386794090271, 0.012997107580304146, -0.2889159321784973, 0.0774153470993042, -0.21846938133239746, -0.3743187487125397, 0.4433227479457855, 0.25683677196502686, -0.03944578021764755, -0.5684950351715088, -1.3344926834106445, -0.3841654062271118, 0.05159352719783783, 0.2673015594482422, -0.8714771270751953, -0.2951403856277466, -1.2794883251190186, -0.0, -0.0, 0.0, 4.099859237670898, 0.0, 0.0, 4.804418563842773, 6.9082512855529785, 0.0, 0.0], [0.0, 0.0, 0.0, -0.5293294191360474, -4.197522163391113, 0.0, 1.9190014600753784, -0.7033160328865051, 0.0, 0.0, 0.0, 0.0, -5.275895595550537, -4.742354869842529, -4.937649726867676, -5.0511884689331055, -4.1550469398498535, -4.040775775909424, -3.7574269771575928, -3.174492597579956, -2.982917547225952, -2.533838987350464, -2.9229345321655273, -2.730116128921509, -2.0153512954711914, -2.0602493286132812, -1.8619853258132935, -1.1993287801742554, -2.2799954414367676, -1.1155809164047241, -2.1055235862731934, -1.6790320873260498, -1.2009470462799072, -1.3414851427078247, -0.7263887524604797, -1.5742765665054321, -0.5604192018508911, -0.12072160840034485, -0.27426737546920776, -0.5179269313812256, -0.8506107330322266, -0.07205846160650253, -0.45629721879959106, -0.262455552816391, -0.220137357711792, 0.5101498961448669, -0.3262999355792999, 0.5227577686309814, 0.3597443401813507, 0.3164326250553131, 0.5646828413009644, 0.2546367645263672, -0.2865104675292969, -0.16074372828006744, 0.21622973680496216, -0.6698306202888489, 0.2089981585741043, 0.5640004277229309, -0.43255579471588135, -0.009177902713418007, 1.139188289642334, 0.1066974475979805, 0.2099190205335617, -0.6788089275360107, -0.27945464849472046, -0.13632625341415405, -0.39327767491340637, 0.7167031764984131, 0.0, 0.0, 0.0, 2.9677340984344482, 0.0, 0.0, 7.440704822540283, 5.208251476287842, 0.0, 0.0, -0.0, -0.0, -0.0, -0.5293294191360474, -4.197522163391113, 0.0, 1.9190014600753784, -0.7033160328865051, -0.0, -0.0, -0.0, -0.0, -5.275895595550537, -4.742354869842529, -4.937649726867676, -5.0511884689331055, -4.1550469398498535, -4.040775775909424, -3.7574269771575928, -3.174492597579956, -2.982917547225952, -2.533838987350464, -2.9229345321655273, -2.730116128921509, -2.0153512954711914, -2.0602493286132812, -1.8619853258132935, -1.1993287801742554, -2.2799954414367676, -1.1155809164047241, -2.1055235862731934, -1.6790320873260498, -1.2009470462799072, -1.3414851427078247, -0.7263887524604797, -1.5742765665054321, -0.5604192018508911, -0.12072160840034485, -0.27426737546920776, -0.5179269313812256, -0.8506107330322266, -0.07205846160650253, -0.45629721879959106, -0.262455552816391, -0.220137357711792, 0.5101498961448669, -0.3262999355792999, 0.5227577686309814, 0.3597443401813507, 0.3164326250553131, 0.5646828413009644, 0.2546367645263672, -0.2865104675292969, -0.16074372828006744, 0.21622973680496216, -0.6698306202888489, 0.2089981585741043, 0.5640004277229309, -0.43255579471588135, -0.009177902713418007, 1.139188289642334, 0.1066974475979805, 0.2099190205335617, -0.6788089275360107, -0.27945464849472046, -0.13632625341415405, -0.39327767491340637, 0.7167031764984131, 0.0, 0.0, 0.0, 2.9677340984344482, 0.0, 0.0, 7.440704822540283, 5.208251476287842, 0.0, 0.0], [0.0, 0.0, -1.563442587852478, -2.9731829166412354, -3.8970725536346436, 0.0, -0.6297017931938171, 0.0, 0.0, 0.0, 0.0, -6.014010906219482, -5.393191337585449, -5.093029975891113, -4.174365997314453, -4.360992908477783, -4.181776523590088, -3.520099639892578, -3.3188631534576416, -3.002443790435791, -2.441469192504883, -2.798875093460083, -3.004924774169922, -2.298407554626465, -2.766188383102417, -1.5480345487594604, -1.3816146850585938, -1.28843355178833, -1.7280305624008179, -1.2371504306793213, -1.0043715238571167, -1.6048578023910522, -1.3034520149230957, 1.134444236755371, -0.6728218793869019, -0.09333465993404388, -1.2538318634033203, -0.46320641040802, 0.8314924240112305, 0.3852262496948242, -0.22701974213123322, 0.40620994567871094, 0.09959890693426132, 0.24913564324378967, 0.49797379970550537, 0.33261263370513916, -0.5101131200790405, 0.06469888985157013, 0.494421124458313, -0.8040149807929993, 0.4765625298023224, -1.9854151010513306, -0.16365906596183777, 0.7941797971725464, 0.08696558326482773, 0.7908868193626404, 0.015531978569924831, -0.9167057871818542, 0.5081344842910767, -0.09910962730646133, 0.4120808243751526, 0.5690256953239441, -0.00677550258114934, 0.05812254548072815, -0.2888892590999603, -0.3285943567752838, -0.41823142766952515, -0.6871247887611389, 2.039337635040283, 0.0, 0.0, 0.0, 0.0, 0.0, 4.202868938446045, 5.569675922393799, 7.093189716339111, 0.0, -0.0, -0.0, -1.563442587852478, -2.9731829166412354, -3.8970725536346436, -0.0, -0.6297017931938171, -0.0, -0.0, -0.0, -0.0, -6.014010906219482, -5.393191337585449, -5.093029975891113, -4.174365997314453, -4.360992908477783, -4.181776523590088, -3.520099639892578, -3.3188631534576416, -3.002443790435791, -2.441469192504883, -2.798875093460083, -3.004924774169922, -2.298407554626465, -2.766188383102417, -1.5480345487594604, -1.3816146850585938, -1.28843355178833, -1.7280305624008179, -1.2371504306793213, -1.0043715238571167, -1.6048578023910522, -1.3034520149230957, 1.134444236755371, -0.6728218793869019, -0.09333465993404388, -1.2538318634033203, -0.46320641040802, 0.8314924240112305, 0.3852262496948242, -0.22701974213123322, 0.40620994567871094, 0.09959890693426132, 0.24913564324378967, 0.49797379970550537, 0.33261263370513916, -0.5101131200790405, 0.06469888985157013, 0.494421124458313, -0.8040149807929993, 0.4765625298023224, -1.9854151010513306, -0.16365906596183777, 0.7941797971725464, 0.08696558326482773, 0.7908868193626404, 0.015531978569924831, -0.9167057871818542, 0.5081344842910767, -0.09910962730646133, 0.4120808243751526, 0.5690256953239441, -0.00677550258114934, 0.05812254548072815, -0.2888892590999603, -0.3285943567752838, -0.41823142766952515, -0.6871247887611389, 2.039337635040283, 0.0, 0.0, 0.0, 0.0, 0.0, 4.202868938446045, 5.569675922393799, 7.093189716339111, 0.0], [0.0, 0.0, -0.5587416291236877, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.467687606811523, -6.531337261199951, -5.619036674499512, -4.912109851837158, -5.305556774139404, -4.563255786895752, -4.502746105194092, -3.2235400676727295, -2.5755889415740967, -2.9225082397460938, -3.143235683441162, -2.270775318145752, -2.8956098556518555, -2.308483600616455, -1.6301841735839844, -1.0442891120910645, -1.323267936706543, -1.4771851301193237, -1.0377380847930908, -1.496114730834961, -1.034226417541504, -0.0071677775122225285, -0.2861253321170807, 0.06519442796707153, -1.0076262950897217, -0.7672706246376038, -0.029468292370438576, -0.17321372032165527, 0.4738209545612335, -0.12056689709424973, 0.04718425124883652, -0.03726788982748985, 0.23560172319412231, 0.2996441423892975, 0.2533400356769562, -0.11500560492277145, -0.21717439591884613, -0.8056692481040955, 0.11358761042356491, 0.1766679733991623, 0.3591875433921814, -0.010442940518260002, 0.07849597930908203, 0.9045318961143494, 0.08425872027873993, 0.9700181484222412, -0.05997602641582489, 0.03125596418976784, 0.4506584405899048, 0.9784785509109497, 0.45939987897872925, 0.44671034812927246, 0.1624809354543686, -0.1577179878950119, 0.20176447927951813, 0.18945105373859406, -0.7790740728378296, -0.7033151984214783, -1.2199962139129639, 0.4136255383491516, 0.0, 0.0, 0.0, 0.0, 0.0, 4.522904872894287, 5.41285514831543, 0.0, -0.0, -0.0, -0.5587416291236877, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.467687606811523, -6.531337261199951, -5.619036674499512, -4.912109851837158, -5.305556774139404, -4.563255786895752, -4.502746105194092, -3.2235400676727295, -2.5755889415740967, -2.9225082397460938, -3.143235683441162, -2.270775318145752, -2.8956098556518555, -2.308483600616455, -1.6301841735839844, -1.0442891120910645, -1.323267936706543, -1.4771851301193237, -1.0377380847930908, -1.496114730834961, -1.034226417541504, -0.0071677775122225285, -0.2861253321170807, 0.06519442796707153, -1.0076262950897217, -0.7672706246376038, -0.029468292370438576, -0.17321372032165527, 0.4738209545612335, -0.12056689709424973, 0.04718425124883652, -0.03726788982748985, 0.23560172319412231, 0.2996441423892975, 0.2533400356769562, -0.11500560492277145, -0.21717439591884613, -0.8056692481040955, 0.11358761042356491, 0.1766679733991623, 0.3591875433921814, -0.010442940518260002, 0.07849597930908203, 0.9045318961143494, 0.08425872027873993, 0.9700181484222412, -0.05997602641582489, 0.03125596418976784, 0.4506584405899048, 0.9784785509109497, 0.45939987897872925, 0.44671034812927246, 0.1624809354543686, -0.1577179878950119, 0.20176447927951813, 0.18945105373859406, -0.7790740728378296, -0.7033151984214783, -1.2199962139129639, 0.4136255383491516, 0.0, 0.0, 0.0, 0.0, 0.0, 4.522904872894287, 5.41285514831543, 0.0], [0.0, -3.3112144470214844, -2.2364301681518555, 0.0, 0.0, -2.391467571258545, 0.0, 0.0, 0.0, -6.122314453125, -6.1874308586120605, -5.890714645385742, -4.870196342468262, -4.516665935516357, -4.054911136627197, -4.317302703857422, -3.969059705734253, -4.063064098358154, -2.7907397747039795, -2.637429714202881, -2.690692901611328, -2.560192108154297, -2.6236348152160645, -1.8123785257339478, -1.4285961389541626, -1.296799659729004, -1.3402314186096191, -1.1969166994094849, -1.5410137176513672, -1.404826283454895, -0.35542619228363037, -1.2585909366607666, -0.5691496729850769, -0.6431030035018921, -0.6416659355163574, -0.52229905128479, -1.1001904010772705, -0.24968655407428741, -0.20673882961273193, -0.054718710482120514, 0.4254211187362671, 0.965579628944397, 0.41800615191459656, 0.04238874837756157, 0.3247247040271759, -0.20637507736682892, 0.028921395540237427, 0.2608259320259094, 0.3732564151287079, 0.3203967809677124, 0.39225828647613525, 0.7762972116470337, 0.3737787902355194, 0.1136493906378746, -0.11456932872533798, 0.48704397678375244, 0.2853679358959198, -0.021117329597473145, -0.44471243023872375, -0.0859861969947815, -0.3046572208404541, 0.19788239896297455, 0.050108641386032104, 0.4412156641483307, -0.24787186086177826, 0.9608396887779236, -0.4519639313220978, -0.26115626096725464, -0.3691355884075165, 0.1091589629650116, 0.0, 0.0, 0.0, 0.0, 5.020095348358154, 3.247343063354492, 5.516127586364746, 5.268322467803955, -0.0, -3.3112144470214844, -2.2364301681518555, -0.0, -0.0, -2.391467571258545, -0.0, -0.0, -0.0, -6.122314453125, -6.1874308586120605, -5.890714645385742, -4.870196342468262, -4.516665935516357, -4.054911136627197, -4.317302703857422, -3.969059705734253, -4.063064098358154, -2.7907397747039795, -2.637429714202881, -2.690692901611328, -2.560192108154297, -2.6236348152160645, -1.8123785257339478, -1.4285961389541626, -1.296799659729004, -1.3402314186096191, -1.1969166994094849, -1.5410137176513672, -1.404826283454895, -0.35542619228363037, -1.2585909366607666, -0.5691496729850769, -0.6431030035018921, -0.6416659355163574, -0.52229905128479, -1.1001904010772705, -0.24968655407428741, -0.20673882961273193, -0.054718710482120514, 0.4254211187362671, 0.965579628944397, 0.41800615191459656, 0.04238874837756157, 0.3247247040271759, -0.20637507736682892, 0.028921395540237427, 0.2608259320259094, 0.3732564151287079, 0.3203967809677124, 0.39225828647613525, 0.7762972116470337, 0.3737787902355194, 0.1136493906378746, -0.11456932872533798, 0.48704397678375244, 0.2853679358959198, -0.021117329597473145, -0.44471243023872375, -0.0859861969947815, -0.3046572208404541, 0.19788239896297455, 0.050108641386032104, 0.4412156641483307, -0.24787186086177826, 0.9608396887779236, -0.4519639313220978, -0.26115626096725464, -0.3691355884075165, 0.1091589629650116, 0.0, 0.0, 0.0, 0.0, 5.020095348358154, 3.247343063354492, 5.516127586364746, 5.268322467803955], [-3.632654905319214, -0.8966782689094543, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.776212215423584, -6.058586597442627, -5.252378463745117, -4.72025203704834, -4.504227161407471, -4.080772876739502, -3.491978406906128, -4.187788486480713, -3.6168007850646973, -3.3600480556488037, -3.0553297996520996, -2.7025530338287354, -1.8354146480560303, -2.803637981414795, -2.783637523651123, -1.8869531154632568, -1.456954836845398, -1.4389384984970093, -1.5433825254440308, -1.2021684646606445, -0.8875815272331238, -1.0844591856002808, -1.608317255973816, -0.8719787001609802, 0.0741424411535263, -1.486621379852295, -0.22465816140174866, -1.1001008749008179, 0.847702145576477, -0.4637504518032074, -0.4004223942756653, 0.47163569927215576, 0.6159331798553467, 0.6453564763069153, 0.9072287082672119, -0.1825276017189026, 0.7465511560440063, 0.9118491411209106, 0.8549156188964844, 1.0557183027267456, 0.23706382513046265, -0.35508185625076294, 0.0940302386879921, 0.8396229147911072, 0.12298239022493362, 0.631727933883667, 0.632879376411438, 0.46596452593803406, -0.1849622279405594, 0.43165820837020874, -0.41385379433631897, 0.993222177028656, 0.5820728540420532, -0.05121362954378128, -0.07069174200296402, -0.4166988432407379, 0.749139666557312, -0.21400417387485504, 0.15726801753044128, 0.14705292880535126, -0.11608915776014328, 0.5420048236846924, 0.0, 0.0, 0.0, 0.0, 0.0, 4.656341552734375, 7.369516849517822, -3.632654905319214, -0.8966782689094543, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.776212215423584, -6.058586597442627, -5.252378463745117, -4.72025203704834, -4.504227161407471, -4.080772876739502, -3.491978406906128, -4.187788486480713, -3.6168007850646973, -3.3600480556488037, -3.0553297996520996, -2.7025530338287354, -1.8354146480560303, -2.803637981414795, -2.783637523651123, -1.8869531154632568, -1.456954836845398, -1.4389384984970093, -1.5433825254440308, -1.2021684646606445, -0.8875815272331238, -1.0844591856002808, -1.608317255973816, -0.8719787001609802, 0.0741424411535263, -1.486621379852295, -0.22465816140174866, -1.1001008749008179, 0.847702145576477, -0.4637504518032074, -0.4004223942756653, 0.47163569927215576, 0.6159331798553467, 0.6453564763069153, 0.9072287082672119, -0.1825276017189026, 0.7465511560440063, 0.9118491411209106, 0.8549156188964844, 1.0557183027267456, 0.23706382513046265, -0.35508185625076294, 0.0940302386879921, 0.8396229147911072, 0.12298239022493362, 0.631727933883667, 0.632879376411438, 0.46596452593803406, -0.1849622279405594, 0.43165820837020874, -0.41385379433631897, 0.993222177028656, 0.5820728540420532, -0.05121362954378128, -0.07069174200296402, -0.4166988432407379, 0.749139666557312, -0.21400417387485504, 0.15726801753044128, 0.14705292880535126, -0.11608915776014328, 0.5420048236846924, 0.0, 0.0, 0.0, 0.0, 0.0, 4.656341552734375, 7.369516849517822], [-2.0216259956359863, -2.758575677871704, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.9000654220581055, -6.027953147888184, -5.007015228271484, -5.1845598220825195, -3.675480604171753, -4.623977184295654, -4.130619049072266, -3.5477135181427, -3.5424509048461914, -3.3366568088531494, -3.0904881954193115, -3.075655698776245, -2.638256072998047, -2.285923719406128, -1.7924330234527588, -0.6079531908035278, -2.207974433898926, -1.1136382818222046, -1.4046448469161987, -1.4908617734909058, -1.6119871139526367, -0.7507092952728271, -0.1560637354850769, -0.7196245193481445, 0.2978825867176056, -1.3666454553604126, -1.2745369672775269, -0.4729679822921753, 0.1141739934682846, -0.12119229882955551, -0.2817108929157257, 0.006104730069637299, 0.3329962193965912, 0.39795610308647156, 0.20360055565834045, 0.07094480097293854, 0.3819679319858551, 0.17905700206756592, 0.4094873368740082, 1.7378318309783936, 0.5848873853683472, -0.01740034855902195, 0.3816090524196625, 0.46899113059043884, 1.1784272193908691, 2.97479510307312, 0.6816598773002625, -0.3413172960281372, 0.024950865656137466, 0.07340189814567566, 0.05891352519392967, -0.016369305551052094, 0.4518706798553467, 0.4766021966934204, 0.18576902151107788, 0.9039484262466431, 0.5276085734367371, 0.6090037226676941, -0.29843395948410034, 0.7708191871643066, 0.1292569935321808, 0.14784348011016846, 0.9501644968986511, 2.0109031200408936, 0.0, 0.0, 5.4322733879089355, 4.754605293273926, 5.71002721786499, 6.661633491516113, -2.0216259956359863, -2.758575677871704, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.9000654220581055, -6.027953147888184, -5.007015228271484, -5.1845598220825195, -3.675480604171753, -4.623977184295654, -4.130619049072266, -3.5477135181427, -3.5424509048461914, -3.3366568088531494, -3.0904881954193115, -3.075655698776245, -2.638256072998047, -2.285923719406128, -1.7924330234527588, -0.6079531908035278, -2.207974433898926, -1.1136382818222046, -1.4046448469161987, -1.4908617734909058, -1.6119871139526367, -0.7507092952728271, -0.1560637354850769, -0.7196245193481445, 0.2978825867176056, -1.3666454553604126, -1.2745369672775269, -0.4729679822921753, 0.1141739934682846, -0.12119229882955551, -0.2817108929157257, 0.006104730069637299, 0.3329962193965912, 0.39795610308647156, 0.20360055565834045, 0.07094480097293854, 0.3819679319858551, 0.17905700206756592, 0.4094873368740082, 1.7378318309783936, 0.5848873853683472, -0.01740034855902195, 0.3816090524196625, 0.46899113059043884, 1.1784272193908691, 2.97479510307312, 0.6816598773002625, -0.3413172960281372, 0.024950865656137466, 0.07340189814567566, 0.05891352519392967, -0.016369305551052094, 0.4518706798553467, 0.4766021966934204, 0.18576902151107788, 0.9039484262466431, 0.5276085734367371, 0.6090037226676941, -0.29843395948410034, 0.7708191871643066, 0.1292569935321808, 0.14784348011016846, 0.9501644968986511, 2.0109031200408936, 0.0, 0.0, 5.4322733879089355, 4.754605293273926, 5.71002721786499, 6.661633491516113], [-3.3280351161956787, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.660953521728516, -5.613277435302734, -5.326931476593018, -5.295506477355957, -4.650269985198975, -4.427667140960693, -3.756883144378662, -3.2785000801086426, -3.3187668323516846, -2.443284273147583, -2.3786780834198, -2.6254258155822754, -2.2395272254943848, -2.6582703590393066, -1.6552704572677612, -1.8142969608306885, -1.8238719701766968, -1.4711450338363647, -1.250143051147461, -0.6567217111587524, -1.351931095123291, -0.1620667278766632, -0.3945741653442383, -1.5982307195663452, 0.585565984249115, -0.5653032064437866, -0.6421166062355042, 0.3378662168979645, -0.6496715545654297, -0.6142363548278809, -0.23410941660404205, 0.48706021904945374, 0.33033159375190735, 0.3385273218154907, 0.34135615825653076, 0.4268491268157959, 0.6879258751869202, 0.2815609574317932, 0.8839069604873657, 0.48529529571533203, 0.7928301095962524, 0.46312540769577026, -0.008531110361218452, 0.6807299852371216, 0.79627525806427, 1.2180278301239014, 1.2477025985717773, 0.8616514801979065, -0.18260475993156433, 1.136298656463623, 0.8304590582847595, 0.7959175705909729, 0.9905931949615479, 1.3208656311035156, 0.21619641780853271, 0.8300172090530396, 0.9930981993675232, 0.04597678408026695, 0.12830999493598938, 0.3277810513973236, 0.323543906211853, -0.08602248877286911, -0.2062944769859314, 1.2699289321899414, 0.0, 0.0, 6.545001029968262, 4.6566362380981445, 2.718418836593628, 4.367589473724365, -3.3280351161956787, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.660953521728516, -5.613277435302734, -5.326931476593018, -5.295506477355957, -4.650269985198975, -4.427667140960693, -3.756883144378662, -3.2785000801086426, -3.3187668323516846, -2.443284273147583, -2.3786780834198, -2.6254258155822754, -2.2395272254943848, -2.6582703590393066, -1.6552704572677612, -1.8142969608306885, -1.8238719701766968, -1.4711450338363647, -1.250143051147461, -0.6567217111587524, -1.351931095123291, -0.1620667278766632, -0.3945741653442383, -1.5982307195663452, 0.585565984249115, -0.5653032064437866, -0.6421166062355042, 0.3378662168979645, -0.6496715545654297, -0.6142363548278809, -0.23410941660404205, 0.48706021904945374, 0.33033159375190735, 0.3385273218154907, 0.34135615825653076, 0.4268491268157959, 0.6879258751869202, 0.2815609574317932, 0.8839069604873657, 0.48529529571533203, 0.7928301095962524, 0.46312540769577026, -0.008531110361218452, 0.6807299852371216, 0.79627525806427, 1.2180278301239014, 1.2477025985717773, 0.8616514801979065, -0.18260475993156433, 1.136298656463623, 0.8304590582847595, 0.7959175705909729, 0.9905931949615479, 1.3208656311035156, 0.21619641780853271, 0.8300172090530396, 0.9930981993675232, 0.04597678408026695, 0.12830999493598938, 0.3277810513973236, 0.323543906211853, -0.08602248877286911, -0.2062944769859314, 1.2699289321899414, 0.0, 0.0, 6.545001029968262, 4.6566362380981445, 2.718418836593628, 4.367589473724365], [-1.5895668268203735, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.114302635192871, -6.305323123931885, -5.911060810089111, -5.229723930358887, -6.01081657409668, -4.773406982421875, -3.746408224105835, -4.529460430145264, -3.5086450576782227, -3.4984028339385986, -3.7985754013061523, -2.2415213584899902, -2.610170841217041, -1.978841781616211, -2.404212236404419, -1.4121849536895752, -2.0333023071289062, -1.441739559173584, -1.305635690689087, -0.8563200235366821, -1.10197114944458, -0.5884134769439697, -0.15541112422943115, -0.7143979668617249, 1.4727303981781006, -0.32015639543533325, -0.35957664251327515, 0.17173701524734497, -0.21992744505405426, 0.5720308423042297, 0.4900526702404022, 0.5839114785194397, 0.7160674333572388, 0.35207778215408325, 0.11702331155538559, -0.07055102288722992, 0.1258493959903717, 0.39837324619293213, -0.6691949367523193, 0.6453964710235596, 0.6729492545127869, 0.6214914321899414, 0.1785779595375061, 0.8769770264625549, 0.8641448020935059, 0.3305545151233673, 0.8455460071563721, 1.4990382194519043, 0.703151285648346, 0.755847692489624, 0.5512649416923523, 0.914162278175354, 0.37853145599365234, 1.3594725131988525, 0.6621034741401672, 0.5150119662284851, -0.2138746827840805, 0.2586444616317749, 0.7768519520759583, 0.9752435088157654, 0.06350550800561905, 0.5492635369300842, -0.4638988673686981, -0.11928824335336685, 2.8962316513061523, 0.0, 0.0, 0.0, 2.7721054553985596, 4.65211296081543, 0.0, -1.5895668268203735, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.114302635192871, -6.305323123931885, -5.911060810089111, -5.229723930358887, -6.01081657409668, -4.773406982421875, -3.746408224105835, -4.529460430145264, -3.5086450576782227, -3.4984028339385986, -3.7985754013061523, -2.2415213584899902, -2.610170841217041, -1.978841781616211, -2.404212236404419, -1.4121849536895752, -2.0333023071289062, -1.441739559173584, -1.305635690689087, -0.8563200235366821, -1.10197114944458, -0.5884134769439697, -0.15541112422943115, -0.7143979668617249, 1.4727303981781006, -0.32015639543533325, -0.35957664251327515, 0.17173701524734497, -0.21992744505405426, 0.5720308423042297, 0.4900526702404022, 0.5839114785194397, 0.7160674333572388, 0.35207778215408325, 0.11702331155538559, -0.07055102288722992, 0.1258493959903717, 0.39837324619293213, -0.6691949367523193, 0.6453964710235596, 0.6729492545127869, 0.6214914321899414, 0.1785779595375061, 0.8769770264625549, 0.8641448020935059, 0.3305545151233673, 0.8455460071563721, 1.4990382194519043, 0.703151285648346, 0.755847692489624, 0.5512649416923523, 0.914162278175354, 0.37853145599365234, 1.3594725131988525, 0.6621034741401672, 0.5150119662284851, -0.2138746827840805, 0.2586444616317749, 0.7768519520759583, 0.9752435088157654, 0.06350550800561905, 0.5492635369300842, -0.4638988673686981, -0.11928824335336685, 2.8962316513061523, 0.0, 0.0, 0.0, 2.7721054553985596, 4.65211296081543, 0.0], [-2.2652485370635986, 0.0, 0.0, 0.0, 0.0, 0.0, -7.384920597076416, -6.241978168487549, -6.310129642486572, -5.240096092224121, -5.421889305114746, -4.936229705810547, -4.816929817199707, -4.409188270568848, -4.058720588684082, -3.3448705673217773, -3.7582879066467285, -3.2488198280334473, -2.460772752761841, -2.8395984172821045, -2.6807234287261963, -2.441035747528076, -1.3110733032226562, -1.3231747150421143, -2.5726747512817383, -1.5707951784133911, -1.9765876531600952, -1.136549472808838, -1.0238680839538574, -0.7210136651992798, -0.6771445274353027, -0.3196110129356384, -1.21328604221344, -0.43313223123550415, 0.06418535858392715, 0.5687293410301208, 0.37673190236091614, 0.0, -0.7415284514427185, 0.9816480278968811, 1.018148422241211, 0.668938398361206, 0.5504986643791199, 0.5895482897758484, 0.12412609159946442, 0.9882029891014099, 1.0442428588867188, 0.30974504351615906, 0.41059228777885437, 0.6022263765335083, 0.5288979411125183, 0.4667109549045563, 0.5940294861793518, 0.67167729139328, 0.7235472202301025, 0.43341219425201416, 0.6700640320777893, 0.5301188230514526, 1.4338873624801636, 0.06532278656959534, 0.6387137174606323, 1.0532225370407104, 1.6288009881973267, 0.1231527104973793, -0.3771349787712097, 0.6590534448623657, 0.6214914321899414, 0.04710482805967331, -0.18285943567752838, 0.4759974181652069, -0.5929573774337769, -0.7539018988609314, 0.0, 0.0, 0.0, 1.6499708890914917, 0.9866552352905273, -2.6989853382110596, -2.2652485370635986, -0.0, -0.0, -0.0, -0.0, -0.0, -7.384920597076416, -6.241978168487549, -6.310129642486572, -5.240096092224121, -5.421889305114746, -4.936229705810547, -4.816929817199707, -4.409188270568848, -4.058720588684082, -3.3448705673217773, -3.7582879066467285, -3.2488198280334473, -2.460772752761841, -2.8395984172821045, -2.6807234287261963, -2.441035747528076, -1.3110733032226562, -1.3231747150421143, -2.5726747512817383, -1.5707951784133911, -1.9765876531600952, -1.136549472808838, -1.0238680839538574, -0.7210136651992798, -0.6771445274353027, -0.3196110129356384, -1.21328604221344, -0.43313223123550415, 0.06418535858392715, 0.5687293410301208, 0.37673190236091614, 0.0, -0.7415284514427185, 0.9816480278968811, 1.018148422241211, 0.668938398361206, 0.5504986643791199, 0.5895482897758484, 0.12412609159946442, 0.9882029891014099, 1.0442428588867188, 0.30974504351615906, 0.41059228777885437, 0.6022263765335083, 0.5288979411125183, 0.4667109549045563, 0.5940294861793518, 0.67167729139328, 0.7235472202301025, 0.43341219425201416, 0.6700640320777893, 0.5301188230514526, 1.4338873624801636, 0.06532278656959534, 0.6387137174606323, 1.0532225370407104, 1.6288009881973267, 0.1231527104973793, -0.3771349787712097, 0.6590534448623657, 0.6214914321899414, 0.04710482805967331, -0.18285943567752838, 0.4759974181652069, -0.5929573774337769, -0.7539018988609314, -0.0, 0.0, 0.0, 1.6499708890914917, 0.9866552352905273, -2.6989853382110596], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.593313217163086, -5.818731307983398, -5.202685832977295, -5.051077365875244, -5.121269702911377, -4.750858783721924, -4.568409442901611, -4.154979228973389, -3.668198347091675, -3.4663355350494385, -4.107511043548584, -3.1102182865142822, -2.6063666343688965, -2.9557063579559326, -2.4890730381011963, -1.1464102268218994, -2.1194663047790527, -1.4180195331573486, -1.4916505813598633, -1.5061957836151123, -2.1035547256469727, -0.9246752262115479, -1.90399169921875, -0.6274698972702026, -0.678611695766449, -0.5188032984733582, -0.44952723383903503, 0.6775379180908203, 0.512173593044281, 0.4037248194217682, 0.6219602227210999, -0.0009160063927993178, 0.3496401309967041, 0.955737292766571, 0.5038453340530396, 0.702114999294281, 1.489404320716858, 0.9432897567749023, 0.5317284464836121, 0.6371882557868958, 0.4957188367843628, 0.44196808338165283, 0.6757339239120483, 1.3354634046554565, 1.5468014478683472, 0.1723933070898056, 0.6249485611915588, 0.7395193576812744, 0.9895334839820862, 0.4525151252746582, 1.6739224195480347, 1.3704769611358643, 1.1124495267868042, 0.6355040669441223, 2.0150604248046875, 1.1172727346420288, 0.9134411811828613, 0.9098220467567444, 0.7436274290084839, 0.6745303869247437, 0.6045461893081665, 1.2572290897369385, 1.1760704517364502, 0.5248929262161255, -0.014737865887582302, -0.8318848609924316, 0.0, 0.0, 0.0, 0.0, 2.5818164348602295, -0.9306181073188782, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.593313217163086, -5.818731307983398, -5.202685832977295, -5.051077365875244, -5.121269702911377, -4.750858783721924, -4.568409442901611, -4.154979228973389, -3.668198347091675, -3.4663355350494385, -4.107511043548584, -3.1102182865142822, -2.6063666343688965, -2.9557063579559326, -2.4890730381011963, -1.1464102268218994, -2.1194663047790527, -1.4180195331573486, -1.4916505813598633, -1.5061957836151123, -2.1035547256469727, -0.9246752262115479, -1.90399169921875, -0.6274698972702026, -0.678611695766449, -0.5188032984733582, -0.44952723383903503, 0.6775379180908203, 0.512173593044281, 0.4037248194217682, 0.6219602227210999, -0.0009160063927993178, 0.3496401309967041, 0.955737292766571, 0.5038453340530396, 0.702114999294281, 1.489404320716858, 0.9432897567749023, 0.5317284464836121, 0.6371882557868958, 0.4957188367843628, 0.44196808338165283, 0.6757339239120483, 1.3354634046554565, 1.5468014478683472, 0.1723933070898056, 0.6249485611915588, 0.7395193576812744, 0.9895334839820862, 0.4525151252746582, 1.6739224195480347, 1.3704769611358643, 1.1124495267868042, 0.6355040669441223, 2.0150604248046875, 1.1172727346420288, 0.9134411811828613, 0.9098220467567444, 0.7436274290084839, 0.6745303869247437, 0.6045461893081665, 1.2572290897369385, 1.1760704517364502, 0.5248929262161255, -0.014737865887582302, -0.8318848609924316, -0.0, -0.0, 0.0, 0.0, 2.5818164348602295, -0.9306181073188782], [0.0, 0.0, 0.0, 0.0, 0.0, -5.390773773193359, -5.559774875640869, -6.206238269805908, -5.793561935424805, -5.638586521148682, -4.892187118530273, -5.352505683898926, -4.25462532043457, -4.344305038452148, -4.01591682434082, -3.938202142715454, -4.575394630432129, -2.4633936882019043, -2.936030387878418, 0.319659948348999, -2.3472025394439697, -2.712808132171631, -1.702953577041626, -0.5237797498703003, -1.3780999183654785, -1.8333052396774292, -1.0321996212005615, -0.848084032535553, -0.8415603637695312, -0.7743740677833557, -0.49647271633148193, -0.23805704712867737, -0.12294788658618927, 0.849955677986145, 0.3020237982273102, 1.5892590284347534, -1.1969202756881714, 0.17781467735767365, 0.7636372447013855, 0.7208351492881775, 0.732621967792511, 0.029732229188084602, 0.7657734751701355, 1.0232867002487183, 0.8791893720626831, 0.7102898955345154, 0.7906429171562195, 0.8023273348808289, 0.6220459342002869, 0.2565440237522125, 1.6988227367401123, 0.794610321521759, 1.0050392150878906, 0.910619854927063, 0.986646831035614, 1.051741361618042, 1.280212163925171, 0.41829076409339905, 0.6341468095779419, 0.7835472822189331, 2.675140857696533, -1.095304012298584, 0.3270605206489563, 1.4458342790603638, 1.0118629932403564, 0.6109501123428345, 1.0169868469238281, 1.6521930694580078, 0.9950971603393555, 0.6193761825561523, 0.6186721324920654, -0.48923081159591675, -0.6973937749862671, 0.0, 0.0, 0.0, 0.0, -2.634723663330078, -0.0, -0.0, -0.0, -0.0, -0.0, -5.390773773193359, -5.559774875640869, -6.206238269805908, -5.793561935424805, -5.638586521148682, -4.892187118530273, -5.352505683898926, -4.25462532043457, -4.344305038452148, -4.01591682434082, -3.938202142715454, -4.575394630432129, -2.4633936882019043, -2.936030387878418, 0.319659948348999, -2.3472025394439697, -2.712808132171631, -1.702953577041626, -0.5237797498703003, -1.3780999183654785, -1.8333052396774292, -1.0321996212005615, -0.848084032535553, -0.8415603637695312, -0.7743740677833557, -0.49647271633148193, -0.23805704712867737, -0.12294788658618927, 0.849955677986145, 0.3020237982273102, 1.5892590284347534, -1.1969202756881714, 0.17781467735767365, 0.7636372447013855, 0.7208351492881775, 0.732621967792511, 0.029732229188084602, 0.7657734751701355, 1.0232867002487183, 0.8791893720626831, 0.7102898955345154, 0.7906429171562195, 0.8023273348808289, 0.6220459342002869, 0.2565440237522125, 1.6988227367401123, 0.794610321521759, 1.0050392150878906, 0.910619854927063, 0.986646831035614, 1.051741361618042, 1.280212163925171, 0.41829076409339905, 0.6341468095779419, 0.7835472822189331, 2.675140857696533, -1.095304012298584, 0.3270605206489563, 1.4458342790603638, 1.0118629932403564, 0.6109501123428345, 1.0169868469238281, 1.6521930694580078, 0.9950971603393555, 0.6193761825561523, 0.6186721324920654, -0.48923081159591675, -0.6973937749862671, -0.0, -0.0, 0.0, 0.0, -2.634723663330078], [0.0, 0.0, 0.0, 0.0, 0.0, -5.180440425872803, -5.194329261779785, -5.30600118637085, -5.84937858581543, -5.935588359832764, -5.759713649749756, -4.5600080490112305, -4.218820571899414, -4.8424763679504395, -3.8950588703155518, -2.9878461360931396, -3.7130138874053955, -2.4676856994628906, -2.6185824871063232, -1.7498631477355957, -1.5088818073272705, -1.997446894645691, -1.1704918146133423, -1.1349431276321411, -0.9345073699951172, -1.4826116561889648, -1.8703696727752686, -0.727240800857544, -0.26029664278030396, -1.127703309059143, -0.084074966609478, 0.10758687555789948, 1.5939568281173706, 0.3904421925544739, 1.2594035863876343, 0.05661317706108093, -0.24178479611873627, 0.016180872917175293, 0.7764246463775635, 0.7923648953437805, 0.32692644000053406, 0.6410108804702759, 0.4194682240486145, 0.7065750360488892, 0.8572914600372314, 0.5795122385025024, 0.8541948795318604, 0.8687165975570679, 1.0665185451507568, 0.698300302028656, 0.7743986248970032, 1.0503785610198975, 1.0562456846237183, 1.1132572889328003, 0.9589682221412659, 0.9859523773193359, 0.43444404006004333, 1.8127775192260742, 0.12456674873828888, 1.8763922452926636, 0.5579804182052612, 0.7346866130828857, 1.7212433815002441, 1.1250741481781006, 1.987756609916687, 0.7034845352172852, 0.9617748856544495, -0.1398167759180069, 0.884941577911377, 0.6876397132873535, 0.94233238697052, 0.5199453234672546, 0.18987365067005157, -0.4070042669773102, 0.0, 0.0, 2.7968380451202393, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.180440425872803, -5.194329261779785, -5.30600118637085, -5.84937858581543, -5.935588359832764, -5.759713649749756, -4.5600080490112305, -4.218820571899414, -4.8424763679504395, -3.8950588703155518, -2.9878461360931396, -3.7130138874053955, -2.4676856994628906, -2.6185824871063232, -1.7498631477355957, -1.5088818073272705, -1.997446894645691, -1.1704918146133423, -1.1349431276321411, -0.9345073699951172, -1.4826116561889648, -1.8703696727752686, -0.727240800857544, -0.26029664278030396, -1.127703309059143, -0.084074966609478, 0.10758687555789948, 1.5939568281173706, 0.3904421925544739, 1.2594035863876343, 0.05661317706108093, -0.24178479611873627, 0.016180872917175293, 0.7764246463775635, 0.7923648953437805, 0.32692644000053406, 0.6410108804702759, 0.4194682240486145, 0.7065750360488892, 0.8572914600372314, 0.5795122385025024, 0.8541948795318604, 0.8687165975570679, 1.0665185451507568, 0.698300302028656, 0.7743986248970032, 1.0503785610198975, 1.0562456846237183, 1.1132572889328003, 0.9589682221412659, 0.9859523773193359, 0.43444404006004333, 1.8127775192260742, 0.12456674873828888, 1.8763922452926636, 0.5579804182052612, 0.7346866130828857, 1.7212433815002441, 1.1250741481781006, 1.987756609916687, 0.7034845352172852, 0.9617748856544495, -0.1398167759180069, 0.884941577911377, 0.6876397132873535, 0.94233238697052, 0.5199453234672546, 0.18987365067005157, -0.4070042669773102, -0.0, 0.0, 2.7968380451202393, 0.0], [0.0, -6.5191497802734375, 0.0, 0.0, -8.978779792785645, -5.26398229598999, -5.083397388458252, -5.567786693572998, -5.752354621887207, -4.924108982086182, -5.196070671081543, -4.748373508453369, -4.644191265106201, -4.536614418029785, -4.1063737869262695, -4.2876362800598145, -4.650697231292725, -2.7158915996551514, -2.9740352630615234, -2.3373312950134277, -1.8649202585220337, -1.304610252380371, -1.6044816970825195, -1.9955226182937622, -1.3307737112045288, -0.9100918173789978, -0.010344761423766613, -0.6159451007843018, -0.606050968170166, 0.018324607983231544, -0.43069231510162354, 1.0948389768600464, -0.4331407845020294, -0.21810787916183472, -2.517380714416504, -0.06881304085254669, 0.8265061378479004, 0.33448082208633423, 0.7333385944366455, 0.27845636010169983, 1.279825210571289, 0.5178537368774414, 0.40708619356155396, 0.18674780428409576, 0.07917921990156174, 1.0393664836883545, 0.8112524747848511, 0.6832289695739746, 1.391709327697754, 0.7556922435760498, 1.5298019647598267, 1.0894789695739746, 0.8264905214309692, 0.9702102541923523, 1.1927363872528076, 0.3496110141277313, 0.6282810568809509, 0.7353261113166809, 1.7006133794784546, 1.0335462093353271, 0.0348239541053772, 0.34844833612442017, 0.8443502187728882, 0.7269328236579895, 2.222486972808838, 0.7434481978416443, 1.6364450454711914, 0.19967471063137054, 1.1242822408676147, 1.3391485214233398, 1.3661088943481445, 0.3173605799674988, 0.697069525718689, 0.816885769367218, 0.7916394472122192, 0.0, 0.0, 1.8317116498947144, -0.0, -6.5191497802734375, -0.0, -0.0, -8.978779792785645, -5.26398229598999, -5.083397388458252, -5.567786693572998, -5.752354621887207, -4.924108982086182, -5.196070671081543, -4.748373508453369, -4.644191265106201, -4.536614418029785, -4.1063737869262695, -4.2876362800598145, -4.650697231292725, -2.7158915996551514, -2.9740352630615234, -2.3373312950134277, -1.8649202585220337, -1.304610252380371, -1.6044816970825195, -1.9955226182937622, -1.3307737112045288, -0.9100918173789978, -0.010344761423766613, -0.6159451007843018, -0.606050968170166, 0.018324607983231544, -0.43069231510162354, 1.0948389768600464, -0.4331407845020294, -0.21810787916183472, -2.517380714416504, -0.06881304085254669, 0.8265061378479004, 0.33448082208633423, 0.7333385944366455, 0.27845636010169983, 1.279825210571289, 0.5178537368774414, 0.40708619356155396, 0.18674780428409576, 0.07917921990156174, 1.0393664836883545, 0.8112524747848511, 0.6832289695739746, 1.391709327697754, 0.7556922435760498, 1.5298019647598267, 1.0894789695739746, 0.8264905214309692, 0.9702102541923523, 1.1927363872528076, 0.3496110141277313, 0.6282810568809509, 0.7353261113166809, 1.7006133794784546, 1.0335462093353271, 0.0348239541053772, 0.34844833612442017, 0.8443502187728882, 0.7269328236579895, 2.222486972808838, 0.7434481978416443, 1.6364450454711914, 0.19967471063137054, 1.1242822408676147, 1.3391485214233398, 1.3661088943481445, 0.3173605799674988, 0.697069525718689, 0.816885769367218, 0.7916394472122192, 0.0, 0.0, 1.8317116498947144], [0.0, -8.268420219421387, 0.0, 0.0, -7.203896999359131, -6.859625816345215, -4.628523826599121, -5.9399094581604, -5.167113304138184, -5.612826824188232, -5.189188480377197, -4.929742336273193, -5.137304306030273, -4.535743236541748, -3.978562355041504, -3.1109862327575684, -2.7040789127349854, -2.904569149017334, -2.4293484687805176, -2.895021438598633, -2.327378749847412, -1.613533616065979, -1.8424313068389893, -1.6313408613204956, -1.5735342502593994, -2.051372528076172, -0.8527193665504456, 0.007089382968842983, -0.11753864586353302, -0.5446536540985107, 0.7730696797370911, -0.27440282702445984, 0.192913219332695, -0.10111457854509354, 1.3812451362609863, 0.8899372816085815, 1.0724953413009644, -1.0537240505218506, 1.046165943145752, 1.0816235542297363, 1.3174461126327515, 3.6475846767425537, -0.31272298097610474, 0.06763844192028046, 0.8206790685653687, -0.7434951066970825, 1.4321857690811157, 0.9299087524414062, 0.7075632214546204, 1.094571590423584, 1.2789950370788574, 1.5328013896942139, 1.6084823608398438, 1.0170396566390991, 1.2627809047698975, 0.9187604784965515, 1.4039983749389648, 1.1918009519577026, 1.4442055225372314, -0.03708971291780472, 1.3777496814727783, 1.2469817399978638, 1.218568205833435, 0.26401233673095703, 1.4044299125671387, 0.5879279971122742, 1.258296012878418, 0.7181596755981445, 1.13565194606781, 1.6664724349975586, 1.030773401260376, 1.4012587070465088, 0.9110442996025085, 1.6330233812332153, 1.0197393894195557, 0.0, 4.6244707107543945, 2.9978575706481934, -0.0, -8.268420219421387, -0.0, -0.0, -7.203896999359131, -6.859625816345215, -4.628523826599121, -5.9399094581604, -5.167113304138184, -5.612826824188232, -5.189188480377197, -4.929742336273193, -5.137304306030273, -4.535743236541748, -3.978562355041504, -3.1109862327575684, -2.7040789127349854, -2.904569149017334, -2.4293484687805176, -2.895021438598633, -2.327378749847412, -1.613533616065979, -1.8424313068389893, -1.6313408613204956, -1.5735342502593994, -2.051372528076172, -0.8527193665504456, 0.007089382968842983, -0.11753864586353302, -0.5446536540985107, 0.7730696797370911, -0.27440282702445984, 0.192913219332695, -0.10111457854509354, 1.3812451362609863, 0.8899372816085815, 1.0724953413009644, -1.0537240505218506, 1.046165943145752, 1.0816235542297363, 1.3174461126327515, 3.6475846767425537, -0.31272298097610474, 0.06763844192028046, 0.8206790685653687, -0.7434951066970825, 1.4321857690811157, 0.9299087524414062, 0.7075632214546204, 1.094571590423584, 1.2789950370788574, 1.5328013896942139, 1.6084823608398438, 1.0170396566390991, 1.2627809047698975, 0.9187604784965515, 1.4039983749389648, 1.1918009519577026, 1.4442055225372314, -0.03708971291780472, 1.3777496814727783, 1.2469817399978638, 1.218568205833435, 0.26401233673095703, 1.4044299125671387, 0.5879279971122742, 1.258296012878418, 0.7181596755981445, 1.13565194606781, 1.6664724349975586, 1.030773401260376, 1.4012587070465088, 0.9110442996025085, 1.6330233812332153, 1.0197393894195557, 0.0, 4.6244707107543945, 2.9978575706481934], [0.0, 0.0, 0.0, 0.0, -6.919111251831055, -7.242990016937256, -6.518311977386475, -5.938467502593994, -5.800800800323486, -5.6879754066467285, -4.911401271820068, -5.052155494689941, -4.5950751304626465, -3.4856321811676025, -4.97018575668335, -3.9467666149139404, -2.7373569011688232, -3.59411883354187, -1.6005887985229492, -1.9476457834243774, -1.8574352264404297, -1.9159462451934814, -1.3587524890899658, -1.6260411739349365, -1.3098981380462646, -0.7388322353363037, 0.2933501899242401, -0.7598342299461365, -0.93349689245224, -0.029318174347281456, -1.2622531652450562, 1.0722455978393555, -0.4368264675140381, 0.01862109638750553, 0.23912551999092102, 0.5972989797592163, 0.8406997323036194, 0.11302558332681656, 0.3519108295440674, 0.6504484415054321, 0.20146355032920837, 0.2687667906284332, 1.2733852863311768, 1.2202239036560059, 2.834887742996216, 0.9576079249382019, 1.4535000324249268, 2.408001184463501, 0.8748904466629028, 0.996865451335907, 1.1226606369018555, 1.963483214378357, 1.1387968063354492, 1.4134767055511475, 1.1887694597244263, 0.9125227928161621, 1.3783968687057495, 0.16008345782756805, 0.9027315974235535, 1.1560587882995605, 1.1980899572372437, 1.2099378108978271, 1.041666030883789, 1.3068491220474243, 1.4640700817108154, 1.1098934412002563, 0.43389448523521423, 0.028441863134503365, 0.7675500512123108, 0.8982521891593933, 0.579391360282898, 1.0213227272033691, 1.4467499256134033, 1.300382375717163, 0.5130879282951355, 0.0, 0.0, 2.9624931812286377, -0.0, -0.0, -0.0, -0.0, -6.919111251831055, -7.242990016937256, -6.518311977386475, -5.938467502593994, -5.800800800323486, -5.6879754066467285, -4.911401271820068, -5.052155494689941, -4.5950751304626465, -3.4856321811676025, -4.97018575668335, -3.9467666149139404, -2.7373569011688232, -3.59411883354187, -1.6005887985229492, -1.9476457834243774, -1.8574352264404297, -1.9159462451934814, -1.3587524890899658, -1.6260411739349365, -1.3098981380462646, -0.7388322353363037, 0.2933501899242401, -0.7598342299461365, -0.93349689245224, -0.029318174347281456, -1.2622531652450562, 1.0722455978393555, -0.4368264675140381, 0.01862109638750553, 0.23912551999092102, 0.5972989797592163, 0.8406997323036194, 0.11302558332681656, 0.3519108295440674, 0.6504484415054321, 0.20146355032920837, 0.2687667906284332, 1.2733852863311768, 1.2202239036560059, 2.834887742996216, 0.9576079249382019, 1.4535000324249268, 2.408001184463501, 0.8748904466629028, 0.996865451335907, 1.1226606369018555, 1.963483214378357, 1.1387968063354492, 1.4134767055511475, 1.1887694597244263, 0.9125227928161621, 1.3783968687057495, 0.16008345782756805, 0.9027315974235535, 1.1560587882995605, 1.1980899572372437, 1.2099378108978271, 1.041666030883789, 1.3068491220474243, 1.4640700817108154, 1.1098934412002563, 0.43389448523521423, 0.028441863134503365, 0.7675500512123108, 0.8982521891593933, 0.579391360282898, 1.0213227272033691, 1.4467499256134033, 1.300382375717163, 0.5130879282951355, 0.0, 0.0, 2.9624931812286377], [0.0, 0.0, 0.0, -7.706531524658203, -7.158838748931885, -6.7028656005859375, -5.980572700500488, -6.219058990478516, -5.1967267990112305, -4.987662315368652, -5.204323768615723, -4.73905611038208, -4.679947853088379, -4.598089218139648, -3.4351909160614014, -3.391230583190918, -3.3255724906921387, -3.2531344890594482, -1.9319822788238525, -2.4022228717803955, -1.6952660083770752, -1.933118462562561, -1.8174272775650024, -1.4834213256835938, -0.9082883596420288, -0.6459329128265381, -0.9632064700126648, -0.9514417052268982, -0.669837474822998, -0.7088921666145325, -0.3495980203151703, 0.19443972408771515, 0.9250562191009521, 0.5746731162071228, 0.5655761957168579, 0.3018155097961426, 0.5941559672355652, -0.4076523780822754, 1.1032520532608032, 0.25702354311943054, 0.0976879745721817, 1.2799851894378662, 1.008071780204773, -1.5317857265472412, 1.7852556705474854, 1.3998451232910156, 0.9513972997665405, 1.9073747396469116, 1.4684585332870483, 1.2272696495056152, 1.2635725736618042, 1.5015833377838135, 1.3680343627929688, 1.5934118032455444, 1.3185316324234009, 1.498181700706482, 1.3832706212997437, 1.2638168334960938, 0.9155442118644714, 1.1733925342559814, 1.373458743095398, 2.6142592430114746, 1.372910976409912, 1.114858865737915, 1.2575500011444092, 0.701728105545044, 0.1628151834011078, 1.1451376676559448, 1.6862642765045166, 0.952015221118927, 1.0774579048156738, 0.5227683782577515, 0.19424909353256226, 1.656514048576355, 1.6175789833068848, 3.813998222351074, 0.0, 0.18847589194774628, -0.0, -0.0, -0.0, -7.706531524658203, -7.158838748931885, -6.7028656005859375, -5.980572700500488, -6.219058990478516, -5.1967267990112305, -4.987662315368652, -5.204323768615723, -4.73905611038208, -4.679947853088379, -4.598089218139648, -3.4351909160614014, -3.391230583190918, -3.3255724906921387, -3.2531344890594482, -1.9319822788238525, -2.4022228717803955, -1.6952660083770752, -1.933118462562561, -1.8174272775650024, -1.4834213256835938, -0.9082883596420288, -0.6459329128265381, -0.9632064700126648, -0.9514417052268982, -0.669837474822998, -0.7088921666145325, -0.3495980203151703, 0.19443972408771515, 0.9250562191009521, 0.5746731162071228, 0.5655761957168579, 0.3018155097961426, 0.5941559672355652, -0.4076523780822754, 1.1032520532608032, 0.25702354311943054, 0.0976879745721817, 1.2799851894378662, 1.008071780204773, -1.5317857265472412, 1.7852556705474854, 1.3998451232910156, 0.9513972997665405, 1.9073747396469116, 1.4684585332870483, 1.2272696495056152, 1.2635725736618042, 1.5015833377838135, 1.3680343627929688, 1.5934118032455444, 1.3185316324234009, 1.498181700706482, 1.3832706212997437, 1.2638168334960938, 0.9155442118644714, 1.1733925342559814, 1.373458743095398, 2.6142592430114746, 1.372910976409912, 1.114858865737915, 1.2575500011444092, 0.701728105545044, 0.1628151834011078, 1.1451376676559448, 1.6862642765045166, 0.952015221118927, 1.0774579048156738, 0.5227683782577515, 0.19424909353256226, 1.656514048576355, 1.6175789833068848, 3.813998222351074, 0.0, 0.18847589194774628], [-6.712433815002441, 0.0, 0.0, -6.909820556640625, -6.991415977478027, -6.595329284667969, -7.508882522583008, -6.112738609313965, -4.762588024139404, -5.188475131988525, -5.08078670501709, -4.107969760894775, -2.2290868759155273, -3.7742278575897217, -3.6194710731506348, -2.522806167602539, -3.393498659133911, -2.5666112899780273, -2.8445894718170166, -2.688248634338379, -2.3411693572998047, -1.5467031002044678, -1.6149152517318726, -1.2321549654006958, -1.096518874168396, -0.13948968052864075, -0.7271982431411743, -0.6749600172042847, -1.2860722541809082, -0.6205341815948486, 0.41201695799827576, -0.3071560859680176, -0.5934045314788818, -0.030016828328371048, -0.020157590508461, 0.27597522735595703, 0.639499843120575, -0.44390636682510376, -0.32311463356018066, 0.8814207315444946, 0.7507566213607788, 1.1223114728927612, 1.2636945247650146, 0.5033535957336426, 1.4759180545806885, 1.3676542043685913, 2.6458725929260254, 1.0215778350830078, 1.341119647026062, 1.9650927782058716, 1.5087841749191284, 0.9389774203300476, 1.4966069459915161, 1.638350486755371, 1.4448270797729492, 1.750952124595642, 4.671553611755371, 2.802518844604492, 0.6230976581573486, 0.3607414960861206, 1.147667407989502, 1.1817572116851807, 1.0275154113769531, 1.5289121866226196, 1.0941747426986694, 0.5971368551254272, 0.9068396091461182, 0.8348418474197388, 0.689522922039032, 1.2815009355545044, 1.1071377992630005, 1.0423316955566406, 1.2830379009246826, 2.0984535217285156, 2.5332536697387695, 2.510561466217041, 0.0, 2.2280807495117188, -6.712433815002441, -0.0, -0.0, -6.909820556640625, -6.991415977478027, -6.595329284667969, -7.508882522583008, -6.112738609313965, -4.762588024139404, -5.188475131988525, -5.08078670501709, -4.107969760894775, -2.2290868759155273, -3.7742278575897217, -3.6194710731506348, -2.522806167602539, -3.393498659133911, -2.5666112899780273, -2.8445894718170166, -2.688248634338379, -2.3411693572998047, -1.5467031002044678, -1.6149152517318726, -1.2321549654006958, -1.096518874168396, -0.13948968052864075, -0.7271982431411743, -0.6749600172042847, -1.2860722541809082, -0.6205341815948486, 0.41201695799827576, -0.3071560859680176, -0.5934045314788818, -0.030016828328371048, -0.020157590508461, 0.27597522735595703, 0.639499843120575, -0.44390636682510376, -0.32311463356018066, 0.8814207315444946, 0.7507566213607788, 1.1223114728927612, 1.2636945247650146, 0.5033535957336426, 1.4759180545806885, 1.3676542043685913, 2.6458725929260254, 1.0215778350830078, 1.341119647026062, 1.9650927782058716, 1.5087841749191284, 0.9389774203300476, 1.4966069459915161, 1.638350486755371, 1.4448270797729492, 1.750952124595642, 4.671553611755371, 2.802518844604492, 0.6230976581573486, 0.3607414960861206, 1.147667407989502, 1.1817572116851807, 1.0275154113769531, 1.5289121866226196, 1.0941747426986694, 0.5971368551254272, 0.9068396091461182, 0.8348418474197388, 0.689522922039032, 1.2815009355545044, 1.1071377992630005, 1.0423316955566406, 1.2830379009246826, 2.0984535217285156, 2.5332536697387695, 2.510561466217041, 0.0, 2.2280807495117188], [0.0, 0.0, -4.680607318878174, -6.621527671813965, -6.85659122467041, -6.1805315017700195, -6.40156364440918, -5.667501449584961, -5.6631622314453125, -5.078242778778076, -4.874209403991699, -4.572932243347168, -2.8769612312316895, -4.663433074951172, -3.8497302532196045, -3.3130404949188232, -3.8256256580352783, -2.6377086639404297, -2.1530699729919434, -2.9934051036834717, -1.7143415212631226, -1.700323224067688, -1.6270524263381958, -1.1265802383422852, -1.4061946868896484, -0.9951755404472351, -0.08589932322502136, -0.8118681907653809, 0.1663779467344284, 0.181175097823143, 0.3289063572883606, 0.26524680852890015, 0.0771489292383194, -0.005178617313504219, 0.1174633651971817, 0.8019676208496094, 1.7087656259536743, -0.9665502309799194, 3.116605281829834, 0.8751223087310791, 1.8799254894256592, 1.9650856256484985, 2.3646721839904785, 1.3209786415100098, 0.9497216939926147, 1.7596502304077148, 4.020109176635742, 2.232375383377075, 1.585274338722229, 1.1675529479980469, 0.9974635243415833, 1.3031989336013794, 2.0382866859436035, 1.2278883457183838, 1.1599292755126953, 0.9112679362297058, 1.085402250289917, 0.7081892490386963, 0.6082738041877747, 1.1984195709228516, 0.7476516962051392, 0.4399554133415222, 1.0980793237686157, 0.4866259694099426, 0.3176141679286957, 1.942747712135315, 1.6097575426101685, 0.9731824398040771, 0.9209127426147461, 0.6749491095542908, 1.0334837436676025, 0.782126247882843, 1.9872980117797852, 2.607170581817627, 2.8781206607818604, 0.9419693350791931, 0.0, 3.649965524673462, -0.0, -0.0, -4.680607318878174, -6.621527671813965, -6.85659122467041, -6.1805315017700195, -6.40156364440918, -5.667501449584961, -5.6631622314453125, -5.078242778778076, -4.874209403991699, -4.572932243347168, -2.8769612312316895, -4.663433074951172, -3.8497302532196045, -3.3130404949188232, -3.8256256580352783, -2.6377086639404297, -2.1530699729919434, -2.9934051036834717, -1.7143415212631226, -1.700323224067688, -1.6270524263381958, -1.1265802383422852, -1.4061946868896484, -0.9951755404472351, -0.08589932322502136, -0.8118681907653809, 0.1663779467344284, 0.181175097823143, 0.3289063572883606, 0.26524680852890015, 0.0771489292383194, -0.005178617313504219, 0.1174633651971817, 0.8019676208496094, 1.7087656259536743, -0.9665502309799194, 3.116605281829834, 0.8751223087310791, 1.8799254894256592, 1.9650856256484985, 2.3646721839904785, 1.3209786415100098, 0.9497216939926147, 1.7596502304077148, 4.020109176635742, 2.232375383377075, 1.585274338722229, 1.1675529479980469, 0.9974635243415833, 1.3031989336013794, 2.0382866859436035, 1.2278883457183838, 1.1599292755126953, 0.9112679362297058, 1.085402250289917, 0.7081892490386963, 0.6082738041877747, 1.1984195709228516, 0.7476516962051392, 0.4399554133415222, 1.0980793237686157, 0.4866259694099426, 0.3176141679286957, 1.942747712135315, 1.6097575426101685, 0.9731824398040771, 0.9209127426147461, 0.6749491095542908, 1.0334837436676025, 0.782126247882843, 1.9872980117797852, 2.607170581817627, 2.8781206607818604, 0.9419693350791931, 0.0, 3.649965524673462], [-8.412612915039062, 0.0, -6.145706653594971, -6.787029266357422, -6.803393363952637, -7.206628322601318, -6.774420738220215, -6.168088436126709, -6.28355073928833, -5.85967493057251, -5.629505157470703, -4.483236312866211, -4.841151237487793, -3.942671537399292, -3.298710584640503, -3.8198440074920654, -3.3869102001190186, -3.6116724014282227, -2.840740442276001, -2.65364933013916, -2.0633397102355957, -1.660250186920166, -2.0763421058654785, -1.6466176509857178, -1.655033826828003, -1.147168517112732, -1.3613865375518799, -0.9759843945503235, -0.5465017557144165, -0.047976039350032806, -0.11530760675668716, 0.08670595288276672, 0.552879810333252, 0.8602330684661865, -0.27345433831214905, 0.5408995747566223, 1.416290044784546, 0.548475444316864, -0.5103718638420105, 0.0, 1.9246959686279297, 2.2114105224609375, 1.4370523691177368, 1.8514059782028198, 1.5103200674057007, 1.4837384223937988, 0.8999768495559692, 1.7454862594604492, 1.3248968124389648, 4.2154741287231445, 1.4553499221801758, 1.3325260877609253, 1.168161392211914, 1.4209229946136475, 1.1299500465393066, 0.7521150708198547, 1.229499101638794, 1.2343932390213013, 1.787408709526062, 0.4621114730834961, 0.4492371082305908, 0.8882225155830383, -0.02678810805082321, 0.8024457097053528, 0.6852068305015564, 0.24925151467323303, 0.5114220380783081, 1.5998551845550537, 1.2435848712921143, 1.4702601432800293, 0.7845591306686401, 1.444055199623108, 1.1003831624984741, 2.225630283355713, 1.9008166790008545, 3.6000633239746094, 0.0, 0.0, -8.412612915039062, -0.0, -6.145706653594971, -6.787029266357422, -6.803393363952637, -7.206628322601318, -6.774420738220215, -6.168088436126709, -6.28355073928833, -5.85967493057251, -5.629505157470703, -4.483236312866211, -4.841151237487793, -3.942671537399292, -3.298710584640503, -3.8198440074920654, -3.3869102001190186, -3.6116724014282227, -2.840740442276001, -2.65364933013916, -2.0633397102355957, -1.660250186920166, -2.0763421058654785, -1.6466176509857178, -1.655033826828003, -1.147168517112732, -1.3613865375518799, -0.9759843945503235, -0.5465017557144165, -0.047976039350032806, -0.11530760675668716, 0.08670595288276672, 0.552879810333252, 0.8602330684661865, -0.27345433831214905, 0.5408995747566223, 1.416290044784546, 0.548475444316864, -0.5103718638420105, 0.0, 1.9246959686279297, 2.2114105224609375, 1.4370523691177368, 1.8514059782028198, 1.5103200674057007, 1.4837384223937988, 0.8999768495559692, 1.7454862594604492, 1.3248968124389648, 4.2154741287231445, 1.4553499221801758, 1.3325260877609253, 1.168161392211914, 1.4209229946136475, 1.1299500465393066, 0.7521150708198547, 1.229499101638794, 1.2343932390213013, 1.787408709526062, 0.4621114730834961, 0.4492371082305908, 0.8882225155830383, -0.02678810805082321, 0.8024457097053528, 0.6852068305015564, 0.24925151467323303, 0.5114220380783081, 1.5998551845550537, 1.2435848712921143, 1.4702601432800293, 0.7845591306686401, 1.444055199623108, 1.1003831624984741, 2.225630283355713, 1.9008166790008545, 3.6000633239746094, 0.0, 0.0], [0.0, 0.0, -7.6032609939575195, -6.686837673187256, -6.377204418182373, -5.806126117706299, -5.882521152496338, -6.25315523147583, -6.191294193267822, -5.6628193855285645, -5.313679218292236, -3.8758416175842285, -4.763637542724609, -5.151418685913086, -4.093221187591553, -3.4931747913360596, -4.088226795196533, -3.2496676445007324, -2.038388729095459, -2.361177682876587, -2.1738686561584473, -1.7572516202926636, -1.708014726638794, -1.2460123300552368, -0.9935075044631958, -0.7335996627807617, -0.8069726824760437, -0.8915005922317505, -2.4320390224456787, 0.3724014163017273, 0.32749295234680176, -0.835611879825592, -0.7131620049476624, 0.44420045614242554, 0.7296057343482971, 0.7218466997146606, -0.29105570912361145, 3.6371068954467773, -0.6780584454536438, 1.9114028215408325, 1.2862193584442139, -1.3814008235931396, 2.793105363845825, 1.556257724761963, 0.7727015614509583, 2.9588141441345215, 0.9641174077987671, 1.600783348083496, 1.4158508777618408, 0.8123342394828796, 0.936229407787323, 1.053688645362854, 1.7393378019332886, 1.6162959337234497, 1.2724305391311646, 1.497178316116333, 1.9247294664382935, 1.4545974731445312, 0.8779873251914978, 1.5711621046066284, 0.43070337176322937, 1.1841961145401, 1.4585810899734497, 1.1537892818450928, 2.187357187271118, 0.4228135645389557, 1.1907620429992676, 0.08387979865074158, 0.8487904667854309, 0.2786957919597626, 1.530666708946228, 1.9168368577957153, 1.5890575647354126, 1.3205639123916626, 1.952043890953064, 5.472659111022949, 0.0, 0.0, -0.0, -0.0, -7.6032609939575195, -6.686837673187256, -6.377204418182373, -5.806126117706299, -5.882521152496338, -6.25315523147583, -6.191294193267822, -5.6628193855285645, -5.313679218292236, -3.8758416175842285, -4.763637542724609, -5.151418685913086, -4.093221187591553, -3.4931747913360596, -4.088226795196533, -3.2496676445007324, -2.038388729095459, -2.361177682876587, -2.1738686561584473, -1.7572516202926636, -1.708014726638794, -1.2460123300552368, -0.9935075044631958, -0.7335996627807617, -0.8069726824760437, -0.8915005922317505, -2.4320390224456787, 0.3724014163017273, 0.32749295234680176, -0.835611879825592, -0.7131620049476624, 0.44420045614242554, 0.7296057343482971, 0.7218466997146606, -0.29105570912361145, 3.6371068954467773, -0.6780584454536438, 1.9114028215408325, 1.2862193584442139, -1.3814008235931396, 2.793105363845825, 1.556257724761963, 0.7727015614509583, 2.9588141441345215, 0.9641174077987671, 1.600783348083496, 1.4158508777618408, 0.8123342394828796, 0.936229407787323, 1.053688645362854, 1.7393378019332886, 1.6162959337234497, 1.2724305391311646, 1.497178316116333, 1.9247294664382935, 1.4545974731445312, 0.8779873251914978, 1.5711621046066284, 0.43070337176322937, 1.1841961145401, 1.4585810899734497, 1.1537892818450928, 2.187357187271118, 0.4228135645389557, 1.1907620429992676, 0.08387979865074158, 0.8487904667854309, 0.2786957919597626, 1.530666708946228, 1.9168368577957153, 1.5890575647354126, 1.3205639123916626, 1.952043890953064, 5.472659111022949, 0.0, 0.0], [0.0, 0.0, -6.802184581756592, -6.650886058807373, -7.241341590881348, -6.8741254806518555, -7.267889976501465, -6.830911159515381, -6.642330169677734, -5.699315547943115, -5.051894187927246, -4.428922653198242, -5.045969486236572, -4.82576847076416, -4.234809875488281, -4.060180187225342, -3.7486910820007324, -5.061652660369873, -2.871561288833618, -3.027980089187622, -1.7795673608779907, -1.3421820402145386, -0.9232684969902039, -2.627917528152466, 1.7820686101913452, -1.2511811256408691, -0.5365903377532959, -0.7796989679336548, -0.15320830047130585, 0.42489534616470337, 0.7591107487678528, 0.26410844922065735, 0.925987958908081, -1.0576605796813965, -0.07701000571250916, 0.019886231049895287, 0.8238465189933777, 1.1518580913543701, 3.962400197982788, 1.9302676916122437, 2.49481201171875, 3.2039589881896973, 0.6836996674537659, 2.492255449295044, 1.183379054069519, 0.0, 1.27065908908844, 1.2919921875, 1.092308521270752, 0.9365184903144836, 1.5732872486114502, 0.8363431096076965, 1.0780138969421387, 0.7738532423973083, 1.2440595626831055, 1.3132035732269287, 1.3784377574920654, 1.2936009168624878, 0.9735362529754639, 0.16069918870925903, 1.5590922832489014, 0.9364506006240845, 0.5926313400268555, 0.3358367383480072, 0.06908030062913895, 1.078334927558899, 0.3477637767791748, -0.10768204927444458, 0.3597709536552429, 1.1998084783554077, 0.7383251190185547, 0.7642208933830261, 2.0510711669921875, 1.873242735862732, 1.3443868160247803, 1.3897857666015625, 0.0, 0.0, -0.0, -0.0, -6.802184581756592, -6.650886058807373, -7.241341590881348, -6.8741254806518555, -7.267889976501465, -6.830911159515381, -6.642330169677734, -5.699315547943115, -5.051894187927246, -4.428922653198242, -5.045969486236572, -4.82576847076416, -4.234809875488281, -4.060180187225342, -3.7486910820007324, -5.061652660369873, -2.871561288833618, -3.027980089187622, -1.7795673608779907, -1.3421820402145386, -0.9232684969902039, -2.627917528152466, 1.7820686101913452, -1.2511811256408691, -0.5365903377532959, -0.7796989679336548, -0.15320830047130585, 0.42489534616470337, 0.7591107487678528, 0.26410844922065735, 0.925987958908081, -1.0576605796813965, -0.07701000571250916, 0.019886231049895287, 0.8238465189933777, 1.1518580913543701, 3.962400197982788, 1.9302676916122437, 2.49481201171875, 3.2039589881896973, 0.6836996674537659, 2.492255449295044, 1.183379054069519, 0.0, 1.27065908908844, 1.2919921875, 1.092308521270752, 0.9365184903144836, 1.5732872486114502, 0.8363431096076965, 1.0780138969421387, 0.7738532423973083, 1.2440595626831055, 1.3132035732269287, 1.3784377574920654, 1.2936009168624878, 0.9735362529754639, 0.16069918870925903, 1.5590922832489014, 0.9364506006240845, 0.5926313400268555, 0.3358367383480072, 0.06908030062913895, 1.078334927558899, 0.3477637767791748, -0.10768204927444458, 0.3597709536552429, 1.1998084783554077, 0.7383251190185547, 0.7642208933830261, 2.0510711669921875, 1.873242735862732, 1.3443868160247803, 1.3897857666015625, 0.0, 0.0], [0.0, 0.0, -7.816426753997803, -7.837141513824463, -6.269292831420898, -6.7466301918029785, -6.107072830200195, -6.413761615753174, -5.019361972808838, -6.917497158050537, -4.929940223693848, -5.758200168609619, -4.895152568817139, -5.317388534545898, -4.268357753753662, -3.271919012069702, -2.9818882942199707, -2.970991611480713, -2.836636543273926, -2.916297197341919, -2.4852449893951416, -1.7414222955703735, -1.8007181882858276, -2.699965000152588, -1.1876730918884277, -1.3255237340927124, -0.952623724937439, -0.40345895290374756, -0.989612340927124, -0.8156515955924988, -0.5507296323776245, -0.1783571094274521, -0.3780058026313782, -0.4372531473636627, 0.4827379882335663, 0.29707780480384827, 0.7330704927444458, 1.1351529359817505, 0.0, -0.5306097269058228, 2.336923837661743, 1.8504728078842163, 1.6916778087615967, 1.747174859046936, 2.308267593383789, 0.3621430993080139, 2.6746575832366943, 1.3528618812561035, 1.4999228715896606, 1.4597883224487305, 1.5798375606536865, 1.0339704751968384, 1.308213472366333, 1.3117330074310303, 1.3775535821914673, 0.8656230568885803, 0.23611776530742645, 3.660963535308838, 0.9573306441307068, 0.38085517287254333, -0.3468858599662781, 1.1850470304489136, 1.3337723016738892, 0.6050860285758972, 0.6191049218177795, 0.3962640166282654, 0.513761579990387, 0.5152623653411865, 0.9184285998344421, -0.41141167283058167, 1.1961853504180908, 0.9689038395881653, 1.40440034866333, 1.852429747581482, 1.6281417608261108, 3.1351206302642822, 0.0, 0.0, -0.0, -0.0, -7.816426753997803, -7.837141513824463, -6.269292831420898, -6.7466301918029785, -6.107072830200195, -6.413761615753174, -5.019361972808838, -6.917497158050537, -4.929940223693848, -5.758200168609619, -4.895152568817139, -5.317388534545898, -4.268357753753662, -3.271919012069702, -2.9818882942199707, -2.970991611480713, -2.836636543273926, -2.916297197341919, -2.4852449893951416, -1.7414222955703735, -1.8007181882858276, -2.699965000152588, -1.1876730918884277, -1.3255237340927124, -0.952623724937439, -0.40345895290374756, -0.989612340927124, -0.8156515955924988, -0.5507296323776245, -0.1783571094274521, -0.3780058026313782, -0.4372531473636627, 0.4827379882335663, 0.29707780480384827, 0.7330704927444458, 1.1351529359817505, 0.0, -0.5306097269058228, 2.336923837661743, 1.8504728078842163, 1.6916778087615967, 1.747174859046936, 2.308267593383789, 0.3621430993080139, 2.6746575832366943, 1.3528618812561035, 1.4999228715896606, 1.4597883224487305, 1.5798375606536865, 1.0339704751968384, 1.308213472366333, 1.3117330074310303, 1.3775535821914673, 0.8656230568885803, 0.23611776530742645, 3.660963535308838, 0.9573306441307068, 0.38085517287254333, -0.3468858599662781, 1.1850470304489136, 1.3337723016738892, 0.6050860285758972, 0.6191049218177795, 0.3962640166282654, 0.513761579990387, 0.5152623653411865, 0.9184285998344421, -0.41141167283058167, 1.1961853504180908, 0.9689038395881653, 1.40440034866333, 1.852429747581482, 1.6281417608261108, 3.1351206302642822, 0.0, 0.0], [0.0, 0.0, -8.685057640075684, -7.9935760498046875, -6.973577976226807, -7.102066516876221, -5.747189044952393, -6.48006010055542, -6.598752498626709, -5.690293312072754, -5.854366302490234, -5.1580939292907715, -5.088011741638184, -4.683323383331299, -3.770479202270508, -3.7297182083129883, -4.139232635498047, -3.479738473892212, -2.9167473316192627, -2.611704111099243, -1.997351050376892, -1.56809401512146, -1.8801534175872803, -1.9099136590957642, -1.9386335611343384, -1.9238736629486084, -0.44386744499206543, -1.4950125217437744, -0.3490031957626343, -0.8805800080299377, -0.4316486120223999, 0.9382644891738892, 0.4932352304458618, 0.6712446808815002, -0.3525618016719818, 0.3531399667263031, 0.3949066698551178, 0.42813318967819214, 0.0, 3.5193846225738525, 1.4479382038116455, 1.7213302850723267, 1.4579769372940063, 2.135951042175293, 1.5749616622924805, 1.2059974670410156, 0.43775150179862976, 2.5224671363830566, 2.557161808013916, 4.845614910125732, 1.2123074531555176, 1.413255214691162, -0.44620639085769653, 1.4829833507537842, 0.4665314555168152, 0.8346410393714905, 1.220507264137268, 0.541698157787323, 0.2898454964160919, 0.052952468395233154, 0.5370326042175293, 1.077276587486267, 0.6113775968551636, 0.6574369072914124, 0.3934151530265808, -0.9143109321594238, 0.5842758417129517, 0.7023941278457642, 0.613884687423706, 0.43512240052223206, 0.6508141756057739, 0.739116370677948, 1.217342495918274, 1.8035598993301392, 1.9940006732940674, 1.1394963264465332, 2.609042167663574, 0.0, -0.0, -0.0, -8.685057640075684, -7.9935760498046875, -6.973577976226807, -7.102066516876221, -5.747189044952393, -6.48006010055542, -6.598752498626709, -5.690293312072754, -5.854366302490234, -5.1580939292907715, -5.088011741638184, -4.683323383331299, -3.770479202270508, -3.7297182083129883, -4.139232635498047, -3.479738473892212, -2.9167473316192627, -2.611704111099243, -1.997351050376892, -1.56809401512146, -1.8801534175872803, -1.9099136590957642, -1.9386335611343384, -1.9238736629486084, -0.44386744499206543, -1.4950125217437744, -0.3490031957626343, -0.8805800080299377, -0.4316486120223999, 0.9382644891738892, 0.4932352304458618, 0.6712446808815002, -0.3525618016719818, 0.3531399667263031, 0.3949066698551178, 0.42813318967819214, 0.0, 3.5193846225738525, 1.4479382038116455, 1.7213302850723267, 1.4579769372940063, 2.135951042175293, 1.5749616622924805, 1.2059974670410156, 0.43775150179862976, 2.5224671363830566, 2.557161808013916, 4.845614910125732, 1.2123074531555176, 1.413255214691162, -0.44620639085769653, 1.4829833507537842, 0.4665314555168152, 0.8346410393714905, 1.220507264137268, 0.541698157787323, 0.2898454964160919, 0.052952468395233154, 0.5370326042175293, 1.077276587486267, 0.6113775968551636, 0.6574369072914124, 0.3934151530265808, -0.9143109321594238, 0.5842758417129517, 0.7023941278457642, 0.613884687423706, 0.43512240052223206, 0.6508141756057739, 0.739116370677948, 1.217342495918274, 1.8035598993301392, 1.9940006732940674, 1.1394963264465332, 2.609042167663574, 0.0], [0.0, -7.855744361877441, -8.023944854736328, -7.56185245513916, -7.552204608917236, -7.819772720336914, -7.661113739013672, -6.623689651489258, -6.319752216339111, -5.622650623321533, -5.78955078125, -5.553622722625732, -4.855904579162598, -5.831871509552002, -5.175635814666748, -4.339456081390381, -4.314233303070068, -3.435941457748413, -3.499574661254883, -2.743048906326294, -2.2324106693267822, -2.1388020515441895, -2.2544116973876953, -2.0547361373901367, -1.4777345657348633, -1.0913286209106445, -3.4779951572418213, -1.4206316471099854, -2.3406753540039062, 1.622136116027832, 0.35403111577033997, -0.10901833325624466, 1.2625600099563599, -0.08239230513572693, 0.061938367784023285, 0.5096992254257202, 0.7686300873756409, -0.8113624453544617, -2.6107001304626465, 0.0, 0.8085125684738159, 0.8675558567047119, 1.9581325054168701, 0.7536142468452454, 1.3405731916427612, 0.20026715099811554, 1.1527693271636963, 1.5032289028167725, 2.6982462406158447, 4.2926106452941895, 1.258913278579712, 0.899710476398468, 1.413618564605713, 1.6326029300689697, 0.45460084080696106, 2.9560952186584473, 1.4200022220611572, 0.6115983128547668, 0.3808661997318268, 0.7240269184112549, 1.0377134084701538, -0.03240581601858139, 0.6862850189208984, -0.22671233117580414, 0.6702326536178589, 0.10209045559167862, 0.5851927399635315, 0.6273843050003052, 0.5860506892204285, -1.3446861505508423, 2.159851312637329, 0.3363623023033142, 1.1542894840240479, 0.9312870502471924, 2.0976037979125977, 1.4691617488861084, 4.484556198120117, 0.0, -0.0, -7.855744361877441, -8.023944854736328, -7.56185245513916, -7.552204608917236, -7.819772720336914, -7.661113739013672, -6.623689651489258, -6.319752216339111, -5.622650623321533, -5.78955078125, -5.553622722625732, -4.855904579162598, -5.831871509552002, -5.175635814666748, -4.339456081390381, -4.314233303070068, -3.435941457748413, -3.499574661254883, -2.743048906326294, -2.2324106693267822, -2.1388020515441895, -2.2544116973876953, -2.0547361373901367, -1.4777345657348633, -1.0913286209106445, -3.4779951572418213, -1.4206316471099854, -2.3406753540039062, 1.622136116027832, 0.35403111577033997, -0.10901833325624466, 1.2625600099563599, -0.08239230513572693, 0.061938367784023285, 0.5096992254257202, 0.7686300873756409, -0.8113624453544617, -2.6107001304626465, 0.0, 0.8085125684738159, 0.8675558567047119, 1.9581325054168701, 0.7536142468452454, 1.3405731916427612, 0.20026715099811554, 1.1527693271636963, 1.5032289028167725, 2.6982462406158447, 4.2926106452941895, 1.258913278579712, 0.899710476398468, 1.413618564605713, 1.6326029300689697, 0.45460084080696106, 2.9560952186584473, 1.4200022220611572, 0.6115983128547668, 0.3808661997318268, 0.7240269184112549, 1.0377134084701538, -0.03240581601858139, 0.6862850189208984, -0.22671233117580414, 0.6702326536178589, 0.10209045559167862, 0.5851927399635315, 0.6273843050003052, 0.5860506892204285, -1.3446861505508423, 2.159851312637329, 0.3363623023033142, 1.1542894840240479, 0.9312870502471924, 2.0976037979125977, 1.4691617488861084, 4.484556198120117, 0.0], [0.0, -8.489211082458496, -8.097448348999023, -8.66435718536377, -8.127310752868652, -8.058834075927734, -7.609302520751953, -6.19763708114624, -6.294440269470215, -6.3373236656188965, -4.928545951843262, -6.202709674835205, -5.876855373382568, -4.869768142700195, -4.622581481933594, -4.402562618255615, -4.092719078063965, -2.828117609024048, -3.9533627033233643, -0.2358899861574173, -3.1777827739715576, -2.5318446159362793, -1.3887593746185303, -2.1124539375305176, -1.4459866285324097, -1.7588081359863281, -1.7998298406600952, -0.30428487062454224, -0.5691611170768738, -0.4985802173614502, -0.43533074855804443, 0.5450541377067566, 0.11029113829135895, 0.19009923934936523, -0.4886152446269989, -0.18446028232574463, -0.4187629222869873, -1.5536019802093506, -2.9653985500335693, 2.498365879058838, 2.7798259258270264, 0.9705333709716797, 1.1337904930114746, 0.6324526071548462, 0.3723813593387604, -0.07711052149534225, 0.7339563965797424, 1.1786798238754272, 1.2679988145828247, 1.1593822240829468, 1.248747706413269, 0.8570224642753601, 0.567720890045166, 1.7699248790740967, 1.1136770248413086, 0.4028712809085846, 1.7166199684143066, 1.3062156438827515, -0.29003605246543884, 0.14070101082324982, 0.1720196008682251, 0.16210295259952545, -0.01785578764975071, 0.6895759701728821, 0.669114351272583, 0.38231611251831055, -0.007667523343116045, -0.07830577343702316, 0.02412707358598709, 0.7351228594779968, 1.5381264686584473, 0.7669504284858704, 1.0226385593414307, 0.2835524082183838, 1.1326733827590942, 1.7671173810958862, 2.059242010116577, 0.0, -0.0, -8.489211082458496, -8.097448348999023, -8.66435718536377, -8.127310752868652, -8.058834075927734, -7.609302520751953, -6.19763708114624, -6.294440269470215, -6.3373236656188965, -4.928545951843262, -6.202709674835205, -5.876855373382568, -4.869768142700195, -4.622581481933594, -4.402562618255615, -4.092719078063965, -2.828117609024048, -3.9533627033233643, -0.2358899861574173, -3.1777827739715576, -2.5318446159362793, -1.3887593746185303, -2.1124539375305176, -1.4459866285324097, -1.7588081359863281, -1.7998298406600952, -0.30428487062454224, -0.5691611170768738, -0.4985802173614502, -0.43533074855804443, 0.5450541377067566, 0.11029113829135895, 0.19009923934936523, -0.4886152446269989, -0.18446028232574463, -0.4187629222869873, -1.5536019802093506, -2.9653985500335693, 2.498365879058838, 2.7798259258270264, 0.9705333709716797, 1.1337904930114746, 0.6324526071548462, 0.3723813593387604, -0.07711052149534225, 0.7339563965797424, 1.1786798238754272, 1.2679988145828247, 1.1593822240829468, 1.248747706413269, 0.8570224642753601, 0.567720890045166, 1.7699248790740967, 1.1136770248413086, 0.4028712809085846, 1.7166199684143066, 1.3062156438827515, -0.29003605246543884, 0.14070101082324982, 0.1720196008682251, 0.16210295259952545, -0.01785578764975071, 0.6895759701728821, 0.669114351272583, 0.38231611251831055, -0.007667523343116045, -0.07830577343702316, 0.02412707358598709, 0.7351228594779968, 1.5381264686584473, 0.7669504284858704, 1.0226385593414307, 0.2835524082183838, 1.1326733827590942, 1.7671173810958862, 2.059242010116577, 0.0], [0.0, -10.136819839477539, -8.897462844848633, -7.878287315368652, -8.461352348327637, -7.93264627456665, -8.317527770996094, -7.379741668701172, -6.709232330322266, -5.61134147644043, -7.050663471221924, -5.905937671661377, -5.92866325378418, -4.827110767364502, -6.013897895812988, -5.036368370056152, -3.6335031986236572, -4.399839401245117, -2.6803855895996094, -2.246364116668701, -2.9683127403259277, -2.477151393890381, -2.8816399574279785, -1.9496015310287476, -1.887799859046936, -1.5700502395629883, 0.4659727215766907, -0.8319332599639893, -1.1176046133041382, -0.8245415091514587, 0.20605945587158203, 0.05565467104315758, 0.378679096698761, -0.3557540476322174, 0.09791958332061768, 0.5587745308876038, -1.332664132118225, 0.0, -0.026565980166196823, 0.14090529084205627, -1.3358961343765259, 0.3994846045970917, 0.6253221035003662, 1.0487664937973022, 1.5072615146636963, 1.812864899635315, 0.9513683319091797, 0.9240642786026001, 1.2193236351013184, 2.3418235778808594, 0.13359864056110382, 0.636600911617279, 0.8820322751998901, 0.8118506669998169, -0.7989208102226257, 1.5511873960494995, 0.9554499983787537, 1.2856144905090332, 0.650983989238739, 0.18679583072662354, 0.48828834295272827, 0.0471714623272419, 0.0008184504113160074, 0.8468596935272217, -0.43622535467147827, -0.21251024305820465, 0.6641951203346252, 0.6123344898223877, -0.04855976998806, -0.18032392859458923, 1.0094013214111328, 0.3517707884311676, 0.39818134903907776, 0.27136391401290894, 0.935727059841156, 2.2083606719970703, 1.5221610069274902, 0.0, -0.0, -10.136819839477539, -8.897462844848633, -7.878287315368652, -8.461352348327637, -7.93264627456665, -8.317527770996094, -7.379741668701172, -6.709232330322266, -5.61134147644043, -7.050663471221924, -5.905937671661377, -5.92866325378418, -4.827110767364502, -6.013897895812988, -5.036368370056152, -3.6335031986236572, -4.399839401245117, -2.6803855895996094, -2.246364116668701, -2.9683127403259277, -2.477151393890381, -2.8816399574279785, -1.9496015310287476, -1.887799859046936, -1.5700502395629883, 0.4659727215766907, -0.8319332599639893, -1.1176046133041382, -0.8245415091514587, 0.20605945587158203, 0.05565467104315758, 0.378679096698761, -0.3557540476322174, 0.09791958332061768, 0.5587745308876038, -1.332664132118225, -0.0, -0.026565980166196823, 0.14090529084205627, -1.3358961343765259, 0.3994846045970917, 0.6253221035003662, 1.0487664937973022, 1.5072615146636963, 1.812864899635315, 0.9513683319091797, 0.9240642786026001, 1.2193236351013184, 2.3418235778808594, 0.13359864056110382, 0.636600911617279, 0.8820322751998901, 0.8118506669998169, -0.7989208102226257, 1.5511873960494995, 0.9554499983787537, 1.2856144905090332, 0.650983989238739, 0.18679583072662354, 0.48828834295272827, 0.0471714623272419, 0.0008184504113160074, 0.8468596935272217, -0.43622535467147827, -0.21251024305820465, 0.6641951203346252, 0.6123344898223877, -0.04855976998806, -0.18032392859458923, 1.0094013214111328, 0.3517707884311676, 0.39818134903907776, 0.27136391401290894, 0.935727059841156, 2.2083606719970703, 1.5221610069274902, 0.0], [0.0, -9.833714485168457, -9.196938514709473, -9.218600273132324, -8.441262245178223, -8.316243171691895, -7.9310832023620605, -9.448524475097656, -8.15116024017334, -6.465439319610596, -5.67205810546875, -6.835117340087891, -6.18020486831665, -5.466098785400391, -5.412742614746094, -5.985762596130371, -3.992419481277466, -3.6380455493927, -3.68023681640625, -4.62846565246582, -2.3852224349975586, -1.06187105178833, -2.5420737266540527, -2.668907880783081, -1.648040533065796, -1.0241241455078125, -1.4455256462097168, -0.7455695867538452, 0.3950282037258148, -3.1627326011657715, -0.35476189851760864, -0.32650473713874817, -0.6480748653411865, -0.30841055512428284, 0.1560503989458084, -0.6418483853340149, -2.137965679168701, 0.0, 0.0, 3.2747623920440674, -1.0114537477493286, 0.06453216075897217, 0.8964623808860779, 1.1697429418563843, 0.47596511244773865, 0.5912217497825623, 0.7284075617790222, -0.34108322858810425, 0.7191789150238037, 1.7368032932281494, 0.12955480813980103, 1.0916301012039185, -0.3824986219406128, 1.0309840440750122, 1.811568260192871, 1.9518126249313354, 1.0438239574432373, 1.1422984600067139, 0.43981707096099854, -0.3742195665836334, 0.19724668562412262, -0.07424217462539673, -0.1638736128807068, -0.5208693742752075, -1.718004584312439, 0.14974096417427063, 0.7715170979499817, -1.2114300727844238, -1.0572490692138672, -0.9986864328384399, 0.1161203384399414, 0.5050556063652039, 0.429189532995224, -0.004800358787178993, 0.8124225735664368, 1.2785441875457764, 2.074925184249878, 0.0, -0.0, -9.833714485168457, -9.196938514709473, -9.218600273132324, -8.441262245178223, -8.316243171691895, -7.9310832023620605, -9.448524475097656, -8.15116024017334, -6.465439319610596, -5.67205810546875, -6.835117340087891, -6.18020486831665, -5.466098785400391, -5.412742614746094, -5.985762596130371, -3.992419481277466, -3.6380455493927, -3.68023681640625, -4.62846565246582, -2.3852224349975586, -1.06187105178833, -2.5420737266540527, -2.668907880783081, -1.648040533065796, -1.0241241455078125, -1.4455256462097168, -0.7455695867538452, 0.3950282037258148, -3.1627326011657715, -0.35476189851760864, -0.32650473713874817, -0.6480748653411865, -0.30841055512428284, 0.1560503989458084, -0.6418483853340149, -2.137965679168701, -0.0, -0.0, 3.2747623920440674, -1.0114537477493286, 0.06453216075897217, 0.8964623808860779, 1.1697429418563843, 0.47596511244773865, 0.5912217497825623, 0.7284075617790222, -0.34108322858810425, 0.7191789150238037, 1.7368032932281494, 0.12955480813980103, 1.0916301012039185, -0.3824986219406128, 1.0309840440750122, 1.811568260192871, 1.9518126249313354, 1.0438239574432373, 1.1422984600067139, 0.43981707096099854, -0.3742195665836334, 0.19724668562412262, -0.07424217462539673, -0.1638736128807068, -0.5208693742752075, -1.718004584312439, 0.14974096417427063, 0.7715170979499817, -1.2114300727844238, -1.0572490692138672, -0.9986864328384399, 0.1161203384399414, 0.5050556063652039, 0.429189532995224, -0.004800358787178993, 0.8124225735664368, 1.2785441875457764, 2.074925184249878, 0.0], [0.0, -10.4456148147583, -8.977989196777344, -8.77120304107666, -8.647244453430176, -8.687630653381348, -8.552826881408691, -7.862881183624268, -7.534922122955322, -8.0594482421875, -6.9107184410095215, -6.923093318939209, -7.15509557723999, -6.030052185058594, -4.380392551422119, -4.871795177459717, -4.490154266357422, -5.14724588394165, -3.4770123958587646, -3.603330612182617, -3.5659356117248535, -2.74086856842041, -3.129326820373535, -3.160243034362793, -3.3540899753570557, -0.6468214988708496, -1.7149661779403687, -1.3201825618743896, 0.630212664604187, -2.658230781555176, -1.7812750339508057, -1.0853662490844727, -0.6253373622894287, 1.307051658630371, 0.26536697149276733, -0.5288432240486145, -1.8808218240737915, 0.0, 0.0, 3.081798553466797, -0.9904680848121643, 0.741804301738739, 0.9204742908477783, 0.9393903017044067, 0.8447622656822205, 1.266479730606079, 0.889797031879425, 1.3750287294387817, 0.9773361682891846, 1.5503877401351929, 0.2951134145259857, 1.4696396589279175, 0.34110233187675476, 1.7417397499084473, 0.7957845330238342, 0.6056123375892639, -0.11277337372303009, 3.0073652267456055, 1.007263422012329, 0.4912174642086029, 0.7011253833770752, 0.4101687967777252, -0.6972717642784119, -0.5246825814247131, -0.002472424181178212, -0.3106701076030731, 0.22990979254245758, -0.49301382899284363, -0.3022876977920532, -0.30047807097435, -0.4146403968334198, -0.12967684864997864, -0.32902762293815613, 0.7391899824142456, 1.103520154953003, 0.6487643718719482, 0.46474769711494446, 0.0, -0.0, -10.4456148147583, -8.977989196777344, -8.77120304107666, -8.647244453430176, -8.687630653381348, -8.552826881408691, -7.862881183624268, -7.534922122955322, -8.0594482421875, -6.9107184410095215, -6.923093318939209, -7.15509557723999, -6.030052185058594, -4.380392551422119, -4.871795177459717, -4.490154266357422, -5.14724588394165, -3.4770123958587646, -3.603330612182617, -3.5659356117248535, -2.74086856842041, -3.129326820373535, -3.160243034362793, -3.3540899753570557, -0.6468214988708496, -1.7149661779403687, -1.3201825618743896, 0.630212664604187, -2.658230781555176, -1.7812750339508057, -1.0853662490844727, -0.6253373622894287, 1.307051658630371, 0.26536697149276733, -0.5288432240486145, -1.8808218240737915, -0.0, 0.0, 3.081798553466797, -0.9904680848121643, 0.741804301738739, 0.9204742908477783, 0.9393903017044067, 0.8447622656822205, 1.266479730606079, 0.889797031879425, 1.3750287294387817, 0.9773361682891846, 1.5503877401351929, 0.2951134145259857, 1.4696396589279175, 0.34110233187675476, 1.7417397499084473, 0.7957845330238342, 0.6056123375892639, -0.11277337372303009, 3.0073652267456055, 1.007263422012329, 0.4912174642086029, 0.7011253833770752, 0.4101687967777252, -0.6972717642784119, -0.5246825814247131, -0.002472424181178212, -0.3106701076030731, 0.22990979254245758, -0.49301382899284363, -0.3022876977920532, -0.30047807097435, -0.4146403968334198, -0.12967684864997864, -0.32902762293815613, 0.7391899824142456, 1.103520154953003, 0.6487643718719482, 0.46474769711494446, 0.0], [0.0, -10.555240631103516, -9.98664379119873, -9.110862731933594, -8.600171089172363, -9.30224323272705, -9.125929832458496, -7.860296726226807, -7.576468467712402, -6.01356840133667, -6.315981864929199, -6.454593181610107, -6.745857238769531, -6.092089653015137, -6.2195048332214355, -4.207541465759277, -5.23445987701416, -4.129881858825684, -3.9897654056549072, -4.244452476501465, -3.8776330947875977, -2.7838637828826904, -2.791240930557251, -2.117802619934082, -4.849300861358643, -2.3133280277252197, -1.1899374723434448, -1.4712669849395752, -1.6744487285614014, -1.898438572883606, -1.3889316320419312, -1.1942498683929443, -1.1369061470031738, 0.7710630893707275, 0.26782408356666565, 0.3369118273258209, -0.9054518342018127, -1.9788354635238647, 0.6128501892089844, 0.4158417880535126, -0.29553496837615967, 0.25274336338043213, 1.9800968170166016, -0.5545791983604431, 1.1797165870666504, 2.2707948684692383, 1.5097506046295166, 0.9832140207290649, 1.1703344583511353, -0.6480856537818909, 0.9019642472267151, 1.289635419845581, 1.464756727218628, 1.6140027046203613, 1.592498779296875, 0.45345011353492737, 0.851214587688446, 0.15947860479354858, 0.6348055601119995, -0.19658498466014862, 0.40705516934394836, 0.16357773542404175, 0.2514793574810028, -0.10761342942714691, 0.02615131251513958, -1.2281805276870728, -1.23395836353302, -0.05267604812979698, -0.00803852453827858, -0.7895553708076477, -0.5444060564041138, -1.380080223083496, -0.3116524815559387, -0.17253373563289642, 0.19551415741443634, -0.8236673474311829, 0.6104567646980286, 0.0, -0.0, -10.555240631103516, -9.98664379119873, -9.110862731933594, -8.600171089172363, -9.30224323272705, -9.125929832458496, -7.860296726226807, -7.576468467712402, -6.01356840133667, -6.315981864929199, -6.454593181610107, -6.745857238769531, -6.092089653015137, -6.2195048332214355, -4.207541465759277, -5.23445987701416, -4.129881858825684, -3.9897654056549072, -4.244452476501465, -3.8776330947875977, -2.7838637828826904, -2.791240930557251, -2.117802619934082, -4.849300861358643, -2.3133280277252197, -1.1899374723434448, -1.4712669849395752, -1.6744487285614014, -1.898438572883606, -1.3889316320419312, -1.1942498683929443, -1.1369061470031738, 0.7710630893707275, 0.26782408356666565, 0.3369118273258209, -0.9054518342018127, -1.9788354635238647, 0.6128501892089844, 0.4158417880535126, -0.29553496837615967, 0.25274336338043213, 1.9800968170166016, -0.5545791983604431, 1.1797165870666504, 2.2707948684692383, 1.5097506046295166, 0.9832140207290649, 1.1703344583511353, -0.6480856537818909, 0.9019642472267151, 1.289635419845581, 1.464756727218628, 1.6140027046203613, 1.592498779296875, 0.45345011353492737, 0.851214587688446, 0.15947860479354858, 0.6348055601119995, -0.19658498466014862, 0.40705516934394836, 0.16357773542404175, 0.2514793574810028, -0.10761342942714691, 0.02615131251513958, -1.2281805276870728, -1.23395836353302, -0.05267604812979698, -0.00803852453827858, -0.7895553708076477, -0.5444060564041138, -1.380080223083496, -0.3116524815559387, -0.17253373563289642, 0.19551415741443634, -0.8236673474311829, 0.6104567646980286, 0.0], [0.0, -10.883615493774414, -10.180562973022461, -9.851244926452637, -9.214366912841797, -8.702263832092285, -8.67883014678955, -9.191475868225098, -7.531099796295166, -8.934553146362305, -9.488117218017578, -6.993464946746826, -6.930294513702393, -6.86149263381958, -4.763411045074463, -4.799191951751709, -5.974635601043701, -4.332900047302246, -5.219178199768066, -5.312397003173828, -3.1678836345672607, -2.89070725440979, -2.0825157165527344, -3.8668718338012695, -1.1843997240066528, -2.8573062419891357, -0.9831629395484924, -1.310410976409912, -0.7885606288909912, -0.8914178609848022, -1.7253936529159546, -3.092108964920044, -0.9205524325370789, -0.5268946886062622, -0.3249891400337219, -0.11257045716047287, 0.984726071357727, 0.065743587911129, -0.10926833003759384, -0.6146105527877808, 0.41397562623023987, 0.8295994997024536, -0.31686049699783325, 0.1164359301328659, 0.49254733324050903, 1.6486222743988037, 1.7019931077957153, 0.36832886934280396, 1.408685326576233, 1.2848780155181885, 0.5366523265838623, 1.2991812229156494, 1.9904588460922241, 2.1674695014953613, 1.092345952987671, 1.1536595821380615, 1.2441068887710571, 0.7550954818725586, 0.30426228046417236, 1.2394957542419434, -0.6760580539703369, -0.3735916018486023, -0.6972247958183289, -1.2932710647583008, -1.0685456991195679, 0.021089600399136543, -0.6493546962738037, -0.8563332557678223, -0.8306612968444824, -1.858586072921753, -0.3043901026248932, -1.7193440198898315, -0.40903908014297485, -0.9379116296768188, -0.7203266620635986, 0.24104951322078705, -1.3523880243301392, 0.0, -0.0, -10.883615493774414, -10.180562973022461, -9.851244926452637, -9.214366912841797, -8.702263832092285, -8.67883014678955, -9.191475868225098, -7.531099796295166, -8.934553146362305, -9.488117218017578, -6.993464946746826, -6.930294513702393, -6.86149263381958, -4.763411045074463, -4.799191951751709, -5.974635601043701, -4.332900047302246, -5.219178199768066, -5.312397003173828, -3.1678836345672607, -2.89070725440979, -2.0825157165527344, -3.8668718338012695, -1.1843997240066528, -2.8573062419891357, -0.9831629395484924, -1.310410976409912, -0.7885606288909912, -0.8914178609848022, -1.7253936529159546, -3.092108964920044, -0.9205524325370789, -0.5268946886062622, -0.3249891400337219, -0.11257045716047287, 0.984726071357727, 0.065743587911129, -0.10926833003759384, -0.6146105527877808, 0.41397562623023987, 0.8295994997024536, -0.31686049699783325, 0.1164359301328659, 0.49254733324050903, 1.6486222743988037, 1.7019931077957153, 0.36832886934280396, 1.408685326576233, 1.2848780155181885, 0.5366523265838623, 1.2991812229156494, 1.9904588460922241, 2.1674695014953613, 1.092345952987671, 1.1536595821380615, 1.2441068887710571, 0.7550954818725586, 0.30426228046417236, 1.2394957542419434, -0.6760580539703369, -0.3735916018486023, -0.6972247958183289, -1.2932710647583008, -1.0685456991195679, 0.021089600399136543, -0.6493546962738037, -0.8563332557678223, -0.8306612968444824, -1.858586072921753, -0.3043901026248932, -1.7193440198898315, -0.40903908014297485, -0.9379116296768188, -0.7203266620635986, 0.24104951322078705, -1.3523880243301392, -0.0], [0.0, -10.909398078918457, -11.01396369934082, -10.275381088256836, -9.953943252563477, -10.418346405029297, -9.555816650390625, -8.8717622756958, -8.700220108032227, -7.049933433532715, -8.265746116638184, -7.494716644287109, -6.874701499938965, -6.296543598175049, -5.784203052520752, -5.84604024887085, -5.025622844696045, -5.301510810852051, -7.380345344543457, -3.4518587589263916, -2.1529808044433594, -2.744715452194214, -2.5145580768585205, -2.02653431892395, -1.187304139137268, -2.2984719276428223, -0.5310496091842651, -1.370945930480957, -1.0342442989349365, -0.11431865394115448, -1.65190589427948, -1.0615252256393433, 0.9446319937705994, -1.1041303873062134, -0.21006512641906738, -0.46996188163757324, -2.5119874477386475, 0.3856005072593689, 0.7414447665214539, -0.5597962737083435, 1.2161645889282227, 1.2236067056655884, 0.8026516437530518, 0.761258602142334, -0.05825340747833252, 1.4073820114135742, 2.250666618347168, -0.28216880559921265, 1.6099488735198975, 1.662688136100769, 2.050074338912964, 1.536393404006958, 0.7795931100845337, -0.9658873081207275, 2.2646565437316895, 0.7672006487846375, 0.7985543608665466, 0.10963606834411621, 0.39836859703063965, 0.0803302749991417, -0.1876278966665268, -0.010325388982892036, -0.6069923639297485, -0.590794026851654, -0.8757148385047913, -1.4767979383468628, -0.313803106546402, 0.6819114685058594, 1.6847490072250366, -0.9566337466239929, -0.408416748046875, -3.053856372833252, 0.3289112448692322, -1.2511565685272217, -0.36778563261032104, 0.18119795620441437, -1.0836529731750488, 0.0, -0.0, -10.909398078918457, -11.01396369934082, -10.275381088256836, -9.953943252563477, -10.418346405029297, -9.555816650390625, -8.8717622756958, -8.700220108032227, -7.049933433532715, -8.265746116638184, -7.494716644287109, -6.874701499938965, -6.296543598175049, -5.784203052520752, -5.84604024887085, -5.025622844696045, -5.301510810852051, -7.380345344543457, -3.4518587589263916, -2.1529808044433594, -2.744715452194214, -2.5145580768585205, -2.02653431892395, -1.187304139137268, -2.2984719276428223, -0.5310496091842651, -1.370945930480957, -1.0342442989349365, -0.11431865394115448, -1.65190589427948, -1.0615252256393433, 0.9446319937705994, -1.1041303873062134, -0.21006512641906738, -0.46996188163757324, -2.5119874477386475, 0.3856005072593689, 0.7414447665214539, -0.5597962737083435, 1.2161645889282227, 1.2236067056655884, 0.8026516437530518, 0.761258602142334, -0.05825340747833252, 1.4073820114135742, 2.250666618347168, -0.28216880559921265, 1.6099488735198975, 1.662688136100769, 2.050074338912964, 1.536393404006958, 0.7795931100845337, -0.9658873081207275, 2.2646565437316895, 0.7672006487846375, 0.7985543608665466, 0.10963606834411621, 0.39836859703063965, 0.0803302749991417, -0.1876278966665268, -0.010325388982892036, -0.6069923639297485, -0.590794026851654, -0.8757148385047913, -1.4767979383468628, -0.313803106546402, 0.6819114685058594, 1.6847490072250366, -0.9566337466239929, -0.408416748046875, -3.053856372833252, 0.3289112448692322, -1.2511565685272217, -0.36778563261032104, 0.18119795620441437, -1.0836529731750488, -0.0], [0.0, -11.695696830749512, -11.463669776916504, -10.744399070739746, -10.366107940673828, -10.336880683898926, -9.737604141235352, -9.011043548583984, -8.738097190856934, -8.256186485290527, -8.157196998596191, -7.13135290145874, -6.7523369789123535, -6.553569793701172, -6.5378570556640625, -5.321138858795166, -5.343533992767334, -5.275467395782471, -5.3166093826293945, -3.176340341567993, -3.663337230682373, -4.213033676147461, -2.902818202972412, -3.4106101989746094, -3.400996446609497, -0.452566534280777, -1.736948847770691, -1.5854681730270386, -0.10329820960760117, -0.729051411151886, -1.241449236869812, -1.8966890573501587, -2.446110248565674, -0.664045512676239, -0.8972581624984741, 0.25209760665893555, 0.3039639890193939, 0.9752411246299744, 0.09944534301757812, 0.37832316756248474, 1.0843913555145264, 1.035998821258545, 0.4888988137245178, 0.6218763589859009, 1.1613253355026245, 0.3161536157131195, -0.04629962891340256, 1.195222020149231, 1.492781639099121, -0.11961585283279419, 0.7555342316627502, 1.3096275329589844, 1.2289214134216309, 0.5774746537208557, 0.8047409653663635, 0.41406065225601196, 0.06462843716144562, 0.5457844734191895, 0.7248300313949585, 0.5360128879547119, -0.4459526538848877, 0.5189996361732483, 0.12377563863992691, -1.4736982583999634, -0.1478865146636963, -0.14485125243663788, -1.3187894821166992, -0.6995912790298462, -0.3975052237510681, -1.7937570810317993, -1.4174058437347412, -0.3624664545059204, -0.9912862777709961, -0.47135740518569946, -0.42329466342926025, -1.9601856470108032, -1.911778211593628, 0.0, -0.0, -11.695696830749512, -11.463669776916504, -10.744399070739746, -10.366107940673828, -10.336880683898926, -9.737604141235352, -9.011043548583984, -8.738097190856934, -8.256186485290527, -8.157196998596191, -7.13135290145874, -6.7523369789123535, -6.553569793701172, -6.5378570556640625, -5.321138858795166, -5.343533992767334, -5.275467395782471, -5.3166093826293945, -3.176340341567993, -3.663337230682373, -4.213033676147461, -2.902818202972412, -3.4106101989746094, -3.400996446609497, -0.452566534280777, -1.736948847770691, -1.5854681730270386, -0.10329820960760117, -0.729051411151886, -1.241449236869812, -1.8966890573501587, -2.446110248565674, -0.664045512676239, -0.8972581624984741, 0.25209760665893555, 0.3039639890193939, 0.9752411246299744, 0.09944534301757812, 0.37832316756248474, 1.0843913555145264, 1.035998821258545, 0.4888988137245178, 0.6218763589859009, 1.1613253355026245, 0.3161536157131195, -0.04629962891340256, 1.195222020149231, 1.492781639099121, -0.11961585283279419, 0.7555342316627502, 1.3096275329589844, 1.2289214134216309, 0.5774746537208557, 0.8047409653663635, 0.41406065225601196, 0.06462843716144562, 0.5457844734191895, 0.7248300313949585, 0.5360128879547119, -0.4459526538848877, 0.5189996361732483, 0.12377563863992691, -1.4736982583999634, -0.1478865146636963, -0.14485125243663788, -1.3187894821166992, -0.6995912790298462, -0.3975052237510681, -1.7937570810317993, -1.4174058437347412, -0.3624664545059204, -0.9912862777709961, -0.47135740518569946, -0.42329466342926025, -1.9601856470108032, -1.911778211593628, -0.0], [0.0, -12.274615287780762, -10.896611213684082, -10.693940162658691, -10.31112003326416, -10.180350303649902, -9.822279930114746, -8.871525764465332, -9.250659942626953, -8.889609336853027, -8.89151668548584, -7.864543914794922, -7.076385974884033, -7.635634422302246, -6.507740020751953, -6.414330005645752, -5.9764580726623535, -5.380906581878662, -5.1127471923828125, -0.8628880977630615, -2.9784631729125977, -2.4752323627471924, -2.0736851692199707, -2.4763400554656982, -2.389580249786377, -2.3069357872009277, -1.6986218690872192, -1.7000335454940796, -2.2539706230163574, -0.3207324147224426, -1.4376497268676758, -0.15595273673534393, -0.7303807139396667, -2.9563405513763428, -0.7709134817123413, 0.418674111366272, -0.4796803891658783, 0.0021770333405584097, -0.48111072182655334, 0.6183478832244873, 0.8108823895454407, 0.36447495222091675, 0.2167535126209259, -0.15025882422924042, 0.03702571988105774, 0.7381368279457092, 1.1419521570205688, 0.6722484230995178, 1.1911190748214722, 0.33959925174713135, 0.851201057434082, -0.1657370626926422, 1.4002959728240967, 1.3509849309921265, 1.1569136381149292, 1.0705575942993164, -0.7631101608276367, 0.10449738055467606, 1.0422641038894653, 0.2025807499885559, 0.16718517243862152, -0.0783521980047226, -0.17790472507476807, -0.017002588137984276, -0.865485429763794, -0.955158531665802, -2.2737066745758057, -0.8451093435287476, -0.9508107304573059, -1.4543148279190063, -0.18746048212051392, -0.9544256925582886, -0.9825191497802734, -0.5081082582473755, -1.5920182466506958, -1.227997064590454, -2.1647322177886963, 0.0, -0.0, -12.274615287780762, -10.896611213684082, -10.693940162658691, -10.31112003326416, -10.180350303649902, -9.822279930114746, -8.871525764465332, -9.250659942626953, -8.889609336853027, -8.89151668548584, -7.864543914794922, -7.076385974884033, -7.635634422302246, -6.507740020751953, -6.414330005645752, -5.9764580726623535, -5.380906581878662, -5.1127471923828125, -0.8628880977630615, -2.9784631729125977, -2.4752323627471924, -2.0736851692199707, -2.4763400554656982, -2.389580249786377, -2.3069357872009277, -1.6986218690872192, -1.7000335454940796, -2.2539706230163574, -0.3207324147224426, -1.4376497268676758, -0.15595273673534393, -0.7303807139396667, -2.9563405513763428, -0.7709134817123413, 0.418674111366272, -0.4796803891658783, 0.0021770333405584097, -0.48111072182655334, 0.6183478832244873, 0.8108823895454407, 0.36447495222091675, 0.2167535126209259, -0.15025882422924042, 0.03702571988105774, 0.7381368279457092, 1.1419521570205688, 0.6722484230995178, 1.1911190748214722, 0.33959925174713135, 0.851201057434082, -0.1657370626926422, 1.4002959728240967, 1.3509849309921265, 1.1569136381149292, 1.0705575942993164, -0.7631101608276367, 0.10449738055467606, 1.0422641038894653, 0.2025807499885559, 0.16718517243862152, -0.0783521980047226, -0.17790472507476807, -0.017002588137984276, -0.865485429763794, -0.955158531665802, -2.2737066745758057, -0.8451093435287476, -0.9508107304573059, -1.4543148279190063, -0.18746048212051392, -0.9544256925582886, -0.9825191497802734, -0.5081082582473755, -1.5920182466506958, -1.227997064590454, -2.1647322177886963, -0.0], [0.0, -12.776845932006836, -11.313175201416016, -11.230849266052246, -10.637460708618164, -10.447127342224121, -10.232192039489746, -9.25648021697998, -8.413544654846191, -8.587971687316895, -8.451164245605469, -8.007795333862305, -7.791425704956055, -6.767348289489746, -7.055093765258789, -5.616142272949219, -7.209200859069824, -6.0487470626831055, -4.012303352355957, -3.6688506603240967, -4.793848037719727, -3.8708221912384033, -3.2089765071868896, -2.625741481781006, -2.580127239227295, -2.5919899940490723, -1.6803779602050781, -2.014866352081299, -1.8953604698181152, -0.20326045155525208, -0.35112664103507996, -1.2063894271850586, -0.5825419425964355, -0.4305560886859894, -0.14165572822093964, -0.45871585607528687, -0.325533002614975, 0.22815413773059845, 0.8538400530815125, -0.2010667622089386, 0.11777282506227493, -0.10743052512407303, 2.050215005874634, -1.3061498403549194, -0.556414783000946, 0.4617086946964264, 0.48635610938072205, 1.251570224761963, 0.09246009588241577, 0.7014337778091431, 0.5690679550170898, 1.3431904315948486, 0.8832880258560181, 2.832340955734253, -2.3808228969573975, -0.22076678276062012, -1.1992316246032715, 0.8970253467559814, -1.0307389497756958, 0.4784926772117615, -0.09584087133407593, -0.44310232996940613, -0.4134027659893036, -0.206907719373703, -0.8188785314559937, -1.250122308731079, -1.5081712007522583, -2.441195011138916, -0.9283289909362793, -1.0058598518371582, -0.4465867280960083, -0.771504282951355, -0.5775882601737976, -1.150098443031311, -0.1530432105064392, -1.8258693218231201, -3.0588746070861816, 0.0, -0.0, -12.776845932006836, -11.313175201416016, -11.230849266052246, -10.637460708618164, -10.447127342224121, -10.232192039489746, -9.25648021697998, -8.413544654846191, -8.587971687316895, -8.451164245605469, -8.007795333862305, -7.791425704956055, -6.767348289489746, -7.055093765258789, -5.616142272949219, -7.209200859069824, -6.0487470626831055, -4.012303352355957, -3.6688506603240967, -4.793848037719727, -3.8708221912384033, -3.2089765071868896, -2.625741481781006, -2.580127239227295, -2.5919899940490723, -1.6803779602050781, -2.014866352081299, -1.8953604698181152, -0.20326045155525208, -0.35112664103507996, -1.2063894271850586, -0.5825419425964355, -0.4305560886859894, -0.14165572822093964, -0.45871585607528687, -0.325533002614975, 0.22815413773059845, 0.8538400530815125, -0.2010667622089386, 0.11777282506227493, -0.10743052512407303, 2.050215005874634, -1.3061498403549194, -0.556414783000946, 0.4617086946964264, 0.48635610938072205, 1.251570224761963, 0.09246009588241577, 0.7014337778091431, 0.5690679550170898, 1.3431904315948486, 0.8832880258560181, 2.832340955734253, -2.3808228969573975, -0.22076678276062012, -1.1992316246032715, 0.8970253467559814, -1.0307389497756958, 0.4784926772117615, -0.09584087133407593, -0.44310232996940613, -0.4134027659893036, -0.206907719373703, -0.8188785314559937, -1.250122308731079, -1.5081712007522583, -2.441195011138916, -0.9283289909362793, -1.0058598518371582, -0.4465867280960083, -0.771504282951355, -0.5775882601737976, -1.150098443031311, -0.1530432105064392, -1.8258693218231201, -3.0588746070861816, -0.0], [0.0, -12.831671714782715, -12.479881286621094, -11.235773086547852, -10.898637771606445, -10.792217254638672, -10.755148887634277, -9.964109420776367, -9.655848503112793, -8.760916709899902, -8.51331901550293, -7.91392707824707, -7.664203643798828, -8.070901870727539, -6.390275955200195, -5.418276786804199, -4.471097469329834, -6.3844313621521, -4.784177303314209, -4.860266208648682, -4.99131965637207, -3.2912960052490234, -5.888683319091797, -2.236708641052246, -3.522310495376587, -2.9301929473876953, -2.767167091369629, -1.1734578609466553, -1.7874726057052612, -1.4260177612304688, -0.5119543075561523, -2.215151071548462, -0.48338863253593445, -0.7347423434257507, -0.24398399889469147, -0.11287371814250946, 0.3854416012763977, -2.0086910724639893, -0.17324520647525787, 0.19676460325717926, -0.3448942303657532, 0.01515169907361269, -0.5723419189453125, 0.15243417024612427, -0.18745291233062744, 1.3155479431152344, 1.770461082458496, 0.22559064626693726, 2.643679141998291, 0.5072770714759827, 0.9504683017730713, 0.3770478367805481, 0.5821134448051453, 0.10910900682210922, -0.8533703088760376, 0.8616052865982056, -1.5096614360809326, -0.6404730081558228, 0.7009344696998596, -1.4475727081298828, -0.6087406873703003, -0.4791881740093231, 0.14602790772914886, -0.3978762626647949, -1.596514344215393, -1.9263747930526733, -1.324653148651123, -0.6757775545120239, -0.9614782929420471, -1.1937617063522339, -1.4981536865234375, -1.841953158378601, -0.7071272730827332, -0.8586384654045105, -0.24773676693439484, -2.036013603210449, -1.1137571334838867, 0.0, -0.0, -12.831671714782715, -12.479881286621094, -11.235773086547852, -10.898637771606445, -10.792217254638672, -10.755148887634277, -9.964109420776367, -9.655848503112793, -8.760916709899902, -8.51331901550293, -7.91392707824707, -7.664203643798828, -8.070901870727539, -6.390275955200195, -5.418276786804199, -4.471097469329834, -6.3844313621521, -4.784177303314209, -4.860266208648682, -4.99131965637207, -3.2912960052490234, -5.888683319091797, -2.236708641052246, -3.522310495376587, -2.9301929473876953, -2.767167091369629, -1.1734578609466553, -1.7874726057052612, -1.4260177612304688, -0.5119543075561523, -2.215151071548462, -0.48338863253593445, -0.7347423434257507, -0.24398399889469147, -0.11287371814250946, 0.3854416012763977, -2.0086910724639893, -0.17324520647525787, 0.19676460325717926, -0.3448942303657532, 0.01515169907361269, -0.5723419189453125, 0.15243417024612427, -0.18745291233062744, 1.3155479431152344, 1.770461082458496, 0.22559064626693726, 2.643679141998291, 0.5072770714759827, 0.9504683017730713, 0.3770478367805481, 0.5821134448051453, 0.10910900682210922, -0.8533703088760376, 0.8616052865982056, -1.5096614360809326, -0.6404730081558228, 0.7009344696998596, -1.4475727081298828, -0.6087406873703003, -0.4791881740093231, 0.14602790772914886, -0.3978762626647949, -1.596514344215393, -1.9263747930526733, -1.324653148651123, -0.6757775545120239, -0.9614782929420471, -1.1937617063522339, -1.4981536865234375, -1.841953158378601, -0.7071272730827332, -0.8586384654045105, -0.24773676693439484, -2.036013603210449, -1.1137571334838867, -0.0], [0.0, -12.632607460021973, -12.515970230102539, -11.180327415466309, -11.344082832336426, -11.102730751037598, -10.02479362487793, -10.122154235839844, -9.703638076782227, -9.550291061401367, -8.569978713989258, -9.028881072998047, -7.502635955810547, -6.823095321655273, -7.375772953033447, -7.01010274887085, -5.535181045532227, -5.438780307769775, -4.268815040588379, -4.8876848220825195, -4.895306587219238, -4.218754768371582, -4.884385585784912, -3.637403726577759, -2.6729602813720703, -2.819875478744507, -1.3847167491912842, -1.349435806274414, -1.7427153587341309, -1.0374414920806885, -1.2093164920806885, -0.4651516079902649, -0.8672134280204773, -0.9294294118881226, -0.22097247838974, -1.3580394983291626, -1.1204403638839722, -0.9636873006820679, -0.10462278872728348, 0.4074421525001526, 0.1779804527759552, -0.2524004280567169, -0.15403664112091064, -0.29921963810920715, 0.4640624225139618, 1.4229129552841187, -0.7257639765739441, 0.09385691583156586, 0.46217548847198486, 1.1457819938659668, 1.0517524480819702, 1.2870126962661743, 1.0257930755615234, 0.5739874839782715, -0.21005761623382568, -0.6929973363876343, 0.4577156901359558, 0.3140712082386017, 0.45643776655197144, -0.26129084825515747, -0.6251753568649292, -0.27960553765296936, -1.2694288492202759, -0.43875688314437866, -0.7588502764701843, -1.3486509323120117, -0.7536067962646484, -1.0911157131195068, -1.1448067426681519, -1.132887363433838, -0.8848549723625183, -0.8623877763748169, -0.6876917481422424, -0.6614776253700256, -1.8885177373886108, -2.342664957046509, -2.313068389892578, 0.0, -0.0, -12.632607460021973, -12.515970230102539, -11.180327415466309, -11.344082832336426, -11.102730751037598, -10.02479362487793, -10.122154235839844, -9.703638076782227, -9.550291061401367, -8.569978713989258, -9.028881072998047, -7.502635955810547, -6.823095321655273, -7.375772953033447, -7.01010274887085, -5.535181045532227, -5.438780307769775, -4.268815040588379, -4.8876848220825195, -4.895306587219238, -4.218754768371582, -4.884385585784912, -3.637403726577759, -2.6729602813720703, -2.819875478744507, -1.3847167491912842, -1.349435806274414, -1.7427153587341309, -1.0374414920806885, -1.2093164920806885, -0.4651516079902649, -0.8672134280204773, -0.9294294118881226, -0.22097247838974, -1.3580394983291626, -1.1204403638839722, -0.9636873006820679, -0.10462278872728348, 0.4074421525001526, 0.1779804527759552, -0.2524004280567169, -0.15403664112091064, -0.29921963810920715, 0.4640624225139618, 1.4229129552841187, -0.7257639765739441, 0.09385691583156586, 0.46217548847198486, 1.1457819938659668, 1.0517524480819702, 1.2870126962661743, 1.0257930755615234, 0.5739874839782715, -0.21005761623382568, -0.6929973363876343, 0.4577156901359558, 0.3140712082386017, 0.45643776655197144, -0.26129084825515747, -0.6251753568649292, -0.27960553765296936, -1.2694288492202759, -0.43875688314437866, -0.7588502764701843, -1.3486509323120117, -0.7536067962646484, -1.0911157131195068, -1.1448067426681519, -1.132887363433838, -0.8848549723625183, -0.8623877763748169, -0.6876917481422424, -0.6614776253700256, -1.8885177373886108, -2.342664957046509, -2.313068389892578, -0.0], [0.0, -12.661757469177246, -12.307416915893555, -11.623400688171387, -11.192954063415527, -10.812143325805664, -10.39254379272461, -9.977736473083496, -9.57789421081543, -9.069209098815918, -8.665392875671387, -7.7419586181640625, -7.869868755340576, -8.15535831451416, -7.774885654449463, -6.4625020027160645, -6.642788887023926, -6.789346694946289, -5.186251640319824, -4.577522277832031, -4.3056464195251465, -3.7443196773529053, -3.002197027206421, -2.071031332015991, -1.5450633764266968, -1.1293736696243286, -3.5546228885650635, -2.65089750289917, -1.85776686668396, -1.0189776420593262, -0.859263002872467, -1.0147511959075928, -0.6751881241798401, -1.308444619178772, -0.12839071452617645, -3.2792415618896484, -2.1575064659118652, 1.210755705833435, -0.18073208630084991, 0.4434038996696472, 0.11069062352180481, 0.0613473616540432, 0.0659898892045021, -0.877627968788147, -0.4233064651489258, 0.06630641967058182, -0.6505231857299805, 0.31711050868034363, 1.5951119661331177, 0.6721630096435547, 0.9640344381332397, 0.394705206155777, 1.0113508701324463, -0.3705649673938751, -0.6791608333587646, 1.414703369140625, 1.1987056732177734, -1.6474494934082031, 1.3918651342391968, 1.1333773136138916, -0.019130347296595573, -0.7233789563179016, -1.0691919326782227, -0.5563709735870361, -0.966382622718811, 0.15347683429718018, -0.6892157793045044, 0.1171722337603569, -0.6955095529556274, -1.0368399620056152, -1.6549463272094727, -1.8864586353302002, -0.9698970317840576, -1.3178638219833374, -1.3665893077850342, -1.8483322858810425, 0.9112012982368469, 0.0, -0.0, -12.661757469177246, -12.307416915893555, -11.623400688171387, -11.192954063415527, -10.812143325805664, -10.39254379272461, -9.977736473083496, -9.57789421081543, -9.069209098815918, -8.665392875671387, -7.7419586181640625, -7.869868755340576, -8.15535831451416, -7.774885654449463, -6.4625020027160645, -6.642788887023926, -6.789346694946289, -5.186251640319824, -4.577522277832031, -4.3056464195251465, -3.7443196773529053, -3.002197027206421, -2.071031332015991, -1.5450633764266968, -1.1293736696243286, -3.5546228885650635, -2.65089750289917, -1.85776686668396, -1.0189776420593262, -0.859263002872467, -1.0147511959075928, -0.6751881241798401, -1.308444619178772, -0.12839071452617645, -3.2792415618896484, -2.1575064659118652, 1.210755705833435, -0.18073208630084991, 0.4434038996696472, 0.11069062352180481, 0.0613473616540432, 0.0659898892045021, -0.877627968788147, -0.4233064651489258, 0.06630641967058182, -0.6505231857299805, 0.31711050868034363, 1.5951119661331177, 0.6721630096435547, 0.9640344381332397, 0.394705206155777, 1.0113508701324463, -0.3705649673938751, -0.6791608333587646, 1.414703369140625, 1.1987056732177734, -1.6474494934082031, 1.3918651342391968, 1.1333773136138916, -0.019130347296595573, -0.7233789563179016, -1.0691919326782227, -0.5563709735870361, -0.966382622718811, 0.15347683429718018, -0.6892157793045044, 0.1171722337603569, -0.6955095529556274, -1.0368399620056152, -1.6549463272094727, -1.8864586353302002, -0.9698970317840576, -1.3178638219833374, -1.3665893077850342, -1.8483322858810425, 0.9112012982368469, 0.0], [0.0, -12.458207130432129, -12.136289596557617, -11.321499824523926, -11.798750877380371, -11.360993385314941, -10.175756454467773, -10.973784446716309, -9.916768074035645, -9.117669105529785, -9.074297904968262, -9.18089485168457, -8.056682586669922, -7.712458610534668, -7.225943565368652, -6.5687689781188965, -6.733808517456055, -5.719622611999512, -5.601937294006348, -4.206361293792725, -4.9422831535339355, -4.671152591705322, -3.9667348861694336, -4.862096786499023, -3.27254581451416, -2.1850905418395996, -2.934290647506714, -2.2741031646728516, -2.000962257385254, -2.4801931381225586, -1.657780408859253, -1.6605422496795654, -1.8153808116912842, -1.1868176460266113, -0.8118404746055603, -2.6919074058532715, -0.5429245829582214, -0.913287878036499, -1.8611100912094116, -1.1959547996520996, -0.9205537438392639, -0.6002104878425598, -1.8147447109222412, -1.2580740451812744, -0.8846780061721802, -1.029075026512146, -0.3874523341655731, 0.518954336643219, 0.8314467072486877, 2.1739957332611084, 1.6251380443572998, 1.404132604598999, -0.11494272947311401, 0.14840030670166016, -0.6488639116287231, -0.5105549097061157, 0.2707693576812744, -0.14686281979084015, -0.4113602638244629, -0.0015269441064447165, 0.06378283351659775, -0.7388647794723511, -0.40556982159614563, -0.826268196105957, -0.39207324385643005, -1.05375075340271, -1.9905484914779663, -0.9396228790283203, -0.2813125252723694, -1.0196329355239868, -1.2937179803848267, -1.004369854927063, -1.1663836240768433, -1.632589340209961, -1.2701294422149658, -1.2186354398727417, 0.7013075351715088, 0.0, -0.0, -12.458207130432129, -12.136289596557617, -11.321499824523926, -11.798750877380371, -11.360993385314941, -10.175756454467773, -10.973784446716309, -9.916768074035645, -9.117669105529785, -9.074297904968262, -9.18089485168457, -8.056682586669922, -7.712458610534668, -7.225943565368652, -6.5687689781188965, -6.733808517456055, -5.719622611999512, -5.601937294006348, -4.206361293792725, -4.9422831535339355, -4.671152591705322, -3.9667348861694336, -4.862096786499023, -3.27254581451416, -2.1850905418395996, -2.934290647506714, -2.2741031646728516, -2.000962257385254, -2.4801931381225586, -1.657780408859253, -1.6605422496795654, -1.8153808116912842, -1.1868176460266113, -0.8118404746055603, -2.6919074058532715, -0.5429245829582214, -0.913287878036499, -1.8611100912094116, -1.1959547996520996, -0.9205537438392639, -0.6002104878425598, -1.8147447109222412, -1.2580740451812744, -0.8846780061721802, -1.029075026512146, -0.3874523341655731, 0.518954336643219, 0.8314467072486877, 2.1739957332611084, 1.6251380443572998, 1.404132604598999, -0.11494272947311401, 0.14840030670166016, -0.6488639116287231, -0.5105549097061157, 0.2707693576812744, -0.14686281979084015, -0.4113602638244629, -0.0015269441064447165, 0.06378283351659775, -0.7388647794723511, -0.40556982159614563, -0.826268196105957, -0.39207324385643005, -1.05375075340271, -1.9905484914779663, -0.9396228790283203, -0.2813125252723694, -1.0196329355239868, -1.2937179803848267, -1.004369854927063, -1.1663836240768433, -1.632589340209961, -1.2701294422149658, -1.2186354398727417, 0.7013075351715088, 0.0], [0.0, -12.363001823425293, -12.95641803741455, -11.869377136230469, -12.024255752563477, -11.56844711303711, -11.255590438842773, -10.113791465759277, -10.135568618774414, -10.25802230834961, -9.599100112915039, -9.070022583007812, -8.39678955078125, -7.91694974899292, -7.476864337921143, -6.930897235870361, -6.500012397766113, -6.02878475189209, -5.361215114593506, -4.652274131774902, -4.407120704650879, -4.416125774383545, -6.339036464691162, -4.536623954772949, -6.543206214904785, -2.4543509483337402, -2.6667864322662354, -2.5259878635406494, -2.626934766769409, -1.6552056074142456, -1.8268721103668213, -1.8344694375991821, -0.680869996547699, -1.4211636781692505, -1.1438512802124023, 0.8494090437889099, -2.274432897567749, -1.939956545829773, -0.2980816960334778, -1.0930269956588745, -1.0120536088943481, -1.0451054573059082, -0.2948821783065796, -0.41791588068008423, -0.415683388710022, -1.060166597366333, -0.341167688369751, -0.16698426008224487, 0.7649245262145996, 1.1346755027770996, -2.0692286491394043, -0.0747540220618248, 0.6913561820983887, -0.4709945321083069, 0.5507518649101257, -0.7269107103347778, -1.7744044065475464, 0.7424512505531311, 0.03748210519552231, -0.49378326535224915, -0.796777606010437, -1.1539149284362793, -0.518599271774292, -1.7495006322860718, -0.47146984934806824, -1.3072147369384766, -1.2856664657592773, -1.073683500289917, -1.2117891311645508, -0.8770172595977783, -1.453035593032837, -1.4346555471420288, -4.086390972137451, -1.4711285829544067, -1.2609857320785522, -1.058260202407837, 0.5931203365325928, 2.4963908195495605, -0.0, -12.363001823425293, -12.95641803741455, -11.869377136230469, -12.024255752563477, -11.56844711303711, -11.255590438842773, -10.113791465759277, -10.135568618774414, -10.25802230834961, -9.599100112915039, -9.070022583007812, -8.39678955078125, -7.91694974899292, -7.476864337921143, -6.930897235870361, -6.500012397766113, -6.02878475189209, -5.361215114593506, -4.652274131774902, -4.407120704650879, -4.416125774383545, -6.339036464691162, -4.536623954772949, -6.543206214904785, -2.4543509483337402, -2.6667864322662354, -2.5259878635406494, -2.626934766769409, -1.6552056074142456, -1.8268721103668213, -1.8344694375991821, -0.680869996547699, -1.4211636781692505, -1.1438512802124023, 0.8494090437889099, -2.274432897567749, -1.939956545829773, -0.2980816960334778, -1.0930269956588745, -1.0120536088943481, -1.0451054573059082, -0.2948821783065796, -0.41791588068008423, -0.415683388710022, -1.060166597366333, -0.341167688369751, -0.16698426008224487, 0.7649245262145996, 1.1346755027770996, -2.0692286491394043, -0.0747540220618248, 0.6913561820983887, -0.4709945321083069, 0.5507518649101257, -0.7269107103347778, -1.7744044065475464, 0.7424512505531311, 0.03748210519552231, -0.49378326535224915, -0.796777606010437, -1.1539149284362793, -0.518599271774292, -1.7495006322860718, -0.47146984934806824, -1.3072147369384766, -1.2856664657592773, -1.073683500289917, -1.2117891311645508, -0.8770172595977783, -1.453035593032837, -1.4346555471420288, -4.086390972137451, -1.4711285829544067, -1.2609857320785522, -1.058260202407837, 0.5931203365325928, 2.4963908195495605], [0.0, -11.530096054077148, -12.398545265197754, -12.205937385559082, -11.923259735107422, -11.335771560668945, -11.481691360473633, -10.342292785644531, -10.177634239196777, -9.25901985168457, -10.180503845214844, -9.24975299835205, -11.439191818237305, -8.314462661743164, -7.740914821624756, -7.150412559509277, -6.247800350189209, -6.115777492523193, -5.405343532562256, -6.135219573974609, -3.792372941970825, -4.694401741027832, -4.669911861419678, -4.974557876586914, -4.852594375610352, -3.4335825443267822, -3.7239882946014404, -2.687910318374634, -2.9267466068267822, -2.292783260345459, -2.1534037590026855, -1.910403847694397, -0.674992561340332, -2.757449150085449, -1.8281850814819336, -2.313359022140503, -1.7146666049957275, -1.7204827070236206, -1.1509475708007812, -1.9400583505630493, -1.3328500986099243, -1.5949498414993286, -1.2721693515777588, -1.6346312761306763, -1.1927117109298706, -1.0192590951919556, -3.2428946495056152, 0.44590845704078674, 0.2699691653251648, -0.06245420500636101, -0.38937246799468994, -0.5251660943031311, -1.4060906171798706, -0.46058064699172974, -1.8649799823760986, 0.6015956997871399, 0.8001885414123535, -1.0449836254119873, -0.5776930451393127, 1.9240202903747559, -0.11632709950208664, -1.077994465827942, -0.4566650390625, -2.598332643508911, 1.311462640762329, -1.305544376373291, -2.0782599449157715, -1.171461582183838, -1.461824893951416, -1.511557698249817, -1.1697371006011963, -1.720585823059082, -1.1028602123260498, -2.27156138420105, -1.4883897304534912, -0.7016134262084961, -0.03746114298701286, 0.0, -0.0, -11.530096054077148, -12.398545265197754, -12.205937385559082, -11.923259735107422, -11.335771560668945, -11.481691360473633, -10.342292785644531, -10.177634239196777, -9.25901985168457, -10.180503845214844, -9.24975299835205, -11.439191818237305, -8.314462661743164, -7.740914821624756, -7.150412559509277, -6.247800350189209, -6.115777492523193, -5.405343532562256, -6.135219573974609, -3.792372941970825, -4.694401741027832, -4.669911861419678, -4.974557876586914, -4.852594375610352, -3.4335825443267822, -3.7239882946014404, -2.687910318374634, -2.9267466068267822, -2.292783260345459, -2.1534037590026855, -1.910403847694397, -0.674992561340332, -2.757449150085449, -1.8281850814819336, -2.313359022140503, -1.7146666049957275, -1.7204827070236206, -1.1509475708007812, -1.9400583505630493, -1.3328500986099243, -1.5949498414993286, -1.2721693515777588, -1.6346312761306763, -1.1927117109298706, -1.0192590951919556, -3.2428946495056152, 0.44590845704078674, 0.2699691653251648, -0.06245420500636101, -0.38937246799468994, -0.5251660943031311, -1.4060906171798706, -0.46058064699172974, -1.8649799823760986, 0.6015956997871399, 0.8001885414123535, -1.0449836254119873, -0.5776930451393127, 1.9240202903747559, -0.11632709950208664, -1.077994465827942, -0.4566650390625, -2.598332643508911, 1.311462640762329, -1.305544376373291, -2.0782599449157715, -1.171461582183838, -1.461824893951416, -1.511557698249817, -1.1697371006011963, -1.720585823059082, -1.1028602123260498, -2.27156138420105, -1.4883897304534912, -0.7016134262084961, -0.03746114298701286, -0.0], [0.0, -10.260953903198242, -11.81768798828125, -13.812066078186035, -11.880380630493164, -12.548213958740234, -11.691327095031738, -10.602017402648926, -9.90652847290039, -10.044626235961914, -8.982598304748535, -8.322439193725586, -8.960871696472168, -8.97946834564209, -8.396830558776855, -7.544439792633057, -6.534801959991455, -6.166551113128662, -5.6887054443359375, -4.731666088104248, -5.9266204833984375, -4.951181411743164, -4.577739238739014, -5.815279960632324, -5.803754806518555, -4.820042610168457, -3.9017562866210938, -2.170422077178955, -4.256842613220215, -2.1041312217712402, -2.323688507080078, -3.02732515335083, -1.8281348943710327, -2.664341926574707, -1.2591713666915894, -1.0103763341903687, -3.0139780044555664, -2.7527146339416504, -2.911761522293091, -2.030707836151123, -2.292617082595825, -2.4591329097747803, -3.1678435802459717, -1.9391146898269653, -1.3526594638824463, -2.242150068283081, -3.567333936691284, 0.30549418926239014, -0.9508099555969238, 0.8017800450325012, -1.0798108577728271, -0.9740157127380371, -2.662505865097046, -1.5385231971740723, -1.5348905324935913, -1.4343088865280151, -0.8597519993782043, -1.3316650390625, -0.7504794597625732, -0.34721043705940247, 1.586362600326538, -0.08517082035541534, -1.435476541519165, -0.8519188165664673, 1.0100936889648438, -2.348667621612549, -1.0527030229568481, -1.4988597631454468, -0.7111402153968811, -1.100285291671753, -0.9351252913475037, -1.3419718742370605, -1.5159491300582886, -1.9470497369766235, -1.7717140913009644, -1.1352143287658691, -0.3834288418292999, 0.0, -0.0, -10.260953903198242, -11.81768798828125, -13.812066078186035, -11.880380630493164, -12.548213958740234, -11.691327095031738, -10.602017402648926, -9.90652847290039, -10.044626235961914, -8.982598304748535, -8.322439193725586, -8.960871696472168, -8.97946834564209, -8.396830558776855, -7.544439792633057, -6.534801959991455, -6.166551113128662, -5.6887054443359375, -4.731666088104248, -5.9266204833984375, -4.951181411743164, -4.577739238739014, -5.815279960632324, -5.803754806518555, -4.820042610168457, -3.9017562866210938, -2.170422077178955, -4.256842613220215, -2.1041312217712402, -2.323688507080078, -3.02732515335083, -1.8281348943710327, -2.664341926574707, -1.2591713666915894, -1.0103763341903687, -3.0139780044555664, -2.7527146339416504, -2.911761522293091, -2.030707836151123, -2.292617082595825, -2.4591329097747803, -3.1678435802459717, -1.9391146898269653, -1.3526594638824463, -2.242150068283081, -3.567333936691284, 0.30549418926239014, -0.9508099555969238, 0.8017800450325012, -1.0798108577728271, -0.9740157127380371, -2.662505865097046, -1.5385231971740723, -1.5348905324935913, -1.4343088865280151, -0.8597519993782043, -1.3316650390625, -0.7504794597625732, -0.34721043705940247, 1.586362600326538, -0.08517082035541534, -1.435476541519165, -0.8519188165664673, 1.0100936889648438, -2.348667621612549, -1.0527030229568481, -1.4988597631454468, -0.7111402153968811, -1.100285291671753, -0.9351252913475037, -1.3419718742370605, -1.5159491300582886, -1.9470497369766235, -1.7717140913009644, -1.1352143287658691, -0.3834288418292999, -0.0], [0.0, -10.657005310058594, -10.613142967224121, -11.661163330078125, -11.945783615112305, -11.876176834106445, -11.32081127166748, -10.265873908996582, -10.148456573486328, -10.496121406555176, -9.678196907043457, -8.745388984680176, -8.343099594116211, -6.818084239959717, -7.969159126281738, -7.783742904663086, -6.321242332458496, -5.3362717628479, -6.4274210929870605, -5.000300884246826, -4.743383884429932, -4.887655258178711, -6.117206573486328, -4.683919429779053, -5.912042140960693, -5.195309638977051, -4.537235260009766, -3.6283035278320312, -2.663614511489868, -3.9850728511810303, -3.7791059017181396, -3.9565751552581787, -1.930708646774292, -3.5441391468048096, -3.592583179473877, -3.172921657562256, -3.285529375076294, -3.2301957607269287, -3.1512022018432617, -3.0667288303375244, -3.2656877040863037, -3.76434588432312, -4.188204765319824, -3.176194906234741, -1.6720120906829834, -3.176711320877075, -2.341339588165283, -1.674682855606079, -0.5091061592102051, -2.4359989166259766, -4.383981227874756, -1.6697120666503906, -2.681864023208618, -1.6963475942611694, -1.7650868892669678, -0.33075621724128723, -0.49615156650543213, -2.4712891578674316, -1.236349105834961, -1.335483431816101, -0.4459579586982727, 0.6003338098526001, -0.5736997127532959, -0.8241404294967651, -3.0955889225006104, -2.2038049697875977, -0.7168492078781128, -0.8792564868927002, -1.2490112781524658, -1.342650294303894, -1.5612232685089111, -1.7306451797485352, -1.3811864852905273, -1.698694109916687, -2.548015832901001, -1.2863508462905884, -1.0046008825302124, 0.0, -0.0, -10.657005310058594, -10.613142967224121, -11.661163330078125, -11.945783615112305, -11.876176834106445, -11.32081127166748, -10.265873908996582, -10.148456573486328, -10.496121406555176, -9.678196907043457, -8.745388984680176, -8.343099594116211, -6.818084239959717, -7.969159126281738, -7.783742904663086, -6.321242332458496, -5.3362717628479, -6.4274210929870605, -5.000300884246826, -4.743383884429932, -4.887655258178711, -6.117206573486328, -4.683919429779053, -5.912042140960693, -5.195309638977051, -4.537235260009766, -3.6283035278320312, -2.663614511489868, -3.9850728511810303, -3.7791059017181396, -3.9565751552581787, -1.930708646774292, -3.5441391468048096, -3.592583179473877, -3.172921657562256, -3.285529375076294, -3.2301957607269287, -3.1512022018432617, -3.0667288303375244, -3.2656877040863037, -3.76434588432312, -4.188204765319824, -3.176194906234741, -1.6720120906829834, -3.176711320877075, -2.341339588165283, -1.674682855606079, -0.5091061592102051, -2.4359989166259766, -4.383981227874756, -1.6697120666503906, -2.681864023208618, -1.6963475942611694, -1.7650868892669678, -0.33075621724128723, -0.49615156650543213, -2.4712891578674316, -1.236349105834961, -1.335483431816101, -0.4459579586982727, 0.6003338098526001, -0.5736997127532959, -0.8241404294967651, -3.0955889225006104, -2.2038049697875977, -0.7168492078781128, -0.8792564868927002, -1.2490112781524658, -1.342650294303894, -1.5612232685089111, -1.7306451797485352, -1.3811864852905273, -1.698694109916687, -2.548015832901001, -1.2863508462905884, -1.0046008825302124, -0.0], [0.0, -11.694639205932617, -10.3135404586792, -11.736635208129883, -11.701349258422852, -11.478560447692871, -11.296440124511719, -10.907356262207031, -10.759259223937988, -10.038572311401367, -8.569758415222168, -8.811700820922852, -7.875922203063965, -7.308030605316162, -7.938168048858643, -7.913026332855225, -6.231892108917236, -5.696105003356934, -5.432737350463867, -5.6542158126831055, -4.4170331954956055, -5.054323673248291, -4.792646408081055, -5.1355414390563965, -4.921105861663818, -4.807475566864014, -4.323502063751221, -4.452002048492432, -3.482367992401123, -3.9983127117156982, -4.67466926574707, -4.006934642791748, -2.957550048828125, -3.4971230030059814, -4.6801652908325195, -4.051640510559082, -3.944584369659424, -3.9641969203948975, -3.0769007205963135, -3.9547533988952637, -3.434948205947876, -4.208220481872559, -3.6583447456359863, -3.0985107421875, -3.4485726356506348, -2.7329277992248535, -3.165494203567505, -2.6548938751220703, -3.0743002891540527, -3.924102306365967, -2.6374778747558594, -1.5320253372192383, -2.9008231163024902, -2.466078758239746, 0.07342082262039185, -1.1044808626174927, -0.893006443977356, -0.7660971283912659, -0.08193735778331757, -1.4482568502426147, -0.5354941487312317, -0.46735092997550964, -0.9088386297225952, -0.532027542591095, -0.8817673325538635, -0.11712042987346649, -1.7380988597869873, -0.9467881321907043, -1.3321783542633057, -0.9964339137077332, -1.3633726835250854, -2.0911707878112793, -1.7851824760437012, -1.6666942834854126, -1.6550743579864502, -1.3963103294372559, -2.261082649230957, 0.0, -0.0, -11.694639205932617, -10.3135404586792, -11.736635208129883, -11.701349258422852, -11.478560447692871, -11.296440124511719, -10.907356262207031, -10.759259223937988, -10.038572311401367, -8.569758415222168, -8.811700820922852, -7.875922203063965, -7.308030605316162, -7.938168048858643, -7.913026332855225, -6.231892108917236, -5.696105003356934, -5.432737350463867, -5.6542158126831055, -4.4170331954956055, -5.054323673248291, -4.792646408081055, -5.1355414390563965, -4.921105861663818, -4.807475566864014, -4.323502063751221, -4.452002048492432, -3.482367992401123, -3.9983127117156982, -4.67466926574707, -4.006934642791748, -2.957550048828125, -3.4971230030059814, -4.6801652908325195, -4.051640510559082, -3.944584369659424, -3.9641969203948975, -3.0769007205963135, -3.9547533988952637, -3.434948205947876, -4.208220481872559, -3.6583447456359863, -3.0985107421875, -3.4485726356506348, -2.7329277992248535, -3.165494203567505, -2.6548938751220703, -3.0743002891540527, -3.924102306365967, -2.6374778747558594, -1.5320253372192383, -2.9008231163024902, -2.466078758239746, 0.07342082262039185, -1.1044808626174927, -0.893006443977356, -0.7660971283912659, -0.08193735778331757, -1.4482568502426147, -0.5354941487312317, -0.46735092997550964, -0.9088386297225952, -0.532027542591095, -0.8817673325538635, -0.11712042987346649, -1.7380988597869873, -0.9467881321907043, -1.3321783542633057, -0.9964339137077332, -1.3633726835250854, -2.0911707878112793, -1.7851824760437012, -1.6666942834854126, -1.6550743579864502, -1.3963103294372559, -2.261082649230957, -0.0], [0.0, 0.0, -10.581618309020996, -11.20019817352295, -11.809715270996094, -11.711609840393066, -10.853686332702637, -11.154876708984375, -11.001543998718262, -11.155173301696777, -9.73393440246582, -9.96342945098877, -8.36808967590332, -8.26219367980957, -7.8398284912109375, -8.221132278442383, -6.723180294036865, -5.88433837890625, -6.10545015335083, -5.8290839195251465, -4.6770124435424805, -4.98764705657959, -5.30837345123291, -4.926486968994141, -4.327144622802734, -5.0202789306640625, -4.8924431800842285, -5.677290439605713, -4.050889015197754, -4.781930923461914, -4.356209754943848, -5.07717227935791, -3.8574016094207764, -6.1700544357299805, -4.741142272949219, -5.974329471588135, -5.313724517822266, -4.85445499420166, -4.8589019775390625, -4.471590042114258, -4.835242748260498, -4.365452289581299, -4.691156387329102, -4.584306716918945, -3.697770833969116, -4.379375457763672, -3.7036545276641846, -3.464010715484619, -4.46336555480957, -3.4697928428649902, -3.393996477127075, -2.6848082542419434, -2.6191327571868896, -2.1003363132476807, -2.4232306480407715, -1.714245319366455, -1.5313313007354736, -1.3904794454574585, -0.6433603763580322, -1.2844740152359009, -1.1829133033752441, -0.01874600350856781, -0.5949145555496216, -0.3926444947719574, -0.5353135466575623, -1.0501407384872437, -1.384821891784668, -1.3437528610229492, -1.0059565305709839, -1.253875970840454, -2.1100096702575684, -1.5469393730163574, -1.9797900915145874, -1.8420847654342651, -0.6502076983451843, -2.2549333572387695, -5.732640266418457, 0.0, -0.0, -0.0, -10.581618309020996, -11.20019817352295, -11.809715270996094, -11.711609840393066, -10.853686332702637, -11.154876708984375, -11.001543998718262, -11.155173301696777, -9.73393440246582, -9.96342945098877, -8.36808967590332, -8.26219367980957, -7.8398284912109375, -8.221132278442383, -6.723180294036865, -5.88433837890625, -6.10545015335083, -5.8290839195251465, -4.6770124435424805, -4.98764705657959, -5.30837345123291, -4.926486968994141, -4.327144622802734, -5.0202789306640625, -4.8924431800842285, -5.677290439605713, -4.050889015197754, -4.781930923461914, -4.356209754943848, -5.07717227935791, -3.8574016094207764, -6.1700544357299805, -4.741142272949219, -5.974329471588135, -5.313724517822266, -4.85445499420166, -4.8589019775390625, -4.471590042114258, -4.835242748260498, -4.365452289581299, -4.691156387329102, -4.584306716918945, -3.697770833969116, -4.379375457763672, -3.7036545276641846, -3.464010715484619, -4.46336555480957, -3.4697928428649902, -3.393996477127075, -2.6848082542419434, -2.6191327571868896, -2.1003363132476807, -2.4232306480407715, -1.714245319366455, -1.5313313007354736, -1.3904794454574585, -0.6433603763580322, -1.2844740152359009, -1.1829133033752441, -0.01874600350856781, -0.5949145555496216, -0.3926444947719574, -0.5353135466575623, -1.0501407384872437, -1.384821891784668, -1.3437528610229492, -1.0059565305709839, -1.253875970840454, -2.1100096702575684, -1.5469393730163574, -1.9797900915145874, -1.8420847654342651, -0.6502076983451843, -2.2549333572387695, -5.732640266418457, -0.0], [-8.950811386108398, 0.0, -9.857857704162598, -10.945311546325684, -11.225086212158203, -11.237051963806152, -11.531493186950684, -11.288856506347656, -10.039595603942871, -10.844298362731934, -9.67663288116455, -8.844757080078125, -9.322681427001953, -8.140067100524902, -7.735167026519775, -7.1385674476623535, -6.2456512451171875, -5.728105068206787, -6.14958381652832, -5.117659091949463, -5.334850788116455, -5.116311073303223, -4.847265720367432, -6.178849697113037, -4.037103176116943, -4.552463054656982, -5.212955474853516, -4.665778160095215, -3.962308168411255, -4.615380764007568, -4.479462146759033, -5.78961181640625, -3.22916316986084, -5.973690986633301, -5.673223972320557, -6.016103744506836, -6.0033087730407715, -5.845414161682129, -5.935112476348877, -6.688487529754639, -6.186278820037842, -6.547614097595215, -5.111602306365967, -4.9937591552734375, -3.9697158336639404, -5.61493444442749, -5.616551399230957, -4.372544288635254, -3.983922004699707, -4.118431568145752, -3.643537998199463, -3.964984893798828, -3.026876211166382, -2.430586576461792, -2.0814967155456543, -1.403243064880371, -2.342538833618164, -1.910498023033142, -0.8111333250999451, -0.6646749377250671, -1.2966450452804565, -0.6828109622001648, -0.8460876941680908, -1.1703740358352661, -0.40564873814582825, -0.8980165123939514, -0.8374108672142029, -1.046553611755371, -0.4766940176486969, -0.5395782589912415, -1.378061294555664, -2.220003604888916, -0.9813056588172913, -2.155487060546875, -3.180126667022705, -3.046447515487671, 0.0, 0.0, -8.950811386108398, -0.0, -9.857857704162598, -10.945311546325684, -11.225086212158203, -11.237051963806152, -11.531493186950684, -11.288856506347656, -10.039595603942871, -10.844298362731934, -9.67663288116455, -8.844757080078125, -9.322681427001953, -8.140067100524902, -7.735167026519775, -7.1385674476623535, -6.2456512451171875, -5.728105068206787, -6.14958381652832, -5.117659091949463, -5.334850788116455, -5.116311073303223, -4.847265720367432, -6.178849697113037, -4.037103176116943, -4.552463054656982, -5.212955474853516, -4.665778160095215, -3.962308168411255, -4.615380764007568, -4.479462146759033, -5.78961181640625, -3.22916316986084, -5.973690986633301, -5.673223972320557, -6.016103744506836, -6.0033087730407715, -5.845414161682129, -5.935112476348877, -6.688487529754639, -6.186278820037842, -6.547614097595215, -5.111602306365967, -4.9937591552734375, -3.9697158336639404, -5.61493444442749, -5.616551399230957, -4.372544288635254, -3.983922004699707, -4.118431568145752, -3.643537998199463, -3.964984893798828, -3.026876211166382, -2.430586576461792, -2.0814967155456543, -1.403243064880371, -2.342538833618164, -1.910498023033142, -0.8111333250999451, -0.6646749377250671, -1.2966450452804565, -0.6828109622001648, -0.8460876941680908, -1.1703740358352661, -0.40564873814582825, -0.8980165123939514, -0.8374108672142029, -1.046553611755371, -0.4766940176486969, -0.5395782589912415, -1.378061294555664, -2.220003604888916, -0.9813056588172913, -2.155487060546875, -3.180126667022705, -3.046447515487671, -0.0, -0.0], [-10.805929183959961, 0.0, -9.635315895080566, -10.323393821716309, -10.409207344055176, -10.92284107208252, -10.948436737060547, -11.019133567810059, -10.68907356262207, -9.703094482421875, -8.808442115783691, -9.140435218811035, -9.116568565368652, -8.421948432922363, -7.397161483764648, -6.531764984130859, -7.564246654510498, -7.135424613952637, -6.322612285614014, -4.874118804931641, -5.684832572937012, -5.2036027908325195, -5.128370761871338, -4.585344314575195, -4.802560806274414, -4.380792140960693, -4.494853973388672, -5.486293315887451, -4.767098426818848, -5.330607891082764, -5.205660343170166, -5.610817909240723, -6.69219446182251, -6.2644572257995605, -6.5753560066223145, -7.030388355255127, -7.145570278167725, -5.473170280456543, -7.282071590423584, -6.9553680419921875, -6.752478122711182, -6.070745944976807, -4.1924285888671875, -6.91334867477417, -4.079738616943359, -6.03452205657959, -5.62495756149292, -4.6433424949646, -6.6792378425598145, -3.6886649131774902, -3.3790435791015625, -3.347917318344116, -3.7410237789154053, -1.7290607690811157, -2.650297164916992, -1.564931869506836, -2.3699111938476562, -1.6639773845672607, -0.3482780158519745, -1.6069996356964111, -0.07254534959793091, -0.5746294856071472, -0.7571457624435425, -0.8830060362815857, -0.5349783897399902, 0.5358484983444214, -0.4483717978000641, -2.279916524887085, -1.5130162239074707, -1.455222249031067, -1.3497062921524048, -1.865962266921997, -2.0085256099700928, -2.1331067085266113, -2.558835506439209, -3.437624931335449, 0.0, 0.0, -10.805929183959961, -0.0, -9.635315895080566, -10.323393821716309, -10.409207344055176, -10.92284107208252, -10.948436737060547, -11.019133567810059, -10.68907356262207, -9.703094482421875, -8.808442115783691, -9.140435218811035, -9.116568565368652, -8.421948432922363, -7.397161483764648, -6.531764984130859, -7.564246654510498, -7.135424613952637, -6.322612285614014, -4.874118804931641, -5.684832572937012, -5.2036027908325195, -5.128370761871338, -4.585344314575195, -4.802560806274414, -4.380792140960693, -4.494853973388672, -5.486293315887451, -4.767098426818848, -5.330607891082764, -5.205660343170166, -5.610817909240723, -6.69219446182251, -6.2644572257995605, -6.5753560066223145, -7.030388355255127, -7.145570278167725, -5.473170280456543, -7.282071590423584, -6.9553680419921875, -6.752478122711182, -6.070745944976807, -4.1924285888671875, -6.91334867477417, -4.079738616943359, -6.03452205657959, -5.62495756149292, -4.6433424949646, -6.6792378425598145, -3.6886649131774902, -3.3790435791015625, -3.347917318344116, -3.7410237789154053, -1.7290607690811157, -2.650297164916992, -1.564931869506836, -2.3699111938476562, -1.6639773845672607, -0.3482780158519745, -1.6069996356964111, -0.07254534959793091, -0.5746294856071472, -0.7571457624435425, -0.8830060362815857, -0.5349783897399902, 0.5358484983444214, -0.4483717978000641, -2.279916524887085, -1.5130162239074707, -1.455222249031067, -1.3497062921524048, -1.865962266921997, -2.0085256099700928, -2.1331067085266113, -2.558835506439209, -3.437624931335449, -0.0, -0.0], [-11.72862720489502, 0.0, -9.329838752746582, -10.104599952697754, -10.6646089553833, -10.750016212463379, -10.507476806640625, -10.275699615478516, -10.599717140197754, -10.216255187988281, -9.822094917297363, -8.318283081054688, -9.301076889038086, -8.679800033569336, -6.923195838928223, -6.528366565704346, -5.99403190612793, -6.117578983306885, -7.048391342163086, -5.656522274017334, -6.609264850616455, -5.720822334289551, -4.645632743835449, -3.810563325881958, -4.8042097091674805, -6.05007791519165, -7.150106430053711, -4.7482452392578125, -5.299524307250977, -5.960963726043701, -5.563041687011719, -6.964214324951172, -7.1766886711120605, -7.37576150894165, -7.9503092765808105, -8.628544807434082, -7.389138221740723, -8.645633697509766, -8.824698448181152, -8.755391120910645, -7.073312282562256, -7.738216876983643, -7.734227180480957, -7.447890758514404, -7.568514347076416, -7.374804496765137, -6.687757968902588, -6.937803745269775, -7.250249862670898, -5.127828121185303, -6.380088806152344, -3.638413190841675, -4.215244770050049, -2.75520920753479, -2.8525173664093018, -2.4626989364624023, -2.254117727279663, -1.8891323804855347, -1.715924620628357, -1.6355688571929932, -2.365966320037842, -0.9316181540489197, -0.8337390422821045, -0.712745189666748, -0.34963756799697876, -0.867039144039154, -0.9504441022872925, -1.8790544271469116, -1.075665831565857, -2.523801565170288, -2.2445900440216064, -1.5228688716888428, -1.6671990156173706, -2.204561233520508, -3.6609838008880615, -1.4937344789505005, 0.0, 1.6319868564605713, -11.72862720489502, -0.0, -9.329838752746582, -10.104599952697754, -10.6646089553833, -10.750016212463379, -10.507476806640625, -10.275699615478516, -10.599717140197754, -10.216255187988281, -9.822094917297363, -8.318283081054688, -9.301076889038086, -8.679800033569336, -6.923195838928223, -6.528366565704346, -5.99403190612793, -6.117578983306885, -7.048391342163086, -5.656522274017334, -6.609264850616455, -5.720822334289551, -4.645632743835449, -3.810563325881958, -4.8042097091674805, -6.05007791519165, -7.150106430053711, -4.7482452392578125, -5.299524307250977, -5.960963726043701, -5.563041687011719, -6.964214324951172, -7.1766886711120605, -7.37576150894165, -7.9503092765808105, -8.628544807434082, -7.389138221740723, -8.645633697509766, -8.824698448181152, -8.755391120910645, -7.073312282562256, -7.738216876983643, -7.734227180480957, -7.447890758514404, -7.568514347076416, -7.374804496765137, -6.687757968902588, -6.937803745269775, -7.250249862670898, -5.127828121185303, -6.380088806152344, -3.638413190841675, -4.215244770050049, -2.75520920753479, -2.8525173664093018, -2.4626989364624023, -2.254117727279663, -1.8891323804855347, -1.715924620628357, -1.6355688571929932, -2.365966320037842, -0.9316181540489197, -0.8337390422821045, -0.712745189666748, -0.34963756799697876, -0.867039144039154, -0.9504441022872925, -1.8790544271469116, -1.075665831565857, -2.523801565170288, -2.2445900440216064, -1.5228688716888428, -1.6671990156173706, -2.204561233520508, -3.6609838008880615, -1.4937344789505005, -0.0, 1.6319868564605713], [-11.572643280029297, 0.0, -9.586298942565918, -10.188072204589844, -10.767461776733398, -10.468229293823242, -10.190475463867188, -10.540407180786133, -8.087958335876465, -10.67575740814209, -8.787748336791992, -8.898837089538574, -9.163698196411133, -7.853117942810059, -8.11264419555664, -6.9280805587768555, -7.473212242126465, -6.929930210113525, -6.753632545471191, -6.288681507110596, -6.681987762451172, -5.153308391571045, -5.540637016296387, -5.582458972930908, -4.478695392608643, -5.515092372894287, -6.480550765991211, -6.212601661682129, -5.810908317565918, -5.89700984954834, -8.663768768310547, -7.91988468170166, -7.5335001945495605, -8.363517761230469, -9.44163990020752, -8.642280578613281, -8.748502731323242, -8.696093559265137, -9.815275192260742, -9.244073867797852, -9.031364440917969, -9.386785507202148, -8.452930450439453, -8.989983558654785, -8.913740158081055, -6.960577487945557, -8.387125968933105, -5.51136589050293, -3.468548059463501, -4.135434150695801, -4.721446514129639, -4.248078346252441, -5.424165725708008, -2.9694759845733643, -3.60974383354187, -1.25889253616333, -1.5917116403579712, -2.4852986335754395, -1.8180029392242432, -1.6419005393981934, -1.2631949186325073, -0.8085490465164185, -0.9004843235015869, -0.20775721967220306, -0.9204996228218079, -0.793114423751831, -0.42712926864624023, -1.1443997621536255, -2.4740116596221924, -1.7853481769561768, -1.5899205207824707, -2.0846567153930664, -2.291964530944824, -2.5731449127197266, -4.162869930267334, 0.0, 0.0, 1.6208888292312622, -11.572643280029297, -0.0, -9.586298942565918, -10.188072204589844, -10.767461776733398, -10.468229293823242, -10.190475463867188, -10.540407180786133, -8.087958335876465, -10.67575740814209, -8.787748336791992, -8.898837089538574, -9.163698196411133, -7.853117942810059, -8.11264419555664, -6.9280805587768555, -7.473212242126465, -6.929930210113525, -6.753632545471191, -6.288681507110596, -6.681987762451172, -5.153308391571045, -5.540637016296387, -5.582458972930908, -4.478695392608643, -5.515092372894287, -6.480550765991211, -6.212601661682129, -5.810908317565918, -5.89700984954834, -8.663768768310547, -7.91988468170166, -7.5335001945495605, -8.363517761230469, -9.44163990020752, -8.642280578613281, -8.748502731323242, -8.696093559265137, -9.815275192260742, -9.244073867797852, -9.031364440917969, -9.386785507202148, -8.452930450439453, -8.989983558654785, -8.913740158081055, -6.960577487945557, -8.387125968933105, -5.51136589050293, -3.468548059463501, -4.135434150695801, -4.721446514129639, -4.248078346252441, -5.424165725708008, -2.9694759845733643, -3.60974383354187, -1.25889253616333, -1.5917116403579712, -2.4852986335754395, -1.8180029392242432, -1.6419005393981934, -1.2631949186325073, -0.8085490465164185, -0.9004843235015869, -0.20775721967220306, -0.9204996228218079, -0.793114423751831, -0.42712926864624023, -1.1443997621536255, -2.4740116596221924, -1.7853481769561768, -1.5899205207824707, -2.0846567153930664, -2.291964530944824, -2.5731449127197266, -4.162869930267334, -0.0, -0.0, 1.6208888292312622], [-13.810705184936523, -12.742125511169434, 0.0, -11.942688941955566, -10.369637489318848, -10.035491943359375, -10.461968421936035, -10.098496437072754, -10.08704662322998, -9.65605640411377, -9.022316932678223, -7.886263847351074, -8.621664047241211, -8.075019836425781, -8.035383224487305, -6.961164951324463, -7.0498528480529785, -7.412862777709961, -7.057868480682373, -5.0103044509887695, -5.956575870513916, -5.5913286209106445, -5.952114105224609, -5.654847621917725, -5.587724208831787, -4.737443923950195, -6.187458038330078, -5.88508415222168, -6.181049346923828, -7.548196792602539, -9.115745544433594, -7.844653606414795, -8.92602825164795, -9.025154113769531, -9.442012786865234, -10.560263633728027, -9.77428913116455, -10.658226013183594, -12.062797546386719, -10.152156829833984, -10.458620071411133, -11.080867767333984, -10.020977020263672, -10.92444133758545, -9.824880599975586, -9.329252243041992, -9.762104988098145, 0.0, -5.92126989364624, -7.074259281158447, -6.083645343780518, -4.986731052398682, -7.462931156158447, -3.3683717250823975, -3.9458348751068115, -3.281296491622925, -2.2463538646698, -1.896813988685608, -2.414653778076172, -1.768591046333313, -1.462244987487793, -1.819528579711914, -1.1725693941116333, -0.2962740659713745, -0.11986370384693146, -1.1320363283157349, -1.0312669277191162, -0.8318864107131958, -1.3858062028884888, -1.6495347023010254, -2.8383259773254395, -2.346538543701172, -2.9088501930236816, -3.611567497253418, -5.537566661834717, 0.0, 0.0, 2.1878342628479004, -13.810705184936523, -12.742125511169434, -0.0, -11.942688941955566, -10.369637489318848, -10.035491943359375, -10.461968421936035, -10.098496437072754, -10.08704662322998, -9.65605640411377, -9.022316932678223, -7.886263847351074, -8.621664047241211, -8.075019836425781, -8.035383224487305, -6.961164951324463, -7.0498528480529785, -7.412862777709961, -7.057868480682373, -5.0103044509887695, -5.956575870513916, -5.5913286209106445, -5.952114105224609, -5.654847621917725, -5.587724208831787, -4.737443923950195, -6.187458038330078, -5.88508415222168, -6.181049346923828, -7.548196792602539, -9.115745544433594, -7.844653606414795, -8.92602825164795, -9.025154113769531, -9.442012786865234, -10.560263633728027, -9.77428913116455, -10.658226013183594, -12.062797546386719, -10.152156829833984, -10.458620071411133, -11.080867767333984, -10.020977020263672, -10.92444133758545, -9.824880599975586, -9.329252243041992, -9.762104988098145, -0.0, -5.92126989364624, -7.074259281158447, -6.083645343780518, -4.986731052398682, -7.462931156158447, -3.3683717250823975, -3.9458348751068115, -3.281296491622925, -2.2463538646698, -1.896813988685608, -2.414653778076172, -1.768591046333313, -1.462244987487793, -1.819528579711914, -1.1725693941116333, -0.2962740659713745, -0.11986370384693146, -1.1320363283157349, -1.0312669277191162, -0.8318864107131958, -1.3858062028884888, -1.6495347023010254, -2.8383259773254395, -2.346538543701172, -2.9088501930236816, -3.611567497253418, -5.537566661834717, -0.0, -0.0, 2.1878342628479004], [-13.928754806518555, -10.451316833496094, -11.865830421447754, -13.612997055053711, -11.022140502929688, -10.358899116516113, -9.649731636047363, -10.511762619018555, -10.663565635681152, -9.827658653259277, -9.49972152709961, -7.735959529876709, -8.236340522766113, -7.537353038787842, -7.766551494598389, -7.499478340148926, -7.440627574920654, -6.6803388595581055, -6.537083148956299, -5.552841663360596, -8.003702163696289, -5.362827777862549, -6.7008538246154785, -6.946072101593018, -5.6937384605407715, -4.342013835906982, -6.153430938720703, 0.0, -6.439145565032959, -8.109346389770508, -7.936756134033203, -9.804001808166504, -10.135367393493652, -10.422013282775879, -11.900389671325684, -11.042473793029785, -12.416797637939453, -10.866828918457031, -11.706356048583984, -12.09003734588623, -11.306548118591309, -11.748312950134277, -11.189664840698242, -11.100896835327148, -10.409964561462402, 0.0, 0.0, -7.605894565582275, -7.835728168487549, -6.52656364440918, -7.4886040687561035, -6.400942325592041, -5.127023220062256, -4.724032402038574, -2.9566471576690674, -3.0333690643310547, -3.674192190170288, -1.3334256410598755, -2.705491542816162, -1.7247544527053833, -1.8620105981826782, -0.35640478134155273, -1.1942535638809204, -1.206199288368225, -0.9218499064445496, -1.1875665187835693, -1.2551097869873047, -1.2280241250991821, -1.6604070663452148, -1.6564644575119019, -1.7322219610214233, -2.388819932937622, -3.126750946044922, -3.6677913665771484, -4.603158950805664, 0.0, 0.0, 0.28272926807403564, -13.928754806518555, -10.451316833496094, -11.865830421447754, -13.612997055053711, -11.022140502929688, -10.358899116516113, -9.649731636047363, -10.511762619018555, -10.663565635681152, -9.827658653259277, -9.49972152709961, -7.735959529876709, -8.236340522766113, -7.537353038787842, -7.766551494598389, -7.499478340148926, -7.440627574920654, -6.6803388595581055, -6.537083148956299, -5.552841663360596, -8.003702163696289, -5.362827777862549, -6.7008538246154785, -6.946072101593018, -5.6937384605407715, -4.342013835906982, -6.153430938720703, -0.0, -6.439145565032959, -8.109346389770508, -7.936756134033203, -9.804001808166504, -10.135367393493652, -10.422013282775879, -11.900389671325684, -11.042473793029785, -12.416797637939453, -10.866828918457031, -11.706356048583984, -12.09003734588623, -11.306548118591309, -11.748312950134277, -11.189664840698242, -11.100896835327148, -10.409964561462402, -0.0, -0.0, -7.605894565582275, -7.835728168487549, -6.52656364440918, -7.4886040687561035, -6.400942325592041, -5.127023220062256, -4.724032402038574, -2.9566471576690674, -3.0333690643310547, -3.674192190170288, -1.3334256410598755, -2.705491542816162, -1.7247544527053833, -1.8620105981826782, -0.35640478134155273, -1.1942535638809204, -1.206199288368225, -0.9218499064445496, -1.1875665187835693, -1.2551097869873047, -1.2280241250991821, -1.6604070663452148, -1.6564644575119019, -1.7322219610214233, -2.388819932937622, -3.126750946044922, -3.6677913665771484, -4.603158950805664, -0.0, 0.0, 0.28272926807403564], [-14.555535316467285, -15.79543685913086, 0.0, -10.59584903717041, -11.91545581817627, -10.760628700256348, -10.29041862487793, -10.004117965698242, -10.214792251586914, -9.633355140686035, -9.444561958312988, -9.042301177978516, -8.187453269958496, -7.198734760284424, -7.676163673400879, 0.0, -6.548978805541992, -7.092068195343018, -6.589395999908447, -6.369043350219727, -6.556869983673096, -6.205017566680908, -6.39471435546875, -7.3934760093688965, -6.834042072296143, -7.103248596191406, -7.507769584655762, -7.456689834594727, -8.29440689086914, -8.33701229095459, -10.779306411743164, -9.048775672912598, -10.476059913635254, -9.478523254394531, -13.19473648071289, -12.666903495788574, -12.902850151062012, -13.691844940185547, -13.621368408203125, -14.387639045715332, -13.208414077758789, -13.577898979187012, -11.83276653289795, -12.383685111999512, -10.07995319366455, 0.0, -11.468050003051758, -9.927104949951172, -9.612556457519531, -8.708754539489746, -7.619040012359619, -6.255131721496582, -5.235982418060303, -4.768606662750244, -5.744638919830322, -3.4502289295196533, -1.3366236686706543, 0.4589384198188782, -2.632181167602539, -2.3045105934143066, -1.2791999578475952, -1.6176129579544067, -1.4819530248641968, -0.9312177896499634, -1.5294214487075806, -0.6619870662689209, -0.7666566371917725, -1.3830069303512573, -1.936457633972168, -1.4585301876068115, -2.2674453258514404, -3.9501919746398926, -2.870457172393799, -4.132604598999023, 0.0, 0.0, 1.1805884838104248, 1.45535147190094, -14.555535316467285, -15.79543685913086, -0.0, -10.59584903717041, -11.91545581817627, -10.760628700256348, -10.29041862487793, -10.004117965698242, -10.214792251586914, -9.633355140686035, -9.444561958312988, -9.042301177978516, -8.187453269958496, -7.198734760284424, -7.676163673400879, -0.0, -6.548978805541992, -7.092068195343018, -6.589395999908447, -6.369043350219727, -6.556869983673096, -6.205017566680908, -6.39471435546875, -7.3934760093688965, -6.834042072296143, -7.103248596191406, -7.507769584655762, -7.456689834594727, -8.29440689086914, -8.33701229095459, -10.779306411743164, -9.048775672912598, -10.476059913635254, -9.478523254394531, -13.19473648071289, -12.666903495788574, -12.902850151062012, -13.691844940185547, -13.621368408203125, -14.387639045715332, -13.208414077758789, -13.577898979187012, -11.83276653289795, -12.383685111999512, -10.07995319366455, -0.0, -11.468050003051758, -9.927104949951172, -9.612556457519531, -8.708754539489746, -7.619040012359619, -6.255131721496582, -5.235982418060303, -4.768606662750244, -5.744638919830322, -3.4502289295196533, -1.3366236686706543, 0.4589384198188782, -2.632181167602539, -2.3045105934143066, -1.2791999578475952, -1.6176129579544067, -1.4819530248641968, -0.9312177896499634, -1.5294214487075806, -0.6619870662689209, -0.7666566371917725, -1.3830069303512573, -1.936457633972168, -1.4585301876068115, -2.2674453258514404, -3.9501919746398926, -2.870457172393799, -4.132604598999023, -0.0, 0.0, 1.1805884838104248, 1.45535147190094], [-14.61712646484375, -14.374415397644043, 0.0, -10.041105270385742, -11.745609283447266, -10.656786918640137, -10.307878494262695, -10.835453033447266, -10.640623092651367, -9.72167682647705, -8.92529010772705, -9.300777435302734, -8.675663948059082, -8.830001831054688, -7.43272590637207, -7.349039077758789, -5.9858317375183105, -6.583534240722656, -7.274295330047607, -4.9816765785217285, -6.982095718383789, -6.795429229736328, -7.089702129364014, -6.40971040725708, -6.729742050170898, -7.694602012634277, -7.759274959564209, -7.35035514831543, -10.650118827819824, 0.0, -9.67226791381836, -10.72763729095459, -10.566896438598633, -10.161336898803711, -14.898940086364746, -15.116647720336914, -15.64045238494873, -13.634419441223145, -15.48831558227539, -15.324562072753906, -15.270977020263672, -14.37259578704834, -14.391144752502441, -16.71358299255371, -14.073379516601562, -15.607271194458008, -12.329048156738281, -10.397732734680176, -11.007014274597168, -10.512575149536133, -7.138744831085205, -7.5756635665893555, -7.2250657081604, -6.338397026062012, -4.097497940063477, -5.054322719573975, -4.338507175445557, -3.2439498901367188, -4.9047698974609375, -2.4273312091827393, -1.9946564435958862, -1.4852415323257446, -0.4550110697746277, -1.2090253829956055, -1.0816105604171753, -1.1333067417144775, -0.5069806575775146, -1.1191840171813965, -1.3426365852355957, -1.9661717414855957, -1.6280086040496826, -1.9277801513671875, -2.5082266330718994, -3.601044178009033, 0.0, 0.0, 1.6847807168960571, 1.5499175786972046, -14.61712646484375, -14.374415397644043, -0.0, -10.041105270385742, -11.745609283447266, -10.656786918640137, -10.307878494262695, -10.835453033447266, -10.640623092651367, -9.72167682647705, -8.92529010772705, -9.300777435302734, -8.675663948059082, -8.830001831054688, -7.43272590637207, -7.349039077758789, -5.9858317375183105, -6.583534240722656, -7.274295330047607, -4.9816765785217285, -6.982095718383789, -6.795429229736328, -7.089702129364014, -6.40971040725708, -6.729742050170898, -7.694602012634277, -7.759274959564209, -7.35035514831543, -10.650118827819824, -0.0, -9.67226791381836, -10.72763729095459, -10.566896438598633, -10.161336898803711, -14.898940086364746, -15.116647720336914, -15.64045238494873, -13.634419441223145, -15.48831558227539, -15.324562072753906, -15.270977020263672, -14.37259578704834, -14.391144752502441, -16.71358299255371, -14.073379516601562, -15.607271194458008, -12.329048156738281, -10.397732734680176, -11.007014274597168, -10.512575149536133, -7.138744831085205, -7.5756635665893555, -7.2250657081604, -6.338397026062012, -4.097497940063477, -5.054322719573975, -4.338507175445557, -3.2439498901367188, -4.9047698974609375, -2.4273312091827393, -1.9946564435958862, -1.4852415323257446, -0.4550110697746277, -1.2090253829956055, -1.0816105604171753, -1.1333067417144775, -0.5069806575775146, -1.1191840171813965, -1.3426365852355957, -1.9661717414855957, -1.6280086040496826, -1.9277801513671875, -2.5082266330718994, -3.601044178009033, -0.0, 0.0, 1.6847807168960571, 1.5499175786972046], [-15.973782539367676, -13.787650108337402, -11.576038360595703, 0.0, -10.596013069152832, -11.341416358947754, -11.133721351623535, -10.334245681762695, -10.112931251525879, -9.164233207702637, -9.23043155670166, -9.963099479675293, -8.80284309387207, -8.421189308166504, -7.4070281982421875, -7.281985759735107, -4.1804070472717285, -6.651654243469238, -6.658990859985352, -6.640469551086426, -6.802004814147949, -6.762728214263916, -6.194294452667236, -7.319737911224365, -7.0610246658325195, -7.171609878540039, -7.041836261749268, -6.238364219665527, 0.0, -10.147518157958984, -11.578984260559082, -10.90144157409668, -11.696877479553223, -13.90690803527832, -14.011031150817871, -15.648170471191406, -17.456958770751953, -15.525423049926758, -17.707578659057617, -16.77817153930664, -17.444154739379883, -16.153989791870117, -15.819613456726074, -15.381121635437012, -17.923385620117188, -14.396097183227539, -13.394736289978027, -13.360882759094238, -11.871490478515625, -10.445150375366211, -10.398785591125488, -9.916584014892578, -6.86760139465332, -6.4735565185546875, -5.978958606719971, -5.560046672821045, -5.199671268463135, -3.525426149368286, -3.4145610332489014, -2.3868227005004883, -2.084892988204956, -2.319276809692383, -1.6641327142715454, -0.9216691255569458, -1.6809552907943726, -1.1992111206054688, -1.2225959300994873, -1.0783188343048096, -1.7067675590515137, -1.5936708450317383, -1.9191137552261353, -1.3070902824401855, -1.0755566358566284, 0.0, 0.0, 0.0, 1.270836353302002, 1.0244413614273071, -15.973782539367676, -13.787650108337402, -11.576038360595703, -0.0, -10.596013069152832, -11.341416358947754, -11.133721351623535, -10.334245681762695, -10.112931251525879, -9.164233207702637, -9.23043155670166, -9.963099479675293, -8.80284309387207, -8.421189308166504, -7.4070281982421875, -7.281985759735107, -4.1804070472717285, -6.651654243469238, -6.658990859985352, -6.640469551086426, -6.802004814147949, -6.762728214263916, -6.194294452667236, -7.319737911224365, -7.0610246658325195, -7.171609878540039, -7.041836261749268, -6.238364219665527, -0.0, -10.147518157958984, -11.578984260559082, -10.90144157409668, -11.696877479553223, -13.90690803527832, -14.011031150817871, -15.648170471191406, -17.456958770751953, -15.525423049926758, -17.707578659057617, -16.77817153930664, -17.444154739379883, -16.153989791870117, -15.819613456726074, -15.381121635437012, -17.923385620117188, -14.396097183227539, -13.394736289978027, -13.360882759094238, -11.871490478515625, -10.445150375366211, -10.398785591125488, -9.916584014892578, -6.86760139465332, -6.4735565185546875, -5.978958606719971, -5.560046672821045, -5.199671268463135, -3.525426149368286, -3.4145610332489014, -2.3868227005004883, -2.084892988204956, -2.319276809692383, -1.6641327142715454, -0.9216691255569458, -1.6809552907943726, -1.1992111206054688, -1.2225959300994873, -1.0783188343048096, -1.7067675590515137, -1.5936708450317383, -1.9191137552261353, -1.3070902824401855, -1.0755566358566284, -0.0, -0.0, 0.0, 1.270836353302002, 1.0244413614273071], [-16.1806583404541, -14.073473930358887, -11.960844039916992, 0.0, 0.0, -9.157017707824707, -10.97472095489502, -10.237321853637695, -10.395130157470703, -9.8070650100708, -9.424010276794434, -8.561010360717773, -9.359498023986816, -8.714408874511719, -8.17921257019043, -7.654244899749756, -7.893393516540527, -6.753871440887451, -7.158125400543213, -6.991087436676025, -6.245448112487793, -8.218228340148926, -7.1141581535339355, -7.9588303565979, -8.68911075592041, -7.863628387451172, 0.0, -5.763178825378418, -10.15628433227539, -9.638019561767578, -12.39838695526123, -13.233546257019043, -14.544074058532715, -15.475692749023438, -15.347060203552246, 0.0, -18.726587295532227, -15.901015281677246, -18.767234802246094, -18.316062927246094, -18.763105392456055, -18.456954956054688, -19.230056762695312, -16.609331130981445, -16.49842071533203, -16.167829513549805, -15.62354850769043, -13.237569808959961, -13.30146598815918, -12.751256942749023, -10.87856674194336, -8.277595520019531, -7.4897027015686035, -6.650190830230713, -7.2047438621521, -5.304758548736572, -4.5633416175842285, -4.2955498695373535, -4.681386470794678, -3.7399861812591553, -3.4006872177124023, -2.4401564598083496, -2.2596487998962402, -1.9201892614364624, -1.3613144159317017, -1.5633100271224976, -1.6679953336715698, -2.338776111602783, -1.6245367527008057, -1.601901650428772, -1.5309685468673706, -1.0206778049468994, -0.3240373432636261, 0.0, 0.0, 2.9129340648651123, 0.09199057519435883, 2.33771014213562, -16.1806583404541, -14.073473930358887, -11.960844039916992, -0.0, -0.0, -9.157017707824707, -10.97472095489502, -10.237321853637695, -10.395130157470703, -9.8070650100708, -9.424010276794434, -8.561010360717773, -9.359498023986816, -8.714408874511719, -8.17921257019043, -7.654244899749756, -7.893393516540527, -6.753871440887451, -7.158125400543213, -6.991087436676025, -6.245448112487793, -8.218228340148926, -7.1141581535339355, -7.9588303565979, -8.68911075592041, -7.863628387451172, -0.0, -5.763178825378418, -10.15628433227539, -9.638019561767578, -12.39838695526123, -13.233546257019043, -14.544074058532715, -15.475692749023438, -15.347060203552246, -0.0, -18.726587295532227, -15.901015281677246, -18.767234802246094, -18.316062927246094, -18.763105392456055, -18.456954956054688, -19.230056762695312, -16.609331130981445, -16.49842071533203, -16.167829513549805, -15.62354850769043, -13.237569808959961, -13.30146598815918, -12.751256942749023, -10.87856674194336, -8.277595520019531, -7.4897027015686035, -6.650190830230713, -7.2047438621521, -5.304758548736572, -4.5633416175842285, -4.2955498695373535, -4.681386470794678, -3.7399861812591553, -3.4006872177124023, -2.4401564598083496, -2.2596487998962402, -1.9201892614364624, -1.3613144159317017, -1.5633100271224976, -1.6679953336715698, -2.338776111602783, -1.6245367527008057, -1.601901650428772, -1.5309685468673706, -1.0206778049468994, -0.3240373432636261, -0.0, 0.0, 2.9129340648651123, 0.09199057519435883, 2.33771014213562], [-16.18128204345703, -16.555696487426758, -13.083154678344727, -12.505497932434082, 0.0, -12.319533348083496, -11.808247566223145, -10.96349048614502, -10.371397018432617, -10.217606544494629, -9.73707389831543, -9.13212776184082, -8.409666061401367, -8.991095542907715, -8.241007804870605, -7.4017229080200195, -7.295883655548096, -7.7162675857543945, -6.830372333526611, -7.083191394805908, -7.243169784545898, -7.618891716003418, -8.378168106079102, -7.805531024932861, -9.249173164367676, 0.0, 0.0, -9.592484474182129, -10.532347679138184, -12.531993865966797, -11.605690956115723, -13.57827377319336, -15.717464447021484, -15.903738021850586, -17.59433364868164, -16.51476287841797, -18.406177520751953, -20.441242218017578, -19.058326721191406, -20.606290817260742, -20.830318450927734, -20.55154800415039, -20.025367736816406, -18.570924758911133, -18.558767318725586, -15.464618682861328, -16.76097869873047, -15.146324157714844, -14.503767967224121, -12.530986785888672, -10.548196792602539, -9.469087600708008, -9.56308364868164, -8.372870445251465, -6.955782413482666, -6.1785407066345215, -5.45156192779541, -4.9116692543029785, -4.255023002624512, -3.723881959915161, -3.637995719909668, -3.1728696823120117, -2.7447268962860107, -2.373389482498169, -1.9968533515930176, -1.581439733505249, -2.0998694896698, -1.7682753801345825, -2.228705883026123, -1.889767050743103, -1.2265700101852417, -1.0988646745681763, 0.0, 0.0, 0.0, 4.9737725257873535, 2.952939748764038, 0.5043659210205078, -16.18128204345703, -16.555696487426758, -13.083154678344727, -12.505497932434082, -0.0, -12.319533348083496, -11.808247566223145, -10.96349048614502, -10.371397018432617, -10.217606544494629, -9.73707389831543, -9.13212776184082, -8.409666061401367, -8.991095542907715, -8.241007804870605, -7.4017229080200195, -7.295883655548096, -7.7162675857543945, -6.830372333526611, -7.083191394805908, -7.243169784545898, -7.618891716003418, -8.378168106079102, -7.805531024932861, -9.249173164367676, -0.0, -0.0, -9.592484474182129, -10.532347679138184, -12.531993865966797, -11.605690956115723, -13.57827377319336, -15.717464447021484, -15.903738021850586, -17.59433364868164, -16.51476287841797, -18.406177520751953, -20.441242218017578, -19.058326721191406, -20.606290817260742, -20.830318450927734, -20.55154800415039, -20.025367736816406, -18.570924758911133, -18.558767318725586, -15.464618682861328, -16.76097869873047, -15.146324157714844, -14.503767967224121, -12.530986785888672, -10.548196792602539, -9.469087600708008, -9.56308364868164, -8.372870445251465, -6.955782413482666, -6.1785407066345215, -5.45156192779541, -4.9116692543029785, -4.255023002624512, -3.723881959915161, -3.637995719909668, -3.1728696823120117, -2.7447268962860107, -2.373389482498169, -1.9968533515930176, -1.581439733505249, -2.0998694896698, -1.7682753801345825, -2.228705883026123, -1.889767050743103, -1.2265700101852417, -1.0988646745681763, -0.0, -0.0, 0.0, 4.9737725257873535, 2.952939748764038, 0.5043659210205078], [-16.223285675048828, -17.098373413085938, -14.440163612365723, -13.336014747619629, 0.0, -13.934500694274902, -12.502199172973633, -10.974098205566406, -10.73292064666748, -11.256850242614746, -9.469082832336426, -8.393033981323242, -8.309181213378906, -8.575535774230957, -9.27824592590332, -7.908499717712402, -7.6711015701293945, -7.209765911102295, -7.068559646606445, -7.169283866882324, -6.855591297149658, -7.956055641174316, -8.359078407287598, -7.938589096069336, -10.100384712219238, -9.415029525756836, -10.358805656433105, -10.549235343933105, -11.744542121887207, -12.468692779541016, -14.347477912902832, -15.299320220947266, -16.158201217651367, -17.419153213500977, -18.598493576049805, -18.606599807739258, -21.671762466430664, -19.563018798828125, -21.79362678527832, 0.0, -21.619626998901367, -21.92137336730957, -22.280256271362305, -20.525236129760742, -21.79070281982422, -17.967863082885742, -18.411359786987305, -16.226762771606445, -15.259050369262695, -14.101302146911621, -13.021798133850098, -10.97034740447998, -9.502362251281738, -8.604513168334961, -7.114009380340576, -6.634164810180664, -5.5987725257873535, -5.500454425811768, -4.851534366607666, -4.271213531494141, -3.2801105976104736, -6.197235107421875, -3.7315921783447266, -2.669384002685547, -2.285393238067627, -1.8161888122558594, -2.3073337078094482, -2.3358945846557617, -1.6512470245361328, -1.6631051301956177, -1.3303816318511963, -1.7291735410690308, 0.0, 0.0, 5.88075590133667, 2.5612752437591553, 3.253641128540039, 3.9802067279815674, -16.223285675048828, -17.098373413085938, -14.440163612365723, -13.336014747619629, -0.0, -13.934500694274902, -12.502199172973633, -10.974098205566406, -10.73292064666748, -11.256850242614746, -9.469082832336426, -8.393033981323242, -8.309181213378906, -8.575535774230957, -9.27824592590332, -7.908499717712402, -7.6711015701293945, -7.209765911102295, -7.068559646606445, -7.169283866882324, -6.855591297149658, -7.956055641174316, -8.359078407287598, -7.938589096069336, -10.100384712219238, -9.415029525756836, -10.358805656433105, -10.549235343933105, -11.744542121887207, -12.468692779541016, -14.347477912902832, -15.299320220947266, -16.158201217651367, -17.419153213500977, -18.598493576049805, -18.606599807739258, -21.671762466430664, -19.563018798828125, -21.79362678527832, -0.0, -21.619626998901367, -21.92137336730957, -22.280256271362305, -20.525236129760742, -21.79070281982422, -17.967863082885742, -18.411359786987305, -16.226762771606445, -15.259050369262695, -14.101302146911621, -13.021798133850098, -10.97034740447998, -9.502362251281738, -8.604513168334961, -7.114009380340576, -6.634164810180664, -5.5987725257873535, -5.500454425811768, -4.851534366607666, -4.271213531494141, -3.2801105976104736, -6.197235107421875, -3.7315921783447266, -2.669384002685547, -2.285393238067627, -1.8161888122558594, -2.3073337078094482, -2.3358945846557617, -1.6512470245361328, -1.6631051301956177, -1.3303816318511963, -1.7291735410690308, -0.0, 0.0, 5.88075590133667, 2.5612752437591553, 3.253641128540039, 3.9802067279815674], [-17.97150421142578, -16.762964248657227, -14.59238338470459, -13.359603881835938, 0.0, 0.0, -11.751275062561035, -11.297913551330566, -10.790453910827637, -10.210487365722656, -9.872312545776367, -9.879603385925293, -9.72616958618164, -9.163355827331543, -8.355008125305176, -8.358705520629883, -8.20489501953125, -8.01278305053711, -8.338640213012695, -7.8538336753845215, -7.984233856201172, -8.31700611114502, -8.380900382995605, -8.797628402709961, -9.981401443481445, -10.949524879455566, -10.190073013305664, -12.135152816772461, -12.094761848449707, -13.74267578125, -14.404057502746582, -15.730422019958496, -17.321834564208984, -19.18400001525879, -19.763900756835938, -21.391538619995117, -21.72197151184082, -24.546939849853516, 0.0, 0.0, -23.05440902709961, -22.582134246826172, -23.565244674682617, -22.99712371826172, -21.712387084960938, -20.891971588134766, -16.937166213989258, -19.088550567626953, -16.028966903686523, -15.212993621826172, -13.878536224365234, -12.453068733215332, -10.964064598083496, -10.786243438720703, -8.916388511657715, -6.58308744430542, -6.72322416305542, -5.2062458992004395, -4.985129356384277, -4.462893486022949, -3.8540573120117188, -3.796809434890747, -3.9321770668029785, -2.6646292209625244, -2.8250792026519775, -2.53245210647583, -1.7877426147460938, -1.2621722221374512, -1.3264110088348389, -1.4507077932357788, -1.0248490571975708, -0.3636859357357025, 0.0, 6.687036037445068, 4.726690769195557, 3.599649429321289, 3.1686131954193115, 3.303546190261841, -17.97150421142578, -16.762964248657227, -14.59238338470459, -13.359603881835938, -0.0, -0.0, -11.751275062561035, -11.297913551330566, -10.790453910827637, -10.210487365722656, -9.872312545776367, -9.879603385925293, -9.72616958618164, -9.163355827331543, -8.355008125305176, -8.358705520629883, -8.20489501953125, -8.01278305053711, -8.338640213012695, -7.8538336753845215, -7.984233856201172, -8.31700611114502, -8.380900382995605, -8.797628402709961, -9.981401443481445, -10.949524879455566, -10.190073013305664, -12.135152816772461, -12.094761848449707, -13.74267578125, -14.404057502746582, -15.730422019958496, -17.321834564208984, -19.18400001525879, -19.763900756835938, -21.391538619995117, -21.72197151184082, -24.546939849853516, -0.0, -0.0, -23.05440902709961, -22.582134246826172, -23.565244674682617, -22.99712371826172, -21.712387084960938, -20.891971588134766, -16.937166213989258, -19.088550567626953, -16.028966903686523, -15.212993621826172, -13.878536224365234, -12.453068733215332, -10.964064598083496, -10.786243438720703, -8.916388511657715, -6.58308744430542, -6.72322416305542, -5.2062458992004395, -4.985129356384277, -4.462893486022949, -3.8540573120117188, -3.796809434890747, -3.9321770668029785, -2.6646292209625244, -2.8250792026519775, -2.53245210647583, -1.7877426147460938, -1.2621722221374512, -1.3264110088348389, -1.4507077932357788, -1.0248490571975708, -0.3636859357357025, 0.0, 6.687036037445068, 4.726690769195557, 3.599649429321289, 3.1686131954193115, 3.303546190261841], [-17.834400177001953, -16.23827362060547, -17.91314125061035, -13.499126434326172, -13.512364387512207, 0.0, -11.857284545898438, -11.662816047668457, -11.411975860595703, -10.290705680847168, -10.091180801391602, -9.802899360656738, -9.362229347229004, -8.915932655334473, -8.221307754516602, -8.69888973236084, -8.337556838989258, -8.079806327819824, -8.083404541015625, -8.697312355041504, -8.274288177490234, -8.369551658630371, -9.328125, -9.498687744140625, -11.939040184020996, -10.610615730285645, -11.042767524719238, -12.37808609008789, -11.756954193115234, -13.977913856506348, -17.67011833190918, -18.345508575439453, -19.183286666870117, -21.1246337890625, -22.40192985534668, -25.835519790649414, -24.824928283691406, -24.98166847229004, -25.796659469604492, 0.0, -26.767423629760742, -26.12942123413086, -24.7204647064209, -24.346511840820312, -24.75542449951172, -22.462270736694336, -21.106800079345703, -18.410017013549805, -18.920494079589844, -16.03201675415039, -14.405999183654785, -13.056076049804688, -11.740784645080566, -8.929226875305176, -8.73944091796875, -5.4032182693481445, -6.2244977951049805, -6.419096946716309, -6.799489974975586, -5.094673156738281, -4.611607074737549, -4.032104969024658, -4.652576923370361, -2.9049460887908936, -2.8679020404815674, -3.164823293685913, -2.0223631858825684, -1.160207986831665, -0.9339593648910522, -0.9338341355323792, -1.0415505170822144, 0.0, 0.0, 5.033799171447754, 2.7577245235443115, 3.081210136413574, 3.3515820503234863, 1.2229323387145996, -17.834400177001953, -16.23827362060547, -17.91314125061035, -13.499126434326172, -13.512364387512207, -0.0, -11.857284545898438, -11.662816047668457, -11.411975860595703, -10.290705680847168, -10.091180801391602, -9.802899360656738, -9.362229347229004, -8.915932655334473, -8.221307754516602, -8.69888973236084, -8.337556838989258, -8.079806327819824, -8.083404541015625, -8.697312355041504, -8.274288177490234, -8.369551658630371, -9.328125, -9.498687744140625, -11.939040184020996, -10.610615730285645, -11.056195259094238, -12.129592895507812, -12.226118087768555, -14.189891815185547, -17.082963943481445, -18.100238800048828, -19.200965881347656, -20.991201400756836, -22.261289596557617, -24.901443481445312, -24.583498001098633, -24.969907760620117, -25.635242462158203, -0.0, -26.362192153930664, -25.87535285949707, -24.818269729614258, -24.266042709350586, -24.190752029418945, -22.30898666381836, -21.017356872558594, -18.698732376098633, -18.436365127563477, -15.977951049804688, -14.382453918457031, -12.97900104522705, -11.600751876831055, -9.361135482788086, -8.686577796936035, -5.4032182693481445, -6.2244977951049805, -6.419096946716309, -6.799489974975586, -5.094673156738281, -4.611607074737549, -4.032104969024658, -4.652576923370361, -2.9049460887908936, -2.8679020404815674, -3.164823293685913, -2.0223631858825684, -1.160207986831665, -0.9339593648910522, -0.9338341355323792, -1.0415505170822144, -0.0, 0.0, 5.033799171447754, 2.7577245235443115, 3.081210136413574, 3.3515820503234863, 1.2229323387145996], [-16.855337142944336, -16.481523513793945, -15.229647636413574, -14.9727783203125, -15.090485572814941, 0.0, 0.0, -10.903953552246094, -10.81236457824707, -10.415480613708496, -9.665045738220215, -9.887669563293457, -9.699199676513672, -8.515926361083984, -9.988640785217285, -8.160268783569336, -7.722502708435059, -8.021198272705078, -8.623902320861816, -8.274185180664062, -9.103594779968262, -9.160004615783691, -9.482852935791016, -9.722424507141113, -10.494523048400879, -10.713908195495605, -11.718819618225098, -11.950559616088867, -14.266007423400879, -16.344100952148438, -20.08091926574707, -20.193359375, -21.421533584594727, -23.954538345336914, -23.338871002197266, -25.802183151245117, -26.831369400024414, -26.639873504638672, -27.100717544555664, -29.346437454223633, -29.248403549194336, -28.801488876342773, -27.82584571838379, -26.124303817749023, -25.93784523010254, -24.093833923339844, -23.211605072021484, -21.615690231323242, -18.15035057067871, -15.31346607208252, -16.321321487426758, -14.442805290222168, -12.100586891174316, -11.375469207763672, -9.974352836608887, -7.4052042961120605, -6.301469326019287, -6.954809188842773, -6.691038131713867, -6.229623317718506, -5.968276500701904, -5.52260160446167, -4.29371976852417, -3.9309334754943848, -2.7007534503936768, -2.4048681259155273, -2.0695364475250244, -1.6185250282287598, -0.5403488874435425, -0.8901723027229309, -0.8191063404083252, 0.0, 5.437742233276367, 3.792398691177368, 2.9632887840270996, 2.6857786178588867, 2.0608887672424316, 1.924526572227478, -16.855337142944336, -16.481523513793945, -15.229647636413574, -14.9727783203125, -15.090485572814941, -0.0, -0.0, -10.903953552246094, -10.81236457824707, -10.415480613708496, -9.665045738220215, -9.887669563293457, -9.699199676513672, -8.515926361083984, -9.988640785217285, -8.160268783569336, -7.722502708435059, -8.021198272705078, -8.623902320861816, -8.274185180664062, -9.103594779968262, -9.160004615783691, -9.482852935791016, -9.722424507141113, -10.494523048400879, -10.713908195495605, -11.768567085266113, -12.704277992248535, -13.802812576293945, -15.49242115020752, -17.498661041259766, -19.102069854736328, -20.589611053466797, -22.179306030273438, -23.66681671142578, -25.215530395507812, -25.99610137939453, -26.641145706176758, -27.260272979736328, -27.715084075927734, -27.76712989807129, -27.403118133544922, -26.699874877929688, -25.97031021118164, -25.152408599853516, -23.801673889160156, -22.303157806396484, -20.57061195373535, -19.122377395629883, -17.272663116455078, -15.48384952545166, -13.778264045715332, -12.161425590515137, -10.591008186340332, -9.650136947631836, -7.4052042961120605, -6.301469326019287, -6.954809188842773, -6.691038131713867, -6.229623317718506, -5.968276500701904, -5.52260160446167, -4.29371976852417, -3.9309334754943848, -2.7007534503936768, -2.4048681259155273, -2.0695364475250244, -1.6185250282287598, -0.5403488874435425, -0.8901723027229309, -0.8191063404083252, 0.0, 5.437742233276367, 3.792398691177368, 2.9632887840270996, 2.6857786178588867, 2.0608887672424316, 1.924526572227478], [-17.764278411865234, -16.818199157714844, -15.84091567993164, -15.722397804260254, -14.924087524414062, 0.0, 0.0, -9.587589263916016, -10.622267723083496, -10.298895835876465, -10.71960163116455, -9.800992012023926, -9.882472038269043, -9.24035930633545, -6.719770908355713, -8.98497486114502, -9.384018898010254, -9.058704376220703, -7.9720869064331055, -8.661834716796875, -9.332891464233398, -9.212332725524902, -9.397650718688965, -10.046283721923828, -10.995668411254883, -11.74381160736084, -11.392396926879883, -14.462754249572754, -15.031774520874023, -16.449844360351562, -18.88161277770996, -20.77680778503418, -23.34342384338379, -24.74843978881836, -24.709632873535156, -27.365446090698242, -29.33760643005371, -29.58978271484375, -27.061363220214844, -29.916217803955078, -30.855426788330078, -30.219539642333984, -28.8537654876709, -29.548500061035156, -27.25765609741211, -26.94384765625, -24.798654556274414, -22.48932647705078, -20.412221908569336, -19.081851959228516, -16.884492874145508, -15.12789249420166, -12.501376152038574, -11.768511772155762, -9.738929748535156, -9.179880142211914, -7.953978538513184, -7.960297584533691, -6.267075538635254, -7.290196418762207, -6.950475692749023, -5.3529510498046875, -3.264859437942505, -2.173666000366211, 0.0, -2.086318016052246, -1.2964614629745483, -1.7071433067321777, -0.8557474613189697, -0.38324210047721863, 0.0, 1.4071346521377563, 5.5820698738098145, 3.4525396823883057, 3.9236624240875244, 2.4423277378082275, 2.555854558944702, 0.9113575220108032, -17.764278411865234, -16.818199157714844, -15.84091567993164, -15.722397804260254, -14.924087524414062, -0.0, -0.0, -9.587589263916016, -10.622267723083496, -10.298895835876465, -10.71960163116455, -9.800992012023926, -9.882472038269043, -9.24035930633545, -6.719770908355713, -8.98497486114502, -9.384018898010254, -9.058704376220703, -7.9720869064331055, -8.661834716796875, -9.332891464233398, -9.212332725524902, -9.397650718688965, -10.046283721923828, -10.995668411254883, -11.74381160736084, -11.851670265197754, -13.534064292907715, -14.994928359985352, -16.553438186645508, -18.304351806640625, -20.032459259033203, -21.634904861450195, -23.1600284576416, -24.621559143066406, -25.950408935546875, -27.09134864807129, -27.99857521057129, -28.682416915893555, -29.092748641967773, -29.171417236328125, -28.893430709838867, -28.292158126831055, -27.44336700439453, -26.380754470825195, -25.107547760009766, -23.60199546813965, -21.95068359375, -20.21629524230957, -18.439908981323242, -16.579557418823242, -14.681632995605469, -12.933379173278809, -11.348064422607422, -9.845475196838379, -9.179880142211914, -7.953978538513184, -7.960297584533691, -6.267075538635254, -7.290196418762207, -6.950475692749023, -5.3529510498046875, -3.264859437942505, -2.173666000366211, -0.0, -2.086318016052246, -1.2964614629745483, -1.7071433067321777, -0.8557474613189697, -0.38324210047721863, -0.0, 1.4071346521377563, 5.5820698738098145, 3.4525396823883057, 3.9236624240875244, 2.4423277378082275, 2.555854558944702, 0.9113575220108032], [-20.714645385742188, -17.474302291870117, -16.638553619384766, -16.034563064575195, -13.223259925842285, -15.556063652038574, 0.0, 0.0, -8.277437210083008, -9.960878372192383, -10.46231460571289, -10.075736999511719, -9.464012145996094, -8.788790702819824, -9.045665740966797, -9.400293350219727, -9.73666763305664, -9.607429504394531, -9.375526428222656, -9.673276901245117, -9.517838478088379, -10.48730754852295, -10.759685516357422, -10.364447593688965, -10.955245971679688, -12.480567932128906, -14.440849304199219, -14.866146087646484, -15.65658950805664, -16.109710693359375, -20.32473373413086, -22.24144172668457, -25.00398063659668, -26.885995864868164, -28.77446174621582, -25.83979606628418, -24.90574073791504, -26.998319625854492, -26.323955535888672, -27.409788131713867, -27.569866180419922, -26.582338333129883, -24.876300811767578, -27.70116424560547, -23.927080154418945, -22.058929443359375, -21.108503341674805, -24.70354461669922, -23.45730972290039, -21.88548469543457, -18.90467643737793, -16.49049949645996, -14.002734184265137, -11.669149398803711, -10.507933616638184, -9.996737480163574, -9.65771198272705, -7.891160011291504, -8.252395629882812, -8.269013404846191, -7.778861045837402, -9.634261131286621, -4.41158390045166, -2.941063165664673, -2.1375045776367188, -1.8753535747528076, -1.9605251550674438, -2.1261467933654785, 0.0, 0.0, 0.0, 3.264728307723999, 4.368448734283447, 4.161822319030762, 4.3642683029174805, 2.616171360015869, 2.2967891693115234, -0.03604433685541153, -20.714645385742188, -17.474302291870117, -16.638553619384766, -16.034563064575195, -13.223259925842285, -15.556063652038574, -0.0, -0.0, -8.277437210083008, -9.960878372192383, -10.46231460571289, -10.075736999511719, -9.464012145996094, -8.788790702819824, -9.045665740966797, -9.400293350219727, -9.73666763305664, -9.607429504394531, -9.375526428222656, -9.673276901245117, -9.517838478088379, -10.48730754852295, -10.759685516357422, -10.364447593688965, -10.955245971679688, -12.480567932128906, -14.069215774536133, -14.738264083862305, -15.92651653289795, -17.453554153442383, -19.214080810546875, -20.9732723236084, -22.505895614624023, -24.009553909301758, -25.473949432373047, -26.859573364257812, -28.139537811279297, -29.22509002685547, -30.041702270507812, -30.52989387512207, -30.655982971191406, -30.400531768798828, -29.78856086730957, -28.884471893310547, -27.763572692871094, -26.45403480529785, -24.9217472076416, -23.22300910949707, -21.42430877685547, -19.601221084594727, -17.670297622680664, -15.684638977050781, -13.850991249084473, -12.204887390136719, -10.632065773010254, -9.996737480163574, -9.65771198272705, -7.891160011291504, -8.252395629882812, -8.269013404846191, -7.778861045837402, -9.634261131286621, -4.41158390045166, -2.941063165664673, -2.1375045776367188, -1.8753535747528076, -1.9605251550674438, -2.1261467933654785, -0.0, -0.0, 0.0, 3.264728307723999, 4.368448734283447, 4.161822319030762, 4.3642683029174805, 2.616171360015869, 2.2967891693115234, -0.03604433685541153], [-19.440967559814453, -17.074159622192383, -15.940987586975098, -15.54010009765625, -17.661409378051758, -15.244507789611816, -12.766022682189941, -12.144609451293945, 0.0, -10.477323532104492, -10.697489738464355, -10.033875465393066, -9.308340072631836, -10.032779693603516, -9.524633407592773, -9.237504005432129, -10.358063697814941, -9.459813117980957, -9.745285034179688, -9.536752700805664, -9.670546531677246, -11.415488243103027, -10.643324851989746, -11.489848136901855, -11.656271934509277, -13.287748336791992, -15.310209274291992, -15.261163711547852, -16.59621238708496, -19.526105880737305, -18.648719787597656, -23.7391300201416, -23.810834884643555, -22.505008697509766, -23.125587463378906, -25.658151626586914, -26.956605911254883, -27.86238670349121, -29.068391799926758, -29.085527420043945, -29.335474014282227, -27.759750366210938, -27.564035415649414, -27.478824615478516, -26.414644241333008, -24.929569244384766, -21.471057891845703, -20.258544921875, -24.34885025024414, -22.31935691833496, -21.226364135742188, -14.720486640930176, -15.900249481201172, -12.19332504272461, -12.648845672607422, -10.757414817810059, -9.479440689086914, -9.125598907470703, -9.022315979003906, -10.083101272583008, -10.634464263916016, -8.704937934875488, -3.9494621753692627, -2.872105598449707, -2.328545570373535, -1.9040250778198242, -2.642827033996582, 0.0, 0.0, 0.0, 4.5917181968688965, 4.803623676300049, 4.664506912231445, 2.955012083053589, 2.1939945220947266, 2.5642127990722656, 1.372756004333496, -0.7647278308868408, -19.440967559814453, -17.074159622192383, -15.940987586975098, -15.54010009765625, -17.661409378051758, -15.244507789611816, -12.766022682189941, -12.144609451293945, -0.0, -10.477323532104492, -10.697489738464355, -10.033875465393066, -9.308340072631836, -10.032779693603516, -9.524633407592773, -9.237504005432129, -10.358063697814941, -9.459813117980957, -9.745285034179688, -9.536752700805664, -9.670546531677246, -11.415488243103027, -10.643324851989746, -11.489848136901855, -11.656271934509277, -13.287748336791992, -14.777158737182617, -15.449265480041504, -16.660982131958008, -18.254199981689453, -19.99028968811035, -21.675045013427734, -23.21518325805664, -24.77651596069336, -26.340845108032227, -27.851009368896484, -29.249004364013672, -30.46754264831543, -31.413618087768555, -32.00587463378906, -32.194610595703125, -31.945465087890625, -31.309925079345703, -30.377735137939453, -29.22269630432129, -27.863155364990234, -26.26534652709961, -24.48825454711914, -22.614473342895508, -20.685714721679688, -18.68387222290039, -16.622568130493164, -14.764500617980957, -13.24074935913086, -12.291645050048828, -10.757414817810059, -9.479440689086914, -9.125598907470703, -9.022315979003906, -10.083101272583008, -10.634464263916016, -8.704937934875488, -3.9494621753692627, -2.872105598449707, -2.328545570373535, -1.9040250778198242, -2.642827033996582, -0.0, -0.0, 0.0, 4.5917181968688965, 4.803623676300049, 4.664506912231445, 2.955012083053589, 2.1939945220947266, 2.5642127990722656, 1.372756004333496, -0.7647278308868408], [-19.616140365600586, -18.503570556640625, -15.679512023925781, -16.556066513061523, -15.429866790771484, -14.490317344665527, -12.893270492553711, -11.650358200073242, -11.358978271484375, 0.0, -9.995945930480957, -10.737777709960938, -9.223563194274902, -8.753210067749023, -10.019082069396973, -9.64967155456543, -9.89399528503418, -9.812311172485352, -10.310148239135742, -9.997797012329102, -11.135865211486816, -10.88195514678955, -9.355752944946289, -11.402203559875488, -11.744707107543945, -13.040026664733887, -14.049485206604004, -16.236223220825195, -16.819015502929688, -17.98277473449707, -20.91611099243164, -24.870132446289062, -22.897192001342773, -23.83588981628418, -26.3522891998291, -28.17474937438965, -28.658918380737305, -30.952924728393555, -28.151077270507812, -30.79084014892578, -31.27535629272461, -26.09834861755371, -26.156320571899414, -27.81352424621582, -26.962215423583984, -25.659814834594727, -24.122417449951172, -22.17121696472168, -20.963390350341797, -24.239355087280273, -20.841279983520508, -18.393396377563477, -18.37140655517578, -13.95236873626709, -12.637382507324219, -11.90163516998291, -10.296456336975098, -9.767560958862305, -10.204256057739258, 0.0, -5.109600067138672, -4.790162563323975, -3.7861526012420654, -4.10754919052124, -5.116549491882324, 0.0, 0.0, 0.0, 0.0, 0.0, 4.754608154296875, 4.795953273773193, 4.015260696411133, 2.270103693008423, 2.2459192276000977, 1.4655053615570068, 0.06201248615980148, 0.0, -19.616140365600586, -18.503570556640625, -15.679512023925781, -16.556066513061523, -15.429866790771484, -14.490317344665527, -12.893270492553711, -11.650358200073242, -11.358978271484375, -0.0, -9.995945930480957, -10.737777709960938, -9.223563194274902, -8.753210067749023, -10.019082069396973, -9.64967155456543, -9.89399528503418, -9.812311172485352, -10.310148239135742, -9.997797012329102, -11.135865211486816, -10.88195514678955, -9.355752944946289, -11.402203559875488, -11.744707107543945, -13.040026664733887, -14.089126586914062, -15.56007194519043, -17.21010398864746, -18.988292694091797, -20.78911018371582, -22.274574279785156, -23.77548599243164, -25.51394271850586, -27.238271713256836, -28.89360237121582, -30.40848731994629, -31.732690811157227, -32.790977478027344, -33.48442459106445, -33.73056411743164, -33.491119384765625, -32.84324645996094, -31.886062622070312, -30.697364807128906, -29.26532745361328, -27.573017120361328, -25.704509735107422, -23.724817276000977, -21.654155731201172, -19.52252197265625, -17.472959518432617, -15.641353607177734, -14.052375793457031, -12.599493026733398, -11.90163516998291, -10.296456336975098, -9.767560958862305, -10.204256057739258, -0.0, -5.109600067138672, -4.790162563323975, -3.7861526012420654, -4.10754919052124, -5.116549491882324, -0.0, -0.0, -0.0, 0.0, 0.0, 4.754608154296875, 4.795953273773193, 4.015260696411133, 2.270103693008423, 2.2459192276000977, 1.4655053615570068, 0.06201248615980148, 0.0], [-18.88078498840332, -18.647401809692383, -17.082000732421875, -18.625255584716797, -15.082109451293945, -13.021595001220703, -13.502751350402832, -11.998164176940918, -11.590492248535156, -12.51927375793457, 0.0, -11.455370903015137, -10.358419418334961, -10.085203170776367, -10.190502166748047, -10.171526908874512, -9.93409538269043, -9.825644493103027, -9.957059860229492, -11.234640121459961, -11.786515235900879, -11.784673690795898, -13.153609275817871, -10.66990852355957, -13.443329811096191, 0.0, -12.22540283203125, -16.02690315246582, -17.92554473876953, -19.334447860717773, -22.90179443359375, -26.387407302856445, -25.722087860107422, -26.45591926574707, -28.365232467651367, -29.77170181274414, -25.356700897216797, -27.923702239990234, -26.802371978759766, -29.742473602294922, -28.875865936279297, -28.641845703125, -26.79982566833496, -25.755287170410156, -24.536901473999023, -21.910179138183594, -21.222427368164062, -21.393470764160156, -21.204919815063477, -19.864856719970703, -22.54492950439453, -19.580698013305664, -16.391319274902344, -13.84788990020752, -13.9129638671875, -15.262911796569824, -13.360713958740234, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.8915717601776123, 3.721006155014038, 3.5605366230010986, 2.275480031967163, 2.7618281841278076, 2.6894192695617676, 0.20202744007110596, 0.0, 0.0, -18.88078498840332, -18.647401809692383, -17.082000732421875, -18.625255584716797, -15.082109451293945, -13.021595001220703, -13.502751350402832, -11.998164176940918, -11.590492248535156, -12.51927375793457, -0.0, -11.455370903015137, -10.358419418334961, -10.085203170776367, -10.190502166748047, -10.171526908874512, -9.93409538269043, -9.825644493103027, -9.957059860229492, -11.234640121459961, -11.786515235900879, -11.784673690795898, -13.153609275817871, -10.66990852355957, -13.443329811096191, -0.0, -13.070897102355957, -15.519791603088379, -17.723215103149414, -19.704002380371094, -21.53995704650879, -22.93642807006836, -24.425453186035156, -26.306127548217773, -28.1700382232666, -29.947101593017578, -31.56476402282715, -32.960357666015625, -34.08831024169922, -34.895355224609375, -35.25548553466797, -34.98490524291992, -34.32233810424805, -33.353816986083984, -32.13004684448242, -30.600872039794922, -28.79665184020996, -26.816635131835938, -24.725332260131836, -22.540857315063477, -20.342098236083984, -18.272031784057617, -16.449668884277344, -14.939611434936523, -13.751716613769531, -15.262911796569824, -13.360713958740234, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 3.8915717601776123, 3.721006155014038, 3.5605366230010986, 2.275480031967163, 2.7618281841278076, 2.6894192695617676, 0.20202744007110596, 0.0, 0.0], [0.0, -20.522701263427734, -16.85768699645996, -14.286554336547852, -14.083681106567383, -13.778953552246094, -12.813179969787598, -13.413617134094238, -11.67237377166748, -11.325651168823242, -10.58443832397461, 0.0, -10.365943908691406, -10.897870063781738, -11.220731735229492, -11.072535514831543, -11.40634536743164, -12.607003211975098, -10.689616203308105, -11.972963333129883, -10.537753105163574, -12.592896461486816, -12.329203605651855, -12.273762702941895, 0.0, 0.0, 0.0, -16.513219833374023, -17.5963077545166, -20.68791389465332, -20.881628036499023, 0.0, -25.046476364135742, -29.63132095336914, -25.78252601623535, -26.120847702026367, -28.355451583862305, -29.346328735351562, -30.66343879699707, -31.22496223449707, -29.923906326293945, -30.590328216552734, -28.95696449279785, -29.10691261291504, -26.706830978393555, -23.155052185058594, -22.48077392578125, -25.88603401184082, -21.8651180267334, -21.335710525512695, -18.745269775390625, -22.025663375854492, -17.735422134399414, -15.201045989990234, -15.485787391662598, -17.63360023498535, -17.426109313964844, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.020182132720947, 4.0203938484191895, 4.695221424102783, 3.8417069911956787, 2.2776992321014404, 2.2621166706085205, 2.125913143157959, 0.9727659821510315, 0.0, 0.0, -0.0, -20.522701263427734, -16.85768699645996, -14.286554336547852, -14.083681106567383, -13.778953552246094, -12.813179969787598, -13.413617134094238, -11.67237377166748, -11.325651168823242, -10.58443832397461, -0.0, -10.365943908691406, -10.897870063781738, -11.220731735229492, -11.072535514831543, -11.40634536743164, -12.607003211975098, -10.689616203308105, -11.972963333129883, -10.537753105163574, -12.592896461486816, -12.329203605651855, -12.273762702941895, -0.0, -0.0, -0.0, -16.107086181640625, -18.390703201293945, -20.442235946655273, -22.38835906982422, -0.0, -25.087862014770508, -27.166881561279297, -29.119558334350586, -30.99213218688965, -32.69960021972656, -34.129905700683594, -35.24574661254883, -36.19208526611328, -36.6303596496582, -36.37376022338867, -35.71269989013672, -34.7534294128418, -33.496543884277344, -31.866466522216797, -29.959640502929688, -27.87291717529297, -25.675193786621094, -23.401527404785156, -21.16303825378418, -19.066926956176758, -17.225955963134766, -15.801131248474121, -14.995889663696289, -17.63360023498535, -17.426109313964844, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 5.020182132720947, 4.0203938484191895, 4.695221424102783, 3.8417069911956787, 2.2776992321014404, 2.2621166706085205, 2.125913143157959, 0.9727659821510315, 0.0, 0.0], [0.0, 0.0, -14.06354808807373, -17.971023559570312, -14.570511817932129, -11.666727066040039, -14.578913688659668, -13.225727081298828, -11.395904541015625, -11.90771484375, -10.534228324890137, -10.739133834838867, 0.0, -11.74058723449707, -8.415789604187012, -9.172581672668457, -11.03513240814209, -11.697145462036133, -11.331866264343262, -12.428634643554688, -12.700559616088867, 0.0, 0.0, -10.65019702911377, 0.0, 0.0, 0.0, 0.0, -22.020427703857422, -22.02165985107422, -22.845741271972656, 0.0, 0.0, -28.75309944152832, -26.461257934570312, -28.745969772338867, -29.86310577392578, -28.879858016967773, -31.679710388183594, -32.41084289550781, -33.231468200683594, -30.376955032348633, -30.39756965637207, -30.196044921875, -27.987274169921875, -26.444276809692383, -24.838523864746094, -28.052621841430664, -25.210359573364258, -21.610774993896484, -18.794662475585938, -22.097454071044922, -18.988069534301758, 0.0, 0.0, 0.0, -18.452917098999023, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.687046527862549, 2.609541416168213, 2.9110960960388184, 1.6981371641159058, 3.654484510421753, 2.5531606674194336, 0.27089110016822815, 0.0, 0.0, 0.0, -0.0, -0.0, -14.06354808807373, -17.971023559570312, -14.570511817932129, -11.666727066040039, -14.578913688659668, -13.225727081298828, -11.395904541015625, -11.90771484375, -10.534228324890137, -10.739133834838867, -0.0, -11.74058723449707, -8.415789604187012, -9.172581672668457, -11.03513240814209, -11.697145462036133, -11.331866264343262, -12.428634643554688, -12.700559616088867, -0.0, -0.0, -10.65019702911377, -0.0, -0.0, -0.0, -0.0, -19.011999130249023, -21.115907669067383, -23.313255310058594, -0.0, -0.0, -28.0648136138916, -30.055273056030273, -32.05586624145508, -33.8524055480957, -35.26814270019531, -36.31793975830078, -37.2401008605957, -37.6967658996582, -37.620025634765625, -36.98395538330078, -36.04000473022461, -34.789913177490234, -33.13239288330078, -31.138809204101562, -28.939027786254883, -26.616811752319336, -24.23697280883789, -21.94387435913086, -19.863489151000977, -18.04749870300293, -0.0, -0.0, -0.0, -18.452917098999023, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 4.687046527862549, 2.609541416168213, 2.9110960960388184, 1.6981371641159058, 3.654484510421753, 2.5531606674194336, 0.27089110016822815, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, -19.290637969970703, -17.27538299560547, -16.430517196655273, -14.687362670898438, -14.23105525970459, -12.544469833374023, -12.824462890625, -10.21609115600586, -9.539538383483887, -12.65556526184082, -11.18962574005127, 0.0, 0.0, -9.561261177062988, 0.0, -14.593454360961914, -13.088287353515625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.43537712097168, -18.105215072631836, -19.37836456298828, -21.70891761779785, -21.89915657043457, 0.0, 0.0, 0.0, -28.78457260131836, -25.425018310546875, -28.09132957458496, -27.599178314208984, 0.0, 0.0, 0.0, 0.0, -32.026939392089844, -33.54391860961914, -30.108816146850586, -28.1503849029541, -29.035436630249023, -29.178630828857422, -27.201501846313477, 0.0, -21.116846084594727, -24.397172927856445, -22.434154510498047, 0.0, 0.0, -15.070362091064453, -13.665016174316406, -12.919015884399414, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.007883071899414, 3.057983160018921, 2.633136510848999, 3.603890895843506, 2.645329236984253, 2.8615634441375732, 4.064540386199951, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -19.290637969970703, -17.27538299560547, -16.430517196655273, -14.687362670898438, -14.23105525970459, -12.544469833374023, -12.824462890625, -10.21609115600586, -9.539538383483887, -12.65556526184082, -11.18962574005127, -0.0, -0.0, -9.561261177062988, -0.0, -14.593454360961914, -13.088287353515625, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.650041580200195, -18.422285079956055, -19.801103591918945, -21.815879821777344, -23.97321891784668, -0.0, -0.0, -0.0, -30.820764541625977, -32.82194519042969, -34.74713134765625, -36.13447570800781, -0.0, -0.0, -0.0, -0.0, -38.03086853027344, -37.117679595947266, -35.93929672241211, -34.39866256713867, -32.32552719116211, -29.99806022644043, -27.5301513671875, -0.0, -22.65479278564453, -20.725954055786133, -19.048315048217773, -0.0, -0.0, -15.070362091064453, -13.665016174316406, -12.919015884399414, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 6.007883071899414, 3.057983160018921, 2.633136510848999, 3.603890895843506, 2.645329236984253, 2.8615634441375732, 4.064540386199951, 0.0, 0.0, 0.0], [0.0, 0.0, -25.744831085205078, 0.0, -15.275166511535645, -15.806039810180664, -13.741429328918457, -13.397188186645508, -14.13780403137207, -12.752068519592285, -12.072468757629395, -12.180122375488281, -10.046835899353027, -12.51848030090332, 0.0, -6.35438346862793, -9.833258628845215, 0.0, -15.521917343139648, -16.69422721862793, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.531450271606445, -19.069364547729492, -21.245203018188477, 0.0, -22.427719116210938, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -31.51332664489746, -32.2663688659668, 0.0, 0.0, -28.765300750732422, -29.75641632080078, -28.82362937927246, -25.679162979125977, -28.486915588378906, -25.040943145751953, -21.903018951416016, -24.654170989990234, -22.77462387084961, 0.0, -16.483097076416016, -15.854233741760254, -15.090864181518555, -13.864360809326172, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.26548171043396, 1.0703654289245605, 2.4046506881713867, 3.6679346561431885, 2.7339468002319336, 1.635453462600708, -0.08805577456951141, 0.0, 0.0, 0.0, -0.0, -0.0, -25.744831085205078, -0.0, -15.275166511535645, -15.806039810180664, -13.741429328918457, -13.397188186645508, -14.13780403137207, -12.752068519592285, -12.072468757629395, -12.180122375488281, -10.046835899353027, -12.51848030090332, -0.0, -6.35438346862793, -9.833258628845215, -0.0, -15.521917343139648, -16.69422721862793, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.534122467041016, -19.681011199951172, -21.06459617614746, -0.0, -24.840192794799805, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -38.98682403564453, -39.0966682434082, -0.0, -0.0, -36.821006774902344, -35.44614791870117, -33.397300720214844, -30.9515380859375, -28.425119400024414, -25.791662216186523, -23.23865509033203, -21.668882369995117, -20.296594619750977, -0.0, -16.414936065673828, -15.854233741760254, -15.090864181518555, -13.864360809326172, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 2.26548171043396, 1.0703654289245605, 2.4046506881713867, 3.6679346561431885, 2.7339468002319336, 1.635453462600708, -0.08805577456951141, -0.0, 0.0, 0.0], [-25.1419734954834, -23.629356384277344, -21.29088592529297, 0.0, -13.078241348266602, -16.283729553222656, -14.865811347961426, -13.979386329650879, -14.673116683959961, -13.970804214477539, -12.780176162719727, -10.815205574035645, -11.32612133026123, -12.079777717590332, 0.0, -7.635781764984131, -7.608219623565674, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -21.686012268066406, -24.254560470581055, -24.801353454589844, -24.051889419555664, -26.46466827392578, 0.0, 0.0, -27.99408721923828, -29.13599967956543, 0.0, -32.36286544799805, -34.39250183105469, 0.0, 0.0, -33.1920051574707, -35.48759841918945, -34.14368438720703, 0.0, 0.0, -28.407230377197266, -30.607393264770508, -26.8582763671875, -25.742023468017578, -24.584491729736328, 0.0, -25.766237258911133, -23.719532012939453, -19.909313201904297, -18.148683547973633, -17.331417083740234, -16.0197696685791, -15.738669395446777, -18.215972900390625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.2084836959838867, 1.9707911014556885, 2.585054397583008, 1.6168427467346191, 2.427935838699341, 0.6633927226066589, 0.0, 4.854883193969727, 0.0, 0.0, -25.1419734954834, -23.629356384277344, -21.29088592529297, -0.0, -13.078241348266602, -16.283729553222656, -14.865811347961426, -13.979386329650879, -14.673116683959961, -13.970804214477539, -12.780176162719727, -10.815205574035645, -11.32612133026123, -12.079777717590332, -0.0, -7.635781764984131, -7.608219623565674, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -21.59699249267578, -21.28556251525879, -22.352474212646484, -23.85025978088379, -25.811033248901367, -0.0, -0.0, -30.480152130126953, -32.1722297668457, -0.0, -35.26100540161133, -36.442100524902344, -0.0, -0.0, -39.46887969970703, -39.50503921508789, -38.954559326171875, -0.0, -0.0, -36.068180084228516, -33.99916076660156, -31.570070266723633, -29.22060775756836, -26.748180389404297, -0.0, -22.69341278076172, -21.275238037109375, -19.375192642211914, -18.14052391052246, -17.331417083740234, -16.0197696685791, -15.738669395446777, -18.215972900390625, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 2.2084836959838867, 1.9707911014556885, 2.585054397583008, 1.6168427467346191, 2.427935838699341, 0.6633927226066589, -0.0, 4.854883193969727, 0.0, 0.0], [-26.50396728515625, -24.29684829711914, -23.674114227294922, 0.0, 0.0, -16.3470458984375, -15.015251159667969, -14.800688743591309, -11.831171989440918, -14.421363830566406, -13.163570404052734, -10.76369857788086, -11.978194236755371, -13.29479694366455, 0.0, 0.0, -4.436125755310059, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.769132614135742, -25.1525936126709, 0.0, 0.0, 0.0, -28.202234268188477, -25.93543243408203, -25.72845458984375, 0.0, 0.0, 0.0, -31.802396774291992, 0.0, 0.0, 0.0, -29.74953269958496, -32.061126708984375, -30.251121520996094, -32.26971435546875, -27.875396728515625, -27.64187240600586, -29.755023956298828, -29.242612838745117, -28.04204750061035, 0.0, 0.0, -16.82174301147461, -17.895029067993164, -17.124948501586914, 0.0, -16.831342697143555, 0.0, 0.0, 0.0, -10.954090118408203, 0.0, 0.0, 0.0, 0.0, 0.0, 0.7885892987251282, 3.2283108234405518, 2.548464298248291, 2.0890913009643555, 1.1618502140045166, 2.4074864387512207, 0.0, 4.407622337341309, 0.0, 0.0, -26.50396728515625, -24.29684829711914, -23.674114227294922, -0.0, -0.0, -16.3470458984375, -15.015251159667969, -14.800688743591309, -11.831171989440918, -14.421363830566406, -13.163570404052734, -10.76369857788086, -11.978194236755371, -13.29479694366455, -0.0, -0.0, -4.436125755310059, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.779342651367188, -25.193565368652344, -0.0, -0.0, -0.0, -31.5441837310791, -32.676387786865234, -34.08474349975586, -0.0, -0.0, -0.0, -38.626373291015625, -0.0, -0.0, -0.0, -38.65412902832031, -37.53675079345703, -35.709869384765625, -33.79536819458008, -31.541147232055664, -29.343746185302734, -27.555461883544922, -25.415992736816406, -23.641407012939453, -0.0, -0.0, -17.77652359008789, -17.895029067993164, -17.124948501586914, -0.0, -16.831342697143555, -0.0, -0.0, -0.0, -10.954090118408203, -0.0, -0.0, 0.0, 0.0, 0.0, 0.7885892987251282, 3.2283108234405518, 2.548464298248291, 2.0890913009643555, 1.1618502140045166, 2.4074864387512207, 0.0, 4.407622337341309, -0.0, -0.0], [-25.86934471130371, 0.0, -20.686460494995117, 0.0, 0.0, 0.0, -15.639466285705566, -15.615923881530762, -14.18388557434082, -13.581537246704102, -11.974906921386719, -11.861834526062012, -12.372695922851562, -13.455810546875, -11.940635681152344, 0.0, -5.5958147048950195, -7.765393257141113, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.232389450073242, -27.12108612060547, 0.0, -30.430137634277344, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -32.34925842285156, -34.28561782836914, -32.565433502197266, 0.0, -33.05818176269531, -33.20648193359375, -31.679121017456055, -30.906373977661133, -28.629108428955078, 0.0, -28.53154754638672, -26.544225692749023, 0.0, 0.0, -20.473522186279297, -21.04489517211914, -19.517541885375977, 0.0, -16.659282684326172, 0.0, 0.0, 0.0, -12.257302284240723, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.727602481842041, 2.6849684715270996, 3.379560947418213, 1.9330955743789673, 0.0, 0.0, 2.111477851867676, -0.8378104567527771, 0.0, -25.86934471130371, -0.0, -20.686460494995117, -0.0, -0.0, -0.0, -15.639466285705566, -15.615923881530762, -14.18388557434082, -13.581537246704102, -11.974906921386719, -11.861834526062012, -12.372695922851562, -13.455810546875, -11.940635681152344, -0.0, -5.5958147048950195, -7.765393257141113, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.368423461914062, -26.86907958984375, -0.0, -29.843469619750977, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -39.4392204284668, -39.53980255126953, -39.14767074584961, -0.0, -36.864044189453125, -34.62403869628906, -32.68384552001953, -30.890583038330078, -29.16025733947754, -0.0, -25.969066619873047, -24.048748016357422, -0.0, -0.0, -20.164928436279297, -21.04489517211914, -19.517541885375977, -0.0, -16.659282684326172, -0.0, -0.0, -0.0, -12.257302284240723, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 2.727602481842041, 2.6849684715270996, 3.379560947418213, 1.9330955743789673, 0.0, 0.0, 2.111477851867676, -0.8378104567527771, -0.0], [0.0, 0.0, 0.0, -22.27549171447754, 0.0, 0.0, -16.628406524658203, -14.223461151123047, -13.699042320251465, -13.322932243347168, -12.547565460205078, -13.304564476013184, -11.738299369812012, -11.543583869934082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.161314010620117, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -31.673498153686523, -35.37504577636719, 0.0, -29.6765079498291, -28.316322326660156, -31.98358726501465, -30.604047775268555, -27.290678024291992, -25.511537551879883, 0.0, -27.956249237060547, -26.87587547302246, 0.0, 0.0, 0.0, 0.0, 0.0, -15.295108795166016, -14.325859069824219, -14.434528350830078, -15.00893497467041, -12.137893676757812, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.189990758895874, 4.992954254150391, 3.2673227787017822, 0.0, 0.0, 1.1098023653030396, 0.0, 0.0, -0.0, -0.0, -0.0, -22.27549171447754, -0.0, -0.0, -16.628406524658203, -14.223461151123047, -13.699042320251465, -13.322932243347168, -12.547565460205078, -13.304564476013184, -11.738299369812012, -11.543583869934082, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.444011688232422, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -38.52517318725586, -38.51567459106445, -0.0, -37.8804817199707, -36.17348861694336, -33.88523864746094, -31.896520614624023, -30.25774574279785, -28.5993595123291, -0.0, -25.476940155029297, -23.49596405029297, -0.0, -0.0, -0.0, -0.0, -0.0, -15.295108795166016, -14.325859069824219, -14.434528350830078, -15.00893497467041, -12.137893676757812, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 2.189990758895874, 4.992954254150391, 3.2673227787017822, 0.0, 0.0, 1.1098023653030396, -0.0, -0.0], [0.0, 0.0, 0.0, -23.32155418395996, -22.533315658569336, 0.0, 0.0, -15.91575813293457, -13.513036727905273, -13.202248573303223, -12.212174415588379, -13.249845504760742, -12.677644729614258, -11.15137767791748, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.67019271850586, 0.0, 0.0, 0.0, 0.0, -26.836565017700195, -27.34128761291504, 0.0, -33.198890686035156, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -38.68046951293945, -35.71656036376953, -33.99580383300781, -33.73960494995117, -33.3796501159668, 0.0, 0.0, 0.0, -29.040958404541016, -26.738361358642578, -24.329513549804688, 0.0, 0.0, -26.719680786132812, 0.0, 0.0, -16.596012115478516, -17.458158493041992, -16.076955795288086, -16.32284927368164, -16.51801300048828, -13.585108757019043, -13.483283042907715, -13.985442161560059, -11.875725746154785, -12.862574577331543, 0.0, 0.0, -6.4037065505981445, -7.563109874725342, -4.881221771240234, 0.0, 1.751980185508728, 1.8800371885299683, 0.04253138601779938, 0.0, 1.4827791452407837, 3.813875913619995, 4.052459716796875, 0.0, -0.0, -0.0, -0.0, -23.32155418395996, -22.533315658569336, -0.0, -0.0, -15.91575813293457, -13.513036727905273, -13.202248573303223, -12.212174415588379, -13.249845504760742, -12.677644729614258, -11.15137767791748, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.67019271850586, -0.0, -0.0, -0.0, -0.0, -28.790983200073242, -30.072406768798828, -0.0, -32.363285064697266, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -36.093013763427734, -37.180152893066406, -37.74174118041992, -37.614158630371094, -37.26365280151367, -0.0, -0.0, -0.0, -31.52706527709961, -29.77126693725586, -28.02355194091797, -0.0, -0.0, -22.727216720581055, -0.0, -0.0, -16.86223793029785, -17.458158493041992, -16.076955795288086, -16.32284927368164, -16.51801300048828, -13.585108757019043, -13.483283042907715, -13.985442161560059, -11.875725746154785, -12.862574577331543, -0.0, -0.0, -6.4037065505981445, -7.563109874725342, -4.881221771240234, 0.0, 1.751980185508728, 1.8800371885299683, 0.04253138601779938, 0.0, 1.4827791452407837, 3.813875913619995, 4.052459716796875, 0.0], [0.0, 0.0, 0.0, -21.318513870239258, -24.29119110107422, 0.0, 0.0, -13.742295265197754, -14.27336597442627, -13.295722961425781, -14.068164825439453, -13.346388816833496, 0.0, -9.005966186523438, 0.0, -12.284911155700684, 0.0, 0.0, -19.297468185424805, -18.942399978637695, 0.0, 0.0, 0.0, -23.63567352294922, -27.111026763916016, -29.647851943969727, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.681421279907227, -31.135021209716797, 0.0, -32.998348236083984, -32.93558883666992, 0.0, 0.0, -32.4234504699707, -32.48499298095703, -30.489471435546875, 0.0, -31.03143310546875, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -30.89019012451172, 0.0, 0.0, 0.0, 0.0, 0.0, -16.964324951171875, -17.694034576416016, -16.26335334777832, -15.06334400177002, -14.663771629333496, -13.866083145141602, -13.265778541564941, -12.067512512207031, -11.523670196533203, -11.11877155303955, 0.0, -5.058064937591553, -7.224656105041504, -8.614104270935059, 0.0, 0.0, 1.3375909328460693, 0.0, -1.5379472970962524, 0.3722027838230133, 3.6428487300872803, 0.0, -0.0, -0.0, -0.0, -21.318513870239258, -24.29119110107422, -0.0, -0.0, -13.742295265197754, -14.27336597442627, -13.295722961425781, -14.068164825439453, -13.346388816833496, -0.0, -9.005966186523438, -0.0, -12.284911155700684, -0.0, -0.0, -19.297468185424805, -18.942399978637695, -0.0, -0.0, -0.0, -23.63567352294922, -27.111026763916016, -29.647851943969727, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -33.554542541503906, -33.88002014160156, -0.0, -34.63071060180664, -34.83666229248047, -0.0, -0.0, -36.843116760253906, -36.76380920410156, -36.51334762573242, -0.0, -34.64772033691406, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.84833335876465, -0.0, -0.0, -0.0, -0.0, -0.0, -16.964324951171875, -17.694034576416016, -16.26335334777832, -15.06334400177002, -14.663771629333496, -13.866083145141602, -13.265778541564941, -12.067512512207031, -11.523670196533203, -11.11877155303955, -0.0, -5.058064937591553, -7.224656105041504, -8.614104270935059, 0.0, 0.0, 1.3375909328460693, -0.0, -1.5379472970962524, 0.3722027838230133, 3.6428487300872803, 0.0], [0.0, 0.0, 0.0, 0.0, -25.05941390991211, 0.0, 0.0, 0.0, -15.157255172729492, -12.947301864624023, -13.640511512756348, -15.983094215393066, 0.0, -13.361169815063477, -12.439312934875488, -15.070765495300293, 0.0, -16.019248962402344, -16.990568161010742, -17.31136703491211, -18.5084171295166, -20.268169403076172, 0.0, -24.016090393066406, -25.918333053588867, -26.96073341369629, 0.0, 0.0, 0.0, -33.49819564819336, -32.358848571777344, -33.67015075683594, -32.46736526489258, -31.47924041748047, 0.0, -31.229995727539062, 0.0, -34.40471267700195, 0.0, 0.0, -29.836484909057617, -32.92790222167969, 0.0, -32.501956939697266, 0.0, 0.0, -29.722658157348633, 0.0, 0.0, 0.0, 0.0, -25.49115753173828, -22.476356506347656, 0.0, -20.902511596679688, -21.990013122558594, -18.33969497680664, -18.27126693725586, -17.571203231811523, -15.883140563964844, -14.979887962341309, -14.698653221130371, -14.104267120361328, -12.578584671020508, -11.101727485656738, -9.85389518737793, -9.515368461608887, -8.241764068603516, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -4.555599212646484, -4.230314254760742, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -25.05941390991211, -0.0, -0.0, -0.0, -15.157255172729492, -12.947301864624023, -13.640511512756348, -15.983094215393066, -0.0, -13.361169815063477, -12.439312934875488, -15.070765495300293, -0.0, -16.019248962402344, -16.990568161010742, -17.31136703491211, -18.5084171295166, -20.268169403076172, -0.0, -24.016090393066406, -25.918333053588867, -26.96073341369629, -0.0, -0.0, -0.0, -32.292442321777344, -33.63045883178711, -34.14762878417969, -34.06608963012695, -34.23298645019531, -0.0, -34.43372344970703, -0.0, -35.06016159057617, -0.0, -0.0, -35.45439147949219, -34.748931884765625, -0.0, -32.80956268310547, -0.0, -0.0, -29.940584182739258, -0.0, -0.0, -0.0, -0.0, -21.461936950683594, -20.06368064880371, -0.0, -20.136831283569336, -21.990013122558594, -18.33969497680664, -18.27126693725586, -17.571203231811523, -15.883140563964844, -14.979887962341309, -14.698653221130371, -14.104267120361328, -12.578584671020508, -11.101727485656738, -9.85389518737793, -9.515368461608887, -8.241764068603516, -0.0, -0.0, 0.0, 0.0, 0.0, -0.0, -4.555599212646484, -4.230314254760742, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -22.112186431884766, -18.881032943725586, 0.0, 0.0, -12.808156967163086, 0.0, 0.0, -13.377167701721191, -11.715314865112305, -13.61425495147705, -12.7859468460083, -17.217205047607422, -16.61213493347168, -17.236019134521484, -18.407535552978516, -20.078039169311523, -22.22823715209961, -23.464420318603516, -25.256799697875977, -25.330078125, -27.783388137817383, 0.0, 0.0, -32.56509017944336, -34.92512893676758, 0.0, 0.0, -28.769329071044922, -33.3201904296875, -32.26460266113281, -33.83347702026367, -34.71808624267578, 0.0, 0.0, -31.688493728637695, -30.974830627441406, -30.429672241210938, -30.856355667114258, -31.293926239013672, -28.7886962890625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.37321949005127, -17.63987922668457, -18.98373031616211, -19.175708770751953, -18.75099754333496, -17.088300704956055, -17.460086822509766, -15.978339195251465, -14.946182250976562, -13.93255615234375, -12.610503196716309, -11.470331192016602, -10.300007820129395, -9.554756164550781, -7.51351261138916, 0.0, -2.96797776222229, 0.09466811269521713, 0.0, 0.0, 0.0, -1.4759918451309204, -4.128509044647217, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.112186431884766, -18.881032943725586, -0.0, -0.0, -12.808156967163086, -0.0, -0.0, -13.377167701721191, -11.715314865112305, -13.61425495147705, -12.7859468460083, -17.217205047607422, -16.61213493347168, -17.236019134521484, -18.407535552978516, -20.078039169311523, -22.22823715209961, -23.464420318603516, -25.256799697875977, -25.330078125, -27.783388137817383, -0.0, -0.0, -31.079402923583984, -32.4972038269043, -0.0, -0.0, -34.82194137573242, -34.70940017700195, -34.857643127441406, -34.57222366333008, -34.23710632324219, -0.0, -0.0, -34.75279998779297, -33.88056564331055, -32.93022537231445, -31.970422744750977, -31.118167877197266, -30.462875366210938, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.33709144592285, -18.128135681152344, -18.98373031616211, -19.175708770751953, -18.75099754333496, -17.088300704956055, -17.460086822509766, -15.978339195251465, -14.946182250976562, -13.93255615234375, -12.610503196716309, -11.470331192016602, -10.300007820129395, -9.554756164550781, -7.51351261138916, -0.0, -2.96797776222229, 0.09466811269521713, 0.0, -0.0, -0.0, -1.4759918451309204, -4.128509044647217, -0.0, -0.0], [0.0, 0.0, -21.629411697387695, 0.0, 0.0, 0.0, 0.0, -16.91234016418457, 0.0, 0.0, 0.0, -13.65725326538086, -12.91795825958252, -10.802200317382812, -12.711037635803223, -14.024481773376465, -14.921876907348633, -16.334373474121094, -17.861663818359375, -19.112422943115234, -20.180543899536133, -21.5910701751709, -23.35106086730957, -25.167884826660156, -26.36512565612793, -28.109939575195312, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -34.80227279663086, -32.49351119995117, 0.0, -31.299100875854492, -31.706117630004883, -31.44998550415039, -30.288644790649414, -28.214059829711914, 0.0, 0.0, -25.215320587158203, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.0633544921875, -19.70967674255371, -19.356149673461914, -19.007164001464844, -18.91839599609375, -17.64707374572754, -16.951478958129883, -15.415553092956543, -14.36255931854248, -13.371038436889648, -12.300765991210938, -10.70589828491211, -9.464412689208984, -7.402526378631592, -4.921645641326904, 0.0, -0.060395143926143646, 0.0, 0.0, -4.825655460357666, -4.141347408294678, -2.3134992122650146, 0.0, 0.0, -0.0, -0.0, -21.629411697387695, -0.0, -0.0, -0.0, -0.0, -16.91234016418457, -0.0, -0.0, -0.0, -13.65725326538086, -12.91795825958252, -10.802200317382812, -12.711037635803223, -14.024481773376465, -14.921876907348633, -16.334373474121094, -17.861663818359375, -19.112422943115234, -20.180543899536133, -21.5910701751709, -23.35106086730957, -25.167884826660156, -26.36512565612793, -28.109939575195312, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -34.91352844238281, -34.395076751708984, -0.0, -34.23939895629883, -33.199974060058594, -32.270263671875, -31.162221908569336, -29.94676971435547, -0.0, -0.0, -28.475004196166992, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.889305114746094, -19.70967674255371, -19.356149673461914, -19.007164001464844, -18.91839599609375, -17.64707374572754, -16.951478958129883, -15.415553092956543, -14.36255931854248, -13.371038436889648, -12.300765991210938, -10.70589828491211, -9.464412689208984, -7.402526378631592, -4.921645641326904, -0.0, -0.060395143926143646, 0.0, -0.0, -4.825655460357666, -4.141347408294678, -2.3134992122650146, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.130908966064453, -13.249035835266113, -10.779741287231445, -13.159516334533691, -14.430337905883789, -15.902870178222656, -17.501996994018555, -18.704105377197266, -20.6284122467041, -22.444313049316406, -23.228973388671875, -25.518972396850586, -26.617719650268555, -28.340999603271484, -28.4183349609375, -26.671520233154297, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -33.11360168457031, -35.56911849975586, -33.89379119873047, -33.69361114501953, -29.794227600097656, -32.6214714050293, -27.694456100463867, -25.907072067260742, 0.0, -28.67057228088379, -26.907047271728516, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.755369186401367, -20.105173110961914, -19.961265563964844, -19.948400497436523, -18.942228317260742, -19.01931381225586, -18.239486694335938, -17.01708221435547, -16.17964744567871, -14.888809204101562, -13.875819206237793, -12.685745239257812, -11.311856269836426, -9.410818099975586, -7.840102672576904, -5.929098129272461, 0.0, -2.9012622833251953, 0.0, 0.0, 0.0, -2.28427791595459, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.130908966064453, -13.249035835266113, -10.779741287231445, -13.159516334533691, -14.430337905883789, -15.902870178222656, -17.501996994018555, -18.704105377197266, -20.6284122467041, -22.444313049316406, -23.228973388671875, -25.518972396850586, -26.617719650268555, -28.340999603271484, -28.714426040649414, -30.20477294921875, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -34.96284103393555, -34.13906478881836, -33.12760543823242, -32.57632064819336, -31.939403533935547, -30.846521377563477, -29.616910934448242, -28.462026596069336, -0.0, -26.827035903930664, -26.938180923461914, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.245683670043945, -20.03116798400879, -19.961265563964844, -19.948400497436523, -18.942228317260742, -19.01931381225586, -18.239486694335938, -17.01708221435547, -16.17964744567871, -14.888809204101562, -13.875819206237793, -12.685745239257812, -11.311856269836426, -9.410818099975586, -7.840102672576904, -5.929098129272461, -0.0, -2.9012622833251953, -0.0, -0.0, -0.0, -2.28427791595459, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -23.052303314208984, 0.0, 0.0, -12.694973945617676, 0.0, 0.0, -13.407516479492188, -12.728680610656738, 0.0, -9.636151313781738, -11.861824035644531, -12.917469024658203, -15.027607917785645, -17.59244155883789, -18.573095321655273, -20.899925231933594, -21.93211555480957, -23.830829620361328, -25.057973861694336, -27.018062591552734, -28.369985580444336, -29.253982543945312, -28.624828338623047, 0.0, 0.0, -30.96086883544922, 0.0, 0.0, 0.0, -32.90081024169922, -30.939762115478516, 0.0, -35.69504928588867, 0.0, -30.50341033935547, -30.512401580810547, 0.0, -24.134641647338867, 0.0, 0.0, -25.83075523376465, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.449905395507812, -19.88527488708496, -20.37249755859375, -20.39607048034668, -19.641820907592773, -18.851106643676758, -18.78498649597168, -17.28978729248047, -15.995708465576172, -14.777897834777832, -13.656218528747559, -12.6342134475708, -11.253507614135742, -9.662871360778809, -7.8553924560546875, -6.814154624938965, -6.119319438934326, -4.720995903015137, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.052303314208984, -0.0, -0.0, -12.694973945617676, -0.0, -0.0, -13.407516479492188, -12.728680610656738, -0.0, -9.636151313781738, -11.861824035644531, -12.917469024658203, -15.027607917785645, -17.59244155883789, -18.573095321655273, -20.899925231933594, -21.93211555480957, -23.830829620361328, -25.057973861694336, -27.018062591552734, -28.369985580444336, -29.322010040283203, -30.417142868041992, -0.0, -0.0, -32.96846008300781, -0.0, -0.0, -0.0, -35.35634994506836, -34.465179443359375, -0.0, -32.14323806762695, -0.0, -30.598939895629883, -29.407163619995117, -0.0, -27.288928985595703, -0.0, -0.0, -25.841310501098633, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.387405395507812, -19.942995071411133, -20.37249755859375, -20.39607048034668, -19.641820907592773, -18.851106643676758, -18.78498649597168, -17.28978729248047, -15.995708465576172, -14.777897834777832, -13.656218528747559, -12.6342134475708, -11.253507614135742, -9.662871360778809, -7.8553924560546875, -6.814154624938965, -6.119319438934326, -4.720995903015137, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.44411563873291, -14.94906997680664, 0.0, 0.0, 0.0, -11.635071754455566, -13.577519416809082, -13.666048049926758, -9.975118637084961, -11.874627113342285, -14.157767295837402, -15.882039070129395, -18.214603424072266, -19.957353591918945, -21.79873275756836, -23.718524932861328, -25.052915573120117, -26.814895629882812, -27.906923294067383, -29.4613094329834, -30.00824737548828, -29.71607208251953, 0.0, -31.119932174682617, 0.0, 0.0, 0.0, -31.736568450927734, -33.417850494384766, -32.66009521484375, -32.830772399902344, 0.0, -32.71246337890625, 0.0, -29.67688751220703, -29.086645126342773, -32.10113525390625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.55009651184082, -20.25450897216797, -19.927452087402344, -20.130619049072266, -19.28913688659668, -18.649120330810547, -18.385982513427734, -16.816478729248047, -16.14503288269043, -15.000192642211914, -13.62922477722168, -11.922585487365723, -10.478254318237305, -9.149776458740234, -8.187775611877441, -7.163862705230713, -8.303152084350586, -6.509908199310303, -4.135880947113037, 0.0, 0.0, -8.153470993041992, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.44411563873291, -14.94906997680664, -0.0, -0.0, -0.0, -11.635071754455566, -13.577519416809082, -13.666048049926758, -9.975118637084961, -11.874627113342285, -14.157767295837402, -15.882039070129395, -18.214603424072266, -19.957353591918945, -21.79873275756836, -23.718524932861328, -25.052915573120117, -26.814895629882812, -27.906923294067383, -29.386829376220703, -30.319808959960938, -31.12946128845215, -0.0, -32.35490036010742, -0.0, -0.0, -0.0, -33.843605041503906, -33.40943145751953, -32.23662185668945, -30.92519760131836, -0.0, -29.44308090209961, -0.0, -26.87300682067871, -25.869958877563477, -25.48357391357422, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.3550968170166, -20.11972427368164, -19.927452087402344, -20.130619049072266, -19.28913688659668, -18.649120330810547, -18.385982513427734, -16.816478729248047, -16.14503288269043, -15.000192642211914, -13.62922477722168, -11.922585487365723, -10.478254318237305, -9.149776458740234, -8.187775611877441, -7.163862705230713, -8.303152084350586, -6.509908199310303, -4.135880947113037, -0.0, -0.0, -8.153470993041992, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.125151634216309, -13.31943130493164, -17.23587417602539, -14.114550590515137, 0.0, 0.0, -14.369400978088379, -15.265193939208984, -14.95455551147461, -15.935147285461426, -12.135290145874023, -14.515585899353027, -16.459712982177734, -19.272159576416016, -21.032194137573242, -23.062210083007812, -24.7736759185791, -26.01824378967285, -28.407268524169922, -28.85134506225586, -29.962072372436523, -30.02752685546875, -28.981456756591797, -27.581274032592773, 0.0, 0.0, 0.0, -34.007423400878906, -31.62217140197754, 0.0, 0.0, 0.0, -32.97842025756836, -31.761470794677734, 0.0, 0.0, -30.778072357177734, -31.199180603027344, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.005508422851562, -19.84255599975586, -19.551795959472656, -19.1635684967041, -18.862001419067383, -18.172348022460938, -16.82909393310547, -16.326683044433594, -15.326374053955078, -14.549764633178711, -12.46339225769043, -10.999322891235352, -9.831903457641602, -9.638340950012207, -8.377172470092773, -8.258294105529785, -7.867300033569336, -9.382944107055664, -6.592959880828857, 0.0, -6.416265964508057, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.125151634216309, -13.31943130493164, -17.23587417602539, -14.114550590515137, -0.0, -0.0, -14.369400978088379, -15.265193939208984, -14.95455551147461, -15.935147285461426, -12.135290145874023, -14.515585899353027, -16.459712982177734, -19.272159576416016, -21.032194137573242, -23.062210083007812, -24.7736759185791, -26.01824378967285, -28.407268524169922, -28.874757766723633, -29.818695068359375, -30.556446075439453, -31.06057357788086, -31.39612579345703, -0.0, -0.0, -0.0, -32.13539123535156, -32.1003532409668, -0.0, -0.0, -0.0, -28.599851608276367, -27.35504150390625, -0.0, -0.0, -24.37042999267578, -23.720909118652344, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.94930076599121, -19.693178176879883, -19.551795959472656, -19.1635684967041, -18.862001419067383, -18.172348022460938, -16.82909393310547, -16.326683044433594, -15.326374053955078, -14.549764633178711, -12.46339225769043, -10.999322891235352, -9.831903457641602, -9.638340950012207, -8.377172470092773, -8.258294105529785, -7.867300033569336, -9.382944107055664, -6.592959880828857, -0.0, -6.416265964508057, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.063261032104492, -14.30692195892334, -13.783044815063477, -15.152107238769531, -15.725435256958008, -11.080279350280762, -15.097143173217773, -15.037288665771484, -14.465442657470703, -15.913006782531738, -11.584023475646973, -15.148037910461426, -16.858491897583008, -19.68478775024414, -21.968158721923828, -23.789670944213867, -25.826831817626953, -27.1806697845459, -28.04424285888672, -28.92444610595703, -29.65156364440918, -29.076900482177734, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.688121795654297, -30.06333351135254, 0.0, 0.0, 0.0, 0.0, 0.0, -27.669240951538086, 0.0, 0.0, 0.0, 0.0, 0.0, -21.235506057739258, -18.887361526489258, -18.191165924072266, -18.07460594177246, -17.086259841918945, -16.855934143066406, -15.500741958618164, -14.125304222106934, -13.701791763305664, -12.66673755645752, -11.119135856628418, -10.135295867919922, -9.525875091552734, -9.015597343444824, -9.089439392089844, -8.493423461914062, 0.0, -8.636155128479004, -8.768699645996094, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.063261032104492, -14.30692195892334, -13.783044815063477, -15.152107238769531, -15.725435256958008, -11.080279350280762, -15.097143173217773, -15.037288665771484, -14.465442657470703, -15.913006782531738, -11.584023475646973, -15.148037910461426, -16.858491897583008, -19.68478775024414, -21.968158721923828, -23.789670944213867, -25.826831817626953, -27.1806697845459, -28.040037155151367, -29.006549835205078, -29.673927307128906, -30.0994873046875, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.562095642089844, -25.75737762451172, -0.0, -0.0, -0.0, -0.0, -0.0, -22.629430770874023, -0.0, -0.0, -0.0, -0.0, -0.0, -19.109886169433594, -18.814199447631836, -18.191165924072266, -18.07460594177246, -17.086259841918945, -16.855934143066406, -15.500741958618164, -14.125304222106934, -13.701791763305664, -12.66673755645752, -11.119135856628418, -10.135295867919922, -9.525875091552734, -9.015597343444824, -9.089439392089844, -8.493423461914062, -0.0, -8.636155128479004, -8.768699645996094, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.93071460723877, -10.45686149597168, -13.50586223602295, -12.041064262390137, -11.527440071105957, -10.283915519714355, -13.973419189453125, -14.65287971496582, -13.845023155212402, -10.638357162475586, -11.342917442321777, -16.454830169677734, -16.10161018371582, -20.323131561279297, -22.290443420410156, -24.14992332458496, -25.92885398864746, -27.735719680786133, -28.352642059326172, -28.804302215576172, -28.656509399414062, -31.74160385131836, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.45640754699707, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.976795196533203, -16.864498138427734, -16.1890926361084, -16.22518539428711, -15.5233736038208, -14.798490524291992, -14.314539909362793, -11.761418342590332, 0.0, -10.377885818481445, -9.95689582824707, -9.752355575561523, -9.369600296020508, -8.422008514404297, -10.232903480529785, -11.442198753356934, 0.0, -10.125266075134277, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.93071460723877, -10.45686149597168, -13.50586223602295, -12.041064262390137, -11.527440071105957, -10.283915519714355, -13.973419189453125, -14.65287971496582, -13.845023155212402, -10.638357162475586, -11.342917442321777, -16.454830169677734, -16.10161018371582, -20.323131561279297, -22.290443420410156, -24.14992332458496, -25.92885398864746, -27.436243057250977, -27.947879791259766, -28.522903442382812, -28.954856872558594, -29.19037437438965, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.92448616027832, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.65897560119629, -16.978654861450195, -16.1890926361084, -16.22518539428711, -15.5233736038208, -14.798490524291992, -14.314539909362793, -11.761418342590332, -0.0, -10.377885818481445, -9.95689582824707, -9.752355575561523, -9.369600296020508, -8.422008514404297, -10.232903480529785, -11.442198753356934, -0.0, -10.125266075134277, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.708961486816406, -10.527434349060059, -13.188250541687012, -10.370492935180664, -9.485018730163574, -9.03101921081543, -12.963313102722168, -16.131040573120117, -13.729531288146973, -14.964856147766113, -13.487548828125, -17.442373275756836, -20.330184936523438, -23.139801025390625, -23.38853645324707, -25.034839630126953, -26.3929443359375, -27.647846221923828, -28.118467330932617, -28.468244552612305, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.68477439880371, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.249412536621094, -15.581887245178223, -14.556879043579102, -14.363736152648926, -12.302288055419922, -11.783526420593262, -12.050278663635254, -10.924830436706543, -12.275294303894043, -13.205348014831543, -8.716276168823242, -9.07723331451416, -10.238932609558105, -10.991836547851562, -9.597700119018555, -12.254632949829102, -11.966872215270996, -10.74841022491455, -13.680025100708008, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -9.708961486816406, -10.527434349060059, -13.188250541687012, -10.370492935180664, -9.485018730163574, -9.03101921081543, -12.963313102722168, -16.131040573120117, -13.729531288146973, -14.964856147766113, -13.487548828125, -17.442373275756836, -20.330184936523438, -23.139801025390625, -23.38853645324707, -25.07732391357422, -26.24125099182129, -27.100244522094727, -27.59579849243164, -27.851261138916016, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.841121673583984, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.97249412536621, -15.885563850402832, -14.977642059326172, -14.363736152648926, -12.302288055419922, -11.783526420593262, -12.050278663635254, -10.924830436706543, -12.275294303894043, -13.205348014831543, -8.716276168823242, -9.07723331451416, -10.238932609558105, -10.991836547851562, -9.597700119018555, -12.254632949829102, -11.966872215270996, -10.74841022491455, -13.680025100708008, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.830418586730957, -12.669229507446289, -11.723902702331543, -10.861711502075195, -14.335506439208984, -13.353581428527832, -13.249839782714844, -16.237045288085938, -14.071595191955566, -17.515695571899414, -19.36771583557129, -20.793916702270508, -21.81797981262207, -24.946929931640625, -25.36198616027832, -26.536273956298828, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.796323776245117, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.206297874450684, -11.327305793762207, -13.15211009979248, 0.0, -10.61642837524414, -15.053519248962402, -13.844429016113281, -13.581871032714844, -12.553400039672852, -8.989158630371094, -10.703962326049805, -12.035303115844727, -12.643250465393066, -11.747974395751953, -12.318276405334473, -13.414135932922363, -13.980466842651367, -15.800442695617676, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.830418586730957, -12.669229507446289, -11.723902702331543, -10.861711502075195, -14.335506439208984, -13.353581428527832, -13.249839782714844, -16.237045288085938, -14.071595191955566, -17.515695571899414, -19.36771583557129, -20.793916702270508, -22.331464767456055, -24.4681396484375, -25.345314025878906, -25.83270263671875, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.32720947265625, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.992026329040527, -11.652371406555176, -13.15211009979248, -0.0, -10.61642837524414, -15.053519248962402, -13.844429016113281, -13.581871032714844, -12.553400039672852, -8.989158630371094, -10.703962326049805, -12.035303115844727, -12.643250465393066, -11.747974395751953, -12.318276405334473, -13.414135932922363, -13.980466842651367, -15.800442695617676, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.388813018798828, -14.895798683166504, 0.0, -13.52608585357666, -12.242928504943848, 0.0, -15.192852020263672, -16.955978393554688, -15.230987548828125, -15.880595207214355, -18.84127426147461, -18.650365829467773, 0.0, -23.168413162231445, -23.160594940185547, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.447234153747559, -10.56195068359375, -11.351923942565918, -11.60272216796875, -12.002223014831543, -10.266035079956055, -11.060965538024902, -9.841283798217773, -12.538307189941406, -13.892276763916016, -14.563226699829102, -13.983845710754395, -12.297998428344727, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.388813018798828, -14.895798683166504, -0.0, -13.52608585357666, -12.242928504943848, -0.0, -15.192852020263672, -16.955978393554688, -15.230987548828125, -15.880595207214355, -18.84127426147461, -19.734277725219727, -0.0, -23.22893524169922, -23.385557174682617, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.001181602478027, -10.56195068359375, -11.351923942565918, -11.60272216796875, -12.002223014831543, -10.266035079956055, -11.060965538024902, -9.841283798217773, -12.538307189941406, -13.892276763916016, -14.563226699829102, -13.983845710754395, -12.297998428344727, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.216068267822266, -13.608600616455078, 0.0, 0.0, 0.0, -11.492559432983398, 0.0, 0.0, -14.847609519958496, 0.0, -15.308302879333496, -17.732173919677734, -20.997652053833008, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.821739196777344, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.143295288085938, 0.0, -12.555680274963379, -14.72033405303955, -15.800222396850586, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.216068267822266, -13.608600616455078, -0.0, -0.0, -0.0, -11.492559432983398, -0.0, -0.0, -14.847609519958496, -0.0, -15.308302879333496, -17.732173919677734, -20.997652053833008, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.821739196777344, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.143295288085938, -0.0, -12.555680274963379, -14.72033405303955, -15.800222396850586, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.497023582458496, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.029754638671875, -19.788576126098633, -21.518037796020508, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.3874568939209, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.611486434936523, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.497023582458496, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.029754638671875, -19.788576126098633, -21.518037796020508, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.3874568939209, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.611486434936523, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.063117027282715, 0.0, 0.0, 0.0, 0.0, 0.0, -18.820871353149414, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.353557586669922, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.063117027282715, -0.0, -0.0, -0.0, -0.0, -0.0, -18.820871353149414, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.353557586669922, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.758676528930664, -27.4405574798584, -25.887325286865234, 0.0, -27.797880172729492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.758676528930664, -27.4405574798584, -25.887325286865234, -0.0, -27.797880172729492, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.516523361206055, -25.069530487060547, -25.76384925842285, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.516523361206055, -25.069530487060547, -25.76384925842285, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.993852615356445, -25.422666549682617, -29.814455032348633, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.993852615356445, -25.422666549682617, -29.814455032348633, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.499177932739258, 0.0, -25.696475982666016, -27.253307342529297, -30.081140518188477, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.499177932739258, -0.0, -25.696475982666016, -27.253307342529297, -30.081140518188477, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.96540069580078, -24.357370376586914, -24.66428565979004, -27.484407424926758, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.96540069580078, -24.357370376586914, -24.66428565979004, -27.484407424926758, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.597225189208984, -23.87970733642578, -21.310653686523438, -21.879959106445312, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.597225189208984, -23.87970733642578, -21.310653686523438, -21.879959106445312, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.85438346862793, -24.554380416870117, -24.204660415649414, -22.795228958129883, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.85438346862793, -24.554380416870117, -24.204660415649414, -22.795228958129883, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.66417121887207, -21.83514404296875, -21.024654388427734, -20.334083557128906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.66417121887207, -21.83514404296875, -21.024654388427734, -20.334083557128906, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.856836318969727, -26.683670043945312, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.856836318969727, -26.683670043945312, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.310890197753906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.310890197753906, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0]]}, {\"colorbar\": {\"title\": {\"text\": \"B<sub>0</sub> (Hz)\"}}, \"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.3333333333333333, \"rgb(230,0,0)\"], [0.6666666666666666, \"rgb(255,210,0)\"], [1.0, \"rgb(255,255,255)\"]], \"name\": \"comparison heatmap\", \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.7544682025909424, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -3.7544682025909424, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.4771902561187744, 0.0, -2.6055123805999756, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.4771902561187744, -0.0, -2.6055123805999756, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.2724734544754028, -2.294301748275757, -1.3810150623321533, 2.9619064331054688, 0.0, 0.0, 5.485415458679199, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.8144751787185669, -2.8283629417419434, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.2724734544754028, -2.294301748275757, -1.3810150623321533, 2.9619064331054688, 0.0, 0.0, 5.485415458679199, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.8144751787185669, -2.8283629417419434, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0332332849502563, -0.8435600996017456, 0.10958760231733322, 4.851920127868652, 6.597630977630615, 8.601966857910156, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0332332849502563, -0.8435600996017456, 0.10958760231733322, 4.851920127868652, 6.597630977630615, 8.601966857910156, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.6873687505722046, 2.221449136734009, 3.258057117462158, 7.560811519622803, 5.531290054321289, 5.9278788566589355, 6.113119125366211, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.3589234352111816, 7.7947235107421875, 7.683083534240723, 8.217047691345215, 7.039155960083008, 6.073802471160889, 6.083266258239746, 9.321097373962402, 6.121196746826172, 6.844245910644531, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.6873687505722046, 2.221449136734009, 3.258057117462158, 7.560811519622803, 5.531290054321289, 5.9278788566589355, 6.113119125366211, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.3589234352111816, 7.7947235107421875, 7.683083534240723, 8.217047691345215, 7.039155960083008, 6.073802471160889, 6.083266258239746, 9.321097373962402, 6.121196746826172, 6.844245910644531, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.7435269355773926, 1.2494035959243774, 4.441827774047852, 5.367823123931885, 4.844820022583008, 3.2674503326416016, 4.929300308227539, 3.647923469543457, 0.0, 0.0, 6.6702046394348145, 5.700337886810303, 2.707005500793457, 1.5115880966186523, 3.330350399017334, 5.071537971496582, 4.447224140167236, 3.9338369369506836, 4.061888694763184, 4.317758083343506, 5.477039337158203, 4.972472190856934, 5.156693935394287, 5.6491289138793945, 5.689183712005615, 5.368321418762207, 6.7394256591796875, 6.592831134796143, 8.620842933654785, 7.2629008293151855, 6.772673606872559, 8.029275894165039, 7.283775329589844, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.7435269355773926, 1.2494035959243774, 4.441827774047852, 5.367823123931885, 4.844820022583008, 3.2674503326416016, 4.929300308227539, 3.647923469543457, 0.0, 0.0, 6.6702046394348145, 5.700337886810303, 2.707005500793457, 1.5115880966186523, 3.330350399017334, 5.071537971496582, 4.447224140167236, 3.9338369369506836, 4.061888694763184, 4.317758083343506, 5.477039337158203, 4.972472190856934, 5.156693935394287, 5.6491289138793945, 5.689183712005615, 5.368321418762207, 6.7394256591796875, 6.592831134796143, 8.620842933654785, 7.2629008293151855, 6.772673606872559, 8.029275894165039, 7.283775329589844, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.339844226837158, 1.6640193462371826, 3.552579641342163, 2.8853509426116943, 7.615435600280762, 6.14055061340332, 6.103548049926758, 7.398604393005371, 6.162565231323242, 5.281968116760254, 7.240322113037109, 4.555334091186523, 3.7607924938201904, 2.9349119663238525, 3.1023595333099365, 2.975186347961426, 4.309037208557129, 1.8355251550674438, 1.5440099239349365, 4.167783260345459, 2.805835008621216, 0.0, 4.885234832763672, 2.4960782527923584, 3.9384071826934814, 2.932572841644287, 3.5182743072509766, 4.8167572021484375, 2.569636344909668, 5.0356597900390625, 5.720646381378174, 5.92334508895874, 5.21905517578125, 2.0546631813049316, 3.6461262702941895, 5.9169602394104, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.339844226837158, 1.6640193462371826, 3.552579641342163, 2.8853509426116943, 7.615435600280762, 6.14055061340332, 6.103548049926758, 7.398604393005371, 6.162565231323242, 5.281968116760254, 7.240322113037109, 4.555334091186523, 3.7607924938201904, 2.9349119663238525, 3.1023595333099365, 2.975186347961426, 4.309037208557129, 1.8355251550674438, 1.5440099239349365, 4.167783260345459, 2.805835008621216, 0.0, 4.885234832763672, 2.4960782527923584, 3.9384071826934814, 2.932572841644287, 3.5182743072509766, 4.8167572021484375, 2.569636344909668, 5.0356597900390625, 5.720646381378174, 5.92334508895874, 5.21905517578125, 2.0546631813049316, 3.6461262702941895, 5.9169602394104, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.9885952472686768, 4.058800220489502, 2.734905481338501, 3.113450765609741, 0.8982183933258057, 5.737351894378662, 5.850457191467285, 4.0732622146606445, 4.335482597351074, 3.355766534805298, 2.984100818634033, 5.115932464599609, 1.6247551441192627, 5.21885871887207, 0.0, 1.0891679525375366, 0.0, 0.0, 0.0, 0.0, 0.0, 1.743099570274353, 0.0, 1.512912392616272, 1.4187166690826416, 1.4859613180160522, 0.0, 0.0, 0.0, 4.435417652130127, 1.5303223133087158, 2.6875524520874023, 4.752162933349609, 4.176468849182129, 4.581552982330322, 5.033862113952637, 4.9872565269470215, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.9885952472686768, 4.058800220489502, 2.734905481338501, 3.113450765609741, 0.8982183933258057, 5.737351894378662, 5.850457191467285, 4.0732622146606445, 4.335482597351074, 3.355766534805298, 2.984100818634033, 5.115932464599609, 1.6247551441192627, 5.21885871887207, 0.0, 1.0891679525375366, 0.0, 0.0, 0.0, 0.0, 0.0, 1.743099570274353, 0.0, 1.512912392616272, 1.4187166690826416, 1.4859613180160522, 0.0, 0.0, 0.0, 4.435417652130127, 1.5303223133087158, 2.6875524520874023, 4.752162933349609, 4.176468849182129, 4.581552982330322, 5.033862113952637, 4.9872565269470215, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.052239418029785, 3.704965353012085, 2.1938443183898926, 5.292795658111572, 6.796655654907227, 2.489384651184082, 2.5385804176330566, 2.0700762271881104, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.6000451445579529, 1.0307338237762451, 1.3101836442947388, 0.0, 0.0, 0.0, 0.0, 2.4160919189453125, 2.3832778930664062, 3.6000280380249023, 3.4119746685028076, 3.4277021884918213, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.052239418029785, 3.704965353012085, 2.1938443183898926, 5.292795658111572, 6.796655654907227, 2.489384651184082, 2.5385804176330566, 2.0700762271881104, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.6000451445579529, 1.0307338237762451, 1.3101836442947388, 0.0, 0.0, 0.0, 0.0, 2.4160919189453125, 2.3832778930664062, 3.6000280380249023, 3.4119746685028076, 3.4277021884918213, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.0047712326049805, 4.140016555786133, 3.7776706218719482, 3.9566080570220947, 4.077197551727295, 5.7955451011657715, 5.4361982345581055, 3.3106777667999268, 4.123631000518799, 0.0, 7.15671443939209, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.720908164978027, 0.0, 0.0, 5.909060478210449, 5.860600471496582, 3.2820961475372314, 3.8273887634277344, 7.127993106842041, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.0047712326049805, 4.140016555786133, 3.7776706218719482, 3.9566080570220947, 4.077197551727295, 5.7955451011657715, 5.4361982345581055, 3.3106777667999268, 4.123631000518799, 0.0, 7.15671443939209, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.720908164978027, 0.0, 0.0, 5.909060478210449, 5.860600471496582, 3.2820961475372314, 3.8273887634277344, 7.127993106842041, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.828196048736572, 6.80756139755249, 4.096606731414795, 3.9073379039764404, 3.677405595779419, 1.5203187465667725, 0.0, 0.0, 5.199567794799805, 4.1984710693359375, 3.80210280418396, 2.7510995864868164, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.7901499271392822, -4.379901885986328, 0.0, 0.0, 0.0, 2.125135898590088, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.301389694213867, 2.0364222526550293, 2.892897129058838, 5.3526482582092285, 3.012343645095825, 0.2156466692686081, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.828196048736572, 6.80756139755249, 4.096606731414795, 3.9073379039764404, 3.677405595779419, 1.5203187465667725, 0.0, 0.0, 5.199567794799805, 4.1984710693359375, 3.80210280418396, 2.7510995864868164, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -2.7901499271392822, -4.379901885986328, -0.0, 0.0, 0.0, 2.125135898590088, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.301389694213867, 2.0364222526550293, 2.892897129058838, 5.3526482582092285, 3.012343645095825, 0.2156466692686081, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.5938515663146973, 2.583279609680176, 3.538191795349121, 2.373903512954712, 2.1806817054748535, 0.0, 0.0, -1.7066453695297241, -3.6341941356658936, 0.0, 0.0, 1.4668000936508179, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.30560630559921265, 0.10266537964344025, -2.7453243732452393, -2.0335936546325684, 0.0, 0.2657546103000641, 2.0569539070129395, -1.8207658529281616, 0.0, 0.0, 0.2611263394355774, 0.703758955001831, 2.7433557510375977, 0.0, 0.0, 0.0, 1.8124638795852661, -0.15148049592971802, 0.0, 0.0, 0.0, 0.0, 0.23328644037246704, 2.633704900741577, 4.458725452423096, 0.0, 7.844603061676025, 5.8479695320129395, 3.186216115951538, 6.687167167663574, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.5938515663146973, 2.583279609680176, 3.538191795349121, 2.373903512954712, 2.1806817054748535, 0.0, 0.0, -1.7066453695297241, -3.6341941356658936, 0.0, 0.0, 1.4668000936508179, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.30560630559921265, 0.10266537964344025, -2.7453243732452393, -2.0335936546325684, 0.0, 0.2657546103000641, 2.0569539070129395, -1.8207658529281616, -0.0, 0.0, 0.2611263394355774, 0.703758955001831, 2.7433557510375977, 0.0, -0.0, 0.0, 1.8124638795852661, -0.15148049592971802, -0.0, -0.0, 0.0, 0.0, 0.23328644037246704, 2.633704900741577, 4.458725452423096, 0.0, 7.844603061676025, 5.8479695320129395, 3.186216115951538, 6.687167167663574, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.676350474357605, 3.5840649604797363, 1.5480645895004272, 1.6381645202636719, 0.4542847275733948, -0.6582963466644287, 0.0, 1.6737943887710571, 1.7073540687561035, 0.0, 0.0, 0.0, 0.0, 0.0, -3.848170757293701, 0.0, 0.0, 0.0, -0.21598811447620392, -1.4889740943908691, 1.0157701969146729, -0.6030967235565186, -1.3673287630081177, -4.284143447875977, -2.417483329772949, -1.3588006496429443, -0.5957255363464355, -1.142593502998352, -2.566788673400879, -2.209840774536133, -1.8635493516921997, -1.3039908409118652, -1.4673280715942383, -0.44020000100135803, -1.0193686485290527, -1.8009568452835083, -0.18904046714305878, -0.7384982705116272, -3.0066721439361572, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.064009666442871, 4.097833156585693, 0.0, 2.2802631855010986, 4.08038854598999, 5.615452289581299, 5.442552089691162, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.676350474357605, 3.5840649604797363, 1.5480645895004272, 1.6381645202636719, 0.4542847275733948, -0.6582963466644287, 0.0, 1.6737943887710571, 1.7073540687561035, -0.0, -0.0, -0.0, 0.0, 0.0, -3.848170757293701, -0.0, -0.0, -0.0, -0.21598811447620392, -1.4889740943908691, 1.0157701969146729, -0.6030967235565186, -1.3673287630081177, -4.284143447875977, -2.417483329772949, -1.3588006496429443, -0.5957255363464355, -1.142593502998352, -2.566788673400879, -2.209840774536133, -1.8635493516921997, -1.3039908409118652, -1.4673280715942383, -0.44020000100135803, -1.0193686485290527, -1.8009568452835083, -0.18904046714305878, -0.7384982705116272, -3.0066721439361572, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 4.064009666442871, 4.097833156585693, 0.0, 2.2802631855010986, 4.08038854598999, 5.615452289581299, 5.442552089691162, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.006822347640991, 1.0428173542022705, 1.2955310344696045, 1.3787407875061035, 3.9917244911193848, 3.509713649749756, 2.4147019386291504, 0.9554809927940369, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -4.907436370849609, -0.5842779874801636, -1.4024807214736938, -1.9521669149398804, -1.8031141757965088, -2.365774631500244, -4.0536789894104, -2.925218343734741, -3.1805238723754883, -5.329107761383057, 0.0, -1.3376600742340088, -0.9682935476303101, -1.8118659257888794, -1.4832780361175537, -1.3664156198501587, -1.415086030960083, -0.9419621825218201, -1.5228583812713623, -1.140375018119812, -0.8508487939834595, -0.6061990261077881, -0.9773272275924683, -0.730607807636261, -1.0187599658966064, -0.9936765432357788, -1.2067382335662842, -2.3120248317718506, 0.0, 0.0, 0.0, 0.0, 0.0, 7.074368000030518, 0.0, 1.1477341651916504, 2.9752798080444336, 5.084829807281494, 6.289032936096191, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.006822347640991, 1.0428173542022705, 1.2955310344696045, 1.3787407875061035, 3.9917244911193848, 3.509713649749756, 2.4147019386291504, 0.9554809927940369, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -4.907436370849609, -0.5842779874801636, -1.4024807214736938, -1.9521669149398804, -1.8031141757965088, -2.365774631500244, -4.0536789894104, -2.925218343734741, -3.1805238723754883, -5.329107761383057, -0.0, -1.3376600742340088, -0.9682935476303101, -1.8118659257888794, -1.4832780361175537, -1.3664156198501587, -1.415086030960083, -0.9419621825218201, -1.5228583812713623, -1.140375018119812, -0.8508487939834595, -0.6061990261077881, -0.9773272275924683, -0.730607807636261, -1.0187599658966064, -0.9936765432357788, -1.2067382335662842, -2.3120248317718506, -0.0, 0.0, 0.0, 0.0, 0.0, 7.074368000030518, 0.0, 1.1477341651916504, 2.9752798080444336, 5.084829807281494, 6.289032936096191, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.8521952629089355, 1.912906527519226, -0.7336441874504089, -1.81123948097229, 0.0, 0.3489944338798523, 2.68363881111145, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0148825645446777, -1.413604497909546, -0.6238964796066284, -0.9319848418235779, -3.4624178409576416, -2.458540916442871, -1.714996337890625, -2.2602481842041016, -1.2969073057174683, -4.591714859008789, -4.343172073364258, -3.187791585922241, -3.763892412185669, -2.653564214706421, -1.2688652276992798, -0.8296510577201843, -1.4977781772613525, -2.405900001525879, -1.6860634088516235, -1.705641508102417, -0.9331114292144775, -0.7332034111022949, -1.049258828163147, -0.9709930419921875, -1.1001086235046387, -0.27555811405181885, -0.36797189712524414, -0.4955557584762573, -0.5862901210784912, -0.3583580553531647, -1.723620057106018, -1.3374888896942139, -0.5257315039634705, 0.9090222120285034, 1.4970802068710327, 2.323603391647339, 0.0, 0.0, 0.0, 1.2901291847229004, 1.674164891242981, 0.0, 5.397497177124023, 4.8862175941467285, 5.854665279388428, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.8521952629089355, 1.912906527519226, -0.7336441874504089, -1.81123948097229, 0.0, 0.3489944338798523, 2.68363881111145, 0.0, 0.0, 0.0, -0.0, -0.0, -1.0148825645446777, -1.413604497909546, -0.6238964796066284, -0.9319848418235779, -3.4624178409576416, -2.458540916442871, -1.714996337890625, -2.2602481842041016, -1.2969073057174683, -4.591714859008789, -4.343172073364258, -3.187791585922241, -3.763892412185669, -2.653564214706421, -1.2688652276992798, -0.8296510577201843, -1.4977781772613525, -2.405900001525879, -1.6860634088516235, -1.705641508102417, -0.9331114292144775, -0.7332034111022949, -1.049258828163147, -0.9709930419921875, -1.1001086235046387, -0.27555811405181885, -0.36797189712524414, -0.4955557584762573, -0.5862901210784912, -0.3583580553531647, -1.723620057106018, -1.3374888896942139, -0.5257315039634705, 0.9090222120285034, 1.4970802068710327, 2.323603391647339, 0.0, 0.0, 0.0, 1.2901291847229004, 1.674164891242981, 0.0, 5.397497177124023, 4.8862175941467285, 5.854665279388428, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.2912235260009766, 2.314535140991211, 1.1098041534423828, -0.05259367823600769, 0.0, 0.0, 0.6779412031173706, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.867736577987671, -2.7204477787017822, -2.9305922985076904, -1.6123404502868652, -0.7589361071586609, -2.081120014190674, -1.769640564918518, -1.1822898387908936, -2.270913600921631, -1.2760967016220093, 0.535286009311676, -4.828015327453613, -4.3173394203186035, -3.4739232063293457, -0.4341914653778076, -1.18982994556427, -0.20579272508621216, -1.3338438272476196, -1.4467837810516357, -1.0613209009170532, -1.2145636081695557, -1.1795111894607544, -1.2723904848098755, -0.9676432609558105, -1.1621196269989014, -0.809668242931366, -1.1500260829925537, -0.6309216022491455, -0.10230475664138794, -0.4140494465827942, -0.7499911189079285, -0.5039623379707336, -0.6794164776802063, -0.43347516655921936, -0.7947831153869629, 0.6976335644721985, 1.4360806941986084, 3.3359220027923584, 1.0122934579849243, 0.0, 2.852478265762329, 5.296825408935547, 0.0, 0.9959774017333984, 3.3152687549591064, 2.747871160507202, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 3.2912235260009766, 2.314535140991211, 1.1098041534423828, -0.05259367823600769, -0.0, -0.0, 0.6779412031173706, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -2.867736577987671, -2.7204477787017822, -2.9305922985076904, -1.6123404502868652, -0.7589361071586609, -2.081120014190674, -1.769640564918518, -1.1822898387908936, -2.270913600921631, -1.2760967016220093, 0.535286009311676, -4.828015327453613, -4.3173394203186035, -3.4739232063293457, -0.4341914653778076, -1.18982994556427, -0.20579272508621216, -1.3338438272476196, -1.4467837810516357, -1.0613209009170532, -1.2145636081695557, -1.1795111894607544, -1.2723904848098755, -0.9676432609558105, -1.1621196269989014, -0.809668242931366, -1.1500260829925537, -0.6309216022491455, -0.10230475664138794, -0.4140494465827942, -0.7499911189079285, -0.5039623379707336, -0.6794164776802063, -0.43347516655921936, -0.7947831153869629, 0.6976335644721985, 1.4360806941986084, 3.3359220027923584, 1.0122934579849243, 0.0, 2.852478265762329, 5.296825408935547, 0.0, 0.9959774017333984, 3.3152687549591064, 2.747871160507202, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.8195477724075317, 1.168658971786499, 3.4649462699890137, 2.381469488143921, 0.0, 0.2462603896856308, 1.384557843208313, 0.0, 0.0, 0.0, -2.3645195960998535, -0.7998126149177551, -3.167170286178589, -3.472127676010132, -2.7962820529937744, -2.197103500366211, -1.7674272060394287, -1.6016225814819336, -1.3515548706054688, -1.5291756391525269, -1.835363745689392, -1.8051103353500366, -1.0095816850662231, -1.6341066360473633, -1.7822352647781372, -1.092297911643982, -0.025293463841080666, -0.8147862553596497, -1.1770169734954834, -1.3501776456832886, -1.685290813446045, -0.9443244338035583, -0.6538648009300232, -2.3740696907043457, -0.25501611828804016, -0.6493158340454102, -0.7084388732910156, -0.6532690525054932, -0.366571307182312, -0.8262555003166199, -0.4590032696723938, -0.3719288110733032, -0.2379826009273529, -0.34358713030815125, -0.8636130094528198, 0.2018081396818161, -1.483479380607605, 0.0007170928292907774, -0.20830883085727692, 0.8043283224105835, 0.24811090528964996, 0.6206223964691162, 1.0289548635482788, 0.0, 3.037726879119873, 2.9290595054626465, 4.438365459442139, 0.0, 4.6341233253479, 3.113198757171631, 5.622631549835205, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.8195477724075317, 1.168658971786499, 3.4649462699890137, 2.381469488143921, -0.0, 0.2462603896856308, 1.384557843208313, 0.0, 0.0, -0.0, -2.3645195960998535, -0.7998126149177551, -3.167170286178589, -3.472127676010132, -2.7962820529937744, -2.197103500366211, -1.7674272060394287, -1.6016225814819336, -1.3515548706054688, -1.5291756391525269, -1.835363745689392, -1.8051103353500366, -1.0095816850662231, -1.6341066360473633, -1.7822352647781372, -1.092297911643982, -0.025293463841080666, -0.8147862553596497, -1.1770169734954834, -1.3501776456832886, -1.685290813446045, -0.9443244338035583, -0.6538648009300232, -2.3740696907043457, -0.25501611828804016, -0.6493158340454102, -0.7084388732910156, -0.6532690525054932, -0.366571307182312, -0.8262555003166199, -0.4590032696723938, -0.3719288110733032, -0.2379826009273529, -0.34358713030815125, -0.8636130094528198, 0.2018081396818161, -1.483479380607605, 0.0007170928292907774, -0.20830883085727692, 0.8043283224105835, 0.24811090528964996, 0.6206223964691162, 1.0289548635482788, 0.0, 3.037726879119873, 2.9290595054626465, 4.438365459442139, 0.0, 4.6341233253479, 3.113198757171631, 5.622631549835205, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.558105707168579, 0.8898727893829346, 0.09967061877250671, 0.0, 0.0, 2.7851266860961914, 1.1706326007843018, 0.0, 0.0, 0.0, 0.0, -1.5664196014404297, -3.786031484603882, -3.6095290184020996, -3.528771162033081, -2.2978601455688477, -1.850568413734436, -1.4445960521697998, -1.9014402627944946, -1.3541353940963745, -1.924950122833252, -1.4900214672088623, -2.386361598968506, -0.8219746947288513, -2.0961179733276367, -2.2397608757019043, -1.4673837423324585, -0.2221561074256897, -0.7673352360725403, -0.8689164519309998, -1.120705008506775, -0.6327658891677856, -1.3759397268295288, -1.176509141921997, -0.8302945494651794, 0.4971991777420044, -0.6901572346687317, -1.2094826698303223, 0.46111056208610535, -0.7391122579574585, 0.1115780621767044, -0.5098612308502197, -0.0499759241938591, -0.6115431785583496, -0.580153226852417, -0.5715218186378479, -0.5350483655929565, -0.39231589436531067, 0.3607294261455536, -0.8805252313613892, 0.17180801928043365, -0.3638785481452942, 0.41283416748046875, 1.0186272859573364, 2.4210877418518066, 0.985816478729248, 1.2930160760879517, 2.9957714080810547, 5.437681674957275, 0.0, 0.0, 2.462480306625366, 5.158374786376953, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.558105707168579, 0.8898727893829346, 0.09967061877250671, 0.0, 0.0, 2.7851266860961914, 1.1706326007843018, 0.0, 0.0, -0.0, -0.0, -1.5664196014404297, -3.786031484603882, -3.6095290184020996, -3.528771162033081, -2.2978601455688477, -1.850568413734436, -1.4445960521697998, -1.9014402627944946, -1.3541353940963745, -1.924950122833252, -1.4900214672088623, -2.386361598968506, -0.8219746947288513, -2.0961179733276367, -2.2397608757019043, -1.4673837423324585, -0.2221561074256897, -0.7673352360725403, -0.8689164519309998, -1.120705008506775, -0.6327658891677856, -1.3759397268295288, -1.176509141921997, -0.8302945494651794, 0.4971991777420044, -0.6901572346687317, -1.2094826698303223, 0.46111056208610535, -0.7391122579574585, 0.1115780621767044, -0.5098612308502197, -0.0499759241938591, -0.6115431785583496, -0.580153226852417, -0.5715218186378479, -0.5350483655929565, -0.39231589436531067, 0.3607294261455536, -0.8805252313613892, 0.17180801928043365, -0.3638785481452942, 0.41283416748046875, 1.0186272859573364, 2.4210877418518066, 0.985816478729248, 1.2930160760879517, 2.9957714080810547, 5.437681674957275, 0.0, 0.0, 2.462480306625366, 5.158374786376953, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.6305099725723267, 0.03733642026782036, -0.33240842819213867, 0.0, 0.7273516058921814, 0.7916419506072998, 0.0, 0.0, 0.0, 0.0, -5.951741695404053, -4.067006587982178, -3.8790228366851807, -3.6972784996032715, -3.625697612762451, -3.017629861831665, -2.9038031101226807, -2.5057485103607178, -2.456347942352295, -1.562423586845398, -1.8305844068527222, -1.6958400011062622, -1.589424967765808, -1.0560652017593384, -1.3528497219085693, -1.5262094736099243, -1.2447824478149414, -1.0576047897338867, -0.9628875851631165, -0.6460714340209961, -0.8597115874290466, -0.6622018218040466, -1.4182668924331665, -0.9994460940361023, -0.768335223197937, -0.8340290188789368, -0.5311097502708435, -0.3762403130531311, -0.5445855855941772, -1.1678308248519897, -0.845092236995697, -0.11324932426214218, -0.8270814418792725, -0.6100610494613647, -0.9588432312011719, -0.3262866735458374, -0.216636061668396, -1.2934905290603638, -0.8141311407089233, -0.6207993626594543, -0.2946779429912567, -1.1323562860488892, -0.28124794363975525, -0.035700723528862, 0.5682691931724548, 0.6046103239059448, 0.8758649230003357, 2.942692756652832, 0.0, 4.932299613952637, 4.375232696533203, 0.0, 5.541635513305664, 3.7527973651885986, 4.483987331390381, 6.110056400299072, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.6305099725723267, 0.03733642026782036, -0.33240842819213867, 0.0, 0.7273516058921814, 0.7916419506072998, 0.0, 0.0, 0.0, -0.0, -5.951741695404053, -4.067006587982178, -3.8790228366851807, -3.6972784996032715, -3.625697612762451, -3.017629861831665, -2.9038031101226807, -2.5057485103607178, -2.456347942352295, -1.562423586845398, -1.8305844068527222, -1.6958400011062622, -1.589424967765808, -1.0560652017593384, -1.3528497219085693, -1.5262094736099243, -1.2447824478149414, -1.0576047897338867, -0.9628875851631165, -0.6460714340209961, -0.8597115874290466, -0.6622018218040466, -1.4182668924331665, -0.9994460940361023, -0.768335223197937, -0.8340290188789368, -0.5311097502708435, -0.3762403130531311, -0.5445855855941772, -1.1678308248519897, -0.845092236995697, -0.11324932426214218, -0.8270814418792725, -0.6100610494613647, -0.9588432312011719, -0.3262866735458374, -0.216636061668396, -1.2934905290603638, -0.8141311407089233, -0.6207993626594543, -0.2946779429912567, -1.1323562860488892, -0.28124794363975525, -0.035700723528862, 0.5682691931724548, 0.6046103239059448, 0.8758649230003357, 2.942692756652832, 0.0, 4.932299613952637, 4.375232696533203, 0.0, 5.541635513305664, 3.7527973651885986, 4.483987331390381, 6.110056400299072, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.427937626838684, -0.6187317371368408, -2.3755388259887695, 0.0, 0.0, -1.036783218383789, 0.0, 0.0, 0.0, 0.0, -3.1932291984558105, -3.8831145763397217, -3.940509080886841, -3.4241058826446533, -3.476372241973877, -3.4807872772216797, -2.6934142112731934, -2.51912784576416, -1.7582612037658691, -1.9833526611328125, -1.8172136545181274, -2.004835605621338, -1.58755624294281, -1.8362962007522583, -2.04207706451416, -0.24349164962768555, -0.9565579295158386, -1.4193905591964722, -1.5451834201812744, -0.39530041813850403, -0.9279940128326416, -1.1595191955566406, -0.787990391254425, -0.9701664447784424, -1.0271793603897095, -0.19246798753738403, -0.7210794687271118, -0.9998272061347961, -0.32200247049331665, -0.7266507148742676, -0.15000225603580475, -0.41944727301597595, -0.2775295078754425, 0.11662700772285461, -0.6380502581596375, 0.060282301157712936, -0.21846739947795868, -0.5110074281692505, 0.0535457618534565, -0.32989323139190674, -0.6305884718894958, 0.24464094638824463, -0.47794049978256226, -0.0958276093006134, 0.0787414088845253, 0.16973619163036346, 0.4523575007915497, 0.9622636437416077, 1.0845988988876343, 1.9348279237747192, 0.0, 0.0, 1.281813144683838, 0.0, 3.741041898727417, 4.40792179107666, 4.696862697601318, 7.4557671546936035, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 1.427937626838684, -0.6187317371368408, -2.3755388259887695, -0.0, -0.0, -1.036783218383789, 0.0, 0.0, -0.0, -0.0, -3.1932291984558105, -3.8831145763397217, -3.940509080886841, -3.4241058826446533, -3.476372241973877, -3.4807872772216797, -2.6934142112731934, -2.51912784576416, -1.7582612037658691, -1.9833526611328125, -1.8172136545181274, -2.004835605621338, -1.58755624294281, -1.8362962007522583, -2.04207706451416, -0.24349164962768555, -0.9565579295158386, -1.4193905591964722, -1.5451834201812744, -0.39530041813850403, -0.9279940128326416, -1.1595191955566406, -0.787990391254425, -0.9701664447784424, -1.0271793603897095, -0.19246798753738403, -0.7210794687271118, -0.9998272061347961, -0.32200247049331665, -0.7266507148742676, -0.15000225603580475, -0.41944727301597595, -0.2775295078754425, 0.11662700772285461, -0.6380502581596375, 0.060282301157712936, -0.21846739947795868, -0.5110074281692505, 0.0535457618534565, -0.32989323139190674, -0.6305884718894958, 0.24464094638824463, -0.47794049978256226, -0.0958276093006134, 0.0787414088845253, 0.16973619163036346, 0.4523575007915497, 0.9622636437416077, 1.0845988988876343, 1.9348279237747192, 0.0, 0.0, 1.281813144683838, 0.0, 3.741041898727417, 4.40792179107666, 4.696862697601318, 7.4557671546936035, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.4875439405441284, -3.6579740047454834, 0.0, 0.0, -4.2769341468811035, 0.0, 0.0, 0.0, 0.0, -3.750028371810913, -4.738703727722168, -3.996192216873169, -4.219812393188477, -3.6451385021209717, -3.120629072189331, -2.4251279830932617, -2.787492036819458, -2.380980968475342, -2.414043426513672, -2.5935349464416504, -1.44951593875885, -1.781057357788086, -0.7026176452636719, -2.436948537826538, -1.3498637676239014, -1.1296428442001343, -1.090763807296753, -0.7575487494468689, -0.9281922578811646, -1.1925240755081177, -1.1245429515838623, -1.38427734375, -0.12878529727458954, -0.5065774321556091, -0.0768575593829155, -0.3907645344734192, -0.5487942099571228, -0.1915544867515564, -0.4517982602119446, -1.3896445035934448, -0.38773587346076965, -0.05178128182888031, -0.012458701618015766, 0.6868308186531067, -0.5969376564025879, -0.023366540670394897, -0.5422958731651306, 0.030717581510543823, -0.6794165372848511, -0.26129597425460815, 0.29045915603637695, 0.5057518482208252, 0.1395220160484314, -0.2656767666339874, -0.7154284715652466, -0.1502610594034195, -0.012564921751618385, 0.6602734327316284, 0.24839602410793304, -0.24335022270679474, 0.0, 0.0, 0.0, 0.9217162728309631, 1.749362587928772, 3.856031894683838, 2.9750895500183105, 7.221002101898193, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.4875439405441284, -3.6579740047454834, -0.0, -0.0, -4.2769341468811035, -0.0, -0.0, -0.0, -0.0, -3.750028371810913, -4.738703727722168, -3.996192216873169, -4.219812393188477, -3.6451385021209717, -3.120629072189331, -2.4251279830932617, -2.787492036819458, -2.380980968475342, -2.414043426513672, -2.5935349464416504, -1.44951593875885, -1.781057357788086, -0.7026176452636719, -2.436948537826538, -1.3498637676239014, -1.1296428442001343, -1.090763807296753, -0.7575487494468689, -0.9281922578811646, -1.1925240755081177, -1.1245429515838623, -1.38427734375, -0.12878529727458954, -0.5065774321556091, -0.0768575593829155, -0.3907645344734192, -0.5487942099571228, -0.1915544867515564, -0.4517982602119446, -1.3896445035934448, -0.38773587346076965, -0.05178128182888031, -0.012458701618015766, 0.6868308186531067, -0.5969376564025879, -0.023366540670394897, -0.5422958731651306, 0.030717581510543823, -0.6794165372848511, -0.26129597425460815, 0.29045915603637695, 0.5057518482208252, 0.1395220160484314, -0.2656767666339874, -0.7154284715652466, -0.1502610594034195, -0.012564921751618385, 0.6602734327316284, 0.24839602410793304, -0.24335022270679474, -0.0, -0.0, 0.0, 0.9217162728309631, 1.749362587928772, 3.856031894683838, 2.9750895500183105, 7.221002101898193, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -1.9527077674865723, 0.20068420469760895, 0.0, 0.0, -1.0317541360855103, 0.0, 0.0, 0.0, -4.944839954376221, -3.5662364959716797, -4.184946537017822, -3.678657054901123, -4.3940815925598145, -3.9005038738250732, -4.382788181304932, -2.821946144104004, -2.943336009979248, -2.573835849761963, -2.7781944274902344, -1.7219679355621338, -1.220061182975769, -1.6715353727340698, -1.5334694385528564, -1.542709231376648, -0.7454127073287964, -1.2130876779556274, -1.292541742324829, -1.9504839181900024, -0.7664556503295898, -0.46091142296791077, -0.9487398862838745, -0.8622210621833801, -1.3817800283432007, -1.059537410736084, -0.20062761008739471, 0.22941182553768158, -0.42605048418045044, 0.15641038119792938, -0.5238199234008789, 0.18220925331115723, 0.32952022552490234, 0.02397107519209385, -0.08022947609424591, 0.12149980664253235, 0.6911182403564453, -0.5006391406059265, -0.2583597004413605, -0.378459632396698, -0.028179418295621872, -0.11528342962265015, 0.5758510231971741, -0.04169054329395294, -0.1386183500289917, -0.0641256794333458, -0.2971007227897644, -0.2348581999540329, -0.8148748278617859, -0.13907350599765778, 0.19433365762233734, -0.5703111290931702, -0.2884368300437927, -0.24788250029087067, 0.0, 0.0, 0.0, -1.4701762199401855, 0.0, 0.0, 5.9439778327941895, 5.496809482574463, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.9527077674865723, 0.20068420469760895, -0.0, -0.0, -1.0317541360855103, -0.0, -0.0, -0.0, -4.944839954376221, -3.5662364959716797, -4.184946537017822, -3.678657054901123, -4.3940815925598145, -3.9005038738250732, -4.382788181304932, -2.821946144104004, -2.943336009979248, -2.573835849761963, -2.7781944274902344, -1.7219679355621338, -1.220061182975769, -1.6715353727340698, -1.5334694385528564, -1.542709231376648, -0.7454127073287964, -1.2130876779556274, -1.292541742324829, -1.9504839181900024, -0.7664556503295898, -0.46091142296791077, -0.9487398862838745, -0.8622210621833801, -1.3817800283432007, -1.059537410736084, -0.20062761008739471, 0.22941182553768158, -0.42605048418045044, 0.15641038119792938, -0.5238199234008789, 0.18220925331115723, 0.32952022552490234, 0.02397107519209385, -0.08022947609424591, 0.12149980664253235, 0.6911182403564453, -0.5006391406059265, -0.2583597004413605, -0.378459632396698, -0.028179418295621872, -0.11528342962265015, 0.5758510231971741, -0.04169054329395294, -0.1386183500289917, -0.0641256794333458, -0.2971007227897644, -0.2348581999540329, -0.8148748278617859, -0.13907350599765778, 0.19433365762233734, -0.5703111290931702, -0.2884368300437927, -0.24788250029087067, -0.0, 0.0, 0.0, -1.4701762199401855, 0.0, 0.0, 5.9439778327941895, 5.496809482574463, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -2.7443177700042725, -3.535001516342163, 0.09411684423685074, 0.0, -0.8511990308761597, 0.0, 0.0, 0.0, -6.252769470214844, -3.33711838722229, -3.876216173171997, -4.194947719573975, -4.145264625549316, -3.890324831008911, -2.6378116607666016, -3.7607970237731934, -2.7380247116088867, -2.4199953079223633, -2.6072983741760254, -2.4668216705322266, -1.327012062072754, -1.2930941581726074, -2.389592170715332, -1.702406883239746, -1.6699814796447754, -1.3623279333114624, -0.6420474052429199, -1.0541250705718994, -1.6093850135803223, -0.6424049139022827, -0.4619884490966797, -0.8928846120834351, -0.3894094228744507, -0.660036563873291, -0.7369935512542725, -0.1643630713224411, -1.4866812229156494, -0.6708276867866516, 0.37607669830322266, 0.39567384123802185, -0.035849679261446, -0.3947507441043854, 0.103474922478199, 0.35595840215682983, -0.00822314154356718, 0.3708190321922302, -0.3034016489982605, -0.0877724438905716, 0.026674728840589523, -0.07060849666595459, 0.7317793965339661, -0.6844654083251953, -0.14201728999614716, -0.20588649809360504, 0.5049363970756531, 0.35942813754081726, -0.32788801193237305, 0.14883409440517426, -0.8603042364120483, -1.0905520915985107, -0.6326623558998108, 0.018569570034742355, -0.475240021944046, 0.0, 0.0, 0.0, 0.0, 7.024283409118652, 0.0, 0.0, 5.571861743927002, 8.371203422546387, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -2.7443177700042725, -3.535001516342163, 0.09411684423685074, 0.0, -0.8511990308761597, -0.0, -0.0, -0.0, -6.252769470214844, -3.33711838722229, -3.876216173171997, -4.194947719573975, -4.145264625549316, -3.890324831008911, -2.6378116607666016, -3.7607970237731934, -2.7380247116088867, -2.4199953079223633, -2.6072983741760254, -2.4668216705322266, -1.327012062072754, -1.2930941581726074, -2.389592170715332, -1.702406883239746, -1.6699814796447754, -1.3623279333114624, -0.6420474052429199, -1.0541250705718994, -1.6093850135803223, -0.6424049139022827, -0.4619884490966797, -0.8928846120834351, -0.3894094228744507, -0.660036563873291, -0.7369935512542725, -0.1643630713224411, -1.4866812229156494, -0.6708276867866516, 0.37607669830322266, 0.39567384123802185, -0.035849679261446, -0.3947507441043854, 0.103474922478199, 0.35595840215682983, -0.00822314154356718, 0.3708190321922302, -0.3034016489982605, -0.0877724438905716, 0.026674728840589523, -0.07060849666595459, 0.7317793965339661, -0.6844654083251953, -0.14201728999614716, -0.20588649809360504, 0.5049363970756531, 0.35942813754081726, -0.32788801193237305, 0.14883409440517426, -0.8603042364120483, -1.0905520915985107, -0.6326623558998108, 0.018569570034742355, -0.475240021944046, -0.0, -0.0, -0.0, -0.0, 7.024283409118652, 0.0, 0.0, 5.571861743927002, 8.371203422546387, 0.0, 0.0], [0.0, 0.0, 0.0, -1.8666490316390991, -0.8321237564086914, -2.5644314289093018, 0.0, -0.7637720108032227, 0.0, 0.0, 0.0, 0.0, -4.161127090454102, -3.689903736114502, -4.3153605461120605, -4.430056571960449, -4.197333812713623, -3.2188432216644287, -3.9838743209838867, -3.285924196243286, -2.7809903621673584, -2.2460598945617676, -2.2140815258026123, -2.208512783050537, -1.4770421981811523, -0.6272294521331787, -1.4137786626815796, -1.2085649967193604, -1.7353323698043823, -1.4743449687957764, -0.47095710039138794, -1.1311098337173462, -0.1496536284685135, -1.9000091552734375, -1.3450037240982056, -0.39916759729385376, -0.07688778638839722, -0.6630607843399048, 0.07752450555562973, -0.6149958372116089, -0.22493427991867065, -0.09762456268072128, 0.1629057675600052, 0.284996896982193, -0.30092760920524597, 0.9011017680168152, -0.11665208637714386, 0.2974417507648468, 0.0061191897839307785, 0.47044461965560913, -0.11421746015548706, 0.40445005893707275, -0.04487479850649834, -0.140248641371727, 1.2241086959838867, 0.6242244839668274, 0.03664090484380722, -0.07256945967674255, 0.35901176929473877, 0.09988296777009964, -0.1703263372182846, -0.5643524527549744, 0.29472705721855164, -0.09770424664020538, 0.11753331124782562, 0.12229464948177338, -0.1172928437590599, -0.44549041986465454, 0.0, 0.0, 0.0, 3.8081555366516113, 3.183377742767334, 0.0, 6.37366247177124, 6.014041900634766, 0.0, 0.0, -0.0, -0.0, -0.0, -1.8666490316390991, -0.8321237564086914, -2.5644314289093018, 0.0, -0.7637720108032227, 0.0, -0.0, -0.0, -0.0, -4.161127090454102, -3.689903736114502, -4.3153605461120605, -4.430056571960449, -4.197333812713623, -3.2188432216644287, -3.9838743209838867, -3.285924196243286, -2.7809903621673584, -2.2460598945617676, -2.2140815258026123, -2.208512783050537, -1.4770421981811523, -0.6272294521331787, -1.4137786626815796, -1.2085649967193604, -1.7353323698043823, -1.4743449687957764, -0.47095710039138794, -1.1311098337173462, -0.1496536284685135, -1.9000091552734375, -1.3450037240982056, -0.39916759729385376, -0.07688778638839722, -0.6630607843399048, 0.07752450555562973, -0.6149958372116089, -0.22493427991867065, -0.09762456268072128, 0.1629057675600052, 0.284996896982193, -0.30092760920524597, 0.9011017680168152, -0.11665208637714386, 0.2974417507648468, 0.0061191897839307785, 0.47044461965560913, -0.11421746015548706, 0.40445005893707275, -0.04487479850649834, -0.140248641371727, 1.2241086959838867, 0.6242244839668274, 0.03664090484380722, -0.07256945967674255, 0.35901176929473877, 0.09988296777009964, -0.1703263372182846, -0.5643524527549744, 0.29472705721855164, -0.09770424664020538, 0.11753331124782562, 0.12229464948177338, -0.1172928437590599, -0.44549041986465454, -0.0, 0.0, 0.0, 3.8081555366516113, 3.183377742767334, 0.0, 6.37366247177124, 6.014041900634766, 0.0, 0.0], [0.0, 0.0, -3.2625980377197266, -3.2820537090301514, 0.11164563149213791, 0.0, -2.9726858139038086, 0.0, 0.0, 0.0, 0.0, -5.320865154266357, -4.607849597930908, -4.755481719970703, -4.646419048309326, -4.323447227478027, -4.171614170074463, -3.1929173469543457, -3.5399720668792725, -3.0705456733703613, -2.54457426071167, -2.5027122497558594, -2.0975284576416016, -1.8270756006240845, -1.8251471519470215, -1.7943633794784546, -1.273399829864502, -1.9593791961669922, -0.7392382621765137, -0.43912193179130554, -1.0173816680908203, -1.8279529809951782, -0.39743974804878235, -0.6366757750511169, 0.146025612950325, -0.4542805850505829, -0.1328705996274948, 0.3443876802921295, -0.4091140031814575, -0.5647761225700378, 0.38173744082450867, -0.026027021929621696, 0.40766358375549316, -0.256780743598938, -0.4349721074104309, 0.08632092922925949, 0.6939350962638855, 0.6068471670150757, -0.4926755428314209, 0.11692487448453903, 0.24502260982990265, 0.5351808071136475, 0.5056341886520386, -0.17370566725730896, 0.2473602443933487, 2.8293511867523193, 0.4019995331764221, 0.6703510284423828, 0.2902155816555023, -0.07316311448812485, -0.3248181641101837, -0.2139977365732193, -0.22629934549331665, -0.5567044615745544, -0.11802758276462555, -0.6668955087661743, -0.4201325476169586, -1.024801254272461, 0.20572376251220703, 0.0, 0.0, 0.0, 4.7969841957092285, 0.0, 5.42043399810791, 6.278903961181641, 4.942432880401611, 0.0, -0.0, -0.0, -3.2625980377197266, -3.2820537090301514, 0.11164563149213791, -0.0, -2.9726858139038086, -0.0, -0.0, -0.0, -0.0, -5.320865154266357, -4.607849597930908, -4.755481719970703, -4.646419048309326, -4.323447227478027, -4.171614170074463, -3.1929173469543457, -3.5399720668792725, -3.0705456733703613, -2.54457426071167, -2.5027122497558594, -2.0975284576416016, -1.8270756006240845, -1.8251471519470215, -1.7943633794784546, -1.273399829864502, -1.9593791961669922, -0.7392382621765137, -0.43912193179130554, -1.0173816680908203, -1.8279529809951782, -0.39743974804878235, -0.6366757750511169, 0.146025612950325, -0.4542805850505829, -0.1328705996274948, 0.3443876802921295, -0.4091140031814575, -0.5647761225700378, 0.38173744082450867, -0.026027021929621696, 0.40766358375549316, -0.256780743598938, -0.4349721074104309, 0.08632092922925949, 0.6939350962638855, 0.6068471670150757, -0.4926755428314209, 0.11692487448453903, 0.24502260982990265, 0.5351808071136475, 0.5056341886520386, -0.17370566725730896, 0.2473602443933487, 2.8293511867523193, 0.4019995331764221, 0.6703510284423828, 0.2902155816555023, -0.07316311448812485, -0.3248181641101837, -0.2139977365732193, -0.22629934549331665, -0.5567044615745544, -0.11802758276462555, -0.6668955087661743, -0.4201325476169586, -1.024801254272461, 0.20572376251220703, 0.0, 0.0, 0.0, 4.7969841957092285, 0.0, 5.42043399810791, 6.278903961181641, 4.942432880401611, 0.0], [0.0, 0.0, -3.834892511367798, -4.386226654052734, 0.0, 0.0, -4.846920013427734, 0.0, 0.0, 0.0, -5.320876121520996, -5.738546848297119, -4.762108325958252, -4.838691711425781, -3.259056806564331, -4.103886604309082, -4.245056629180908, -3.8909127712249756, -2.4345803260803223, -3.0580713748931885, -3.056633472442627, -2.263723373413086, -2.799320697784424, -2.21736478805542, -2.3297252655029297, -0.5459039807319641, -1.348042607307434, -1.2670705318450928, -0.645215630531311, -1.0582025051116943, -0.5954967141151428, -0.38987046480178833, -0.26580536365509033, -0.3503522574901581, -0.3556482791900635, -0.0047649177722632885, -0.8201456069946289, 0.10821061581373215, 0.19941042363643646, 1.0882567167282104, 0.21978603303432465, 0.6374031901359558, 0.5022845268249512, -0.2756296694278717, -0.23829281330108643, -0.4125235378742218, -0.2959156036376953, 0.8471602201461792, 0.4649341106414795, 0.6777496337890625, 0.008185459300875664, 0.6905010342597961, 0.8509416580200195, -0.6265955567359924, 0.6628370881080627, 0.605792760848999, 0.6953805088996887, 0.46651333570480347, 0.010450886562466621, 0.5336835384368896, 0.529236912727356, 0.16381479799747467, 0.21597765386104584, 0.041550055146217346, 0.020671814680099487, 1.2836053371429443, 0.9191004037857056, -0.06982573121786118, -0.1858987659215927, -2.0223960876464844, 0.0, 0.0, 1.1497793197631836, 0.0, 0.0, 5.58651876449585, 6.239944934844971, 0.0, -0.0, -0.0, -3.834892511367798, -4.386226654052734, 0.0, -0.0, -4.846920013427734, -0.0, -0.0, -0.0, -5.320876121520996, -5.738546848297119, -4.762108325958252, -4.838691711425781, -3.259056806564331, -4.103886604309082, -4.245056629180908, -3.8909127712249756, -2.4345803260803223, -3.0580713748931885, -3.056633472442627, -2.263723373413086, -2.799320697784424, -2.21736478805542, -2.3297252655029297, -0.5459039807319641, -1.348042607307434, -1.2670705318450928, -0.645215630531311, -1.0582025051116943, -0.5954967141151428, -0.38987046480178833, -0.26580536365509033, -0.3503522574901581, -0.3556482791900635, -0.0047649177722632885, -0.8201456069946289, 0.10821061581373215, 0.19941042363643646, 1.0882567167282104, 0.21978603303432465, 0.6374031901359558, 0.5022845268249512, -0.2756296694278717, -0.23829281330108643, -0.4125235378742218, -0.2959156036376953, 0.8471602201461792, 0.4649341106414795, 0.6777496337890625, 0.008185459300875664, 0.6905010342597961, 0.8509416580200195, -0.6265955567359924, 0.6628370881080627, 0.605792760848999, 0.6953805088996887, 0.46651333570480347, 0.010450886562466621, 0.5336835384368896, 0.529236912727356, 0.16381479799747467, 0.21597765386104584, 0.041550055146217346, 0.020671814680099487, 1.2836053371429443, 0.9191004037857056, -0.06982573121786118, -0.1858987659215927, -2.0223960876464844, -0.0, 0.0, 1.1497793197631836, 0.0, 0.0, 5.58651876449585, 6.239944934844971, 0.0], [0.0, -2.4265105724334717, -3.9386579990386963, 0.0, 0.0, -2.9649763107299805, 0.0, 0.0, 0.0, -7.506483554840088, -6.4701361656188965, -5.795198917388916, -4.486860275268555, -4.544959545135498, -4.220703125, -3.331972122192383, -4.671536445617676, -3.172316551208496, -2.215456962585449, -2.2529869079589844, -3.011758327484131, -2.1664695739746094, -2.204289436340332, -1.8079527616500854, -0.8971500992774963, -1.6221476793289185, -1.1181588172912598, -1.725250244140625, -0.9659306406974792, -0.5400615930557251, -0.4508885443210602, -0.5545845627784729, -0.09965532273054123, -0.2397271692752838, -0.24578158557415009, -0.06214703246951103, -0.3010771870613098, -0.2028617411851883, 0.42845892906188965, 0.048286665230989456, 0.4491010308265686, 0.5863967537879944, 0.0058176699094474316, -0.04299239441752434, 0.038622815161943436, 0.25087451934814453, 0.1368635594844818, 0.42284759879112244, 0.4056922495365143, 0.02431403286755085, 0.20020905137062073, 0.9612246751785278, 0.3962743878364563, 1.0988091230392456, 1.0766596794128418, 0.583554744720459, 0.5046003460884094, 0.1567310243844986, 0.5231266617774963, 0.8135726451873779, 0.2963446378707886, -0.2530619204044342, 0.3578248918056488, -0.2369088977575302, -0.33324313163757324, -0.4599369764328003, 0.7589471936225891, 0.5625680088996887, 0.3155974745750427, 0.26015567779541016, -1.094052791595459, 0.0, 0.0, 0.0, 0.0, 4.447543144226074, 5.128393650054932, 4.4900221824646, -0.0, -2.4265105724334717, -3.9386579990386963, -0.0, -0.0, -2.9649763107299805, -0.0, -0.0, -0.0, -7.506483554840088, -6.4701361656188965, -5.795198917388916, -4.486860275268555, -4.544959545135498, -4.220703125, -3.331972122192383, -4.671536445617676, -3.172316551208496, -2.215456962585449, -2.2529869079589844, -3.011758327484131, -2.1664695739746094, -2.204289436340332, -1.8079527616500854, -0.8971500992774963, -1.6221476793289185, -1.1181588172912598, -1.725250244140625, -0.9659306406974792, -0.5400615930557251, -0.4508885443210602, -0.5545845627784729, -0.09965532273054123, -0.2397271692752838, -0.24578158557415009, -0.06214703246951103, -0.3010771870613098, -0.2028617411851883, 0.42845892906188965, 0.048286665230989456, 0.4491010308265686, 0.5863967537879944, 0.0058176699094474316, -0.04299239441752434, 0.038622815161943436, 0.25087451934814453, 0.1368635594844818, 0.42284759879112244, 0.4056922495365143, 0.02431403286755085, 0.20020905137062073, 0.9612246751785278, 0.3962743878364563, 1.0988091230392456, 1.0766596794128418, 0.583554744720459, 0.5046003460884094, 0.1567310243844986, 0.5231266617774963, 0.8135726451873779, 0.2963446378707886, -0.2530619204044342, 0.3578248918056488, -0.2369088977575302, -0.33324313163757324, -0.4599369764328003, 0.7589471936225891, 0.5625680088996887, 0.3155974745750427, 0.26015567779541016, -1.094052791595459, -0.0, 0.0, 0.0, 0.0, 4.447543144226074, 5.128393650054932, 4.4900221824646], [0.0, -1.2401986122131348, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.971374034881592, -5.333996772766113, -4.824819087982178, -5.2776594161987305, -4.4172892570495605, -4.039593696594238, -2.9317517280578613, -3.1300997734069824, -3.389911413192749, -3.7569258213043213, -2.9283499717712402, -1.4780433177947998, -2.237150192260742, -1.5084600448608398, -2.2610020637512207, -1.4681516885757446, -1.0668655633926392, -1.8760204315185547, -1.4402894973754883, -0.030132265761494637, -1.1880650520324707, -0.9803170561790466, -0.4081740379333496, -0.49180689454078674, 0.2631218135356903, 0.3395080268383026, 0.08695327490568161, 0.5632429718971252, -0.1973312497138977, 0.6413091421127319, 1.1114062070846558, 0.6013296246528625, -0.05869510769844055, 0.12581366300582886, 0.4078376293182373, 0.7890371680259705, 0.5292905569076538, 0.5875748991966248, 0.8110218048095703, 1.1646137237548828, -0.15880613029003143, 0.12543030083179474, 0.7143602967262268, 1.0588431358337402, 0.7476686239242554, 0.37781113386154175, 0.8007035851478577, 0.765917956829071, 1.154883861541748, 0.8901836276054382, 0.8095467686653137, 1.0240896940231323, -0.0397924967110157, -1.1220660209655762, -0.09601929038763046, 0.7541776299476624, 0.4952006936073303, 0.08118176460266113, 1.601100206375122, -0.30982398986816406, 0.14841602742671967, 0.27755117416381836, 0.0, 0.0, 0.0, 4.790582656860352, 1.8762829303741455, 1.9870938062667847, 3.021841049194336, -0.0, -1.2401986122131348, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.971374034881592, -5.333996772766113, -4.824819087982178, -5.2776594161987305, -4.4172892570495605, -4.039593696594238, -2.9317517280578613, -3.1300997734069824, -3.389911413192749, -3.7569258213043213, -2.9283499717712402, -1.4780433177947998, -2.237150192260742, -1.5084600448608398, -2.2610020637512207, -1.4681516885757446, -1.0668655633926392, -1.8760204315185547, -1.4402894973754883, -0.030132265761494637, -1.1880650520324707, -0.9803170561790466, -0.4081740379333496, -0.49180689454078674, 0.2631218135356903, 0.3395080268383026, 0.08695327490568161, 0.5632429718971252, -0.1973312497138977, 0.6413091421127319, 1.1114062070846558, 0.6013296246528625, -0.05869510769844055, 0.12581366300582886, 0.4078376293182373, 0.7890371680259705, 0.5292905569076538, 0.5875748991966248, 0.8110218048095703, 1.1646137237548828, -0.15880613029003143, 0.12543030083179474, 0.7143602967262268, 1.0588431358337402, 0.7476686239242554, 0.37781113386154175, 0.8007035851478577, 0.765917956829071, 1.154883861541748, 0.8901836276054382, 0.8095467686653137, 1.0240896940231323, -0.0397924967110157, -1.1220660209655762, -0.09601929038763046, 0.7541776299476624, 0.4952006936073303, 0.08118176460266113, 1.601100206375122, -0.30982398986816406, 0.14841602742671967, 0.27755117416381836, 0.0, 0.0, 0.0, 4.790582656860352, 1.8762829303741455, 1.9870938062667847, 3.021841049194336], [-0.9991978406906128, -2.069450855255127, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.0387091636657715, -5.9704976081848145, -5.303472995758057, -5.735041618347168, -4.625833511352539, -3.879514455795288, -4.381655216217041, -3.307352066040039, -3.578112840652466, -2.99519681930542, -3.2381410598754883, -1.9534598588943481, -2.6293206214904785, -2.637507677078247, -2.0489888191223145, -1.4968419075012207, -1.8243719339370728, -1.543170690536499, -0.6554210782051086, -0.5637354254722595, -1.1469742059707642, -1.0194522142410278, -0.5202869176864624, -0.1500914841890335, 0.8299824595451355, 0.6330935955047607, 1.201400876045227, 0.22430430352687836, 0.500186562538147, 0.1112767830491066, 0.18818286061286926, 0.5463512539863586, 0.16755585372447968, -0.9283075928688049, 0.20406237244606018, 0.09017559885978699, 0.45939409732818604, 0.5884156227111816, 0.17604921758174896, 1.5602062940597534, 0.750835657119751, 1.2448689937591553, 0.5205181241035461, 0.16927467286586761, 0.20966485142707825, 0.18735240399837494, 0.6805940270423889, -0.011091354303061962, -0.074166439473629, 0.597130298614502, 0.8095229864120483, 0.6409873962402344, 0.5792336463928223, -0.04975432530045509, 0.14870144426822662, 0.40545278787612915, 0.2497950792312622, 0.9987713098526001, -0.9193714261054993, 1.0120378732681274, 0.8933951258659363, 0.6004019379615784, 0.4266044497489929, 2.444631814956665, 0.0, 0.0, 5.5804643630981445, 2.331144332885742, 1.8584438562393188, 3.9648194313049316, -0.9991978406906128, -2.069450855255127, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.0387091636657715, -5.9704976081848145, -5.303472995758057, -5.735041618347168, -4.625833511352539, -3.879514455795288, -4.381655216217041, -3.307352066040039, -3.578112840652466, -2.99519681930542, -3.2381410598754883, -1.9534598588943481, -2.6293206214904785, -2.637507677078247, -2.0489888191223145, -1.4968419075012207, -1.8243719339370728, -1.543170690536499, -0.6554210782051086, -0.5637354254722595, -1.1469742059707642, -1.0194522142410278, -0.5202869176864624, -0.1500914841890335, 0.8299824595451355, 0.6330935955047607, 1.201400876045227, 0.22430430352687836, 0.500186562538147, 0.1112767830491066, 0.18818286061286926, 0.5463512539863586, 0.16755585372447968, -0.9283075928688049, 0.20406237244606018, 0.09017559885978699, 0.45939409732818604, 0.5884156227111816, 0.17604921758174896, 1.5602062940597534, 0.750835657119751, 1.2448689937591553, 0.5205181241035461, 0.16927467286586761, 0.20966485142707825, 0.18735240399837494, 0.6805940270423889, -0.011091354303061962, -0.074166439473629, 0.597130298614502, 0.8095229864120483, 0.6409873962402344, 0.5792336463928223, -0.04975432530045509, 0.14870144426822662, 0.40545278787612915, 0.2497950792312622, 0.9987713098526001, -0.9193714261054993, 1.0120378732681274, 0.8933951258659363, 0.6004019379615784, 0.4266044497489929, 2.444631814956665, 0.0, 0.0, 5.5804643630981445, 2.331144332885742, 1.8584438562393188, 3.9648194313049316], [-0.68156498670578, -1.5440515279769897, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.313475131988525, -5.61132287979126, -5.207200527191162, -4.750563144683838, -4.531886100769043, -4.419370651245117, -3.902184247970581, -3.811558485031128, -3.4122681617736816, -3.1046488285064697, -2.6740541458129883, -2.5066728591918945, -1.7648513317108154, -1.753046989440918, -1.62974214553833, -2.4681663513183594, -1.3903167247772217, -1.7143480777740479, -1.2599766254425049, -0.994880735874176, -1.119520664215088, -1.4113439321517944, -0.5872370004653931, -0.411050409078598, 0.11163543164730072, 0.15229013562202454, 1.688470482826233, 0.506813645362854, 1.300699234008789, 0.04935196042060852, 0.7396187782287598, 0.5526395440101624, 0.1002948135137558, -0.045290280133485794, 0.2287198007106781, 0.08478626608848572, -1.5894075632095337, 0.5389642715454102, 0.3376108705997467, 0.8357821702957153, 0.9626840353012085, 1.2546027898788452, 1.028444528579712, 0.4815080463886261, 0.7935434579849243, 1.178197979927063, 1.1948730945587158, 1.2677083015441895, 0.820824921131134, 0.581826388835907, 0.8023629188537598, 0.665640652179718, 0.6307324767112732, 0.23994238674640656, 1.0632989406585693, 0.7810913920402527, 0.8326063752174377, 0.4233691692352295, 0.27519354224205017, 0.007210969924926758, 0.5443778038024902, 0.44335708022117615, 1.2610629796981812, 0.8223597407341003, 0.0, 0.0, 5.725254535675049, 2.517972946166992, 2.5194318294525146, 6.72799825668335, -0.68156498670578, -1.5440515279769897, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.313475131988525, -5.61132287979126, -5.207200527191162, -4.750563144683838, -4.531886100769043, -4.419370651245117, -3.902184247970581, -3.811558485031128, -3.4122681617736816, -3.1046488285064697, -2.6740541458129883, -2.5066728591918945, -1.7648513317108154, -1.753046989440918, -1.62974214553833, -2.4681663513183594, -1.3903167247772217, -1.7143480777740479, -1.2599766254425049, -0.994880735874176, -1.119520664215088, -1.4113439321517944, -0.5872370004653931, -0.411050409078598, 0.11163543164730072, 0.15229013562202454, 1.688470482826233, 0.506813645362854, 1.300699234008789, 0.04935196042060852, 0.7396187782287598, 0.5526395440101624, 0.1002948135137558, -0.045290280133485794, 0.2287198007106781, 0.08478626608848572, -1.5894075632095337, 0.5389642715454102, 0.3376108705997467, 0.8357821702957153, 0.9626840353012085, 1.2546027898788452, 1.028444528579712, 0.4815080463886261, 0.7935434579849243, 1.178197979927063, 1.1948730945587158, 1.2677083015441895, 0.820824921131134, 0.581826388835907, 0.8023629188537598, 0.665640652179718, 0.6307324767112732, 0.23994238674640656, 1.0632989406585693, 0.7810913920402527, 0.8326063752174377, 0.4233691692352295, 0.27519354224205017, 0.007210969924926758, 0.5443778038024902, 0.44335708022117615, 1.2610629796981812, 0.8223597407341003, 0.0, 0.0, 5.725254535675049, 2.517972946166992, 2.5194318294525146, 6.72799825668335], [-0.1650761365890503, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.349355220794678, -6.072271347045898, -4.869210720062256, -4.82156229019165, -5.2506866455078125, -4.514575004577637, -4.212460994720459, -4.282116413116455, -3.188089609146118, -3.518256902694702, -2.712087631225586, -2.8041350841522217, -2.7765629291534424, -2.1609482765197754, -1.6178460121154785, -1.5689595937728882, -1.6247113943099976, -1.8095648288726807, -1.0014426708221436, -1.1744219064712524, -1.4802170991897583, -0.3294987380504608, -0.6513030529022217, 0.2522168457508087, 0.7396501898765564, 0.19803917407989502, 0.9554029107093811, -0.564142644405365, 0.3886606693267822, 0.47801610827445984, 1.5262999534606934, 0.5497108697891235, 0.35467997193336487, 0.37752801179885864, 0.7483127117156982, -0.17592470347881317, -0.10247115790843964, 0.42265400290489197, 0.6398444771766663, 0.5468727350234985, 1.5315494537353516, 1.2933995723724365, 0.8134716153144836, 1.2099976539611816, 3.2187135219573975, 1.3334640264511108, 0.888836145401001, 1.4968276023864746, 1.0753015279769897, -0.635549783706665, 0.5107032656669617, 0.7261955142021179, 0.2652372717857361, 1.2202366590499878, 0.695184051990509, 0.5875889658927917, 0.6015257835388184, 0.9032249450683594, 1.0637314319610596, 0.5115982890129089, 0.48012614250183105, 1.376786231994629, -0.17676080763339996, 0.34762370586395264, 0.5183934569358826, 0.0, 0.0, 0.0, -0.14779667556285858, 1.5710110664367676, 0.0, -0.1650761365890503, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.349355220794678, -6.072271347045898, -4.869210720062256, -4.82156229019165, -5.2506866455078125, -4.514575004577637, -4.212460994720459, -4.282116413116455, -3.188089609146118, -3.518256902694702, -2.712087631225586, -2.8041350841522217, -2.7765629291534424, -2.1609482765197754, -1.6178460121154785, -1.5689595937728882, -1.6247113943099976, -1.8095648288726807, -1.0014426708221436, -1.1744219064712524, -1.4802170991897583, -0.3294987380504608, -0.6513030529022217, 0.2522168457508087, 0.7396501898765564, 0.19803917407989502, 0.9554029107093811, -0.564142644405365, 0.3886606693267822, 0.47801610827445984, 1.5262999534606934, 0.5497108697891235, 0.35467997193336487, 0.37752801179885864, 0.7483127117156982, -0.17592470347881317, -0.10247115790843964, 0.42265400290489197, 0.6398444771766663, 0.5468727350234985, 1.5315494537353516, 1.2933995723724365, 0.8134716153144836, 1.2099976539611816, 3.2187135219573975, 1.3334640264511108, 0.888836145401001, 1.4968276023864746, 1.0753015279769897, -0.635549783706665, 0.5107032656669617, 0.7261955142021179, 0.2652372717857361, 1.2202366590499878, 0.695184051990509, 0.5875889658927917, 0.6015257835388184, 0.9032249450683594, 1.0637314319610596, 0.5115982890129089, 0.48012614250183105, 1.376786231994629, -0.17676080763339996, 0.34762370586395264, 0.5183934569358826, 0.0, 0.0, 0.0, -0.14779667556285858, 1.5710110664367676, 0.0], [-3.145110845565796, 0.0, 0.0, 0.0, 0.0, 0.0, -3.8651235103607178, -5.864945888519287, -5.857339382171631, -4.8705573081970215, -4.473487377166748, -4.772974491119385, -4.394392967224121, -3.8067357540130615, -4.487734794616699, -4.047067642211914, -2.9730546474456787, -2.542102336883545, -2.4005258083343506, -2.8597607612609863, -2.234100818634033, -1.6968803405761719, -0.6864959597587585, -1.349928855895996, -1.573697805404663, -1.731365442276001, 0.22267962992191315, -0.8879790306091309, -0.6903461217880249, -0.6235607862472534, -0.6523484587669373, -0.1467466652393341, 0.05028229579329491, -0.06569528579711914, -0.21203090250492096, 0.47091779112815857, 0.07796811312437057, -1.4033899307250977, -0.6368958950042725, 0.5031465888023376, 0.540160596370697, 0.16423623263835907, 0.7856000065803528, 0.6467359662055969, 1.063767910003662, 0.31463682651519775, 0.6563246250152588, -1.7397445440292358, -0.0598541684448719, 1.2714787721633911, 1.7681019306182861, 0.7553120851516724, 2.149263381958008, 1.1283009052276611, 0.9305922389030457, 0.2307242602109909, 0.9748509526252747, 0.998628556728363, 0.9021598696708679, 1.0870243310928345, 0.025664081797003746, 1.0697122812271118, 0.7270606160163879, 0.5621922016143799, 1.0976107120513916, 1.1946849822998047, 0.7195401787757874, 2.0091676712036133, 0.9347920417785645, 0.3530004918575287, 0.5865664482116699, 1.0415594577789307, 1.4889945983886719, 0.0, 0.0, 0.5863475799560547, 1.3346409797668457, -1.6816052198410034, -3.145110845565796, -0.0, -0.0, -0.0, -0.0, -0.0, -3.8651235103607178, -5.864945888519287, -5.857339382171631, -4.8705573081970215, -4.473487377166748, -4.772974491119385, -4.394392967224121, -3.8067357540130615, -4.487734794616699, -4.047067642211914, -2.9730546474456787, -2.542102336883545, -2.4005258083343506, -2.8597607612609863, -2.234100818634033, -1.6968803405761719, -0.6864959597587585, -1.349928855895996, -1.573697805404663, -1.731365442276001, 0.22267962992191315, -0.8879790306091309, -0.6903461217880249, -0.6235607862472534, -0.6523484587669373, -0.1467466652393341, 0.05028229579329491, -0.06569528579711914, -0.21203090250492096, 0.47091779112815857, 0.07796811312437057, -1.4033899307250977, -0.6368958950042725, 0.5031465888023376, 0.540160596370697, 0.16423623263835907, 0.7856000065803528, 0.6467359662055969, 1.063767910003662, 0.31463682651519775, 0.6563246250152588, -1.7397445440292358, -0.0598541684448719, 1.2714787721633911, 1.7681019306182861, 0.7553120851516724, 2.149263381958008, 1.1283009052276611, 0.9305922389030457, 0.2307242602109909, 0.9748509526252747, 0.998628556728363, 0.9021598696708679, 1.0870243310928345, 0.025664081797003746, 1.0697122812271118, 0.7270606160163879, 0.5621922016143799, 1.0976107120513916, 1.1946849822998047, 0.7195401787757874, 2.0091676712036133, 0.9347920417785645, 0.3530004918575287, 0.5865664482116699, 1.0415594577789307, 1.4889945983886719, 0.0, 0.0, 0.5863475799560547, 1.3346409797668457, -1.6816052198410034], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.449836730957031, -5.431687355041504, -5.517150402069092, -5.543557167053223, -5.529800891876221, -3.953247308731079, -3.7720885276794434, -4.441932201385498, -2.5286672115325928, -3.518014669418335, -3.0445754528045654, -2.9054477214813232, -2.5004775524139404, -2.164916515350342, -2.1574764251708984, -1.5525121688842773, -2.2506356239318848, -0.8199502825737, -1.5846787691116333, -0.5900894999504089, -1.0032695531845093, -1.5884546041488647, -0.822632908821106, -1.0678504705429077, -0.3828752636909485, -0.24192850291728973, -0.17224903404712677, 0.24362115561962128, -0.1544092297554016, -1.0268809795379639, 1.0607664585113525, -1.7821513414382935, -0.20481759309768677, 0.4524999260902405, 0.5045392513275146, 0.2894190549850464, 0.8114149570465088, 0.6777619123458862, 1.1323550939559937, 0.12072284519672394, 0.6750836372375488, 0.8643589019775391, 1.3478851318359375, 1.4295207262039185, 0.9557817578315735, 1.5729820728302002, 0.45495110750198364, 0.9411301016807556, 0.7332156896591187, 1.1401861906051636, 0.5339928269386292, 1.477724313735962, 0.8668949007987976, 0.6257370114326477, 1.278269648551941, 0.8844199180603027, 1.5070545673370361, 0.557165801525116, 1.0450583696365356, 1.4732346534729004, 1.1307528018951416, 1.0613975524902344, 0.783342719078064, 1.107865571975708, 0.02956203557550907, 0.14342939853668213, 0.3162972629070282, 0.0, 0.0, 0.0, 1.06764817237854, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.449836730957031, -5.431687355041504, -5.517150402069092, -5.543557167053223, -5.529800891876221, -3.953247308731079, -3.7720885276794434, -4.441932201385498, -2.5286672115325928, -3.518014669418335, -3.0445754528045654, -2.9054477214813232, -2.5004775524139404, -2.164916515350342, -2.1574764251708984, -1.5525121688842773, -2.2506356239318848, -0.8199502825737, -1.5846787691116333, -0.5900894999504089, -1.0032695531845093, -1.5884546041488647, -0.822632908821106, -1.0678504705429077, -0.3828752636909485, -0.24192850291728973, -0.17224903404712677, 0.24362115561962128, -0.1544092297554016, -1.0268809795379639, 1.0607664585113525, -1.7821513414382935, -0.20481759309768677, 0.4524999260902405, 0.5045392513275146, 0.2894190549850464, 0.8114149570465088, 0.6777619123458862, 1.1323550939559937, 0.12072284519672394, 0.6750836372375488, 0.8643589019775391, 1.3478851318359375, 1.4295207262039185, 0.9557817578315735, 1.5729820728302002, 0.45495110750198364, 0.9411301016807556, 0.7332156896591187, 1.1401861906051636, 0.5339928269386292, 1.477724313735962, 0.8668949007987976, 0.6257370114326477, 1.278269648551941, 0.8844199180603027, 1.5070545673370361, 0.557165801525116, 1.0450583696365356, 1.4732346534729004, 1.1307528018951416, 1.0613975524902344, 0.783342719078064, 1.107865571975708, 0.02956203557550907, 0.14342939853668213, 0.3162972629070282, 0.0, 0.0, 0.0, 1.06764817237854, 0.0], [-5.316143989562988, 0.0, 0.0, 0.0, 0.0, -5.5499444007873535, -4.749346733093262, -5.532393455505371, -5.5394062995910645, -5.0429301261901855, -4.860915184020996, -5.336297512054443, -4.3730316162109375, -3.3747658729553223, -3.7720179557800293, -3.7077078819274902, -3.185385227203369, -2.28851056098938, -3.415174722671509, -2.137014389038086, -3.022498369216919, -1.9828037023544312, -1.659276008605957, -0.8168842196464539, -1.222575306892395, -1.152480959892273, -1.4655519723892212, -1.0341001749038696, -0.5369040369987488, -0.878028154373169, 0.961991548538208, -0.49756869673728943, 0.06370460987091064, 0.5444169044494629, 0.17477869987487793, 0.40386804938316345, 0.06412416696548462, -1.5414930582046509, -1.746315360069275, -1.8259913921356201, 0.9884577989578247, -0.07244878262281418, 0.11824537068605423, 1.1869093179702759, 0.1760491579771042, 0.8300693035125732, 0.9752273559570312, 1.4157369136810303, -0.5447628498077393, 1.5342257022857666, 1.8489036560058594, 1.4435665607452393, 0.6091513633728027, 0.820625901222229, 1.4761368036270142, 0.6495203971862793, 1.9733459949493408, 1.3737672567367554, 1.0559797286987305, 1.394797444343567, 0.8172499537467957, 1.130034327507019, 0.8862879872322083, -0.3114154636859894, 0.9655162692070007, 0.419141560792923, 0.8634732365608215, 0.5215450525283813, 0.8552544116973877, 1.1082390546798706, 0.20438940823078156, 0.3991135358810425, 0.7203142642974854, 0.0, 0.0, 0.0, 2.7644646167755127, 0.0, -5.316143989562988, -0.0, -0.0, -0.0, -0.0, -5.5499444007873535, -4.749346733093262, -5.532393455505371, -5.5394062995910645, -5.0429301261901855, -4.860915184020996, -5.336297512054443, -4.3730316162109375, -3.3747658729553223, -3.7720179557800293, -3.7077078819274902, -3.185385227203369, -2.28851056098938, -3.415174722671509, -2.137014389038086, -3.022498369216919, -1.9828037023544312, -1.659276008605957, -0.8168842196464539, -1.222575306892395, -1.152480959892273, -1.4655519723892212, -1.0341001749038696, -0.5369040369987488, -0.878028154373169, 0.961991548538208, -0.49756869673728943, 0.06370460987091064, 0.5444169044494629, 0.17477869987487793, 0.40386804938316345, 0.06412416696548462, -1.5414930582046509, -1.746315360069275, -1.8259913921356201, 0.9884577989578247, -0.07244878262281418, 0.11824537068605423, 1.1869093179702759, 0.1760491579771042, 0.8300693035125732, 0.9752273559570312, 1.4157369136810303, -0.5447628498077393, 1.5342257022857666, 1.8489036560058594, 1.4435665607452393, 0.6091513633728027, 0.820625901222229, 1.4761368036270142, 0.6495203971862793, 1.9733459949493408, 1.3737672567367554, 1.0559797286987305, 1.394797444343567, 0.8172499537467957, 1.130034327507019, 0.8862879872322083, -0.3114154636859894, 0.9655162692070007, 0.419141560792923, 0.8634732365608215, 0.5215450525283813, 0.8552544116973877, 1.1082390546798706, 0.20438940823078156, 0.3991135358810425, 0.7203142642974854, 0.0, 0.0, 0.0, 2.7644646167755127, 0.0], [-3.2682044506073, 0.0, 0.0, 0.0, 0.0, -5.661307334899902, -5.674117565155029, -5.556199073791504, -5.511413097381592, -5.648533821105957, -6.043732643127441, -4.095362186431885, -4.549173355102539, -3.3445510864257812, -3.573390007019043, -4.131521701812744, -3.66945219039917, -3.230372428894043, -3.0149943828582764, -4.0566229820251465, -2.6192665100097656, -1.8641178607940674, -1.0143619775772095, -1.1009265184402466, -0.9688764810562134, -0.7203890085220337, -0.7502419948577881, -0.7200855612754822, -1.297151803970337, -0.8464727401733398, -0.024727320298552513, 0.13495376706123352, 0.15236981213092804, 0.7419922947883606, -1.3501105308532715, 0.23882220685482025, 1.043470859527588, 2.4856071831891313e-05, -0.1225111111998558, 1.324103832244873, 0.8195681571960449, 0.722922682762146, 0.3988652229309082, 0.634749174118042, 0.47673818469047546, 0.87713623046875, -0.49969956278800964, 0.2450665384531021, 2.0169591903686523, 1.0196186304092407, 1.0207395553588867, 0.8135198950767517, 0.8988380432128906, 1.5681813955307007, 0.94700688123703, 0.48535671830177307, 0.8221314549446106, 1.595513939857483, 1.3983266353607178, 0.8465811014175415, 1.4483211040496826, 0.6733085513114929, 0.19534015655517578, 1.1728657484054565, 0.2495332956314087, 0.5244393348693848, 0.3619097173213959, 1.1751763820648193, 0.7127037048339844, 0.7546966075897217, 0.7515234351158142, 0.07503333687782288, 0.4851859211921692, 0.887856662273407, 0.0, 0.0, 3.2827870845794678, 0.0, -3.2682044506073, -0.0, -0.0, -0.0, -0.0, -5.661307334899902, -5.674117565155029, -5.556199073791504, -5.511413097381592, -5.648533821105957, -6.043732643127441, -4.095362186431885, -4.549173355102539, -3.3445510864257812, -3.573390007019043, -4.131521701812744, -3.66945219039917, -3.230372428894043, -3.0149943828582764, -4.0566229820251465, -2.6192665100097656, -1.8641178607940674, -1.0143619775772095, -1.1009265184402466, -0.9688764810562134, -0.7203890085220337, -0.7502419948577881, -0.7200855612754822, -1.297151803970337, -0.8464727401733398, -0.024727320298552513, 0.13495376706123352, 0.15236981213092804, 0.7419922947883606, -1.3501105308532715, 0.23882220685482025, 1.043470859527588, 2.4856071831891313e-05, -0.1225111111998558, 1.324103832244873, 0.8195681571960449, 0.722922682762146, 0.3988652229309082, 0.634749174118042, 0.47673818469047546, 0.87713623046875, -0.49969956278800964, 0.2450665384531021, 2.0169591903686523, 1.0196186304092407, 1.0207395553588867, 0.8135198950767517, 0.8988380432128906, 1.5681813955307007, 0.94700688123703, 0.48535671830177307, 0.8221314549446106, 1.595513939857483, 1.3983266353607178, 0.8465811014175415, 1.4483211040496826, 0.6733085513114929, 0.19534015655517578, 1.1728657484054565, 0.2495332956314087, 0.5244393348693848, 0.3619097173213959, 1.1751763820648193, 0.7127037048339844, 0.7546966075897217, 0.7515234351158142, 0.07503333687782288, 0.4851859211921692, 0.887856662273407, 0.0, 0.0, 3.2827870845794678, 0.0], [0.0, 0.0, 0.0, 0.0, -8.77134895324707, -6.776024341583252, -5.957365989685059, -6.311906814575195, -4.577499866485596, -3.971895933151245, -5.096151828765869, -4.2674946784973145, -3.417736291885376, -3.862814426422119, -3.759347915649414, -3.8130462169647217, -4.221683025360107, -2.476539373397827, -2.604973793029785, -2.724893569946289, -2.541545867919922, -0.29870131611824036, -1.842162847518921, -0.5619168281555176, -1.7033015489578247, -0.7585042715072632, -0.8922312259674072, -1.3951752185821533, -0.9062849283218384, 0.0808701440691948, 0.2156071662902832, -0.3965003490447998, 0.8279362320899963, 0.12151742726564407, 0.006951274815946817, 0.10742925107479095, 0.3782595992088318, 1.3046369552612305, 0.5422404408454895, 0.9291396141052246, 0.1386246532201767, 0.8543883562088013, 0.42151349782943726, 0.4153496325016022, 0.5856512784957886, 1.1418415307998657, 1.847184658050537, 1.4462629556655884, 2.636763334274292, 1.7504489421844482, 0.6477925181388855, 1.1977487802505493, 0.9452208280563354, 1.0300943851470947, 1.3326016664505005, 1.3732185363769531, 0.7665112018585205, 1.0522735118865967, 0.6454554796218872, 1.6326408386230469, 1.2819339036941528, 0.8057517409324646, 1.5783685445785522, 0.688747227191925, 1.161068081855774, 0.8300617337226868, 0.5534156560897827, 0.7188512086868286, 0.5007380843162537, 0.9178184270858765, 1.123341679573059, 0.8934897780418396, 0.8130667209625244, 0.5558597445487976, 0.0, 0.0, 0.0, 3.3068387508392334, -0.0, -0.0, -0.0, -0.0, -8.77134895324707, -6.776024341583252, -5.957365989685059, -6.311906814575195, -4.577499866485596, -3.971895933151245, -5.096151828765869, -4.2674946784973145, -3.417736291885376, -3.862814426422119, -3.759347915649414, -3.8130462169647217, -4.221683025360107, -2.476539373397827, -2.604973793029785, -2.724893569946289, -2.541545867919922, -0.29870131611824036, -1.842162847518921, -0.5619168281555176, -1.7033015489578247, -0.7585042715072632, -0.8922312259674072, -1.3951752185821533, -0.9062849283218384, 0.0808701440691948, 0.2156071662902832, -0.3965003490447998, 0.8279362320899963, 0.12151742726564407, 0.006951274815946817, 0.10742925107479095, 0.3782595992088318, 1.3046369552612305, 0.5422404408454895, 0.9291396141052246, 0.1386246532201767, 0.8543883562088013, 0.42151349782943726, 0.4153496325016022, 0.5856512784957886, 1.1418415307998657, 1.847184658050537, 1.4462629556655884, 2.636763334274292, 1.7504489421844482, 0.6477925181388855, 1.1977487802505493, 0.9452208280563354, 1.0300943851470947, 1.3326016664505005, 1.3732185363769531, 0.7665112018585205, 1.0522735118865967, 0.6454554796218872, 1.6326408386230469, 1.2819339036941528, 0.8057517409324646, 1.5783685445785522, 0.688747227191925, 1.161068081855774, 0.8300617337226868, 0.5534156560897827, 0.7188512086868286, 0.5007380843162537, 0.9178184270858765, 1.123341679573059, 0.8934897780418396, 0.8130667209625244, 0.5558597445487976, 0.0, 0.0, 0.0, 3.3068387508392334], [0.0, -8.405536651611328, 0.0, 0.0, -7.505568027496338, -6.933213710784912, -5.804582595825195, -5.958757400512695, -4.904759407043457, -4.892093658447266, -5.470479965209961, -4.527352333068848, -4.299366474151611, -4.5438714027404785, -4.660305976867676, -3.6908342838287354, -2.770538568496704, -2.293775796890259, -3.5002901554107666, -2.8994364738464355, -2.102205514907837, -1.2578096389770508, -1.8439232110977173, -1.2375646829605103, -0.8874245882034302, -0.06975062191486359, -0.8506536483764648, 2.178168773651123, -0.5839623212814331, -0.3370569050312042, -0.40267589688301086, 0.6230608224868774, 0.3196905553340912, 0.2211696207523346, 0.27993935346603394, 1.9375544786453247, 0.3159829080104828, 1.0015619993209839, 0.9272314310073853, 1.341454029083252, 2.554879903793335, 0.18991108238697052, 1.6782220602035522, 0.6860646605491638, 1.1597869396209717, 0.7540661096572876, 0.9694889187812805, 1.413574457168579, 0.6861324906349182, 1.047736644744873, 1.177405834197998, 1.0068875551223755, 1.243289828300476, 0.9956300854682922, 1.4622609615325928, 1.0561399459838867, 1.0907518863677979, 1.435914158821106, 2.05352783203125, 0.05783015117049217, 1.3393198251724243, 1.212754249572754, 1.1625723838806152, 1.7293801307678223, 1.2085864543914795, -0.0981573611497879, 0.67566978931427, 1.2761374711990356, 0.35806387662887573, 0.024909429252147675, 0.7808548212051392, 1.148634672164917, 0.32558390498161316, 0.540063738822937, 1.2803027629852295, 0.0, 0.0, -0.48276033997535706, -0.0, -8.405536651611328, -0.0, -0.0, -7.505568027496338, -6.933213710784912, -5.804582595825195, -5.958757400512695, -4.904759407043457, -4.892093658447266, -5.470479965209961, -4.527352333068848, -4.299366474151611, -4.5438714027404785, -4.660305976867676, -3.6908342838287354, -2.770538568496704, -2.293775796890259, -3.5002901554107666, -2.8994364738464355, -2.102205514907837, -1.2578096389770508, -1.8439232110977173, -1.2375646829605103, -0.8874245882034302, -0.06975062191486359, -0.8506536483764648, 2.178168773651123, -0.5839623212814331, -0.3370569050312042, -0.40267589688301086, 0.6230608224868774, 0.3196905553340912, 0.2211696207523346, 0.27993935346603394, 1.9375544786453247, 0.3159829080104828, 1.0015619993209839, 0.9272314310073853, 1.341454029083252, 2.554879903793335, 0.18991108238697052, 1.6782220602035522, 0.6860646605491638, 1.1597869396209717, 0.7540661096572876, 0.9694889187812805, 1.413574457168579, 0.6861324906349182, 1.047736644744873, 1.177405834197998, 1.0068875551223755, 1.243289828300476, 0.9956300854682922, 1.4622609615325928, 1.0561399459838867, 1.0907518863677979, 1.435914158821106, 2.05352783203125, 0.05783015117049217, 1.3393198251724243, 1.212754249572754, 1.1625723838806152, 1.7293801307678223, 1.2085864543914795, -0.0981573611497879, 0.67566978931427, 1.2761374711990356, 0.35806387662887573, 0.024909429252147675, 0.7808548212051392, 1.148634672164917, 0.32558390498161316, 0.540063738822937, 1.2803027629852295, 0.0, 0.0, -0.48276033997535706], [-7.950754165649414, -6.092984199523926, 0.0, 0.0, -6.407270908355713, -6.185057163238525, -6.425861835479736, -5.1254496574401855, -5.569942951202393, -5.890594959259033, -5.255850315093994, -4.362008094787598, -3.4996025562286377, -5.359399318695068, -3.9163897037506104, -3.919924020767212, -3.434262990951538, -3.612337350845337, -1.6859549283981323, -2.2745957374572754, -1.8077088594436646, -1.605616569519043, -1.2727690935134888, -1.332014560699463, -1.153963327407837, -1.0881800651550293, -0.28659510612487793, -1.5056253671646118, -0.49180036783218384, -0.41255682706832886, 0.2388114184141159, 0.0960821658372879, -0.8307923674583435, 0.23572608828544617, 1.4627628326416016, -0.0076551963575184345, -0.34582123160362244, 0.3035036027431488, 0.5483270287513733, 1.6413456201553345, 2.138615608215332, 0.06667766720056534, 1.1868793964385986, 0.011022854596376419, 0.9575907588005066, 0.718660831451416, 1.137162685394287, 4.138093948364258, 0.982648491859436, 1.620898723602295, 1.5613207817077637, 1.201777458190918, 1.6197558641433716, 1.3799139261245728, 1.0641593933105469, 0.8243420124053955, 1.382562518119812, 0.7322455048561096, -0.3320171535015106, 2.0386719703674316, 0.5322230458259583, 0.9080730080604553, 1.6520249843597412, 2.106842517852783, 4.075516223907471, 1.4258737564086914, 0.7731305360794067, 1.3151295185089111, 1.1400177478790283, 1.7014013528823853, 1.8216774463653564, 2.2375500202178955, 1.6575528383255005, 1.4502383470535278, 2.15989351272583, 0.0, 0.0, 1.8014025688171387, -7.950754165649414, -6.092984199523926, -0.0, -0.0, -6.407270908355713, -6.185057163238525, -6.425861835479736, -5.1254496574401855, -5.569942951202393, -5.890594959259033, -5.255850315093994, -4.362008094787598, -3.4996025562286377, -5.359399318695068, -3.9163897037506104, -3.919924020767212, -3.434262990951538, -3.612337350845337, -1.6859549283981323, -2.2745957374572754, -1.8077088594436646, -1.605616569519043, -1.2727690935134888, -1.332014560699463, -1.153963327407837, -1.0881800651550293, -0.28659510612487793, -1.5056253671646118, -0.49180036783218384, -0.41255682706832886, 0.2388114184141159, 0.0960821658372879, -0.8307923674583435, 0.23572608828544617, 1.4627628326416016, -0.0076551963575184345, -0.34582123160362244, 0.3035036027431488, 0.5483270287513733, 1.6413456201553345, 2.138615608215332, 0.06667766720056534, 1.1868793964385986, 0.011022854596376419, 0.9575907588005066, 0.718660831451416, 1.137162685394287, 4.138093948364258, 0.982648491859436, 1.620898723602295, 1.5613207817077637, 1.201777458190918, 1.6197558641433716, 1.3799139261245728, 1.0641593933105469, 0.8243420124053955, 1.382562518119812, 0.7322455048561096, -0.3320171535015106, 2.0386719703674316, 0.5322230458259583, 0.9080730080604553, 1.6520249843597412, 2.106842517852783, 4.075516223907471, 1.4258737564086914, 0.7731305360794067, 1.3151295185089111, 1.1400177478790283, 1.7014013528823853, 1.8216774463653564, 2.2375500202178955, 1.6575528383255005, 1.4502383470535278, 2.15989351272583, 0.0, 0.0, 1.8014025688171387], [0.0, -7.572059154510498, 0.0, -6.5260796546936035, -7.000036239624023, -6.43168306350708, -6.142668724060059, -6.146917343139648, -5.251428604125977, -5.399746417999268, -5.098636150360107, -5.183161735534668, -4.040326118469238, -4.045670509338379, -2.315997838973999, -3.7417221069335938, -3.7098724842071533, -3.029627561569214, -2.3135852813720703, -2.0653133392333984, -2.202543258666992, -1.8700577020645142, -1.4884352684020996, -1.081180453300476, -0.7841780185699463, -0.43186473846435547, -1.401160717010498, -2.242154121398926, -0.09476155042648315, 0.6822750568389893, -0.04258015751838684, -0.7561695575714111, 0.6083548069000244, 0.2511548101902008, 0.7731804251670837, 1.9041310548782349, 2.680368185043335, 0.8360079526901245, 0.3856997489929199, -0.12365919351577759, 1.2793521881103516, 1.4042646884918213, 1.8019345998764038, 1.9902079105377197, 2.1640639305114746, -0.40011724829673767, 1.7796038389205933, 1.4657748937606812, 1.2582299709320068, 1.3579517602920532, 1.2086410522460938, 1.8719048500061035, 1.4116989374160767, 1.6696293354034424, 1.6265491247177124, 1.5769044160842896, 1.608657717704773, 1.691137671470642, 1.1368707418441772, 1.7804819345474243, 0.6799726486206055, 0.9514027237892151, 0.8477879762649536, 1.7749377489089966, 3.085846424102783, 0.52462238073349, 0.8941912651062012, 1.4286974668502808, 1.1217279434204102, 1.339939832687378, 0.9399141669273376, 1.8698782920837402, 2.7339770793914795, 1.8268482685089111, 1.906110405921936, 0.0, 0.0, 1.9523154497146606, -0.0, -7.572059154510498, -0.0, -6.5260796546936035, -7.000036239624023, -6.43168306350708, -6.142668724060059, -6.146917343139648, -5.251428604125977, -5.399746417999268, -5.098636150360107, -5.183161735534668, -4.040326118469238, -4.045670509338379, -2.315997838973999, -3.7417221069335938, -3.7098724842071533, -3.029627561569214, -2.3135852813720703, -2.0653133392333984, -2.202543258666992, -1.8700577020645142, -1.4884352684020996, -1.081180453300476, -0.7841780185699463, -0.43186473846435547, -1.401160717010498, -2.242154121398926, -0.09476155042648315, 0.6822750568389893, -0.04258015751838684, -0.7561695575714111, 0.6083548069000244, 0.2511548101902008, 0.7731804251670837, 1.9041310548782349, 2.680368185043335, 0.8360079526901245, 0.3856997489929199, -0.12365919351577759, 1.2793521881103516, 1.4042646884918213, 1.8019345998764038, 1.9902079105377197, 2.1640639305114746, -0.40011724829673767, 1.7796038389205933, 1.4657748937606812, 1.2582299709320068, 1.3579517602920532, 1.2086410522460938, 1.8719048500061035, 1.4116989374160767, 1.6696293354034424, 1.6265491247177124, 1.5769044160842896, 1.608657717704773, 1.691137671470642, 1.1368707418441772, 1.7804819345474243, 0.6799726486206055, 0.9514027237892151, 0.8477879762649536, 1.7749377489089966, 3.085846424102783, 0.52462238073349, 0.8941912651062012, 1.4286974668502808, 1.1217279434204102, 1.339939832687378, 0.9399141669273376, 1.8698782920837402, 2.7339770793914795, 1.8268482685089111, 1.906110405921936, 0.0, 0.0, 1.9523154497146606], [-7.560130596160889, 0.0, 0.0, -6.590407848358154, -7.207407474517822, -6.160279750823975, -5.64721155166626, -5.724721908569336, -4.88375997543335, -5.271067142486572, -5.143551826477051, -4.924726486206055, -2.3032612800598145, -3.648202896118164, -4.099889278411865, -3.8906021118164062, -4.377438545227051, -1.4263118505477905, -2.7291910648345947, -1.8121497631072998, -2.437160015106201, -1.6626983880996704, -0.9697406888008118, -1.3017805814743042, -0.9959977865219116, -1.321277141571045, -1.162845253944397, -0.055456388741731644, -0.654340922832489, -0.5436124205589294, -0.8050698041915894, 0.031830839812755585, -0.036684323102235794, 0.7559910416603088, 0.7464797496795654, 0.6710189580917358, -1.5491034984588623, 0.0, 1.5577003955841064, 1.010857105255127, 2.2447683811187744, 1.8284387588500977, 0.5360904335975647, 1.7659672498703003, 0.8932531476020813, 1.5999352931976318, 1.5807689428329468, 1.1525678634643555, 1.3720366954803467, 1.7534068822860718, 1.183037519454956, 1.3626888990402222, 1.3992305994033813, 1.2165110111236572, 1.7077665328979492, 1.3038661479949951, 2.0925633907318115, 0.1894109845161438, 1.4812021255493164, 1.3277685642242432, 1.60826575756073, 1.4667627811431885, 1.3670562505722046, 1.1914178133010864, 0.25311097502708435, -0.14084197580814362, 1.3896021842956543, 1.261813998222351, 1.3154557943344116, 1.4539086818695068, 1.097835898399353, 1.117296576499939, 1.186126947402954, 2.1195154190063477, 1.965063452720642, 0.0, 0.0, 2.77270245552063, -7.560130596160889, -0.0, -0.0, -6.590407848358154, -7.207407474517822, -6.160279750823975, -5.64721155166626, -5.724721908569336, -4.88375997543335, -5.271067142486572, -5.143551826477051, -4.924726486206055, -2.3032612800598145, -3.648202896118164, -4.099889278411865, -3.8906021118164062, -4.377438545227051, -1.4263118505477905, -2.7291910648345947, -1.8121497631072998, -2.437160015106201, -1.6626983880996704, -0.9697406888008118, -1.3017805814743042, -0.9959977865219116, -1.321277141571045, -1.162845253944397, -0.055456388741731644, -0.654340922832489, -0.5436124205589294, -0.8050698041915894, 0.031830839812755585, -0.036684323102235794, 0.7559910416603088, 0.7464797496795654, 0.6710189580917358, -1.5491034984588623, 0.0, 1.5577003955841064, 1.010857105255127, 2.2447683811187744, 1.8284387588500977, 0.5360904335975647, 1.7659672498703003, 0.8932531476020813, 1.5999352931976318, 1.5807689428329468, 1.1525678634643555, 1.3720366954803467, 1.7534068822860718, 1.183037519454956, 1.3626888990402222, 1.3992305994033813, 1.2165110111236572, 1.7077665328979492, 1.3038661479949951, 2.0925633907318115, 0.1894109845161438, 1.4812021255493164, 1.3277685642242432, 1.60826575756073, 1.4667627811431885, 1.3670562505722046, 1.1914178133010864, 0.25311097502708435, -0.14084197580814362, 1.3896021842956543, 1.261813998222351, 1.3154557943344116, 1.4539086818695068, 1.097835898399353, 1.117296576499939, 1.186126947402954, 2.1195154190063477, 1.965063452720642, 0.0, 0.0, 2.77270245552063], [-7.027310371398926, 0.0, -6.789928436279297, -6.632329940795898, -5.863948345184326, -5.823143005371094, -5.946840763092041, -5.755674362182617, -5.4795145988464355, -5.276947975158691, -6.004317760467529, -4.783059597015381, -4.08864164352417, -4.165007591247559, -3.3192639350891113, -3.413517951965332, -3.3134450912475586, -0.06966758519411087, -3.2910959720611572, -4.015172958374023, -1.8708738088607788, -2.0529637336730957, -1.6010022163391113, -1.8168256282806396, -0.833655059337616, -0.9204769730567932, -0.9730722308158875, 1.896315336227417, 1.0516043901443481, -0.2846749722957611, 1.5905874967575073, 1.6180267333984375, -2.8468470573425293, -1.6294907331466675, 1.5416555404663086, 1.3446309566497803, 2.405785083770752, 2.469346761703491, 5.011450290679932, 4.33786678314209, 2.573939085006714, 2.2279937267303467, 1.4462271928787231, 1.7179239988327026, 1.181156039237976, 1.5309879779815674, 0.8172990679740906, 1.2093234062194824, 1.3154162168502808, 1.5985578298568726, 1.4552932977676392, 1.4264432191848755, 2.065965175628662, 1.6206653118133545, 1.10645592212677, 1.5375653505325317, 1.4853585958480835, 1.0741307735443115, 0.5339181423187256, 0.35230183601379395, 3.111372709274292, 0.9223729968070984, 0.8376396298408508, 3.1264734268188477, 0.7096028923988342, 0.26356664299964905, 1.1691901683807373, 0.7594919800758362, 0.185003399848938, 3.10684871673584, 1.759495735168457, 1.697227120399475, 0.23287853598594666, 1.3275450468063354, 2.4959096908569336, 0.32895371317863464, 0.0, 3.62237286567688, -7.027310371398926, -0.0, -6.789928436279297, -6.632329940795898, -5.863948345184326, -5.823143005371094, -5.946840763092041, -5.755674362182617, -5.4795145988464355, -5.276947975158691, -6.004317760467529, -4.783059597015381, -4.08864164352417, -4.165007591247559, -3.3192639350891113, -3.413517951965332, -3.3134450912475586, -0.06966758519411087, -3.2910959720611572, -4.015172958374023, -1.8708738088607788, -2.0529637336730957, -1.6010022163391113, -1.8168256282806396, -0.833655059337616, -0.9204769730567932, -0.9730722308158875, 1.896315336227417, 1.0516043901443481, -0.2846749722957611, 1.5905874967575073, 1.6180267333984375, -2.8468470573425293, -1.6294907331466675, 1.5416555404663086, 1.3446309566497803, 2.405785083770752, 2.469346761703491, 5.011450290679932, 4.33786678314209, 2.573939085006714, 2.2279937267303467, 1.4462271928787231, 1.7179239988327026, 1.181156039237976, 1.5309879779815674, 0.8172990679740906, 1.2093234062194824, 1.3154162168502808, 1.5985578298568726, 1.4552932977676392, 1.4264432191848755, 2.065965175628662, 1.6206653118133545, 1.10645592212677, 1.5375653505325317, 1.4853585958480835, 1.0741307735443115, 0.5339181423187256, 0.35230183601379395, 3.111372709274292, 0.9223729968070984, 0.8376396298408508, 3.1264734268188477, 0.7096028923988342, 0.26356664299964905, 1.1691901683807373, 0.7594919800758362, 0.185003399848938, 3.10684871673584, 1.759495735168457, 1.697227120399475, 0.23287853598594666, 1.3275450468063354, 2.4959096908569336, 0.32895371317863464, 0.0, 3.62237286567688], [-5.700186252593994, 0.0, -5.616659164428711, -6.869457721710205, -5.3705573081970215, -6.66259241104126, -5.383339881896973, -6.540637016296387, -6.176364898681641, -5.541138648986816, -5.3591389656066895, -5.050304412841797, -5.3642168045043945, -4.878273010253906, -4.341250896453857, -4.080178737640381, -2.5313873291015625, -3.8082404136657715, -2.395871639251709, -2.7730796337127686, -2.061182975769043, -1.6897858381271362, -1.4581053256988525, -1.55508553981781, -1.3141247034072876, -1.1641947031021118, -0.6893930435180664, -0.8245777487754822, -0.2469600886106491, -3.1224071979522705, 0.8633246421813965, -0.31553319096565247, 1.0935134887695312, 1.350782871246338, 1.8466318845748901, 1.4042108058929443, 1.9118033647537231, 3.149182081222534, 3.5975520610809326, 4.288842678070068, -0.050967372953891754, 2.7597904205322266, 1.611817479133606, 2.1712284088134766, 0.9842936992645264, -0.4652482569217682, 1.8241455554962158, 1.1795680522918701, 1.770085096359253, 2.078512668609619, 1.098773717880249, 2.522688865661621, 1.5359915494918823, 1.4949558973312378, 1.3626514673233032, 1.1747092008590698, 1.572317123413086, 1.3404698371887207, 1.1360200643539429, -0.13770554959774017, 1.3422770500183105, 0.9645175337791443, 0.5069299340248108, 0.7876562476158142, 1.0552960634231567, 2.9347333908081055, 1.0433955192565918, 0.3150460422039032, 0.3110737204551697, 2.2270193099975586, 0.7287232279777527, 0.5672888159751892, 1.6783232688903809, 1.0103455781936646, 1.447503924369812, 2.3933846950531006, 0.0, 0.0, -5.700186252593994, -0.0, -5.616659164428711, -6.869457721710205, -5.3705573081970215, -6.66259241104126, -5.383339881896973, -6.540637016296387, -6.176364898681641, -5.541138648986816, -5.3591389656066895, -5.050304412841797, -5.3642168045043945, -4.878273010253906, -4.341250896453857, -4.080178737640381, -2.5313873291015625, -3.8082404136657715, -2.395871639251709, -2.7730796337127686, -2.061182975769043, -1.6897858381271362, -1.4581053256988525, -1.55508553981781, -1.3141247034072876, -1.1641947031021118, -0.6893930435180664, -0.8245777487754822, -0.2469600886106491, -3.1224071979522705, 0.8633246421813965, -0.31553319096565247, 1.0935134887695312, 1.350782871246338, 1.8466318845748901, 1.4042108058929443, 1.9118033647537231, 3.149182081222534, 3.5975520610809326, 4.288842678070068, -0.050967372953891754, 2.7597904205322266, 1.611817479133606, 2.1712284088134766, 0.9842936992645264, -0.4652482569217682, 1.8241455554962158, 1.1795680522918701, 1.770085096359253, 2.078512668609619, 1.098773717880249, 2.522688865661621, 1.5359915494918823, 1.4949558973312378, 1.3626514673233032, 1.1747092008590698, 1.572317123413086, 1.3404698371887207, 1.1360200643539429, -0.13770554959774017, 1.3422770500183105, 0.9645175337791443, 0.5069299340248108, 0.7876562476158142, 1.0552960634231567, 2.9347333908081055, 1.0433955192565918, 0.3150460422039032, 0.3110737204551697, 2.2270193099975586, 0.7287232279777527, 0.5672888159751892, 1.6783232688903809, 1.0103455781936646, 1.447503924369812, 2.3933846950531006, 0.0, 0.0], [0.0, 0.0, -7.097921848297119, -6.35927152633667, -6.857222557067871, -6.831215858459473, -6.520391464233398, -5.546482086181641, -6.159627437591553, -4.755775451660156, -4.954891681671143, -4.612060546875, -4.495759010314941, -4.022392749786377, -4.415165901184082, -3.2327206134796143, -3.874931812286377, -2.946498155593872, -3.1395950317382812, -2.463871479034424, -1.6391957998275757, -1.6016842126846313, -2.340060234069824, -0.7454242706298828, -0.6543759107589722, -0.6690212488174438, -0.8556657433509827, -0.5534051656723022, 0.5154074430465698, -0.5906913876533508, -0.05888013541698456, -0.35467344522476196, -0.3620821237564087, 0.21011938154697418, 0.1052892878651619, 0.575464129447937, 1.5471866130828857, 2.7550883293151855, 4.170526027679443, 3.0484986305236816, 1.8849819898605347, 0.09464552998542786, 1.1950135231018066, 0.9355523586273193, 1.922042965888977, 0.9694147706031799, 1.6892257928848267, 1.7395942211151123, 1.728847861289978, 1.8786698579788208, 1.6197354793548584, 1.3369534015655518, 1.6729553937911987, 1.725422739982605, 2.324794054031372, 1.305237054824829, 0.8434069156646729, 0.17803990840911865, 1.498103141784668, 1.127977728843689, 1.047741413116455, 1.0057156085968018, 0.9623567461967468, 0.22552776336669922, 1.3707919120788574, 0.9903209805488586, 2.109496593475342, 2.647376298904419, 0.6367688775062561, 1.8787940740585327, 0.948278546333313, 1.5483309030532837, 1.0651462078094482, 1.0919264554977417, 1.738873839378357, 2.091282606124878, 0.0, 0.0, -0.0, -0.0, -7.097921848297119, -6.35927152633667, -6.857222557067871, -6.831215858459473, -6.520391464233398, -5.546482086181641, -6.159627437591553, -4.755775451660156, -4.954891681671143, -4.612060546875, -4.495759010314941, -4.022392749786377, -4.415165901184082, -3.2327206134796143, -3.874931812286377, -2.946498155593872, -3.1395950317382812, -2.463871479034424, -1.6391957998275757, -1.6016842126846313, -2.340060234069824, -0.7454242706298828, -0.6543759107589722, -0.6690212488174438, -0.8556657433509827, -0.5534051656723022, 0.5154074430465698, -0.5906913876533508, -0.05888013541698456, -0.35467344522476196, -0.3620821237564087, 0.21011938154697418, 0.1052892878651619, 0.575464129447937, 1.5471866130828857, 2.7550883293151855, 4.170526027679443, 3.0484986305236816, 1.8849819898605347, 0.09464552998542786, 1.1950135231018066, 0.9355523586273193, 1.922042965888977, 0.9694147706031799, 1.6892257928848267, 1.7395942211151123, 1.728847861289978, 1.8786698579788208, 1.6197354793548584, 1.3369534015655518, 1.6729553937911987, 1.725422739982605, 2.324794054031372, 1.305237054824829, 0.8434069156646729, 0.17803990840911865, 1.498103141784668, 1.127977728843689, 1.047741413116455, 1.0057156085968018, 0.9623567461967468, 0.22552776336669922, 1.3707919120788574, 0.9903209805488586, 2.109496593475342, 2.647376298904419, 0.6367688775062561, 1.8787940740585327, 0.948278546333313, 1.5483309030532837, 1.0651462078094482, 1.0919264554977417, 1.738873839378357, 2.091282606124878, 0.0, 0.0], [0.0, 0.0, -6.877466201782227, -7.472219944000244, -6.354844093322754, -6.694805145263672, -5.6357293128967285, -6.355104923248291, -6.0176520347595215, -5.985734462738037, -5.529625415802002, -5.243221282958984, -4.933083534240723, -3.5269110202789307, -3.729477882385254, -4.394883632659912, -4.1722025871276855, -3.956728219985962, -2.361514091491699, -5.2971954345703125, -2.2590503692626953, -1.4326279163360596, -1.6800148487091064, -0.6482333540916443, -0.65804123878479, -1.014326810836792, -0.8156577944755554, -0.6024175882339478, 0.7519773840904236, -0.18255260586738586, 0.33116281032562256, 0.5578114986419678, -0.09471479803323746, 0.9476360082626343, 1.375748634338379, 1.146513819694519, 1.3678815364837646, 2.457037925720215, 2.279346227645874, 1.7343790531158447, 1.8986486196517944, 1.2359024286270142, 0.5196453332901001, 0.2873802185058594, 2.2977914810180664, 1.4164880514144897, 1.499502182006836, 1.4665738344192505, 1.307181715965271, 0.9478302001953125, 1.868492841720581, 1.6760250329971313, 1.8056892156600952, 0.853476881980896, 0.8186087608337402, 1.2770848274230957, 0.9434391260147095, 1.042083978652954, -0.21483276784420013, 0.549519419670105, 0.4678579866886139, 1.028875470161438, 1.0155603885650635, 0.36506620049476624, 1.743729829788208, 1.8921279907226562, -0.1686251312494278, 1.2591822147369385, 0.97322678565979, 0.7274560928344727, 0.781554639339447, 1.0153868198394775, 1.2375974655151367, 1.7621558904647827, 1.767926812171936, 3.468553304672241, 0.0, 0.0, -0.0, -0.0, -6.877466201782227, -7.472219944000244, -6.354844093322754, -6.694805145263672, -5.6357293128967285, -6.355104923248291, -6.0176520347595215, -5.985734462738037, -5.529625415802002, -5.243221282958984, -4.933083534240723, -3.5269110202789307, -3.729477882385254, -4.394883632659912, -4.1722025871276855, -3.956728219985962, -2.361514091491699, -5.2971954345703125, -2.2590503692626953, -1.4326279163360596, -1.6800148487091064, -0.6482333540916443, -0.65804123878479, -1.014326810836792, -0.8156577944755554, -0.6024175882339478, 0.7519773840904236, -0.18255260586738586, 0.33116281032562256, 0.5578114986419678, -0.09471479803323746, 0.9476360082626343, 1.375748634338379, 1.146513819694519, 1.3678815364837646, 2.457037925720215, 2.279346227645874, 1.7343790531158447, 1.8986486196517944, 1.2359024286270142, 0.5196453332901001, 0.2873802185058594, 2.2977914810180664, 1.4164880514144897, 1.499502182006836, 1.4665738344192505, 1.307181715965271, 0.9478302001953125, 1.868492841720581, 1.6760250329971313, 1.8056892156600952, 0.853476881980896, 0.8186087608337402, 1.2770848274230957, 0.9434391260147095, 1.042083978652954, -0.21483276784420013, 0.549519419670105, 0.4678579866886139, 1.028875470161438, 1.0155603885650635, 0.36506620049476624, 1.743729829788208, 1.8921279907226562, -0.1686251312494278, 1.2591822147369385, 0.97322678565979, 0.7274560928344727, 0.781554639339447, 1.0153868198394775, 1.2375974655151367, 1.7621558904647827, 1.767926812171936, 3.468553304672241, 0.0, 0.0], [0.0, 0.0, -7.508618354797363, -7.133927822113037, -6.61947774887085, -6.464460849761963, -6.442854404449463, -6.5002593994140625, -6.134713172912598, -6.415943622589111, -5.871654510498047, -5.623396396636963, -5.187783718109131, -4.770418643951416, -4.094407081604004, -4.413200855255127, -3.351064443588257, -4.492151260375977, -3.7139971256256104, -2.805628538131714, -0.5853703022003174, -1.9616718292236328, -1.7987208366394043, -1.0496020317077637, -0.8171921372413635, -1.156427264213562, -1.0171587467193604, -0.41683855652809143, -1.0036519765853882, -1.4064619541168213, 0.4936372935771942, 0.1999097466468811, 0.2531689405441284, 0.6407289505004883, 0.42071130871772766, 1.5251888036727905, 1.569736123085022, 2.4916775226593018, 2.704289436340332, 2.8459689617156982, 1.6143603324890137, 1.2834374904632568, 1.5160125494003296, 1.0525810718536377, 1.056839108467102, 0.9403027892112732, 1.7093302011489868, 1.478340983390808, 1.17293381690979, 1.8349734544754028, 1.9154878854751587, 1.7484607696533203, 1.9151149988174438, 1.9680521488189697, 1.4153836965560913, 2.3905439376831055, 0.5227129459381104, 0.6385484933853149, 2.108684539794922, 0.30021658539772034, -0.0038169410545378923, 0.5159876346588135, -0.09989402443170547, 0.36253124475479126, 1.0364028215408325, 0.8815573453903198, 0.17491526901721954, 1.7614561319351196, 1.844630241394043, 0.9930534362792969, 1.0912303924560547, 0.2588390111923218, 1.1700769662857056, 1.442596197128296, 2.288224697113037, 1.310052514076233, 0.0, 0.0, -0.0, -0.0, -7.508618354797363, -7.133927822113037, -6.61947774887085, -6.464460849761963, -6.442854404449463, -6.5002593994140625, -6.134713172912598, -6.415943622589111, -5.871654510498047, -5.623396396636963, -5.187783718109131, -4.770418643951416, -4.094407081604004, -4.413200855255127, -3.351064443588257, -4.492151260375977, -3.7139971256256104, -2.805628538131714, -0.5853703022003174, -1.9616718292236328, -1.7987208366394043, -1.0496020317077637, -0.8171921372413635, -1.156427264213562, -1.0171587467193604, -0.41683855652809143, -1.0036519765853882, -1.4064619541168213, 0.4936372935771942, 0.1999097466468811, 0.2531689405441284, 0.6407289505004883, 0.42071130871772766, 1.5251888036727905, 1.569736123085022, 2.4916775226593018, 2.704289436340332, 2.8459689617156982, 1.6143603324890137, 1.2834374904632568, 1.5160125494003296, 1.0525810718536377, 1.056839108467102, 0.9403027892112732, 1.7093302011489868, 1.478340983390808, 1.17293381690979, 1.8349734544754028, 1.9154878854751587, 1.7484607696533203, 1.9151149988174438, 1.9680521488189697, 1.4153836965560913, 2.3905439376831055, 0.5227129459381104, 0.6385484933853149, 2.108684539794922, 0.30021658539772034, -0.0038169410545378923, 0.5159876346588135, -0.09989402443170547, 0.36253124475479126, 1.0364028215408325, 0.8815573453903198, 0.17491526901721954, 1.7614561319351196, 1.844630241394043, 0.9930534362792969, 1.0912303924560547, 0.2588390111923218, 1.1700769662857056, 1.442596197128296, 2.288224697113037, 1.310052514076233, 0.0, 0.0], [0.0, -5.503340721130371, -8.955659866333008, -7.80196475982666, -6.982827186584473, -7.517284870147705, -7.607773303985596, -7.179851531982422, -6.320066452026367, -7.08755350112915, -4.838441848754883, -5.156537055969238, -1.808585524559021, -4.523498058319092, -4.243091106414795, -4.1333394050598145, -3.4106392860412598, -3.115877389907837, 0.053010787814855576, -1.0386683940887451, -2.5222489833831787, -1.7206485271453857, -2.1121487617492676, -0.8333373665809631, -1.663818597793579, -0.9455168843269348, -0.6968451738357544, -1.0140035152435303, 0.5995749831199646, -1.2445369958877563, -0.6101623773574829, 0.022057870402932167, 0.34674394130706787, -0.09545416384935379, 0.22606432437896729, 0.5517488121986389, 1.086190938949585, 2.0876712799072266, 3.092684268951416, 3.1612443923950195, 2.4218666553497314, 1.973312258720398, 1.4079320430755615, 1.6689575910568237, 1.58413827419281, 3.2484562397003174, 0.4746183753013611, 0.16830269992351532, 0.7107792496681213, 0.993305504322052, 1.907246470451355, 1.7997565269470215, 1.2810956239700317, 1.528203010559082, 1.7202414274215698, 2.504021644592285, 0.5342692732810974, 1.7139909267425537, 1.3971304893493652, -0.47731417417526245, 1.1596760749816895, 0.03753543272614479, 0.6058022379875183, 0.8514947891235352, 0.5175934433937073, 0.5382569432258606, 1.321150302886963, 1.1304556131362915, 1.6221309900283813, 0.7620058059692383, 1.6779320240020752, -0.19102002680301666, 1.245156168937683, 0.7896339893341064, 1.4704915285110474, 2.456493616104126, 0.0, 0.0, -0.0, -5.503340721130371, -8.955659866333008, -7.80196475982666, -6.982827186584473, -7.517284870147705, -7.607773303985596, -7.179851531982422, -6.320066452026367, -7.08755350112915, -4.838441848754883, -5.156537055969238, -1.808585524559021, -4.523498058319092, -4.243091106414795, -4.1333394050598145, -3.4106392860412598, -3.115877389907837, 0.053010787814855576, -1.0386683940887451, -2.5222489833831787, -1.7206485271453857, -2.1121487617492676, -0.8333373665809631, -1.663818597793579, -0.9455168843269348, -0.6968451738357544, -1.0140035152435303, 0.5995749831199646, -1.2445369958877563, -0.6101623773574829, 0.022057870402932167, 0.34674394130706787, -0.09545416384935379, 0.22606432437896729, 0.5517488121986389, 1.086190938949585, 2.0876712799072266, 3.092684268951416, 3.1612443923950195, 2.4218666553497314, 1.973312258720398, 1.4079320430755615, 1.6689575910568237, 1.58413827419281, 3.2484562397003174, 0.4746183753013611, 0.16830269992351532, 0.7107792496681213, 0.993305504322052, 1.907246470451355, 1.7997565269470215, 1.2810956239700317, 1.528203010559082, 1.7202414274215698, 2.504021644592285, 0.5342692732810974, 1.7139909267425537, 1.3971304893493652, -0.47731417417526245, 1.1596760749816895, 0.03753543272614479, 0.6058022379875183, 0.8514947891235352, 0.5175934433937073, 0.5382569432258606, 1.321150302886963, 1.1304556131362915, 1.6221309900283813, 0.7620058059692383, 1.6779320240020752, -0.19102002680301666, 1.245156168937683, 0.7896339893341064, 1.4704915285110474, 2.456493616104126, 0.0, 0.0], [0.0, -8.141569137573242, -7.554371356964111, -7.566970348358154, -7.243105411529541, -6.909729957580566, -7.159043312072754, -7.172635078430176, -6.956089973449707, -6.6619439125061035, -4.26779317855835, -5.063641548156738, -6.437005519866943, -5.219005107879639, -4.051558017730713, -4.90355920791626, -3.9666740894317627, -4.315178871154785, -1.740238904953003, -3.064399480819702, -3.0855753421783447, -1.9310294389724731, -2.5706863403320312, -2.150141716003418, -1.863467812538147, -0.9651716351509094, -0.6938122510910034, -0.8858840465545654, -0.5339193344116211, -0.433711439371109, -0.7885461449623108, -0.30242934823036194, -0.4448918402194977, 0.2187395691871643, 0.26550787687301636, 0.5181809663772583, 0.09937385469675064, -1.7347456216812134, 1.1501644849777222, 2.306600332260132, 2.256998300552368, 1.2163969278335571, 1.5959073305130005, 0.9171414971351624, 1.7239820957183838, 0.9994292855262756, 0.35061120986938477, 0.9231723546981812, 1.1478629112243652, 1.5351377725601196, -0.002563808113336563, 1.8323853015899658, 0.7379984259605408, 1.0713274478912354, 1.476050615310669, 0.3821071684360504, 1.387665033340454, 1.0215752124786377, 0.9549868106842041, -0.8213310837745667, 0.13234053552150726, 0.3713380992412567, 0.059302229434251785, 0.0916820839047432, 0.0004438633914105594, 0.7297045588493347, 0.008673762902617455, -0.1092691719532013, 0.8787205219268799, 1.5507121086120605, 1.6302196979522705, 0.802557110786438, 1.9767036437988281, 2.234734058380127, 1.5886561870574951, 2.273334503173828, 3.511166572570801, 0.0, -0.0, -8.141569137573242, -7.554371356964111, -7.566970348358154, -7.243105411529541, -6.909729957580566, -7.159043312072754, -7.172635078430176, -6.956089973449707, -6.6619439125061035, -4.26779317855835, -5.063641548156738, -6.437005519866943, -5.219005107879639, -4.051558017730713, -4.90355920791626, -3.9666740894317627, -4.315178871154785, -1.740238904953003, -3.064399480819702, -3.0855753421783447, -1.9310294389724731, -2.5706863403320312, -2.150141716003418, -1.863467812538147, -0.9651716351509094, -0.6938122510910034, -0.8858840465545654, -0.5339193344116211, -0.433711439371109, -0.7885461449623108, -0.30242934823036194, -0.4448918402194977, 0.2187395691871643, 0.26550787687301636, 0.5181809663772583, 0.09937385469675064, -1.7347456216812134, 1.1501644849777222, 2.306600332260132, 2.256998300552368, 1.2163969278335571, 1.5959073305130005, 0.9171414971351624, 1.7239820957183838, 0.9994292855262756, 0.35061120986938477, 0.9231723546981812, 1.1478629112243652, 1.5351377725601196, -0.002563808113336563, 1.8323853015899658, 0.7379984259605408, 1.0713274478912354, 1.476050615310669, 0.3821071684360504, 1.387665033340454, 1.0215752124786377, 0.9549868106842041, -0.8213310837745667, 0.13234053552150726, 0.3713380992412567, 0.059302229434251785, 0.0916820839047432, 0.0004438633914105594, 0.7297045588493347, 0.008673762902617455, -0.1092691719532013, 0.8787205219268799, 1.5507121086120605, 1.6302196979522705, 0.802557110786438, 1.9767036437988281, 2.234734058380127, 1.5886561870574951, 2.273334503173828, 3.511166572570801, 0.0], [0.0, -8.560935974121094, -8.885004043579102, -7.667325973510742, -6.970229625701904, -7.761673927307129, -6.46591854095459, -7.215414524078369, -6.7433319091796875, -7.936849594116211, -6.613678455352783, -6.892153739929199, -4.951967239379883, -4.7368011474609375, -5.130246162414551, -5.10796594619751, -3.994567632675171, -4.288189888000488, -3.6775364875793457, -2.1609978675842285, -3.401573896408081, -2.7009730339050293, -2.2014098167419434, -2.805399179458618, -1.062403917312622, -1.5603424310684204, -1.3334943056106567, -0.9769821166992188, -0.8246967792510986, -0.4596315622329712, -0.5394924283027649, -0.9724491834640503, -1.139253854751587, -0.07363475114107132, 0.6308972835540771, 0.14403124153614044, 0.41196122765541077, 0.4052528142929077, -0.236312597990036, 0.8387818932533264, 2.297159433364868, 1.2682087421417236, 0.6383455395698547, -0.031702931970357895, 1.0946427583694458, -0.001329311984591186, 1.0911842584609985, 0.48592409491539, 1.029106855392456, 0.8762373328208923, 0.5491250157356262, 0.9748406410217285, -0.04914717748761177, 1.2711231708526611, -0.48066404461860657, 0.4336341917514801, 1.0231417417526245, 1.2036964893341064, 0.7971151471138, 0.2852574288845062, 0.8204920291900635, 0.21830672025680542, 0.903083324432373, -0.3366296589374542, 0.40037718415260315, 0.20474876463413239, -0.1553763747215271, 0.061040136963129044, 0.6902686953544617, -0.4919692873954773, 0.8671943545341492, 0.37736350297927856, 0.7410193681716919, -1.1786471605300903, 2.1472694873809814, 1.7349598407745361, 2.7426576614379883, 0.0, -0.0, -8.560935974121094, -8.885004043579102, -7.667325973510742, -6.970229625701904, -7.761673927307129, -6.46591854095459, -7.215414524078369, -6.7433319091796875, -7.936849594116211, -6.613678455352783, -6.892153739929199, -4.951967239379883, -4.7368011474609375, -5.130246162414551, -5.10796594619751, -3.994567632675171, -4.288189888000488, -3.6775364875793457, -2.1609978675842285, -3.401573896408081, -2.7009730339050293, -2.2014098167419434, -2.805399179458618, -1.062403917312622, -1.5603424310684204, -1.3334943056106567, -0.9769821166992188, -0.8246967792510986, -0.4596315622329712, -0.5394924283027649, -0.9724491834640503, -1.139253854751587, -0.07363475114107132, 0.6308972835540771, 0.14403124153614044, 0.41196122765541077, 0.4052528142929077, -0.236312597990036, 0.8387818932533264, 2.297159433364868, 1.2682087421417236, 0.6383455395698547, -0.031702931970357895, 1.0946427583694458, -0.001329311984591186, 1.0911842584609985, 0.48592409491539, 1.029106855392456, 0.8762373328208923, 0.5491250157356262, 0.9748406410217285, -0.04914717748761177, 1.2711231708526611, -0.48066404461860657, 0.4336341917514801, 1.0231417417526245, 1.2036964893341064, 0.7971151471138, 0.2852574288845062, 0.8204920291900635, 0.21830672025680542, 0.903083324432373, -0.3366296589374542, 0.40037718415260315, 0.20474876463413239, -0.1553763747215271, 0.061040136963129044, 0.6902686953544617, -0.4919692873954773, 0.8671943545341492, 0.37736350297927856, 0.7410193681716919, -1.1786471605300903, 2.1472694873809814, 1.7349598407745361, 2.7426576614379883, 0.0], [0.0, -8.772053718566895, -8.838729858398438, -8.275972366333008, -8.711285591125488, -8.411787986755371, -7.530776023864746, -7.260497093200684, -6.989810943603516, -5.897951126098633, -6.004156112670898, -6.374632835388184, -6.749459266662598, -4.601099014282227, -3.4504342079162598, -4.409939289093018, -4.6109724044799805, -3.9842288494110107, -3.0001063346862793, -1.7334542274475098, -1.9401549100875854, -2.664882183074951, -2.3295607566833496, -2.1822571754455566, -1.2064398527145386, -1.023490071296692, -0.6144803166389465, -1.8787364959716797, -0.9739692807197571, 2.3515191078186035, 1.5140286684036255, 0.7973809838294983, -1.122033953666687, 0.5221937298774719, 0.08161398023366928, 0.5126097202301025, 0.19878587126731873, 0.11818214505910873, 1.8753734827041626, 0.0, 0.20602257549762726, 0.9614589810371399, 1.087199091911316, -0.025038888677954674, 0.9422580003738403, 1.109079122543335, 0.9469615817070007, 0.6286704540252686, 1.5068273544311523, 1.0790830850601196, 1.0187848806381226, 1.0699117183685303, 0.9611154198646545, 0.21602460741996765, 0.07358770817518234, 1.2917234897613525, 1.161238431930542, 1.5598644018173218, -0.35021984577178955, 0.6230762004852295, 0.8636798858642578, 0.5240214467048645, 0.7290067076683044, 0.29474589228630066, -0.03311816230416298, 0.08342054486274719, -0.3085632920265198, 0.2591356933116913, -0.40183529257774353, 1.470154881477356, 0.25263357162475586, 0.28896021842956543, 0.3213880956172943, 0.5887110233306885, 1.2564455270767212, 1.7036865949630737, 3.685753107070923, 0.0, -0.0, -8.772053718566895, -8.838729858398438, -8.275972366333008, -8.711285591125488, -8.411787986755371, -7.530776023864746, -7.260497093200684, -6.989810943603516, -5.897951126098633, -6.004156112670898, -6.374632835388184, -6.749459266662598, -4.601099014282227, -3.4504342079162598, -4.409939289093018, -4.6109724044799805, -3.9842288494110107, -3.0001063346862793, -1.7334542274475098, -1.9401549100875854, -2.664882183074951, -2.3295607566833496, -2.1822571754455566, -1.2064398527145386, -1.023490071296692, -0.6144803166389465, -1.8787364959716797, -0.9739692807197571, 2.3515191078186035, 1.5140286684036255, 0.7973809838294983, -1.122033953666687, 0.5221937298774719, 0.08161398023366928, 0.5126097202301025, 0.19878587126731873, 0.11818214505910873, 1.8753734827041626, 0.0, 0.20602257549762726, 0.9614589810371399, 1.087199091911316, -0.025038888677954674, 0.9422580003738403, 1.109079122543335, 0.9469615817070007, 0.6286704540252686, 1.5068273544311523, 1.0790830850601196, 1.0187848806381226, 1.0699117183685303, 0.9611154198646545, 0.21602460741996765, 0.07358770817518234, 1.2917234897613525, 1.161238431930542, 1.5598644018173218, -0.35021984577178955, 0.6230762004852295, 0.8636798858642578, 0.5240214467048645, 0.7290067076683044, 0.29474589228630066, -0.03311816230416298, 0.08342054486274719, -0.3085632920265198, 0.2591356933116913, -0.40183529257774353, 1.470154881477356, 0.25263357162475586, 0.28896021842956543, 0.3213880956172943, 0.5887110233306885, 1.2564455270767212, 1.7036865949630737, 3.685753107070923, 0.0], [0.0, -9.105329513549805, -8.622310638427734, -9.179057121276855, -8.280320167541504, -9.276628494262695, -8.135509490966797, -7.298637866973877, -7.3215012550354, -6.4363837242126465, -7.0886616706848145, -6.763992786407471, -5.854057788848877, -5.718461990356445, -5.871891021728516, -5.203094005584717, -5.358678817749023, -3.750235080718994, -3.7638232707977295, -4.174737930297852, -2.473977565765381, -3.926938772201538, -1.679129719734192, -2.5689268112182617, -1.8660914897918701, -0.7614117860794067, 0.8769702911376953, -0.6997872591018677, -0.016305461525917053, -0.130568727850914, -0.26571938395500183, -0.2783726155757904, -1.3560657501220703, 0.08128322660923004, 0.06979977339506149, -0.1462189108133316, 0.7843393087387085, 1.1968352794647217, 5.137537479400635, 0.0, 0.46201083064079285, 0.49240854382514954, 0.9735337495803833, 1.0858726501464844, 0.9477244019508362, 1.269038200378418, 0.8381525278091431, 0.9173095226287842, 1.0856250524520874, 0.28744128346443176, 0.5609948635101318, 0.7474346160888672, 0.23756173253059387, 0.920170247554779, 1.582300066947937, 2.240931987762451, 1.1454800367355347, 0.7739747166633606, 0.29295361042022705, -0.13414840400218964, -0.10721225291490555, 0.28249865770339966, 0.2769436538219452, -0.04916677251458168, 1.2286633253097534, 0.3772600293159485, 0.2730973958969116, 0.2784397304058075, -0.5024459362030029, -0.42304790019989014, 0.2536950707435608, 0.22677986323833466, 0.4028571546077728, 0.49487218260765076, 1.0272059440612793, 1.8353456258773804, 1.6291903257369995, 0.0, -0.0, -9.105329513549805, -8.622310638427734, -9.179057121276855, -8.280320167541504, -9.276628494262695, -8.135509490966797, -7.298637866973877, -7.3215012550354, -6.4363837242126465, -7.0886616706848145, -6.763992786407471, -5.854057788848877, -5.718461990356445, -5.871891021728516, -5.203094005584717, -5.358678817749023, -3.750235080718994, -3.7638232707977295, -4.174737930297852, -2.473977565765381, -3.926938772201538, -1.679129719734192, -2.5689268112182617, -1.8660914897918701, -0.7614117860794067, 0.8769702911376953, -0.6997872591018677, -0.016305461525917053, -0.130568727850914, -0.26571938395500183, -0.2783726155757904, -1.3560657501220703, 0.08128322660923004, 0.06979977339506149, -0.1462189108133316, 0.7843393087387085, 1.1968352794647217, 5.137537479400635, 0.0, 0.46201083064079285, 0.49240854382514954, 0.9735337495803833, 1.0858726501464844, 0.9477244019508362, 1.269038200378418, 0.8381525278091431, 0.9173095226287842, 1.0856250524520874, 0.28744128346443176, 0.5609948635101318, 0.7474346160888672, 0.23756173253059387, 0.920170247554779, 1.582300066947937, 2.240931987762451, 1.1454800367355347, 0.7739747166633606, 0.29295361042022705, -0.13414840400218964, -0.10721225291490555, 0.28249865770339966, 0.2769436538219452, -0.04916677251458168, 1.2286633253097534, 0.3772600293159485, 0.2730973958969116, 0.2784397304058075, -0.5024459362030029, -0.42304790019989014, 0.2536950707435608, 0.22677986323833466, 0.4028571546077728, 0.49487218260765076, 1.0272059440612793, 1.8353456258773804, 1.6291903257369995, 0.0], [0.0, -9.773489952087402, -9.494102478027344, -8.821139335632324, -8.211276054382324, -8.457406997680664, -7.593374729156494, -8.050674438476562, -7.5139055252075195, -7.631164073944092, -7.7261176109313965, -4.444565296173096, -5.493387699127197, -6.056198596954346, -6.024752140045166, -6.448894023895264, -7.466884136199951, -3.4550538063049316, -4.4834160804748535, -4.031244277954102, -3.2299537658691406, -1.1980117559432983, -3.074711799621582, -1.876395583152771, -0.9337098598480225, -0.9924963712692261, -1.4074091911315918, -0.5150114893913269, -0.8279424905776978, -1.1486666202545166, -0.65171879529953, -0.7327410578727722, -2.976863145828247, -0.6151377558708191, -0.15836510062217712, -0.22334086894989014, 0.024683231487870216, 0.5404504537582397, 2.3330368995666504, 1.6621674299240112, 0.5852631330490112, 1.2659635543823242, 0.9285022020339966, 0.8681211471557617, 0.48575037717819214, 1.301386833190918, 0.7584050297737122, 0.6213841438293457, 1.4336010217666626, -0.4509885609149933, 0.7714675068855286, 1.070249319076538, 1.7120996713638306, 1.484726905822754, 0.8388346433639526, 0.37114593386650085, -0.8552011251449585, -0.4247604012489319, 0.6010316014289856, 0.27138301730155945, 0.47102388739585876, -0.14738769829273224, -0.6077769994735718, 0.058749232441186905, -1.7852040529251099, -1.2562255859375, -0.13854610919952393, 0.44987916946411133, -0.7868212461471558, -0.17076367139816284, 0.5142930746078491, -0.16328980028629303, 0.6054848432540894, -0.2896651327610016, 0.9966986775398254, 1.6217095851898193, 0.7301203608512878, 0.0, -0.0, -9.773489952087402, -9.494102478027344, -8.821139335632324, -8.211276054382324, -8.457406997680664, -7.593374729156494, -8.050674438476562, -7.5139055252075195, -7.631164073944092, -7.7261176109313965, -4.444565296173096, -5.493387699127197, -6.056198596954346, -6.024752140045166, -6.448894023895264, -7.466884136199951, -3.4550538063049316, -4.4834160804748535, -4.031244277954102, -3.2299537658691406, -1.1980117559432983, -3.074711799621582, -1.876395583152771, -0.9337098598480225, -0.9924963712692261, -1.4074091911315918, -0.5150114893913269, -0.8279424905776978, -1.1486666202545166, -0.65171879529953, -0.7327410578727722, -2.976863145828247, -0.6151377558708191, -0.15836510062217712, -0.22334086894989014, 0.024683231487870216, 0.5404504537582397, 2.3330368995666504, 1.6621674299240112, 0.5852631330490112, 1.2659635543823242, 0.9285022020339966, 0.8681211471557617, 0.48575037717819214, 1.301386833190918, 0.7584050297737122, 0.6213841438293457, 1.4336010217666626, -0.4509885609149933, 0.7714675068855286, 1.070249319076538, 1.7120996713638306, 1.484726905822754, 0.8388346433639526, 0.37114593386650085, -0.8552011251449585, -0.4247604012489319, 0.6010316014289856, 0.27138301730155945, 0.47102388739585876, -0.14738769829273224, -0.6077769994735718, 0.058749232441186905, -1.7852040529251099, -1.2562255859375, -0.13854610919952393, 0.44987916946411133, -0.7868212461471558, -0.17076367139816284, 0.5142930746078491, -0.16328980028629303, 0.6054848432540894, -0.2896651327610016, 0.9966986775398254, 1.6217095851898193, 0.7301203608512878, 0.0], [0.0, -10.494745254516602, -9.462250709533691, -8.866781234741211, -9.2284574508667, -8.751121520996094, -8.444397926330566, -8.622689247131348, -7.509444713592529, -6.499786376953125, -6.960165977478027, -6.817461013793945, -8.083802223205566, -5.049924850463867, -5.7356061935424805, -4.82968282699585, -4.883522033691406, -4.878326416015625, -2.8802452087402344, -3.876239776611328, -3.2871742248535156, -0.1588032841682434, -2.786886692047119, -2.02873158454895, -1.9646707773208618, -2.686432361602783, -2.0431571006774902, -3.810011625289917, -1.4162232875823975, -0.8062134981155396, -0.18682628870010376, -1.0663059949874878, -1.0014632940292358, -0.32000869512557983, -0.32034575939178467, 0.05807000771164894, -0.19475175440311432, -3.264439344406128, -0.8951743245124817, -1.3288792371749878, 0.16932903230190277, -0.1988457441329956, 1.821607232093811, 0.3980158865451813, 1.5110100507736206, 1.0107898712158203, 0.7998684048652649, 1.5919257402420044, 0.7780183553695679, -0.04202581197023392, -0.13355018198490143, 1.453515887260437, 1.6644986867904663, 1.5931930541992188, 0.4862593114376068, 0.8270692825317383, 1.0782239437103271, 0.48370569944381714, 1.2697234153747559, -0.07241743803024292, -0.09228456765413284, 0.6913312673568726, 0.09196321666240692, 0.6767787337303162, -0.5085602402687073, 0.23142307996749878, 0.6533875465393066, -0.6160000562667847, -1.0799200534820557, -0.12586785852909088, -0.27053216099739075, 0.3616630434989929, -0.1325169950723648, 0.6027556657791138, 0.5633860230445862, 0.7165898680686951, 0.8986297845840454, 0.0, -0.0, -10.494745254516602, -9.462250709533691, -8.866781234741211, -9.2284574508667, -8.751121520996094, -8.444397926330566, -8.622689247131348, -7.509444713592529, -6.499786376953125, -6.960165977478027, -6.817461013793945, -8.083802223205566, -5.049924850463867, -5.7356061935424805, -4.82968282699585, -4.883522033691406, -4.878326416015625, -2.8802452087402344, -3.876239776611328, -3.2871742248535156, -0.1588032841682434, -2.786886692047119, -2.02873158454895, -1.9646707773208618, -2.686432361602783, -2.0431571006774902, -3.810011625289917, -1.4162232875823975, -0.8062134981155396, -0.18682628870010376, -1.0663059949874878, -1.0014632940292358, -0.32000869512557983, -0.32034575939178467, 0.05807000771164894, -0.19475175440311432, -3.264439344406128, -0.8951743245124817, -1.3288792371749878, 0.16932903230190277, -0.1988457441329956, 1.821607232093811, 0.3980158865451813, 1.5110100507736206, 1.0107898712158203, 0.7998684048652649, 1.5919257402420044, 0.7780183553695679, -0.04202581197023392, -0.13355018198490143, 1.453515887260437, 1.6644986867904663, 1.5931930541992188, 0.4862593114376068, 0.8270692825317383, 1.0782239437103271, 0.48370569944381714, 1.2697234153747559, -0.07241743803024292, -0.09228456765413284, 0.6913312673568726, 0.09196321666240692, 0.6767787337303162, -0.5085602402687073, 0.23142307996749878, 0.6533875465393066, -0.6160000562667847, -1.0799200534820557, -0.12586785852909088, -0.27053216099739075, 0.3616630434989929, -0.1325169950723648, 0.6027556657791138, 0.5633860230445862, 0.7165898680686951, 0.8986297845840454, 0.0], [0.0, -9.96944808959961, -10.394232749938965, -10.405673027038574, -9.493362426757812, -9.282410621643066, -9.71865463256836, -8.312976837158203, -7.254645824432373, -8.39499282836914, -6.632697105407715, -6.576627731323242, -6.609926223754883, -6.078392028808594, -5.492887496948242, -3.183791160583496, -4.675730228424072, -4.1544904708862305, -4.474837779998779, -4.0295257568359375, -3.1244239807128906, -3.7489757537841797, -3.3232502937316895, -2.6474242210388184, -1.5192099809646606, -1.0785412788391113, -1.2436332702636719, -0.6542233824729919, -1.2857398986816406, 0.0031875779386609793, -0.8695580959320068, -0.6244969964027405, 0.2976369857788086, -1.284367322921753, -0.032036829739809036, -0.317218542098999, 0.6978205442428589, -0.07541404664516449, 0.1992463916540146, 0.6413173675537109, 0.42821866273880005, 0.7253007292747498, 2.6020400524139404, -1.0040665864944458, 1.9452800750732422, 0.5322059988975525, 0.862249493598938, 0.7543807625770569, -0.14150506258010864, 0.18803347647190094, 0.9262964725494385, 0.9811736941337585, 1.3519306182861328, 0.7255361080169678, -0.6622151732444763, 1.3048889636993408, 0.35402417182922363, 0.5041126608848572, -0.7082628011703491, 0.41875627636909485, -0.3216557204723358, -1.0410993099212646, -0.23909048736095428, -1.0877809524536133, 0.38616183400154114, -0.2587348520755768, -0.36373499035835266, 0.31905731558799744, -1.4674245119094849, -0.4134918749332428, -0.7220520377159119, 0.8110865354537964, -1.5216528177261353, -0.820743978023529, 0.05694720149040222, -0.518903374671936, 0.09589360654354095, 0.0, -0.0, -9.96944808959961, -10.394232749938965, -10.405673027038574, -9.493362426757812, -9.282410621643066, -9.71865463256836, -8.312976837158203, -7.254645824432373, -8.39499282836914, -6.632697105407715, -6.576627731323242, -6.609926223754883, -6.078392028808594, -5.492887496948242, -3.183791160583496, -4.675730228424072, -4.1544904708862305, -4.474837779998779, -4.0295257568359375, -3.1244239807128906, -3.7489757537841797, -3.3232502937316895, -2.6474242210388184, -1.5192099809646606, -1.0785412788391113, -1.2436332702636719, -0.6542233824729919, -1.2857398986816406, 0.0031875779386609793, -0.8695580959320068, -0.6244969964027405, 0.2976369857788086, -1.284367322921753, -0.032036829739809036, -0.317218542098999, 0.6978205442428589, -0.07541404664516449, 0.1992463916540146, 0.6413173675537109, 0.42821866273880005, 0.7253007292747498, 2.6020400524139404, -1.0040665864944458, 1.9452800750732422, 0.5322059988975525, 0.862249493598938, 0.7543807625770569, -0.14150506258010864, 0.18803347647190094, 0.9262964725494385, 0.9811736941337585, 1.3519306182861328, 0.7255361080169678, -0.6622151732444763, 1.3048889636993408, 0.35402417182922363, 0.5041126608848572, -0.7082628011703491, 0.41875627636909485, -0.3216557204723358, -1.0410993099212646, -0.23909048736095428, -1.0877809524536133, 0.38616183400154114, -0.2587348520755768, -0.36373499035835266, 0.31905731558799744, -1.4674245119094849, -0.4134918749332428, -0.7220520377159119, 0.8110865354537964, -1.5216528177261353, -0.820743978023529, 0.05694720149040222, -0.518903374671936, 0.09589360654354095, 0.0], [0.0, -11.121297836303711, -10.581929206848145, -9.365875244140625, -10.744683265686035, -9.862909317016602, -8.100055694580078, -9.110725402832031, -9.10493278503418, -8.375839233398438, -8.067305564880371, -7.664972305297852, -6.78629732131958, -5.681339740753174, -6.086567401885986, -5.580946445465088, -5.5496625900268555, -4.6883344650268555, -4.461646556854248, -3.439216375350952, -4.4106268882751465, -4.6914896965026855, -2.6653523445129395, -2.1053080558776855, -2.0946476459503174, -2.08833646774292, -2.6059858798980713, -1.0594942569732666, -1.9255931377410889, -3.4915220737457275, -2.8820061683654785, -0.1244836375117302, -1.1732885837554932, 0.6079510450363159, 0.7033607959747314, 0.10799405723810196, 0.31102508306503296, 0.13074597716331482, 0.17863582074642181, 0.4404471814632416, 0.69688481092453, 0.3310976028442383, 0.19158020615577698, 0.4068754017353058, 1.4051458835601807, 1.1339811086654663, 1.76316499710083, 1.2043452262878418, 0.6061384081840515, 1.2576076984405518, 1.038287878036499, 1.764049768447876, 0.044497307389974594, 0.8540610074996948, 0.8664584159851074, 0.4981667101383209, -0.7415279746055603, 0.5207818746566772, -0.3694658875465393, 0.5731174349784851, 0.5159518122673035, 0.4245518445968628, -0.19715029001235962, 0.2842459976673126, 0.41139885783195496, -1.480855107307434, -1.2041116952896118, -0.23194773495197296, 0.19824138283729553, -0.7710584402084351, -0.5439273715019226, -0.008081506006419659, -1.3700897693634033, -0.901032567024231, -1.3685517311096191, -0.995857298374176, -0.10566683113574982, 0.0, -0.0, -11.121297836303711, -10.581929206848145, -9.365875244140625, -10.744683265686035, -9.862909317016602, -8.100055694580078, -9.110725402832031, -9.10493278503418, -8.375839233398438, -8.067305564880371, -7.664972305297852, -6.78629732131958, -5.681339740753174, -6.086567401885986, -5.580946445465088, -5.5496625900268555, -4.6883344650268555, -4.461646556854248, -3.439216375350952, -4.4106268882751465, -4.6914896965026855, -2.6653523445129395, -2.1053080558776855, -2.0946476459503174, -2.08833646774292, -2.6059858798980713, -1.0594942569732666, -1.9255931377410889, -3.4915220737457275, -2.8820061683654785, -0.1244836375117302, -1.1732885837554932, 0.6079510450363159, 0.7033607959747314, 0.10799405723810196, 0.31102508306503296, 0.13074597716331482, 0.17863582074642181, 0.4404471814632416, 0.69688481092453, 0.3310976028442383, 0.19158020615577698, 0.4068754017353058, 1.4051458835601807, 1.1339811086654663, 1.76316499710083, 1.2043452262878418, 0.6061384081840515, 1.2576076984405518, 1.038287878036499, 1.764049768447876, 0.044497307389974594, 0.8540610074996948, 0.8664584159851074, 0.4981667101383209, -0.7415279746055603, 0.5207818746566772, -0.3694658875465393, 0.5731174349784851, 0.5159518122673035, 0.4245518445968628, -0.19715029001235962, 0.2842459976673126, 0.41139885783195496, -1.480855107307434, -1.2041116952896118, -0.23194773495197296, 0.19824138283729553, -0.7710584402084351, -0.5439273715019226, -0.008081506006419659, -1.3700897693634033, -0.901032567024231, -1.3685517311096191, -0.995857298374176, -0.10566683113574982, -0.0], [0.0, -11.984309196472168, -11.001713752746582, -10.167346000671387, -10.163568496704102, -10.116049766540527, -9.253680229187012, -7.924442768096924, -8.722917556762695, -9.402020454406738, -7.250061511993408, -7.355133056640625, -6.463940143585205, -6.050513744354248, -6.212988376617432, -5.8604207038879395, -5.557265758514404, -4.466111183166504, -4.733201503753662, -3.1677706241607666, -5.5960822105407715, -2.6480817794799805, -3.1626198291778564, -2.2896275520324707, -2.6316933631896973, -2.238849401473999, -0.3242368698120117, -3.268644094467163, -2.7213823795318604, -1.244877576828003, -0.8483554720878601, 0.6547791957855225, -0.22784845530986786, -0.4816478490829468, 0.6132328510284424, 0.21173109114170074, -0.3038111627101898, -0.039595793932676315, 0.3981136977672577, 0.5066535472869873, 0.8215039968490601, 0.3652694821357727, 1.944558024406433, 2.1587812900543213, 0.6096000075340271, 1.523594856262207, 1.5404469966888428, 0.7113837599754333, 0.5454330444335938, 1.2337605953216553, 0.9002693295478821, 1.4656469821929932, 2.528597593307495, 1.5356836318969727, 2.651301145553589, 0.3453561067581177, -1.1428022384643555, -3.2618725299835205, -0.37565964460372925, -0.9127816557884216, -0.5019937753677368, -0.8426581621170044, -0.22664472460746765, -0.8002958297729492, -0.3233982026576996, 0.15631335973739624, -0.5757045745849609, -0.13875386118888855, -1.0146515369415283, -0.473812997341156, 0.09660448879003525, -0.8510156273841858, -0.2950710356235504, -0.5819111466407776, -0.9215648174285889, -1.2152466773986816, -0.9707298278808594, 0.0, -0.0, -11.984309196472168, -11.001713752746582, -10.167346000671387, -10.163568496704102, -10.116049766540527, -9.253680229187012, -7.924442768096924, -8.722917556762695, -9.402020454406738, -7.250061511993408, -7.355133056640625, -6.463940143585205, -6.050513744354248, -6.212988376617432, -5.8604207038879395, -5.557265758514404, -4.466111183166504, -4.733201503753662, -3.1677706241607666, -5.5960822105407715, -2.6480817794799805, -3.1626198291778564, -2.2896275520324707, -2.6316933631896973, -2.238849401473999, -0.3242368698120117, -3.268644094467163, -2.7213823795318604, -1.244877576828003, -0.8483554720878601, 0.6547791957855225, -0.22784845530986786, -0.4816478490829468, 0.6132328510284424, 0.21173109114170074, -0.3038111627101898, -0.039595793932676315, 0.3981136977672577, 0.5066535472869873, 0.8215039968490601, 0.3652694821357727, 1.944558024406433, 2.1587812900543213, 0.6096000075340271, 1.523594856262207, 1.5404469966888428, 0.7113837599754333, 0.5454330444335938, 1.2337605953216553, 0.9002693295478821, 1.4656469821929932, 2.528597593307495, 1.5356836318969727, 2.651301145553589, 0.3453561067581177, -1.1428022384643555, -3.2618725299835205, -0.37565964460372925, -0.9127816557884216, -0.5019937753677368, -0.8426581621170044, -0.22664472460746765, -0.8002958297729492, -0.3233982026576996, 0.15631335973739624, -0.5757045745849609, -0.13875386118888855, -1.0146515369415283, -0.473812997341156, 0.09660448879003525, -0.8510156273841858, -0.2950710356235504, -0.5819111466407776, -0.9215648174285889, -1.2152466773986816, -0.9707298278808594, -0.0], [0.0, -12.243338584899902, -11.710050582885742, -8.511222839355469, -9.739782333374023, -11.026307106018066, -10.38339614868164, -9.315313339233398, -8.432238578796387, -8.234993934631348, -7.440221309661865, -7.2468953132629395, -7.12039041519165, -7.638533592224121, -5.395874500274658, -6.02906608581543, -5.804474830627441, -4.308010578155518, -5.108020782470703, -4.526375770568848, -4.222217082977295, -2.5211918354034424, -3.270458459854126, -3.035468339920044, -3.6814377307891846, -1.0410001277923584, -2.272888660430908, -0.35028040409088135, -0.9898372292518616, -3.5089449882507324, -0.4917391836643219, 1.4892942905426025, -1.079118251800537, -1.2819695472717285, 1.3959983587265015, -0.44834256172180176, 0.2640150487422943, -0.23362526297569275, 0.2620924711227417, 0.9137371182441711, 0.49380409717559814, 0.33164724707603455, -0.2348555624485016, 0.6772294640541077, 0.22434456646442413, 0.9333602786064148, 1.219568133354187, 2.3179073333740234, -0.9080485701560974, -0.45279139280319214, 1.2859680652618408, 0.3916303813457489, 0.38242781162261963, 1.0638673305511475, 0.9998438358306885, -0.6145893335342407, 3.077970266342163, 1.1129331588745117, 0.3766166567802429, -0.03276350721716881, -0.32515132427215576, -0.9322597980499268, 0.61821448802948, -0.6661348342895508, -1.679046392440796, -2.388017177581787, -0.3409354090690613, -0.6895005106925964, -0.6020236611366272, -1.1518938541412354, -1.0315189361572266, 0.46500715613365173, -1.89024019241333, -3.6386523246765137, -0.9550142288208008, -2.509004592895508, -1.5135971307754517, 0.0, -0.0, -12.243338584899902, -11.710050582885742, -8.511222839355469, -9.739782333374023, -11.026307106018066, -10.38339614868164, -9.315313339233398, -8.432238578796387, -8.234993934631348, -7.440221309661865, -7.2468953132629395, -7.12039041519165, -7.638533592224121, -5.395874500274658, -6.02906608581543, -5.804474830627441, -4.308010578155518, -5.108020782470703, -4.526375770568848, -4.222217082977295, -2.5211918354034424, -3.270458459854126, -3.035468339920044, -3.6814377307891846, -1.0410001277923584, -2.272888660430908, -0.35028040409088135, -0.9898372292518616, -3.5089449882507324, -0.4917391836643219, 1.4892942905426025, -1.079118251800537, -1.2819695472717285, 1.3959983587265015, -0.44834256172180176, 0.2640150487422943, -0.23362526297569275, 0.2620924711227417, 0.9137371182441711, 0.49380409717559814, 0.33164724707603455, -0.2348555624485016, 0.6772294640541077, 0.22434456646442413, 0.9333602786064148, 1.219568133354187, 2.3179073333740234, -0.9080485701560974, -0.45279139280319214, 1.2859680652618408, 0.3916303813457489, 0.38242781162261963, 1.0638673305511475, 0.9998438358306885, -0.6145893335342407, 3.077970266342163, 1.1129331588745117, 0.3766166567802429, -0.03276350721716881, -0.32515132427215576, -0.9322597980499268, 0.61821448802948, -0.6661348342895508, -1.679046392440796, -2.388017177581787, -0.3409354090690613, -0.6895005106925964, -0.6020236611366272, -1.1518938541412354, -1.0315189361572266, 0.46500715613365173, -1.89024019241333, -3.6386523246765137, -0.9550142288208008, -2.509004592895508, -1.5135971307754517, -0.0], [0.0, -12.273703575134277, -12.300445556640625, -11.733418464660645, -11.594676971435547, -11.130236625671387, -9.896417617797852, -10.059065818786621, -8.579141616821289, -8.96028995513916, -8.618306159973145, -8.23405933380127, -8.329187393188477, -6.95942497253418, -6.839620113372803, -5.6904706954956055, -5.740471839904785, -5.082897663116455, -4.072958469390869, -3.9560635089874268, -3.3564159870147705, -3.529482841491699, -3.823965311050415, -2.932877540588379, -2.6311068534851074, -4.3037896156311035, -0.8592519760131836, -1.7355730533599854, -1.3629765510559082, -1.0576730966567993, -0.6137135028839111, -0.9681466817855835, -1.8009849786758423, -2.163715362548828, -0.7567681670188904, 0.8340883851051331, -0.7669093608856201, -0.31405016779899597, 0.14237672090530396, 0.5295150876045227, -0.21142931282520294, 1.0441547632217407, -0.3290993869304657, -1.4601432085037231, -0.4183928072452545, -0.1522578001022339, 0.10655028373003006, 0.7538000345230103, 0.6442617177963257, 0.7328736186027527, 1.0044218301773071, 0.5698471665382385, 1.1149519681930542, 0.5904128551483154, -2.6060452461242676, 1.0547996759414673, 0.38156256079673767, 0.31719914078712463, 0.18367019295692444, 0.274971604347229, -0.14404095709323883, -0.3110496401786804, -0.8043976426124573, -0.8242731094360352, -0.3406530022621155, -0.31783655285835266, -0.8991254568099976, -1.1310346126556396, -0.14517080783843994, -1.5127159357070923, 0.6618226170539856, -1.3251986503601074, -1.412527322769165, -1.1495107412338257, -0.8593096137046814, -2.4781272411346436, -2.749654769897461, 0.0, -0.0, -12.273703575134277, -12.300445556640625, -11.733418464660645, -11.594676971435547, -11.130236625671387, -9.896417617797852, -10.059065818786621, -8.579141616821289, -8.96028995513916, -8.618306159973145, -8.23405933380127, -8.329187393188477, -6.95942497253418, -6.839620113372803, -5.6904706954956055, -5.740471839904785, -5.082897663116455, -4.072958469390869, -3.9560635089874268, -3.3564159870147705, -3.529482841491699, -3.823965311050415, -2.932877540588379, -2.6311068534851074, -4.3037896156311035, -0.8592519760131836, -1.7355730533599854, -1.3629765510559082, -1.0576730966567993, -0.6137135028839111, -0.9681466817855835, -1.8009849786758423, -2.163715362548828, -0.7567681670188904, 0.8340883851051331, -0.7669093608856201, -0.31405016779899597, 0.14237672090530396, 0.5295150876045227, -0.21142931282520294, 1.0441547632217407, -0.3290993869304657, -1.4601432085037231, -0.4183928072452545, -0.1522578001022339, 0.10655028373003006, 0.7538000345230103, 0.6442617177963257, 0.7328736186027527, 1.0044218301773071, 0.5698471665382385, 1.1149519681930542, 0.5904128551483154, -2.6060452461242676, 1.0547996759414673, 0.38156256079673767, 0.31719914078712463, 0.18367019295692444, 0.274971604347229, -0.14404095709323883, -0.3110496401786804, -0.8043976426124573, -0.8242731094360352, -0.3406530022621155, -0.31783655285835266, -0.8991254568099976, -1.1310346126556396, -0.14517080783843994, -1.5127159357070923, 0.6618226170539856, -1.3251986503601074, -1.412527322769165, -1.1495107412338257, -0.8593096137046814, -2.4781272411346436, -2.749654769897461, -0.0], [0.0, -12.944734573364258, -12.563532829284668, -11.8391752243042, -11.461949348449707, -11.904428482055664, -10.731913566589355, -9.718365669250488, -9.43387508392334, -9.150458335876465, -8.675956726074219, -8.50068473815918, -8.208327293395996, -7.008976936340332, -6.557115077972412, -7.2944722175598145, -5.779935359954834, -5.465575695037842, -5.707919597625732, -3.577096939086914, -3.9803223609924316, -3.955951452255249, -2.8755297660827637, -3.7465951442718506, -1.302046537399292, -1.2315647602081299, -2.684746503829956, -1.6760461330413818, -1.3813657760620117, -1.6986463069915771, -0.9060367941856384, -0.8651242256164551, -0.47764232754707336, -1.4585914611816406, -1.1476681232452393, -2.2251741886138916, -0.6051366329193115, -0.42307934165000916, -1.015992283821106, 0.0191036444157362, 0.062287330627441406, -0.22886300086975098, -0.3365345299243927, -0.1938755065202713, -1.001482605934143, -0.489076167345047, 0.6616812944412231, 0.4290202856063843, -0.1464829295873642, 0.7111742496490479, -1.4032533168792725, 0.694381594657898, 0.9489628672599792, 1.527127981185913, 0.448890745639801, 1.3486367464065552, -1.0169610977172852, -2.0944223403930664, 1.0064908266067505, 0.7300937175750732, -0.18307383358478546, -0.11444947123527527, -0.6806530952453613, -0.6143205761909485, -0.383980393409729, -0.9440329074859619, -0.603367805480957, -0.6410307288169861, -1.0888203382492065, -1.024673581123352, -0.7853564023971558, -1.2143045663833618, -1.2638392448425293, -1.848000168800354, -0.6930220127105713, -1.8656176328659058, -1.6289989948272705, 0.0, -0.0, -12.944734573364258, -12.563532829284668, -11.8391752243042, -11.461949348449707, -11.904428482055664, -10.731913566589355, -9.718365669250488, -9.43387508392334, -9.150458335876465, -8.675956726074219, -8.50068473815918, -8.208327293395996, -7.008976936340332, -6.557115077972412, -7.2944722175598145, -5.779935359954834, -5.465575695037842, -5.707919597625732, -3.577096939086914, -3.9803223609924316, -3.955951452255249, -2.8755297660827637, -3.7465951442718506, -1.302046537399292, -1.2315647602081299, -2.684746503829956, -1.6760461330413818, -1.3813657760620117, -1.6986463069915771, -0.9060367941856384, -0.8651242256164551, -0.47764232754707336, -1.4585914611816406, -1.1476681232452393, -2.2251741886138916, -0.6051366329193115, -0.42307934165000916, -1.015992283821106, 0.0191036444157362, 0.062287330627441406, -0.22886300086975098, -0.3365345299243927, -0.1938755065202713, -1.001482605934143, -0.489076167345047, 0.6616812944412231, 0.4290202856063843, -0.1464829295873642, 0.7111742496490479, -1.4032533168792725, 0.694381594657898, 0.9489628672599792, 1.527127981185913, 0.448890745639801, 1.3486367464065552, -1.0169610977172852, -2.0944223403930664, 1.0064908266067505, 0.7300937175750732, -0.18307383358478546, -0.11444947123527527, -0.6806530952453613, -0.6143205761909485, -0.383980393409729, -0.9440329074859619, -0.603367805480957, -0.6410307288169861, -1.0888203382492065, -1.024673581123352, -0.7853564023971558, -1.2143045663833618, -1.2638392448425293, -1.848000168800354, -0.6930220127105713, -1.8656176328659058, -1.6289989948272705, -0.0], [0.0, -15.416716575622559, -12.878467559814453, -11.592490196228027, -12.40379524230957, -11.068163871765137, -10.55955982208252, -11.175369262695312, -10.221686363220215, -8.674718856811523, -8.362547874450684, -7.819003582000732, -7.461649417877197, -7.161810398101807, -4.735849857330322, -6.9106340408325195, -7.1803789138793945, -4.546971321105957, -5.32139778137207, -4.326725006103516, -4.330292224884033, -4.5754852294921875, -3.381490468978882, -3.399388313293457, -4.429380893707275, -1.8486088514328003, -2.0005836486816406, -0.9386789798736572, -1.4578211307525635, -1.3974695205688477, -1.0219429731369019, -1.8416482210159302, -1.220705270767212, -1.8650457859039307, -1.8342297077178955, -2.269369125366211, -1.3242249488830566, -0.9020200967788696, -0.1369326263666153, -1.4995373487472534, -0.5109180808067322, 0.47140276432037354, -0.8294524550437927, -0.36063623428344727, -0.20071178674697876, 0.3109954595565796, -0.40781280398368835, -0.4909476041793823, -0.4580300748348236, 2.46561336517334, 0.46888378262519836, 1.5505633354187012, 0.1913250982761383, 1.4194554090499878, 0.6250315308570862, -0.41924241185188293, -0.41368022561073303, 0.250878244638443, -0.06266877800226212, 0.9590256810188293, -1.5408246517181396, 0.23718620836734772, -0.6815708875656128, -0.494977205991745, 1.826985239982605, -0.4218443036079407, -1.6749128103256226, -0.7074248194694519, -1.0846538543701172, -0.7332608699798584, -1.4600880146026611, -0.8157231211662292, -1.4642196893692017, -1.6114108562469482, -1.1868497133255005, -3.469892740249634, -0.5040799379348755, 0.0, -0.0, -15.416716575622559, -12.878467559814453, -11.592490196228027, -12.40379524230957, -11.068163871765137, -10.55955982208252, -11.175369262695312, -10.221686363220215, -8.674718856811523, -8.362547874450684, -7.819003582000732, -7.461649417877197, -7.161810398101807, -4.735849857330322, -6.9106340408325195, -7.1803789138793945, -4.546971321105957, -5.32139778137207, -4.326725006103516, -4.330292224884033, -4.5754852294921875, -3.381490468978882, -3.399388313293457, -4.429380893707275, -1.8486088514328003, -2.0005836486816406, -0.9386789798736572, -1.4578211307525635, -1.3974695205688477, -1.0219429731369019, -1.8416482210159302, -1.220705270767212, -1.8650457859039307, -1.8342297077178955, -2.269369125366211, -1.3242249488830566, -0.9020200967788696, -0.1369326263666153, -1.4995373487472534, -0.5109180808067322, 0.47140276432037354, -0.8294524550437927, -0.36063623428344727, -0.20071178674697876, 0.3109954595565796, -0.40781280398368835, -0.4909476041793823, -0.4580300748348236, 2.46561336517334, 0.46888378262519836, 1.5505633354187012, 0.1913250982761383, 1.4194554090499878, 0.6250315308570862, -0.41924241185188293, -0.41368022561073303, 0.250878244638443, -0.06266877800226212, 0.9590256810188293, -1.5408246517181396, 0.23718620836734772, -0.6815708875656128, -0.494977205991745, 1.826985239982605, -0.4218443036079407, -1.6749128103256226, -0.7074248194694519, -1.0846538543701172, -0.7332608699798584, -1.4600880146026611, -0.8157231211662292, -1.4642196893692017, -1.6114108562469482, -1.1868497133255005, -3.469892740249634, -0.5040799379348755, -0.0], [0.0, -14.577889442443848, -13.205721855163574, -12.692625999450684, -11.539095878601074, -11.318500518798828, -10.30851936340332, -10.313028335571289, -10.253429412841797, -9.28342056274414, -9.10233211517334, -8.548235893249512, -8.223816871643066, -8.669734954833984, -7.393312931060791, -6.770349502563477, -6.090860843658447, -5.2695441246032715, -5.4922614097595215, -4.51703405380249, -3.8778674602508545, -4.124485015869141, -1.9645577669143677, -3.0580437183380127, -3.3834807872772217, -2.672377586364746, -2.6527884006500244, -1.8629534244537354, -1.6603763103485107, -2.3547215461730957, -1.61985182762146, -0.9898593425750732, -1.3576741218566895, -2.903879404067993, -3.353008270263672, -3.2831478118896484, -1.3294273614883423, -0.21392156183719635, -0.5223769545555115, -1.2639756202697754, -1.2858526706695557, -0.316866934299469, -0.045816436409950256, -0.7496521472930908, -1.1536051034927368, -2.403961420059204, -1.480077862739563, 0.20209378004074097, 0.3463194668292999, 3.4351789951324463, 0.8524260520935059, 0.07601451128721237, -1.376308798789978, 1.4794902801513672, 0.5749559998512268, -0.3849288523197174, -1.1493948698043823, -0.09002948552370071, 1.211047887802124, 0.6217244267463684, -0.09648875147104263, 0.036683496087789536, -0.673381507396698, -0.8951181173324585, -1.9657177925109863, 0.5905512571334839, -1.0989822149276733, -2.6079258918762207, -1.9315029382705688, -1.1367695331573486, -0.6203821897506714, -0.7481958866119385, -1.5569956302642822, -1.3748705387115479, -2.686217784881592, -3.332484722137451, -2.644080877304077, 0.0, -0.0, -14.577889442443848, -13.205721855163574, -12.692625999450684, -11.539095878601074, -11.318500518798828, -10.30851936340332, -10.313028335571289, -10.253429412841797, -9.28342056274414, -9.10233211517334, -8.548235893249512, -8.223816871643066, -8.669734954833984, -7.393312931060791, -6.770349502563477, -6.090860843658447, -5.2695441246032715, -5.4922614097595215, -4.51703405380249, -3.8778674602508545, -4.124485015869141, -1.9645577669143677, -3.0580437183380127, -3.3834807872772217, -2.672377586364746, -2.6527884006500244, -1.8629534244537354, -1.6603763103485107, -2.3547215461730957, -1.61985182762146, -0.9898593425750732, -1.3576741218566895, -2.903879404067993, -3.353008270263672, -3.2831478118896484, -1.3294273614883423, -0.21392156183719635, -0.5223769545555115, -1.2639756202697754, -1.2858526706695557, -0.316866934299469, -0.045816436409950256, -0.7496521472930908, -1.1536051034927368, -2.403961420059204, -1.480077862739563, 0.20209378004074097, 0.3463194668292999, 3.4351789951324463, 0.8524260520935059, 0.07601451128721237, -1.376308798789978, 1.4794902801513672, 0.5749559998512268, -0.3849288523197174, -1.1493948698043823, -0.09002948552370071, 1.211047887802124, 0.6217244267463684, -0.09648875147104263, 0.036683496087789536, -0.673381507396698, -0.8951181173324585, -1.9657177925109863, 0.5905512571334839, -1.0989822149276733, -2.6079258918762207, -1.9315029382705688, -1.1367695331573486, -0.6203821897506714, -0.7481958866119385, -1.5569956302642822, -1.3748705387115479, -2.686217784881592, -3.332484722137451, -2.644080877304077, -0.0], [0.0, -13.773138999938965, -13.585854530334473, -12.419889450073242, -11.408108711242676, -11.27132511138916, -10.245993614196777, -10.199575424194336, -9.523008346557617, -9.190325736999512, -8.523035049438477, -8.780195236206055, -8.539132118225098, -7.510872840881348, -6.672499656677246, -6.56873083114624, -6.504561901092529, -5.91566801071167, -5.4787797927856445, -4.819583415985107, -3.746854305267334, -2.9946885108947754, -4.759471416473389, -4.1309356689453125, -4.191693305969238, -2.059969425201416, -3.864353895187378, -2.5889413356781006, -1.1696618795394897, -1.7892787456512451, -1.7659733295440674, -1.5532714128494263, -1.3280086517333984, -1.9046907424926758, -1.163629174232483, -1.7977849245071411, -4.43739128112793, -1.428436040878296, -0.7295206785202026, -1.1190840005874634, -2.1483678817749023, -0.5847395658493042, -0.3842723071575165, -0.8108372092247009, -1.150439977645874, -1.0294748544692993, -1.1926125288009644, -1.2065205574035645, -1.4918370246887207, 0.7581546902656555, 0.5946820378303528, 0.2690616250038147, -0.009535757824778557, 0.7376514673233032, 0.3702435791492462, -1.2150492668151855, -0.9823757410049438, 0.24116556346416473, -0.2647145688533783, -1.2814810276031494, -0.4945928156375885, -0.3676080107688904, -0.486013799905777, -1.2748318910598755, 0.0, -0.8727803230285645, -0.03121834062039852, -0.6691142320632935, -0.31457239389419556, -0.25383034348487854, -0.4662472605705261, -0.14256468415260315, -1.4671865701675415, -1.588861107826233, -2.169952869415283, -2.4535861015319824, -3.7247281074523926, 0.0, -0.0, -13.773138999938965, -13.585854530334473, -12.419889450073242, -11.408108711242676, -11.27132511138916, -10.245993614196777, -10.199575424194336, -9.523008346557617, -9.190325736999512, -8.523035049438477, -8.780195236206055, -8.539132118225098, -7.510872840881348, -6.672499656677246, -6.56873083114624, -6.504561901092529, -5.91566801071167, -5.4787797927856445, -4.819583415985107, -3.746854305267334, -2.9946885108947754, -4.759471416473389, -4.1309356689453125, -4.191693305969238, -2.059969425201416, -3.864353895187378, -2.5889413356781006, -1.1696618795394897, -1.7892787456512451, -1.7659733295440674, -1.5532714128494263, -1.3280086517333984, -1.9046907424926758, -1.163629174232483, -1.7977849245071411, -4.43739128112793, -1.428436040878296, -0.7295206785202026, -1.1190840005874634, -2.1483678817749023, -0.5847395658493042, -0.3842723071575165, -0.8108372092247009, -1.150439977645874, -1.0294748544692993, -1.1926125288009644, -1.2065205574035645, -1.4918370246887207, 0.7581546902656555, 0.5946820378303528, 0.2690616250038147, -0.009535757824778557, 0.7376514673233032, 0.3702435791492462, -1.2150492668151855, -0.9823757410049438, 0.24116556346416473, -0.2647145688533783, -1.2814810276031494, -0.4945928156375885, -0.3676080107688904, -0.486013799905777, -1.2748318910598755, -0.0, -0.8727803230285645, -0.03121834062039852, -0.6691142320632935, -0.31457239389419556, -0.25383034348487854, -0.4662472605705261, -0.14256468415260315, -1.4671865701675415, -1.588861107826233, -2.169952869415283, -2.4535861015319824, -3.7247281074523926, -0.0], [0.0, -13.935558319091797, -13.362475395202637, -11.983619689941406, -11.498191833496094, -10.962662696838379, -10.444089889526367, -9.788287162780762, -10.38821029663086, -9.201800346374512, -8.564858436584473, -8.924686431884766, -8.27501106262207, -5.801474571228027, -6.9008378982543945, -6.5177836418151855, -6.235221862792969, -5.62007999420166, -5.56490421295166, -6.427916526794434, -3.2361178398132324, -3.845005989074707, -4.561554431915283, -3.3302276134490967, -2.8078951835632324, -3.6740405559539795, -2.3853254318237305, -2.5866541862487793, -2.38405179977417, -2.1771960258483887, -0.8200570344924927, -1.2588005065917969, -1.532821536064148, -1.041892647743225, -1.5557962656021118, -2.794997215270996, -0.5754073858261108, -1.934287190437317, -1.0580813884735107, -1.3549178838729858, -1.4853520393371582, -0.3056775629520416, -0.8778368830680847, -1.579277515411377, 0.08985859900712967, -2.062053680419922, -1.482125163078308, -0.5767194032669067, -0.5831220149993896, -1.761047124862671, -0.8906393051147461, -0.05078611150383949, -1.3431928157806396, -0.1655627191066742, 0.14663174748420715, -1.3319005966186523, -0.0282606054097414, 2.0469703674316406, 0.12658533453941345, 0.15950682759284973, 0.429647833108902, -0.35670146346092224, 0.10626940429210663, -0.4084923565387726, 1.3723608255386353, -1.1536660194396973, -1.2078531980514526, -1.9357147216796875, -1.048369288444519, -1.9069087505340576, -0.890124499797821, -0.9106481075286865, -0.8624095916748047, -2.643325090408325, -1.9287210702896118, -2.9658727645874023, -1.3823355436325073, 0.0, -0.0, -13.935558319091797, -13.362475395202637, -11.983619689941406, -11.498191833496094, -10.962662696838379, -10.444089889526367, -9.788287162780762, -10.38821029663086, -9.201800346374512, -8.564858436584473, -8.924686431884766, -8.27501106262207, -5.801474571228027, -6.9008378982543945, -6.5177836418151855, -6.235221862792969, -5.62007999420166, -5.56490421295166, -6.427916526794434, -3.2361178398132324, -3.845005989074707, -4.561554431915283, -3.3302276134490967, -2.8078951835632324, -3.6740405559539795, -2.3853254318237305, -2.5866541862487793, -2.38405179977417, -2.1771960258483887, -0.8200570344924927, -1.2588005065917969, -1.532821536064148, -1.041892647743225, -1.5557962656021118, -2.794997215270996, -0.5754073858261108, -1.934287190437317, -1.0580813884735107, -1.3549178838729858, -1.4853520393371582, -0.3056775629520416, -0.8778368830680847, -1.579277515411377, 0.08985859900712967, -2.062053680419922, -1.482125163078308, -0.5767194032669067, -0.5831220149993896, -1.761047124862671, -0.8906393051147461, -0.05078611150383949, -1.3431928157806396, -0.1655627191066742, 0.14663174748420715, -1.3319005966186523, -0.0282606054097414, 2.0469703674316406, 0.12658533453941345, 0.15950682759284973, 0.429647833108902, -0.35670146346092224, 0.10626940429210663, -0.4084923565387726, 1.3723608255386353, -1.1536660194396973, -1.2078531980514526, -1.9357147216796875, -1.048369288444519, -1.9069087505340576, -0.890124499797821, -0.9106481075286865, -0.8624095916748047, -2.643325090408325, -1.9287210702896118, -2.9658727645874023, -1.3823355436325073, -0.0], [0.0, -15.000543594360352, -12.861858367919922, -12.140010833740234, -11.743041038513184, -11.04639720916748, -10.477354049682617, -10.58545970916748, -10.180116653442383, -10.00924015045166, -9.577289581298828, -8.564866065979004, -8.670876502990723, -8.004908561706543, -7.051663875579834, -6.758498191833496, -6.207050800323486, -5.689716815948486, -5.154311180114746, -6.131862640380859, -4.200983047485352, -3.814490556716919, -4.121205806732178, -6.077420234680176, -5.1721415519714355, -3.9059975147247314, -4.086444854736328, -6.049904823303223, -2.6772658824920654, -2.0316967964172363, -3.589571952819824, -1.5944641828536987, -2.968212842941284, -1.5029196739196777, -2.8854072093963623, -1.567672610282898, -1.6670349836349487, -1.7472617626190186, -1.8560553789138794, -2.153956174850464, -2.005176067352295, -1.593733549118042, -2.514735698699951, -2.0783300399780273, -1.3709169626235962, -0.18481172621250153, -1.429989218711853, -1.5900273323059082, -2.8634345531463623, 1.1571654081344604, -0.4788386821746826, -0.29234200716018677, -0.5742818713188171, 0.2937878966331482, -0.4995335340499878, -1.0165095329284668, -0.10867435485124588, -1.8871153593063354, -1.0863128900527954, -0.7287619113922119, -0.7108482122421265, -0.5214264988899231, -1.1219401359558105, -1.154569387435913, -1.8322199583053589, -0.7883437275886536, -1.412833571434021, 0.3186780512332916, -0.8105241060256958, -1.2196033000946045, -1.368607997894287, -1.2938709259033203, -1.7418893575668335, -2.0491080284118652, -1.4031682014465332, -1.8268488645553589, -1.8279478549957275, 0.0, -0.0, -15.000543594360352, -12.861858367919922, -12.140010833740234, -11.743041038513184, -11.04639720916748, -10.477354049682617, -10.58545970916748, -10.180116653442383, -10.00924015045166, -9.577289581298828, -8.564866065979004, -8.670876502990723, -8.004908561706543, -7.051663875579834, -6.758498191833496, -6.207050800323486, -5.689716815948486, -5.154311180114746, -6.131862640380859, -4.200983047485352, -3.814490556716919, -4.121205806732178, -6.077420234680176, -5.1721415519714355, -3.9059975147247314, -4.086444854736328, -6.049904823303223, -2.6772658824920654, -2.0316967964172363, -3.589571952819824, -1.5944641828536987, -2.968212842941284, -1.5029196739196777, -2.8854072093963623, -1.567672610282898, -1.6670349836349487, -1.7472617626190186, -1.8560553789138794, -2.153956174850464, -2.005176067352295, -1.593733549118042, -2.514735698699951, -2.0783300399780273, -1.3709169626235962, -0.18481172621250153, -1.429989218711853, -1.5900273323059082, -2.8634345531463623, 1.1571654081344604, -0.4788386821746826, -0.29234200716018677, -0.5742818713188171, 0.2937878966331482, -0.4995335340499878, -1.0165095329284668, -0.10867435485124588, -1.8871153593063354, -1.0863128900527954, -0.7287619113922119, -0.7108482122421265, -0.5214264988899231, -1.1219401359558105, -1.154569387435913, -1.8322199583053589, -0.7883437275886536, -1.412833571434021, 0.3186780512332916, -0.8105241060256958, -1.2196033000946045, -1.368607997894287, -1.2938709259033203, -1.7418893575668335, -2.0491080284118652, -1.4031682014465332, -1.8268488645553589, -1.8279478549957275, -0.0], [0.0, -14.085752487182617, -12.53667163848877, -12.11347484588623, -11.026567459106445, -10.674888610839844, -10.061356544494629, -10.032997131347656, -9.969432830810547, -9.739745140075684, -9.827190399169922, -9.21872615814209, -7.001165866851807, -8.497687339782715, -7.359316349029541, -6.709237575531006, -6.128892421722412, -5.299101829528809, -6.145443916320801, -5.727408409118652, -5.350879192352295, -4.677223205566406, -4.410473823547363, -4.619497299194336, -4.287014484405518, -3.8489153385162354, -3.1746039390563965, -3.8572001457214355, -1.8559836149215698, -3.420649290084839, -1.7087398767471313, -2.320671558380127, -1.7468454837799072, -2.1625189781188965, -1.2449865341186523, -2.153047561645508, -3.617276906967163, -3.192056655883789, -3.178102970123291, -3.6774778366088867, -3.040990114212036, -2.5035386085510254, -2.627119541168213, -2.9981675148010254, -2.547490119934082, -1.956967830657959, -1.740214467048645, -0.5611777305603027, -0.7161689400672913, -1.0281281471252441, -1.83091402053833, -1.1300175189971924, -0.28747981786727905, -0.6804866790771484, -1.4069998264312744, -0.6237444281578064, -0.862644612789154, -0.43821701407432556, -1.3839362859725952, -0.42057639360427856, 0.07204209268093109, -0.2867066264152527, -1.1489839553833008, 0.05032685771584511, -1.075778603553772, -0.6479763388633728, -1.221787452697754, -1.8019012212753296, -0.8208432197570801, -1.891462802886963, -1.567528247833252, -1.52167546749115, -1.5296627283096313, -1.6051214933395386, -2.222787380218506, -2.265159845352173, -2.330122709274292, 0.0, -0.0, -14.085752487182617, -12.53667163848877, -12.11347484588623, -11.026567459106445, -10.674888610839844, -10.061356544494629, -10.032997131347656, -9.969432830810547, -9.739745140075684, -9.827190399169922, -9.21872615814209, -7.001165866851807, -8.497687339782715, -7.359316349029541, -6.709237575531006, -6.128892421722412, -5.299101829528809, -6.145443916320801, -5.727408409118652, -5.350879192352295, -4.677223205566406, -4.410473823547363, -4.619497299194336, -4.287014484405518, -3.8489153385162354, -3.1746039390563965, -3.8572001457214355, -1.8559836149215698, -3.420649290084839, -1.7087398767471313, -2.320671558380127, -1.7468454837799072, -2.1625189781188965, -1.2449865341186523, -2.153047561645508, -3.617276906967163, -3.192056655883789, -3.178102970123291, -3.6774778366088867, -3.040990114212036, -2.5035386085510254, -2.627119541168213, -2.9981675148010254, -2.547490119934082, -1.956967830657959, -1.740214467048645, -0.5611777305603027, -0.7161689400672913, -1.0281281471252441, -1.83091402053833, -1.1300175189971924, -0.28747981786727905, -0.6804866790771484, -1.4069998264312744, -0.6237444281578064, -0.862644612789154, -0.43821701407432556, -1.3839362859725952, -0.42057639360427856, 0.07204209268093109, -0.2867066264152527, -1.1489839553833008, 0.05032685771584511, -1.075778603553772, -0.6479763388633728, -1.221787452697754, -1.8019012212753296, -0.8208432197570801, -1.891462802886963, -1.567528247833252, -1.52167546749115, -1.5296627283096313, -1.6051214933395386, -2.222787380218506, -2.265159845352173, -2.330122709274292, -0.0], [0.0, -12.343677520751953, -12.01153564453125, -12.316393852233887, -11.598960876464844, -11.429195404052734, -10.332139015197754, -10.670655250549316, -10.426350593566895, -8.781753540039062, -9.883878707885742, -9.088271141052246, -8.333497047424316, -7.862536907196045, -7.189378261566162, -7.425937652587891, -6.512606620788574, -6.250338554382324, -5.9278764724731445, -6.030472278594971, -5.976433277130127, -4.118648052215576, -6.013129234313965, -3.3899717330932617, -4.640988826751709, -2.279588460922241, -3.723451852798462, -3.596532106399536, -1.2397490739822388, -2.401454210281372, -3.073490619659424, -3.1230719089508057, -3.0825870037078857, -2.5737831592559814, -2.5448811054229736, -3.5234899520874023, -3.4006447792053223, -3.847450017929077, -3.575491189956665, -2.751530647277832, -4.183873653411865, -3.153299331665039, -3.7167136669158936, -3.4095311164855957, -3.7479705810546875, -3.7409567832946777, -1.6303309202194214, -1.7533459663391113, -3.037344217300415, -2.5357329845428467, -2.5764763355255127, -0.757043719291687, -0.6465967893600464, -1.9770426750183105, -1.7602565288543701, -0.9865646958351135, -0.7272800803184509, -1.3103965520858765, -1.7190779447555542, -0.013383709825575352, -0.6267517805099487, -0.6346911191940308, -0.3515521287918091, -1.2681200504302979, -0.9550676941871643, -0.45052453875541687, -0.4519943296909332, -1.5672104358673096, -2.0056302547454834, -1.6010454893112183, -1.301908254623413, -0.9064372181892395, -1.7025420665740967, -0.6253530979156494, -1.8831019401550293, -2.4378206729888916, -2.959702968597412, 0.0, -0.0, -12.343677520751953, -12.01153564453125, -12.316393852233887, -11.598960876464844, -11.429195404052734, -10.332139015197754, -10.670655250549316, -10.426350593566895, -8.781753540039062, -9.883878707885742, -9.088271141052246, -8.333497047424316, -7.862536907196045, -7.189378261566162, -7.425937652587891, -6.512606620788574, -6.250338554382324, -5.9278764724731445, -6.030472278594971, -5.976433277130127, -4.118648052215576, -6.013129234313965, -3.3899717330932617, -4.640988826751709, -2.279588460922241, -3.723451852798462, -3.596532106399536, -1.2397490739822388, -2.401454210281372, -3.073490619659424, -3.1230719089508057, -3.0825870037078857, -2.5737831592559814, -2.5448811054229736, -3.5234899520874023, -3.4006447792053223, -3.847450017929077, -3.575491189956665, -2.751530647277832, -4.183873653411865, -3.153299331665039, -3.7167136669158936, -3.4095311164855957, -3.7479705810546875, -3.7409567832946777, -1.6303309202194214, -1.7533459663391113, -3.037344217300415, -2.5357329845428467, -2.5764763355255127, -0.757043719291687, -0.6465967893600464, -1.9770426750183105, -1.7602565288543701, -0.9865646958351135, -0.7272800803184509, -1.3103965520858765, -1.7190779447555542, -0.013383709825575352, -0.6267517805099487, -0.6346911191940308, -0.3515521287918091, -1.2681200504302979, -0.9550676941871643, -0.45052453875541687, -0.4519943296909332, -1.5672104358673096, -2.0056302547454834, -1.6010454893112183, -1.301908254623413, -0.9064372181892395, -1.7025420665740967, -0.6253530979156494, -1.8831019401550293, -2.4378206729888916, -2.959702968597412, -0.0], [0.0, 0.0, -10.883241653442383, -11.968961715698242, -11.593832015991211, -12.347357749938965, -11.231100082397461, -11.145096778869629, -10.23204517364502, -8.379233360290527, -9.894493103027344, -7.686965465545654, -8.782081604003906, -8.506064414978027, -8.214695930480957, -6.631196022033691, -6.29519510269165, -6.157183647155762, -5.272397041320801, -5.678356647491455, -5.522848606109619, -4.1700263023376465, -4.764700889587402, -4.800996780395508, -5.1078009605407715, -2.3940160274505615, -4.136890888214111, -4.5415825843811035, -2.493419647216797, -3.942209482192993, -2.5436244010925293, -3.222377061843872, -3.226984977722168, -5.67231559753418, -2.488525867462158, -4.0501885414123535, -4.598620891571045, -4.458470821380615, -4.6502766609191895, -5.027044773101807, -3.864924192428589, -3.9705803394317627, -3.589293956756592, -5.760072708129883, -3.5638785362243652, -3.2937817573547363, -2.659487724304199, -1.572900414466858, -2.617717742919922, -1.7373859882354736, -1.9781676530838013, -1.9859347343444824, -0.8465873599052429, 1.109657883644104, -0.983467161655426, -2.319507122039795, -1.1277663707733154, -1.2476186752319336, 0.19537784159183502, -1.7112454175949097, -0.5886141061782837, -0.35498368740081787, -0.2684885859489441, -1.163680911064148, -0.9213070273399353, -0.11296284943819046, -0.3995552659034729, -1.4534378051757812, -1.5125406980514526, -2.1086857318878174, -1.3037360906600952, -1.1703277826309204, -2.031482219696045, -2.0478768348693848, -2.4987902641296387, -2.7563929557800293, -5.109699249267578, 0.0, -0.0, -0.0, -10.883241653442383, -11.968961715698242, -11.593832015991211, -12.347357749938965, -11.231100082397461, -11.145096778869629, -10.23204517364502, -8.379233360290527, -9.894493103027344, -7.686965465545654, -8.782081604003906, -8.506064414978027, -8.214695930480957, -6.631196022033691, -6.29519510269165, -6.157183647155762, -5.272397041320801, -5.678356647491455, -5.522848606109619, -4.1700263023376465, -4.764700889587402, -4.800996780395508, -5.1078009605407715, -2.3940160274505615, -4.136890888214111, -4.5415825843811035, -2.493419647216797, -3.942209482192993, -2.5436244010925293, -3.222377061843872, -3.226984977722168, -5.67231559753418, -2.488525867462158, -4.0501885414123535, -4.598620891571045, -4.458470821380615, -4.6502766609191895, -5.027044773101807, -3.864924192428589, -3.9705803394317627, -3.589293956756592, -5.760072708129883, -3.5638785362243652, -3.2937817573547363, -2.659487724304199, -1.572900414466858, -2.617717742919922, -1.7373859882354736, -1.9781676530838013, -1.9859347343444824, -0.8465873599052429, 1.109657883644104, -0.983467161655426, -2.319507122039795, -1.1277663707733154, -1.2476186752319336, 0.19537784159183502, -1.7112454175949097, -0.5886141061782837, -0.35498368740081787, -0.2684885859489441, -1.163680911064148, -0.9213070273399353, -0.11296284943819046, -0.3995552659034729, -1.4534378051757812, -1.5125406980514526, -2.1086857318878174, -1.3037360906600952, -1.1703277826309204, -2.031482219696045, -2.0478768348693848, -2.4987902641296387, -2.7563929557800293, -5.109699249267578, -0.0], [0.0, 0.0, 0.0, -11.661523818969727, -11.861412048339844, -11.326294898986816, -11.732958793640137, -11.626126289367676, -10.580672264099121, -9.346023559570312, -10.640599250793457, -8.967510223388672, -9.125529289245605, -9.027945518493652, -7.258748531341553, -6.706265926361084, -6.630097389221191, -6.437097549438477, -6.05028772354126, -5.9497270584106445, -5.17691707611084, -5.621679306030273, -4.797774314880371, -4.732577800750732, -5.049675464630127, -5.400688171386719, -4.471058368682861, -5.334205150604248, -5.50654411315918, -5.711462020874023, -2.9571704864501953, -3.8573029041290283, -4.910583019256592, -4.577906608581543, -4.012523174285889, -5.42161750793457, -5.096852779388428, -6.8558783531188965, -5.176103591918945, -4.561903953552246, -4.825239658355713, -3.9190175533294678, -3.8454997539520264, -4.8805694580078125, -3.3562779426574707, -3.479637384414673, -3.560323476791382, -2.276458740234375, -2.3606925010681152, -1.5581388473510742, -2.4944207668304443, -3.419341564178467, -2.8469865322113037, -1.76317298412323, -2.7022106647491455, -2.514904022216797, -1.4813828468322754, -0.6018938422203064, -1.099839687347412, -2.246229887008667, -0.2029494196176529, -0.8981999754905701, -0.9257912635803223, -1.5863556861877441, -0.19801990687847137, -0.8809454441070557, -0.14067910611629486, -0.8639622926712036, -1.021715760231018, -1.392924189567566, -1.444087028503418, -3.1416971683502197, -1.983328938484192, -2.5031039714813232, -2.076586961746216, -3.8598239421844482, -5.500319480895996, 0.0, -0.0, -0.0, -0.0, -11.661523818969727, -11.861412048339844, -11.326294898986816, -11.732958793640137, -11.626126289367676, -10.580672264099121, -9.346023559570312, -10.640599250793457, -8.967510223388672, -9.125529289245605, -9.027945518493652, -7.258748531341553, -6.706265926361084, -6.630097389221191, -6.437097549438477, -6.05028772354126, -5.9497270584106445, -5.17691707611084, -5.621679306030273, -4.797774314880371, -4.732577800750732, -5.049675464630127, -5.400688171386719, -4.471058368682861, -5.334205150604248, -5.50654411315918, -5.711462020874023, -2.9571704864501953, -3.8573029041290283, -4.910583019256592, -4.577906608581543, -4.012523174285889, -5.42161750793457, -5.096852779388428, -6.8558783531188965, -5.176103591918945, -4.561903953552246, -4.825239658355713, -3.9190175533294678, -3.8454997539520264, -4.8805694580078125, -3.3562779426574707, -3.479637384414673, -3.560323476791382, -2.276458740234375, -2.3606925010681152, -1.5581388473510742, -2.4944207668304443, -3.419341564178467, -2.8469865322113037, -1.76317298412323, -2.7022106647491455, -2.514904022216797, -1.4813828468322754, -0.6018938422203064, -1.099839687347412, -2.246229887008667, -0.2029494196176529, -0.8981999754905701, -0.9257912635803223, -1.5863556861877441, -0.19801990687847137, -0.8809454441070557, -0.14067910611629486, -0.8639622926712036, -1.021715760231018, -1.392924189567566, -1.444087028503418, -3.1416971683502197, -1.983328938484192, -2.5031039714813232, -2.076586961746216, -3.8598239421844482, -5.500319480895996, -0.0], [0.0, 0.0, 0.0, -11.280324935913086, -12.793028831481934, -11.396203994750977, -10.802696228027344, -10.420838356018066, -11.275491714477539, -9.747057914733887, -9.603129386901855, -9.438985824584961, -8.679940223693848, -8.599112510681152, -8.379597663879395, -7.842226028442383, -7.063804626464844, -5.778006553649902, -5.512298583984375, -6.2679314613342285, -4.852287292480469, -5.261257171630859, -2.5421202182769775, -4.8877973556518555, -1.8655847311019897, -4.844545364379883, -3.8095264434814453, -5.327418327331543, -6.044960975646973, -5.637084007263184, -4.640266418457031, -6.289281368255615, -5.350586891174316, -6.774355888366699, -5.845759868621826, -5.621890544891357, -6.530694484710693, -6.280611038208008, -5.384486198425293, -5.775390625, -5.6455302238464355, -5.784614562988281, -4.921660900115967, -5.306264400482178, -5.767741680145264, -4.98331880569458, -3.515016555786133, -5.328674793243408, -3.430103302001953, -5.318851947784424, -5.200257778167725, -3.3765666484832764, -2.774160385131836, -2.3916566371917725, -2.3174898624420166, -1.8574963808059692, -0.5341755151748657, -2.0460457801818848, -1.089944839477539, -1.1909723281860352, -1.9628318548202515, -0.7247138023376465, -1.0105775594711304, -0.37730470299720764, -1.308849573135376, -0.3607981503009796, 0.023166228085756302, -1.3027375936508179, -1.7681572437286377, -1.646069049835205, -1.3424569368362427, -2.0815234184265137, -2.0174078941345215, -2.2929744720458984, -2.4776182174682617, -4.918065071105957, 0.0, 0.0, -0.0, -0.0, -0.0, -11.280324935913086, -12.793028831481934, -11.396203994750977, -10.802696228027344, -10.420838356018066, -11.275491714477539, -9.747057914733887, -9.603129386901855, -9.438985824584961, -8.679940223693848, -8.599112510681152, -8.379597663879395, -7.842226028442383, -7.063804626464844, -5.778006553649902, -5.512298583984375, -6.2679314613342285, -4.852287292480469, -5.261257171630859, -2.5421202182769775, -4.8877973556518555, -1.8655847311019897, -4.844545364379883, -3.8095264434814453, -5.327418327331543, -6.044960975646973, -5.637084007263184, -4.640266418457031, -6.289281368255615, -5.350586891174316, -6.774355888366699, -5.845759868621826, -5.621890544891357, -6.530694484710693, -6.280611038208008, -5.384486198425293, -5.775390625, -5.6455302238464355, -5.784614562988281, -4.921660900115967, -5.306264400482178, -5.767741680145264, -4.98331880569458, -3.515016555786133, -5.328674793243408, -3.430103302001953, -5.318851947784424, -5.200257778167725, -3.3765666484832764, -2.774160385131836, -2.3916566371917725, -2.3174898624420166, -1.8574963808059692, -0.5341755151748657, -2.0460457801818848, -1.089944839477539, -1.1909723281860352, -1.9628318548202515, -0.7247138023376465, -1.0105775594711304, -0.37730470299720764, -1.308849573135376, -0.3607981503009796, 0.023166228085756302, -1.3027375936508179, -1.7681572437286377, -1.646069049835205, -1.3424569368362427, -2.0815234184265137, -2.0174078941345215, -2.2929744720458984, -2.4776182174682617, -4.918065071105957, -0.0, -0.0], [-9.617775917053223, 0.0, -8.972673416137695, -12.90020751953125, -11.75658893585205, -11.597865104675293, -11.128076553344727, -11.573902130126953, -10.864924430847168, -10.160693168640137, -9.876133918762207, -9.911563873291016, -9.08167839050293, -9.72132396697998, -7.613657474517822, -6.823258876800537, -6.575812816619873, -6.500734806060791, -5.699170112609863, -6.2116546630859375, -5.3037190437316895, -4.987522125244141, -5.319591045379639, -5.684892177581787, -5.527826309204102, -5.818327903747559, -6.010627269744873, -5.973727226257324, -6.094667911529541, -6.728585720062256, -7.262132167816162, -7.275666236877441, -6.377662181854248, -4.708161354064941, -7.211268901824951, -6.376491069793701, -7.136812210083008, -6.686637878417969, -7.715145587921143, -7.350117206573486, -6.695987701416016, -5.492992877960205, -7.283018589019775, -6.8598246574401855, -6.157674312591553, -4.894759178161621, -6.210174083709717, -4.7949652671813965, -4.291849613189697, -3.544877529144287, -4.1945061683654785, -5.007786273956299, -3.8716671466827393, -1.905656099319458, -3.1398088932037354, -2.3764212131500244, -2.783869504928589, -2.321052312850952, -0.713217556476593, -1.3361401557922363, -0.19905084371566772, -1.5027832984924316, -1.201122522354126, -1.4436025619506836, -1.1726384162902832, -0.8602051734924316, -1.3111917972564697, -1.2926585674285889, -1.6573944091796875, -2.087062358856201, -2.7561686038970947, -1.7206940650939941, -2.185220718383789, -3.7687556743621826, -4.269446849822998, -4.328976631164551, 0.0, 0.0, -9.617775917053223, -0.0, -8.972673416137695, -12.90020751953125, -11.75658893585205, -11.597865104675293, -11.128076553344727, -11.573902130126953, -10.864924430847168, -10.160693168640137, -9.876133918762207, -9.911563873291016, -9.08167839050293, -9.72132396697998, -7.613657474517822, -6.823258876800537, -6.575812816619873, -6.500734806060791, -5.699170112609863, -6.2116546630859375, -5.3037190437316895, -4.987522125244141, -5.319591045379639, -5.684892177581787, -5.527826309204102, -5.818327903747559, -6.010627269744873, -5.973727226257324, -6.094667911529541, -6.728585720062256, -7.262132167816162, -7.275666236877441, -6.377662181854248, -4.708161354064941, -7.211268901824951, -6.376491069793701, -7.136812210083008, -6.686637878417969, -7.715145587921143, -7.350117206573486, -6.695987701416016, -5.492992877960205, -7.283018589019775, -6.8598246574401855, -6.157674312591553, -4.894759178161621, -6.210174083709717, -4.7949652671813965, -4.291849613189697, -3.544877529144287, -4.1945061683654785, -5.007786273956299, -3.8716671466827393, -1.905656099319458, -3.1398088932037354, -2.3764212131500244, -2.783869504928589, -2.321052312850952, -0.713217556476593, -1.3361401557922363, -0.19905084371566772, -1.5027832984924316, -1.201122522354126, -1.4436025619506836, -1.1726384162902832, -0.8602051734924316, -1.3111917972564697, -1.2926585674285889, -1.6573944091796875, -2.087062358856201, -2.7561686038970947, -1.7206940650939941, -2.185220718383789, -3.7687556743621826, -4.269446849822998, -4.328976631164551, -0.0, -0.0], [-7.780128479003906, 0.0, 0.0, -13.218146324157715, -10.892602920532227, -11.490721702575684, -11.537149429321289, -10.323271751403809, -10.436600685119629, -10.07021713256836, -10.214101791381836, -9.10807991027832, -8.426051139831543, -7.161129474639893, -7.813225746154785, -7.3008952140808105, -6.689944744110107, -5.332265853881836, -6.20544958114624, -6.711655139923096, -5.753509521484375, -6.607729434967041, -6.176967144012451, -6.201638221740723, -6.030206203460693, -6.241615295410156, -5.242751121520996, -4.152192115783691, -5.623704433441162, -8.096110343933105, -8.187376022338867, -7.541154861450195, -8.386762619018555, -7.434509754180908, -7.608585357666016, -8.221565246582031, -7.718930721282959, -8.266077995300293, -8.089356422424316, -8.152705192565918, -7.876191139221191, -7.468304634094238, -8.030327796936035, -7.915488243103027, -8.542057991027832, -6.846197128295898, -6.7582550048828125, -7.847843170166016, -5.4186530113220215, -5.398386001586914, -5.6552557945251465, -5.272251605987549, -3.4179062843322754, -2.7513961791992188, -2.927504301071167, -2.4008915424346924, -2.365809679031372, -2.252122402191162, -1.7612333297729492, -2.1996796131134033, -0.7457475066184998, -1.7079434394836426, -1.4766721725463867, -1.4365540742874146, -0.5899100303649902, -0.7443212270736694, -1.0529237985610962, -0.5582393407821655, -1.4473228454589844, -1.5616786479949951, -1.6542056798934937, -2.1524200439453125, -2.961341142654419, -3.0420315265655518, -3.916203737258911, -5.50077486038208, 0.0, 0.0, -7.780128479003906, -0.0, -0.0, -13.218146324157715, -10.892602920532227, -11.490721702575684, -11.537149429321289, -10.323271751403809, -10.436600685119629, -10.07021713256836, -10.214101791381836, -9.10807991027832, -8.426051139831543, -7.161129474639893, -7.813225746154785, -7.3008952140808105, -6.689944744110107, -5.332265853881836, -6.20544958114624, -6.711655139923096, -5.753509521484375, -6.607729434967041, -6.176967144012451, -6.201638221740723, -6.030206203460693, -6.241615295410156, -5.242751121520996, -4.152192115783691, -5.623704433441162, -8.096110343933105, -8.187376022338867, -7.541154861450195, -8.386762619018555, -7.434509754180908, -7.608585357666016, -8.221565246582031, -7.718930721282959, -8.266077995300293, -8.089356422424316, -8.152705192565918, -7.876191139221191, -7.468304634094238, -8.030327796936035, -7.915488243103027, -8.542057991027832, -6.846197128295898, -6.7582550048828125, -7.847843170166016, -5.4186530113220215, -5.398386001586914, -5.6552557945251465, -5.272251605987549, -3.4179062843322754, -2.7513961791992188, -2.927504301071167, -2.4008915424346924, -2.365809679031372, -2.252122402191162, -1.7612333297729492, -2.1996796131134033, -0.7457475066184998, -1.7079434394836426, -1.4766721725463867, -1.4365540742874146, -0.5899100303649902, -0.7443212270736694, -1.0529237985610962, -0.5582393407821655, -1.4473228454589844, -1.5616786479949951, -1.6542056798934937, -2.1524200439453125, -2.961341142654419, -3.0420315265655518, -3.916203737258911, -5.50077486038208, -0.0, -0.0], [-10.826986312866211, 0.0, -9.740870475769043, -11.56438159942627, -10.786699295043945, -11.702716827392578, -11.400392532348633, -10.03183650970459, -11.14425277709961, -10.500127792358398, -9.638830184936523, -9.786473274230957, -8.907136917114258, -8.208894729614258, -6.731061935424805, -6.907516956329346, -6.835052967071533, -5.506246089935303, -7.429502487182617, -6.491489887237549, -5.0030131340026855, -4.269479274749756, -6.03414249420166, -6.407447814941406, -6.7358856201171875, -4.753684997558594, -5.740441799163818, -7.43879508972168, -6.496297836303711, -7.199785232543945, -8.24837589263916, -8.691283226013184, -9.136032104492188, -8.964066505432129, -6.630338668823242, -8.733664512634277, -8.441474914550781, -10.208495140075684, -9.400078773498535, -9.250847816467285, -9.65723991394043, -9.650065422058105, -9.601266860961914, -9.357470512390137, -8.686964988708496, -8.657340049743652, -8.927635192871094, -6.138442516326904, -5.793661594390869, -4.705766201019287, -4.829814434051514, -6.2351837158203125, -3.516511917114258, -3.476250648498535, -3.824951410293579, -2.9522287845611572, -2.6769070625305176, -3.0694198608398438, -2.1607325077056885, -1.5875333547592163, -1.9485255479812622, -1.5678836107254028, -0.7994444370269775, -0.5130563378334045, -0.952663004398346, -1.0799715518951416, -0.6555581092834473, -1.9432448148727417, -0.6421813368797302, -1.6670955419540405, -1.389085054397583, -2.2744252681732178, -3.1700079441070557, -4.470108509063721, -5.586302280426025, 0.0, 0.0, 0.0, -10.826986312866211, -0.0, -9.740870475769043, -11.56438159942627, -10.786699295043945, -11.702716827392578, -11.400392532348633, -10.03183650970459, -11.14425277709961, -10.500127792358398, -9.638830184936523, -9.786473274230957, -8.907136917114258, -8.208894729614258, -6.731061935424805, -6.907516956329346, -6.835052967071533, -5.506246089935303, -7.429502487182617, -6.491489887237549, -5.0030131340026855, -4.269479274749756, -6.03414249420166, -6.407447814941406, -6.7358856201171875, -4.753684997558594, -5.740441799163818, -7.43879508972168, -6.496297836303711, -7.199785232543945, -8.24837589263916, -8.691283226013184, -9.136032104492188, -8.964066505432129, -6.630338668823242, -8.733664512634277, -8.441474914550781, -10.208495140075684, -9.400078773498535, -9.250847816467285, -9.65723991394043, -9.650065422058105, -9.601266860961914, -9.357470512390137, -8.686964988708496, -8.657340049743652, -8.927635192871094, -6.138442516326904, -5.793661594390869, -4.705766201019287, -4.829814434051514, -6.2351837158203125, -3.516511917114258, -3.476250648498535, -3.824951410293579, -2.9522287845611572, -2.6769070625305176, -3.0694198608398438, -2.1607325077056885, -1.5875333547592163, -1.9485255479812622, -1.5678836107254028, -0.7994444370269775, -0.5130563378334045, -0.952663004398346, -1.0799715518951416, -0.6555581092834473, -1.9432448148727417, -0.6421813368797302, -1.6670955419540405, -1.389085054397583, -2.2744252681732178, -3.1700079441070557, -4.470108509063721, -5.586302280426025, -0.0, -0.0, -0.0], [-14.089801788330078, 0.0, 0.0, -14.250142097473145, -11.548876762390137, -11.247806549072266, -11.212626457214355, -10.80452823638916, -10.751047134399414, -10.501530647277832, -9.855929374694824, -8.762333869934082, -8.928165435791016, -7.546258926391602, -5.796416282653809, -7.938631534576416, -6.420795440673828, -6.5630011558532715, -5.023542881011963, -6.750974178314209, -6.0618896484375, -6.695250511169434, -6.090656757354736, -5.721896648406982, -6.157229423522949, -6.430922985076904, -7.521083831787109, -6.76569938659668, -9.867514610290527, -7.716897964477539, -9.229572296142578, -9.109941482543945, -8.674805641174316, -9.993890762329102, -10.164772033691406, -11.023833274841309, -10.487448692321777, -10.189580917358398, -12.42138671875, -9.677057266235352, -11.975125312805176, -14.007365226745605, -10.940779685974121, -11.840340614318848, -9.847476959228516, -8.633552551269531, -10.33790111541748, -7.3104166984558105, -9.425054550170898, -6.850863456726074, -5.917910575866699, -7.0353264808654785, -3.158358335494995, -4.200146675109863, -3.5269076824188232, -4.634066104888916, -3.5082321166992188, -3.4758105278015137, -2.9457015991210938, -1.9751049280166626, -1.9987410306930542, -1.391174077987671, -2.3462095260620117, -1.121253490447998, -0.3669043183326721, -0.8850340843200684, -1.0079036951065063, -1.0880334377288818, -2.3116462230682373, -2.107630729675293, -2.4794743061065674, -2.949453592300415, -2.900620222091675, -4.6224365234375, -5.631153106689453, 0.0, 0.0, 0.2729696035385132, -14.089801788330078, -0.0, -0.0, -14.250142097473145, -11.548876762390137, -11.247806549072266, -11.212626457214355, -10.80452823638916, -10.751047134399414, -10.501530647277832, -9.855929374694824, -8.762333869934082, -8.928165435791016, -7.546258926391602, -5.796416282653809, -7.938631534576416, -6.420795440673828, -6.5630011558532715, -5.023542881011963, -6.750974178314209, -6.0618896484375, -6.695250511169434, -6.090656757354736, -5.721896648406982, -6.157229423522949, -6.430922985076904, -7.521083831787109, -6.76569938659668, -9.867514610290527, -7.716897964477539, -9.229572296142578, -9.109941482543945, -8.674805641174316, -9.993890762329102, -10.164772033691406, -11.023833274841309, -10.487448692321777, -10.189580917358398, -12.42138671875, -9.677057266235352, -11.975125312805176, -14.007365226745605, -10.940779685974121, -11.840340614318848, -9.847476959228516, -8.633552551269531, -10.33790111541748, -7.3104166984558105, -9.425054550170898, -6.850863456726074, -5.917910575866699, -7.0353264808654785, -3.158358335494995, -4.200146675109863, -3.5269076824188232, -4.634066104888916, -3.5082321166992188, -3.4758105278015137, -2.9457015991210938, -1.9751049280166626, -1.9987410306930542, -1.391174077987671, -2.3462095260620117, -1.121253490447998, -0.3669043183326721, -0.8850340843200684, -1.0079036951065063, -1.0880334377288818, -2.3116462230682373, -2.107630729675293, -2.4794743061065674, -2.949453592300415, -2.900620222091675, -4.6224365234375, -5.631153106689453, -0.0, -0.0, 0.2729696035385132], [-14.042360305786133, 0.0, 0.0, -16.651216506958008, -11.645888328552246, -11.378730773925781, -11.652010917663574, -11.194439888000488, -11.598522186279297, -9.611214637756348, -8.014686584472656, -9.638543128967285, -9.356878280639648, -8.010152816772461, -7.922905445098877, 0.0, -6.255112648010254, -6.750431060791016, -6.418919563293457, -5.560338020324707, -6.749694347381592, -6.936980724334717, -5.556616306304932, -6.2235541343688965, -7.086750507354736, -8.389232635498047, -6.851708889007568, -9.011366844177246, -8.610272407531738, -8.048494338989258, -8.50298023223877, -9.446399688720703, -10.666251182556152, -9.14291000366211, -10.554659843444824, -12.065970420837402, -12.157068252563477, -11.406218528747559, -11.563691139221191, -11.032182693481445, -12.560866355895996, -12.223118782043457, -11.729141235351562, -11.458271980285645, -11.197614669799805, -9.023982048034668, -9.572090148925781, -9.221677780151367, -8.899737358093262, -7.168929100036621, -6.954109191894531, -4.716909408569336, -5.035099983215332, -4.218559265136719, -4.3187255859375, -5.138779640197754, -4.256723880767822, -0.8763545751571655, -2.442397117614746, -2.3237814903259277, -1.8645373582839966, -2.2618420124053955, -0.784138560295105, -0.994259774684906, -1.2166013717651367, -0.9728170037269592, -1.4494599103927612, -1.1696431636810303, -1.151213526725769, -2.106387138366699, -3.042675495147705, -2.717447280883789, -4.722528457641602, -4.801516532897949, -5.793187141418457, 0.0, 0.0, -0.3706229031085968, -14.042360305786133, -0.0, -0.0, -16.651216506958008, -11.645888328552246, -11.378730773925781, -11.652010917663574, -11.194439888000488, -11.598522186279297, -9.611214637756348, -8.014686584472656, -9.638543128967285, -9.356878280639648, -8.010152816772461, -7.922905445098877, -0.0, -6.255112648010254, -6.750431060791016, -6.418919563293457, -5.560338020324707, -6.749694347381592, -6.936980724334717, -5.556616306304932, -6.2235541343688965, -7.086750507354736, -8.389232635498047, -6.851708889007568, -9.011366844177246, -8.610272407531738, -8.048494338989258, -8.50298023223877, -9.446399688720703, -10.666251182556152, -9.14291000366211, -10.554659843444824, -12.065970420837402, -12.157068252563477, -11.406218528747559, -11.563691139221191, -11.032182693481445, -12.560866355895996, -12.223118782043457, -11.729141235351562, -11.458271980285645, -11.197614669799805, -9.023982048034668, -9.572090148925781, -9.221677780151367, -8.899737358093262, -7.168929100036621, -6.954109191894531, -4.716909408569336, -5.035099983215332, -4.218559265136719, -4.3187255859375, -5.138779640197754, -4.256723880767822, -0.8763545751571655, -2.442397117614746, -2.3237814903259277, -1.8645373582839966, -2.2618420124053955, -0.784138560295105, -0.994259774684906, -1.2166013717651367, -0.9728170037269592, -1.4494599103927612, -1.1696431636810303, -1.151213526725769, -2.106387138366699, -3.042675495147705, -2.717447280883789, -4.722528457641602, -4.801516532897949, -5.793187141418457, -0.0, -0.0, -0.3706229031085968], [-15.00172233581543, 0.0, 0.0, -13.53239631652832, -12.450565338134766, -11.87001895904541, -10.957918167114258, -11.370635032653809, -11.344903945922852, -10.171009063720703, -9.115209579467773, -8.87038803100586, -9.124502182006836, -7.995803356170654, -7.789120197296143, -7.143202304840088, -7.948290824890137, -6.642091274261475, -7.083209037780762, -6.251166820526123, -5.414766311645508, -6.877755641937256, -5.802762985229492, -7.296116352081299, -6.34545373916626, -7.5502028465271, -8.270955085754395, -8.491599082946777, -9.079805374145508, -8.835598945617676, -8.952619552612305, -10.265180587768555, -10.489214897155762, -11.090025901794434, -10.941877365112305, -11.398059844970703, -11.517428398132324, -12.339213371276855, -13.844776153564453, -12.839417457580566, -13.308713912963867, -13.690347671508789, -13.45455265045166, -11.90551471710205, -11.787301063537598, -10.305587768554688, -8.439684867858887, -11.983682632446289, -7.09902811050415, -7.941307544708252, -7.782260894775391, -6.853457450866699, -6.64224910736084, -3.42950439453125, -4.059676647186279, -4.116358757019043, -3.5653557777404785, -2.508592367172241, -3.5727615356445312, -1.4697386026382446, -2.7909905910491943, -2.758038282394409, -1.448397159576416, -1.0854833126068115, -1.4855234622955322, -1.5303961038589478, -1.719560980796814, -1.8987327814102173, -1.4631186723709106, -1.9609705209732056, -2.934972047805786, -2.6611952781677246, -4.296317100524902, -5.118200302124023, 0.0, 0.0, 0.0, -0.22457323968410492, -15.00172233581543, -0.0, -0.0, -13.53239631652832, -12.450565338134766, -11.87001895904541, -10.957918167114258, -11.370635032653809, -11.344903945922852, -10.171009063720703, -9.115209579467773, -8.87038803100586, -9.124502182006836, -7.995803356170654, -7.789120197296143, -7.143202304840088, -7.948290824890137, -6.642091274261475, -7.083209037780762, -6.251166820526123, -5.414766311645508, -6.877755641937256, -5.802762985229492, -7.296116352081299, -6.34545373916626, -7.5502028465271, -8.270955085754395, -8.491599082946777, -9.079805374145508, -8.835598945617676, -8.952619552612305, -10.265180587768555, -10.489214897155762, -11.090025901794434, -10.941877365112305, -11.398059844970703, -11.517428398132324, -12.339213371276855, -13.844776153564453, -12.839417457580566, -13.308713912963867, -13.690347671508789, -13.45455265045166, -11.90551471710205, -11.787301063537598, -10.305587768554688, -8.439684867858887, -11.983682632446289, -7.09902811050415, -7.941307544708252, -7.782260894775391, -6.853457450866699, -6.64224910736084, -3.42950439453125, -4.059676647186279, -4.116358757019043, -3.5653557777404785, -2.508592367172241, -3.5727615356445312, -1.4697386026382446, -2.7909905910491943, -2.758038282394409, -1.448397159576416, -1.0854833126068115, -1.4855234622955322, -1.5303961038589478, -1.719560980796814, -1.8987327814102173, -1.4631186723709106, -1.9609705209732056, -2.934972047805786, -2.6611952781677246, -4.296317100524902, -5.118200302124023, -0.0, -0.0, -0.0, -0.22457323968410492], [-15.685356140136719, -13.159192085266113, 0.0, 0.0, -13.472332954406738, -11.956311225891113, -11.547098159790039, -10.542091369628906, -11.121363639831543, -9.993341445922852, -9.697802543640137, -9.17526912689209, -8.06112003326416, -8.139421463012695, -8.021509170532227, -6.96432638168335, -7.6509833335876465, -7.185901641845703, -6.850008010864258, -6.77850341796875, -7.578800201416016, -6.582450866699219, -7.411903381347656, -8.17060375213623, -7.553829669952393, -8.747476577758789, -8.626696586608887, -8.264034271240234, -9.088053703308105, -9.407492637634277, -10.508705139160156, -10.893658638000488, -13.587374687194824, -12.284461975097656, -11.76066780090332, -12.028482437133789, -14.618639945983887, -14.843111991882324, -12.46218204498291, -15.442951202392578, -14.283596992492676, -14.962392807006836, -14.537171363830566, -14.006242752075195, -13.33193302154541, -10.719552040100098, -12.260907173156738, -9.771958351135254, -11.635452270507812, -9.143356323242188, -8.051399230957031, -7.801701068878174, -6.368001461029053, -6.127066612243652, -4.203862190246582, -4.184813499450684, -4.196943759918213, -3.726081609725952, -3.081857204437256, -3.297762870788574, -0.9720861911773682, -2.2322933673858643, -2.5886733531951904, -1.3060476779937744, -2.2305960655212402, -1.6733957529067993, -1.9715279340744019, -2.7055821418762207, -1.883421540260315, -2.277517318725586, -2.399229049682617, -2.364184856414795, -4.032927989959717, -5.211606979370117, 0.0, 0.0, -0.3965129256248474, 0.48076850175857544, -15.685356140136719, -13.159192085266113, -0.0, -0.0, -13.472332954406738, -11.956311225891113, -11.547098159790039, -10.542091369628906, -11.121363639831543, -9.993341445922852, -9.697802543640137, -9.17526912689209, -8.06112003326416, -8.139421463012695, -8.021509170532227, -6.96432638168335, -7.6509833335876465, -7.185901641845703, -6.850008010864258, -6.77850341796875, -7.578800201416016, -6.582450866699219, -7.411903381347656, -8.17060375213623, -7.553829669952393, -8.747476577758789, -8.626696586608887, -8.264034271240234, -9.088053703308105, -9.407492637634277, -10.508705139160156, -10.893658638000488, -13.587374687194824, -12.284461975097656, -11.76066780090332, -12.028482437133789, -14.618639945983887, -14.843111991882324, -12.46218204498291, -15.442951202392578, -14.283596992492676, -14.962392807006836, -14.537171363830566, -14.006242752075195, -13.33193302154541, -10.719552040100098, -12.260907173156738, -9.771958351135254, -11.635452270507812, -9.143356323242188, -8.051399230957031, -7.801701068878174, -6.368001461029053, -6.127066612243652, -4.203862190246582, -4.184813499450684, -4.196943759918213, -3.726081609725952, -3.081857204437256, -3.297762870788574, -0.9720861911773682, -2.2322933673858643, -2.5886733531951904, -1.3060476779937744, -2.2305960655212402, -1.6733957529067993, -1.9715279340744019, -2.7055821418762207, -1.883421540260315, -2.277517318725586, -2.399229049682617, -2.364184856414795, -4.032927989959717, -5.211606979370117, -0.0, -0.0, -0.3965129256248474, 0.48076850175857544], [-16.278507232666016, -14.771876335144043, 0.0, 0.0, -13.571600914001465, -12.487850189208984, -11.913250923156738, -11.425570487976074, -10.44066047668457, -9.846390724182129, -9.834784507751465, -9.642769813537598, -9.08853530883789, -8.150506019592285, -8.46989631652832, -8.157896041870117, -7.004252910614014, -7.030486583709717, -7.881129264831543, -7.114565849304199, -7.898401260375977, -7.177703857421875, -7.572512626647949, -7.4880452156066895, -7.7360734939575195, -8.195713996887207, -9.05390453338623, -10.12995433807373, -10.690244674682617, -13.270487785339355, -11.487102508544922, -13.4243803024292, -13.068498611450195, -13.888470649719238, -14.768620491027832, -12.445701599121094, -13.799261093139648, -15.275217056274414, -15.670758247375488, -16.22759246826172, -16.625181198120117, -16.277746200561523, -16.391189575195312, -14.921420097351074, -14.425663948059082, -15.958869934082031, -12.923321723937988, -11.936810493469238, -12.586865425109863, -9.931710243225098, -8.314741134643555, -8.796116828918457, -6.490787029266357, -6.556037425994873, -6.038149833679199, -5.0634446144104, -4.91825532913208, -4.993825435638428, -3.6837024688720703, -3.6808154582977295, -3.3128466606140137, -2.6954421997070312, -2.208590269088745, -1.39640212059021, -1.8892416954040527, -2.1576085090637207, -2.2701001167297363, -2.008932590484619, -2.8401734828948975, -2.3463683128356934, -2.4076714515686035, -2.961167812347412, -3.884883165359497, -5.3165388107299805, 0.0, 0.0, 2.032898426055908, 1.9465886354446411, -16.278507232666016, -14.771876335144043, -0.0, -0.0, -13.571600914001465, -12.487850189208984, -11.913250923156738, -11.425570487976074, -10.44066047668457, -9.846390724182129, -9.834784507751465, -9.642769813537598, -9.08853530883789, -8.150506019592285, -8.46989631652832, -8.157896041870117, -7.004252910614014, -7.030486583709717, -7.881129264831543, -7.114565849304199, -7.898401260375977, -7.177703857421875, -7.572512626647949, -7.4880452156066895, -7.7360734939575195, -8.195713996887207, -9.05390453338623, -10.12995433807373, -10.690244674682617, -13.270487785339355, -11.487102508544922, -13.4243803024292, -13.068498611450195, -13.888470649719238, -14.768620491027832, -12.445701599121094, -13.799261093139648, -15.275217056274414, -15.670758247375488, -16.22759246826172, -16.625181198120117, -16.277746200561523, -16.391189575195312, -14.921420097351074, -14.425663948059082, -15.958869934082031, -12.923321723937988, -11.936810493469238, -12.586865425109863, -9.931710243225098, -8.314741134643555, -8.796116828918457, -6.490787029266357, -6.556037425994873, -6.038149833679199, -5.0634446144104, -4.91825532913208, -4.993825435638428, -3.6837024688720703, -3.6808154582977295, -3.3128466606140137, -2.6954421997070312, -2.208590269088745, -1.39640212059021, -1.8892416954040527, -2.1576085090637207, -2.2701001167297363, -2.008932590484619, -2.8401734828948975, -2.3463683128356934, -2.4076714515686035, -2.961167812347412, -3.884883165359497, -5.3165388107299805, -0.0, 0.0, 2.032898426055908, 1.9465886354446411], [-18.025659561157227, -14.30298900604248, -14.225069999694824, 0.0, -17.15353775024414, -13.190889358520508, -11.783899307250977, -11.545709609985352, -10.918944358825684, -10.75074577331543, -9.94477653503418, -10.150593757629395, -8.407637596130371, -8.941577911376953, -8.946545600891113, -7.976062774658203, -7.29771089553833, -6.745480060577393, -7.525995254516602, -7.511448860168457, -7.894805431365967, -8.422849655151367, -7.580154895782471, -8.515591621398926, -6.996379375457764, -8.79222297668457, -10.546185493469238, -10.70107364654541, -11.60447883605957, -10.365839004516602, -14.682589530944824, -15.325292587280273, -14.104422569274902, -15.39492416381836, -18.23206901550293, -14.75804615020752, -17.300485610961914, -18.356182098388672, -16.644315719604492, -18.217453002929688, -16.687829971313477, -15.962316513061523, -17.055479049682617, -16.9583683013916, -16.461923599243164, -15.219388961791992, -14.685202598571777, -15.36845874786377, -12.917003631591797, -12.586307525634766, -11.030882835388184, -10.124683380126953, -7.699376106262207, -8.149560928344727, -5.953985691070557, -4.847350597381592, -5.517613410949707, -4.51126766204834, -4.571192741394043, -4.1027045249938965, -2.820270538330078, -3.0504446029663086, -1.6114625930786133, -2.184817314147949, -2.1553750038146973, -1.8001154661178589, -2.2555627822875977, -2.4852824211120605, -2.6466643810272217, -2.7810146808624268, -3.0215675830841064, -2.7232959270477295, -3.5277392864227295, 0.0, 0.0, 2.2209060192108154, 1.3331819772720337, 2.6554293632507324, -18.025659561157227, -14.30298900604248, -14.225069999694824, -0.0, -17.15353775024414, -13.190889358520508, -11.783899307250977, -11.545709609985352, -10.918944358825684, -10.75074577331543, -9.94477653503418, -10.150593757629395, -8.407637596130371, -8.941577911376953, -8.946545600891113, -7.976062774658203, -7.29771089553833, -6.745480060577393, -7.525995254516602, -7.511448860168457, -7.894805431365967, -8.422849655151367, -7.580154895782471, -8.515591621398926, -6.996379375457764, -8.79222297668457, -10.546185493469238, -10.70107364654541, -11.60447883605957, -10.365839004516602, -14.682589530944824, -15.325292587280273, -14.104422569274902, -15.39492416381836, -18.23206901550293, -14.75804615020752, -17.300485610961914, -18.356182098388672, -16.644315719604492, -18.217453002929688, -16.687829971313477, -15.962316513061523, -17.055479049682617, -16.9583683013916, -16.461923599243164, -15.219388961791992, -14.685202598571777, -15.36845874786377, -12.917003631591797, -12.586307525634766, -11.030882835388184, -10.124683380126953, -7.699376106262207, -8.149560928344727, -5.953985691070557, -4.847350597381592, -5.517613410949707, -4.51126766204834, -4.571192741394043, -4.1027045249938965, -2.820270538330078, -3.0504446029663086, -1.6114625930786133, -2.184817314147949, -2.1553750038146973, -1.8001154661178589, -2.2555627822875977, -2.4852824211120605, -2.6466643810272217, -2.7810146808624268, -3.0215675830841064, -2.7232959270477295, -3.5277392864227295, -0.0, 0.0, 2.2209060192108154, 1.3331819772720337, 2.6554293632507324], [-18.596590042114258, -15.618781089782715, -14.509835243225098, 0.0, 0.0, -14.485811233520508, -13.132576942443848, -11.070454597473145, -11.461865425109863, -10.252557754516602, -10.513916969299316, -9.608853340148926, -9.514595985412598, -9.22777271270752, -8.512651443481445, -7.484778881072998, -7.701037406921387, -7.389544486999512, -7.325343132019043, -8.58287239074707, -8.336920738220215, -8.244248390197754, -7.4799485206604, -9.378667831420898, -8.378583908081055, -6.9725847244262695, -8.633949279785156, -11.813213348388672, -11.546341896057129, -12.739945411682129, -13.751070976257324, 0.0, -14.719427108764648, -17.493534088134766, -17.906478881835938, -18.209827423095703, -19.687801361083984, -18.182710647583008, -21.05567169189453, -22.48927116394043, -21.335689544677734, -19.914310455322266, -20.265026092529297, -18.461633682250977, -17.84925651550293, -16.628095626831055, -16.03102684020996, -15.17128849029541, -14.742110252380371, -14.71996784210205, -11.01456356048584, -9.590846061706543, -8.277846336364746, -8.248493194580078, -6.951613426208496, -7.978976249694824, -5.849130630493164, -5.26983118057251, -5.133393287658691, -3.628473997116089, -4.511002063751221, -2.6528995037078857, -3.0665411949157715, -2.832298994064331, -2.855980157852173, -2.5798909664154053, -2.5199923515319824, -2.496823310852051, -2.5650737285614014, -2.5520875453948975, -1.6170117855072021, -1.9235708713531494, 0.0, 0.0, 0.0, 2.63559889793396, 2.3459606170654297, 2.437390089035034, -18.596590042114258, -15.618781089782715, -14.509835243225098, -0.0, -0.0, -14.485811233520508, -13.132576942443848, -11.070454597473145, -11.461865425109863, -10.252557754516602, -10.513916969299316, -9.608853340148926, -9.514595985412598, -9.22777271270752, -8.512651443481445, -7.484778881072998, -7.701037406921387, -7.389544486999512, -7.325343132019043, -8.58287239074707, -8.336920738220215, -8.244248390197754, -7.4799485206604, -9.378667831420898, -8.378583908081055, -6.9725847244262695, -8.633949279785156, -11.813213348388672, -11.546341896057129, -12.739945411682129, -13.751070976257324, -0.0, -14.719427108764648, -17.493534088134766, -17.906478881835938, -18.209827423095703, -19.687801361083984, -18.182710647583008, -21.05567169189453, -22.48927116394043, -21.335689544677734, -19.914310455322266, -20.265026092529297, -18.461633682250977, -17.84925651550293, -16.628095626831055, -16.03102684020996, -15.17128849029541, -14.742110252380371, -14.71996784210205, -11.01456356048584, -9.590846061706543, -8.277846336364746, -8.248493194580078, -6.951613426208496, -7.978976249694824, -5.849130630493164, -5.26983118057251, -5.133393287658691, -3.628473997116089, -4.511002063751221, -2.6528995037078857, -3.0665411949157715, -2.832298994064331, -2.855980157852173, -2.5798909664154053, -2.5199923515319824, -2.496823310852051, -2.5650737285614014, -2.5520875453948975, -1.6170117855072021, -1.9235708713531494, -0.0, -0.0, 0.0, 2.63559889793396, 2.3459606170654297, 2.437390089035034], [-18.30720329284668, -16.45279312133789, -15.694869041442871, 0.0, 0.0, 0.0, -12.551243782043457, -11.477139472961426, -11.45607852935791, -10.608222007751465, -10.451568603515625, -9.716477394104004, -9.25847053527832, -8.906388282775879, -8.656537055969238, -8.306051254272461, -7.736302852630615, -8.062361717224121, -7.618191719055176, -7.854055404663086, -8.956744194030762, -8.693108558654785, -8.525479316711426, -9.037017822265625, -8.402201652526855, -7.9270405769348145, -10.288077354431152, -11.675408363342285, -12.719518661499023, -12.5525541305542, -14.987222671508789, -15.983229637145996, -15.137948989868164, -18.03226089477539, -18.268436431884766, -18.84473991394043, -20.12995147705078, -19.50702476501465, 0.0, 0.0, -21.2286434173584, -20.098533630371094, -20.914194107055664, -21.906665802001953, -19.509740829467773, -18.648439407348633, -17.193405151367188, -15.920537948608398, -14.765429496765137, -13.215069770812988, -13.397216796875, -12.461304664611816, -11.04803466796875, -9.255351066589355, -8.492734909057617, -7.327093124389648, -6.585105895996094, -5.965078830718994, -4.519073009490967, -4.83595609664917, -3.903503656387329, -4.121848106384277, -3.8700461387634277, -2.710906982421875, -3.1440510749816895, -2.8181591033935547, -2.8427538871765137, -2.0659379959106445, -2.7532105445861816, -1.8826707601547241, -1.3328776359558105, -0.46803849935531616, 0.0, 0.0, 0.0, 2.773726463317871, 2.4518439769744873, 1.1111838817596436, -18.30720329284668, -16.45279312133789, -15.694869041442871, -0.0, -0.0, -0.0, -12.551243782043457, -11.477139472961426, -11.45607852935791, -10.608222007751465, -10.451568603515625, -9.716477394104004, -9.25847053527832, -8.906388282775879, -8.656537055969238, -8.306051254272461, -7.736302852630615, -8.062361717224121, -7.618191719055176, -7.854055404663086, -8.956744194030762, -8.693108558654785, -8.525479316711426, -9.037017822265625, -8.402201652526855, -7.9270405769348145, -10.288077354431152, -11.675408363342285, -12.719518661499023, -12.5525541305542, -14.987222671508789, -15.983229637145996, -15.137948989868164, -18.03226089477539, -18.268436431884766, -18.84473991394043, -20.12995147705078, -19.50702476501465, -0.0, -0.0, -21.2286434173584, -20.098533630371094, -20.914194107055664, -21.906665802001953, -19.509740829467773, -18.648439407348633, -17.193405151367188, -15.920537948608398, -14.765429496765137, -13.215069770812988, -13.397216796875, -12.461304664611816, -11.04803466796875, -9.255351066589355, -8.492734909057617, -7.327093124389648, -6.585105895996094, -5.965078830718994, -4.519073009490967, -4.83595609664917, -3.903503656387329, -4.121848106384277, -3.8700461387634277, -2.710906982421875, -3.1440510749816895, -2.8181591033935547, -2.8427538871765137, -2.0659379959106445, -2.7532105445861816, -1.8826707601547241, -1.3328776359558105, -0.46803849935531616, -0.0, 0.0, 0.0, 2.773726463317871, 2.4518439769744873, 1.1111838817596436], [-18.381942749023438, -17.826175689697266, -16.564815521240234, -14.387924194335938, 0.0, 0.0, -11.32290267944336, -11.189262390136719, -11.101088523864746, -10.663557052612305, -10.257552146911621, -9.721830368041992, -9.699705123901367, -8.512354850769043, -9.00820541381836, -8.763853073120117, -8.94271183013916, -8.147387504577637, -7.909351825714111, -8.20876407623291, -8.409944534301758, -10.071065902709961, -9.16315746307373, -10.522406578063965, -9.572423934936523, -11.177451133728027, -11.288256645202637, -11.994821548461914, -13.854098320007324, -14.386740684509277, -16.272857666015625, -17.072168350219727, -17.532285690307617, -19.231142044067383, -20.117393493652344, -22.81220817565918, -21.9781494140625, -22.85296058654785, 0.0, 0.0, -23.74172592163086, -22.591455459594727, -23.3880558013916, -23.34511375427246, -21.8387451171875, -20.102323532104492, -18.98733901977539, -17.47016716003418, -16.41812515258789, -15.079805374145508, -14.744182586669922, -13.256023406982422, -10.77890396118164, -9.48474407196045, -8.882567405700684, -7.455356597900391, -7.646383285522461, -7.783709526062012, -5.458255767822266, -4.938559532165527, -5.077123641967773, -4.1286773681640625, -4.357218265533447, -3.510014772415161, -2.8682563304901123, -2.7575502395629883, -2.6525962352752686, -2.5103235244750977, -1.9369438886642456, -0.9499242305755615, -0.8915401101112366, 0.0, 0.0, 0.0, 3.154010057449341, 3.2376720905303955, 2.130155563354492, -0.34395596385002136, -18.381942749023438, -17.826175689697266, -16.564815521240234, -14.387924194335938, -0.0, -0.0, -11.32290267944336, -11.189262390136719, -11.101088523864746, -10.663557052612305, -10.257552146911621, -9.721830368041992, -9.699705123901367, -8.512354850769043, -9.00820541381836, -8.763853073120117, -8.94271183013916, -8.147387504577637, -7.909351825714111, -8.20876407623291, -8.409944534301758, -10.071065902709961, -9.16315746307373, -10.522406578063965, -9.572423934936523, -11.177451133728027, -11.288256645202637, -11.994821548461914, -13.854098320007324, -14.386740684509277, -16.272857666015625, -17.072168350219727, -17.532285690307617, -19.231142044067383, -20.117393493652344, -22.81220817565918, -21.9781494140625, -22.85296058654785, -0.0, -0.0, -23.74172592163086, -22.591455459594727, -23.3880558013916, -23.34511375427246, -21.8387451171875, -20.102323532104492, -18.98733901977539, -17.47016716003418, -16.41812515258789, -15.079805374145508, -14.744182586669922, -13.256023406982422, -10.77890396118164, -9.48474407196045, -8.882567405700684, -7.455356597900391, -7.646383285522461, -7.783709526062012, -5.458255767822266, -4.938559532165527, -5.077123641967773, -4.1286773681640625, -4.357218265533447, -3.510014772415161, -2.8682563304901123, -2.7575502395629883, -2.6525962352752686, -2.5103235244750977, -1.9369438886642456, -0.9499242305755615, -0.8915401101112366, -0.0, -0.0, 0.0, 3.154010057449341, 3.2376720905303955, 2.130155563354492, -0.34395596385002136], [-18.818912506103516, -16.840167999267578, -17.187480926513672, -15.635286331176758, 0.0, 0.0, -10.279126167297363, -10.632329940795898, -10.952680587768555, -10.509028434753418, -10.225872993469238, -9.923675537109375, -9.708595275878906, -9.930665016174316, -9.059788703918457, -8.36965274810791, -8.916683197021484, -8.73282527923584, -7.806283950805664, -9.198126792907715, -9.146920204162598, -8.89665412902832, -9.9909029006958, -8.795295715332031, -10.54003620147705, -11.679657936096191, -12.670072555541992, -12.610037803649902, -13.354701042175293, -17.761493682861328, -16.027563095092773, -17.178543090820312, -18.25109100341797, -21.755006790161133, -22.70846939086914, -22.770002365112305, -23.0212459564209, -24.80588150024414, -27.85748863220215, -26.234981536865234, -26.045969009399414, -24.880935668945312, -22.77928352355957, -24.061710357666016, -23.651105880737305, -22.062278747558594, -20.814069747924805, -18.594087600708008, -18.083568572998047, -15.679200172424316, -15.769216537475586, -12.81331729888916, -13.001742362976074, -9.829523086547852, -10.224079132080078, -9.105507850646973, -7.482913970947266, -7.765348434448242, -6.9331746101379395, -5.943235874176025, -4.121623992919922, -4.484800338745117, -4.9834489822387695, -5.136783599853516, -3.394522190093994, -3.2339725494384766, -2.7578237056732178, -2.7048747539520264, -1.6057933568954468, -1.1328057050704956, -2.8437817096710205, 0.0, 0.0, 4.083518981933594, 3.5937836170196533, 4.883324146270752, 2.3432860374450684, 1.2481300830841064, -18.818912506103516, -16.840167999267578, -17.187480926513672, -15.635286331176758, -0.0, -0.0, -10.279126167297363, -10.632329940795898, -10.952680587768555, -10.509028434753418, -10.225872993469238, -9.923675537109375, -9.708595275878906, -9.930665016174316, -9.059788703918457, -8.36965274810791, -8.916683197021484, -8.73282527923584, -7.806283950805664, -9.198126792907715, -9.146920204162598, -8.89665412902832, -9.9909029006958, -8.795295715332031, -10.54003620147705, -11.679657936096191, -12.340639114379883, -12.82409954071045, -13.676526069641113, -16.953079223632812, -16.219343185424805, -17.440704345703125, -18.53083038330078, -21.279375076293945, -22.312211990356445, -22.77884864807129, -23.373241424560547, -24.818988800048828, -26.977705001831055, -26.011104583740234, -25.72761344909668, -24.751401901245117, -23.150192260742188, -23.766437530517578, -23.223896026611328, -21.866682052612305, -20.61166763305664, -18.649097442626953, -17.868112564086914, -15.808281898498535, -15.500712394714355, -12.969183921813965, -12.657685279846191, -10.224833488464355, -9.889223098754883, -9.105507850646973, -7.482913970947266, -7.765348434448242, -6.9331746101379395, -5.943235874176025, -4.121623992919922, -4.484800338745117, -4.9834489822387695, -5.136783599853516, -3.394522190093994, -3.2339725494384766, -2.7578237056732178, -2.7048747539520264, -1.6057933568954468, -1.1328057050704956, -2.8437817096710205, -0.0, 0.0, 4.083518981933594, 3.5937836170196533, 4.883324146270752, 2.3432860374450684, 1.2481300830841064], [-18.64521026611328, -17.960346221923828, -17.197601318359375, -15.561182975769043, -16.802867889404297, 0.0, 0.0, -13.51194953918457, -10.398419380187988, -10.597673416137695, -10.20954704284668, -9.0139741897583, -9.941884994506836, -9.232383728027344, -9.875431060791016, -9.309091567993164, -9.355091094970703, -9.791868209838867, -9.151529312133789, -8.912627220153809, -8.639740943908691, -9.922496795654297, -10.525954246520996, -8.972890853881836, -10.221639633178711, -12.00092887878418, -12.103301048278809, -14.287300109863281, -14.807435035705566, -16.979480743408203, -18.644296646118164, -17.48680305480957, -22.619102478027344, -22.9315185546875, -23.9139461517334, -24.534568786621094, -26.87997055053711, -24.900766372680664, -28.16691017150879, -28.1108455657959, -27.629953384399414, -25.965551376342773, -27.83317756652832, -26.318645477294922, -25.21856689453125, -24.838815689086914, -22.638273239135742, -23.18575096130371, -19.973308563232422, -18.117639541625977, -16.789527893066406, -14.832216262817383, -13.91176986694336, -11.52741527557373, -10.302760124206543, -9.694648742675781, -7.876471996307373, -8.081880569458008, -7.364134788513184, -6.619648456573486, -6.070415019989014, -4.842748641967773, -5.580621719360352, -5.0465497970581055, -4.019224166870117, 0.0, -2.6787896156311035, -1.8164607286453247, -1.049912929534912, -0.8767436742782593, 0.0, 0.0, 3.4411027431488037, 4.135524749755859, 3.700732469558716, 2.231975555419922, 2.0746564865112305, 1.7995485067367554, -18.64521026611328, -17.960346221923828, -17.197601318359375, -15.561182975769043, -16.802867889404297, -0.0, -0.0, -13.51194953918457, -10.398419380187988, -10.597673416137695, -10.20954704284668, -9.0139741897583, -9.941884994506836, -9.232383728027344, -9.875431060791016, -9.309091567993164, -9.355091094970703, -9.791868209838867, -9.151529312133789, -8.912627220153809, -8.639740943908691, -9.922496795654297, -10.525954246520996, -8.972890853881836, -10.221639633178711, -12.00092887878418, -12.375088691711426, -13.605599403381348, -14.901410102844238, -16.536149978637695, -17.46430206298828, -18.792253494262695, -20.38477897644043, -22.19905662536621, -23.51172637939453, -24.476451873779297, -25.418678283691406, -26.55156707763672, -27.53319549560547, -27.473630905151367, -26.863996505737305, -26.088747024536133, -25.287729263305664, -24.93844985961914, -24.284915924072266, -23.184062957763672, -21.825918197631836, -20.29934310913086, -18.93387794494629, -17.400177001953125, -15.971001625061035, -14.211252212524414, -12.879623413085938, -11.353340148925781, -10.252253532409668, -9.694648742675781, -7.876471996307373, -8.081880569458008, -7.364134788513184, -6.619648456573486, -6.070415019989014, -4.842748641967773, -5.580621719360352, -5.0465497970581055, -4.019224166870117, -0.0, -2.6787896156311035, -1.8164607286453247, -1.049912929534912, -0.8767436742782593, -0.0, 0.0, 3.4411027431488037, 4.135524749755859, 3.700732469558716, 2.231975555419922, 2.0746564865112305, 1.7995485067367554], [-19.24483871459961, -19.228796005249023, -16.693883895874023, -15.477859497070312, -14.942119598388672, 0.0, 0.0, 0.0, -11.18161392211914, -10.749037742614746, -10.43397045135498, -10.457369804382324, -9.589325904846191, -9.383034706115723, -8.666659355163574, -9.745989799499512, -9.46250057220459, -9.41595458984375, -9.127880096435547, -8.99892807006836, -9.085728645324707, -9.88416576385498, -10.538803100585938, -10.607791900634766, -11.727733612060547, -12.515191078186035, -13.598358154296875, -13.086786270141602, -15.251484870910645, -17.07830238342285, -20.24153709411621, -21.736730575561523, -23.430225372314453, -23.81881332397461, -24.594995498657227, -27.352603912353516, -30.950090408325195, -28.363142013549805, -25.551599502563477, -28.089075088500977, -28.832687377929688, -29.8210391998291, -28.25043296813965, -28.24138832092285, -28.205270767211914, -25.855098724365234, -24.672435760498047, -20.789371490478516, -22.59431266784668, -20.549875259399414, -17.423664093017578, -15.231168746948242, -13.59152889251709, -12.931975364685059, -10.55588436126709, -9.888764381408691, -9.71602725982666, -8.118315696716309, -8.032468795776367, -7.081625461578369, -7.260000705718994, -6.156607627868652, -7.2000274658203125, -4.383237361907959, -6.757277011871338, -1.7274377346038818, -1.9384582042694092, -1.7968097925186157, -1.2886710166931152, -3.223696231842041, -0.6996400952339172, 0.0, 7.217516899108887, 6.342301368713379, 4.463384628295898, 1.9205505847930908, 2.1590449810028076, 0.6034388542175293, -19.24483871459961, -19.228796005249023, -16.693883895874023, -15.477859497070312, -14.942119598388672, -0.0, -0.0, -0.0, -11.18161392211914, -10.749037742614746, -10.43397045135498, -10.457369804382324, -9.589325904846191, -9.383034706115723, -8.666659355163574, -9.745989799499512, -9.46250057220459, -9.41595458984375, -9.127880096435547, -8.99892807006836, -9.085728645324707, -9.88416576385498, -10.538803100585938, -10.607791900634766, -11.727733612060547, -12.515191078186035, -13.557703971862793, -14.452679634094238, -15.625725746154785, -16.866031646728516, -18.3018856048584, -19.992197036743164, -21.800539016723633, -23.386363983154297, -24.836267471313477, -26.090818405151367, -27.17328643798828, -28.0419921875, -28.472537994384766, -28.263967514038086, -27.757678985595703, -27.35312271118164, -26.851741790771484, -26.241239547729492, -25.45444107055664, -24.387908935546875, -23.044767379760742, -21.580707550048828, -20.055965423583984, -18.453805923461914, -16.701080322265625, -15.034125328063965, -13.488755226135254, -12.085046768188477, -10.671433448791504, -9.888764381408691, -9.71602725982666, -8.118315696716309, -8.032468795776367, -7.081625461578369, -7.260000705718994, -6.156607627868652, -7.2000274658203125, -4.383237361907959, -6.757277011871338, -1.7274377346038818, -1.9384582042694092, -1.7968097925186157, -1.2886710166931152, -3.223696231842041, -0.6996400952339172, 0.0, 7.217516899108887, 6.342301368713379, 4.463384628295898, 1.9205505847930908, 2.1590449810028076, 0.6034388542175293], [-21.089380264282227, -16.914827346801758, -16.880126953125, -15.784958839416504, -15.472757339477539, -12.727081298828125, 0.0, 0.0, -9.099997520446777, -10.289034843444824, -10.383996963500977, -9.82911491394043, -10.31314468383789, -9.743748664855957, -9.151354789733887, -9.377480506896973, -10.090241432189941, -10.311159133911133, -9.480412483215332, -10.033672332763672, -9.73392105102539, -10.695243835449219, -11.475356101989746, -10.72150707244873, -12.249434471130371, -12.254287719726562, -13.639853477478027, -15.068289756774902, -16.149682998657227, -16.691261291503906, -22.536436080932617, -22.35051727294922, -26.08380126953125, -26.87662696838379, -27.135791778564453, -26.273412704467773, -29.683326721191406, -30.191791534423828, -28.949878692626953, -26.562225341796875, -31.569515228271484, -30.322492599487305, -30.040903091430664, -26.529754638671875, -27.571311950683594, -22.00916290283203, -26.10822296142578, -24.538013458251953, -23.195045471191406, -21.859039306640625, -16.97752571105957, -14.830512046813965, -14.469820976257324, -12.993680000305176, -11.694624900817871, -10.717010498046875, -11.54974365234375, -8.991031646728516, -8.068055152893066, -8.149892807006836, -7.374569416046143, -7.492431163787842, -3.3351705074310303, -1.1159753799438477, -1.620228886604309, -2.390529155731201, -2.115417718887329, -2.148209571838379, 0.0, 0.0, 0.0, 2.9501030445098877, 5.900162696838379, 4.628108501434326, 4.511499881744385, 3.077779531478882, -0.35487252473831177, 2.4789717197418213, -21.089380264282227, -16.914827346801758, -16.880126953125, -15.784958839416504, -15.472757339477539, -12.727081298828125, -0.0, -0.0, -9.099997520446777, -10.289034843444824, -10.383996963500977, -9.82911491394043, -10.31314468383789, -9.743748664855957, -9.151354789733887, -9.377480506896973, -10.090241432189941, -10.311159133911133, -9.480412483215332, -10.033672332763672, -9.73392105102539, -10.695243835449219, -11.475356101989746, -10.72150707244873, -12.249434471130371, -12.254287719726562, -13.840457916259766, -15.148746490478516, -16.25494956970215, -17.38359260559082, -18.92250633239746, -20.850849151611328, -22.853443145751953, -24.58259391784668, -26.154449462890625, -27.570344924926758, -28.6871280670166, -29.295156478881836, -29.159452438354492, -28.91652488708496, -28.826200485229492, -28.610984802246094, -28.20952796936035, -27.582136154174805, -26.729934692382812, -25.618391036987305, -24.25929832458496, -22.731830596923828, -21.072372436523438, -19.295373916625977, -17.47117042541504, -15.766773223876953, -14.235617637634277, -12.894461631774902, -11.66476058959961, -10.717010498046875, -11.54974365234375, -8.991031646728516, -8.068055152893066, -8.149892807006836, -7.374569416046143, -7.492431163787842, -3.3351705074310303, -1.1159753799438477, -1.620228886604309, -2.390529155731201, -2.115417718887329, -2.148209571838379, -0.0, -0.0, -0.0, 2.9501030445098877, 5.900162696838379, 4.628108501434326, 4.511499881744385, 3.077779531478882, -0.35487252473831177, 2.4789717197418213], [-19.357973098754883, 0.0, -16.252452850341797, -15.877796173095703, -15.54430103302002, -14.253179550170898, -14.227179527282715, 0.0, 0.0, -11.443050384521484, -10.15036392211914, -10.301283836364746, -10.191211700439453, -10.504727363586426, -10.290504455566406, -10.324434280395508, -10.513911247253418, -10.554058074951172, -10.217466354370117, -10.444887161254883, -9.93547248840332, -10.491976737976074, -12.035051345825195, -12.282780647277832, -12.859436988830566, -13.82034683227539, -15.58971881866455, -16.206897735595703, -16.747514724731445, -17.816085815429688, -21.00025749206543, -24.157920837402344, -26.541643142700195, -25.272550582885742, -28.936742782592773, -24.51158905029297, -26.353256225585938, -28.147626876831055, -28.952159881591797, -28.099720001220703, -30.021087646484375, -27.957651138305664, -25.67420768737793, -29.47455596923828, -25.422100067138672, -23.377971649169922, -21.7925968170166, -19.46651268005371, -23.05320930480957, -21.83018684387207, -16.377269744873047, -16.636842727661133, -14.313138961791992, -13.946928024291992, -12.761310577392578, -11.757550239562988, -11.243803024291992, -9.5576753616333, -8.031744956970215, -8.481071472167969, -8.143256187438965, -7.654752254486084, 0.0, 0.0, -2.91644549369812, -2.66473388671875, -3.2826812267303467, 0.0, 0.0, 0.0, 0.0, 5.88776969909668, 4.838476657867432, 3.99074649810791, 4.951406955718994, 1.83653724193573, 1.0642940998077393, -1.8485952615737915, -19.357973098754883, -0.0, -16.252452850341797, -15.877796173095703, -15.54430103302002, -14.253179550170898, -14.227179527282715, -0.0, -0.0, -11.443050384521484, -10.15036392211914, -10.301283836364746, -10.191211700439453, -10.504727363586426, -10.290504455566406, -10.324434280395508, -10.513911247253418, -10.554058074951172, -10.217466354370117, -10.444887161254883, -9.93547248840332, -10.491976737976074, -12.035051345825195, -12.282780647277832, -12.859436988830566, -13.82034683227539, -15.32558822631836, -16.01220703125, -16.939350128173828, -18.092737197875977, -19.615747451782227, -21.487363815307617, -23.57024383544922, -25.55022430419922, -27.296218872070312, -28.86486053466797, -29.99559211730957, -29.809814453125, -29.622234344482422, -29.833803176879883, -29.973705291748047, -29.885005950927734, -29.544879913330078, -28.94454002380371, -28.048368453979492, -26.872995376586914, -25.44277000427246, -23.813581466674805, -22.025596618652344, -20.129634857177734, -18.2536678314209, -16.528087615966797, -15.034443855285645, -13.76017951965332, -12.657596588134766, -11.757550239562988, -11.243803024291992, -9.5576753616333, -8.031744956970215, -8.481071472167969, -8.143256187438965, -7.654752254486084, -0.0, -0.0, -2.91644549369812, -2.66473388671875, -3.2826812267303467, -0.0, -0.0, 0.0, 0.0, 5.88776969909668, 4.838476657867432, 3.99074649810791, 4.951406955718994, 1.83653724193573, 1.0642940998077393, -1.8485952615737915], [-20.819408416748047, -20.3319091796875, -17.854007720947266, -16.681554794311523, -14.976552963256836, -14.220521926879883, -13.272635459899902, -11.874290466308594, 0.0, 0.0, -11.757275581359863, -11.051782608032227, -10.630773544311523, -10.620570182800293, -10.368632316589355, -8.884170532226562, -10.109910011291504, -10.591033935546875, -9.96973991394043, -10.815264701843262, -10.66784954071045, -11.037481307983398, -13.510015487670898, -13.536014556884766, -12.61439323425293, -14.675511360168457, -16.407005310058594, -16.10283851623535, -18.572751998901367, -18.799875259399414, -23.55721664428711, -24.36555290222168, -27.508686065673828, -23.829801559448242, -27.408092498779297, -28.76105499267578, -27.99030876159668, -26.72633934020996, -29.02318000793457, -30.742815017700195, -29.384597778320312, -26.54471206665039, -28.63689422607422, -28.682924270629883, -27.145488739013672, -22.330482482910156, -22.77837371826172, -23.082347869873047, -25.015302658081055, -23.499202728271484, -19.865402221679688, -19.573917388916016, -16.756654739379883, -15.160895347595215, -13.266735076904297, -14.206500053405762, -11.154162406921387, -9.971123695373535, -9.50800895690918, -11.889678001403809, -8.708210945129395, 0.0, 0.0, 0.0, -4.686432361602783, 0.0, -5.887032985687256, 0.0, 0.0, 0.0, 5.4508137702941895, 3.2956531047821045, 4.974302768707275, 4.609023094177246, 1.6137237548828125, 3.197323799133301, 0.6956979036331177, 0.0, -20.819408416748047, -20.3319091796875, -17.854007720947266, -16.681554794311523, -14.976552963256836, -14.220521926879883, -13.272635459899902, -11.874290466308594, -0.0, -0.0, -11.757275581359863, -11.051782608032227, -10.630773544311523, -10.620570182800293, -10.368632316589355, -8.884170532226562, -10.109910011291504, -10.591033935546875, -9.96973991394043, -10.815264701843262, -10.66784954071045, -11.037481307983398, -13.510015487670898, -13.536014556884766, -12.61439323425293, -14.675511360168457, -16.1186580657959, -16.82018280029297, -17.85395622253418, -18.954084396362305, -20.305076599121094, -22.082740783691406, -24.191621780395508, -26.30567741394043, -28.180496215820312, -29.819290161132812, -30.550418853759766, -30.156349182128906, -30.361087799072266, -30.900964736938477, -31.214651107788086, -31.21795082092285, -30.917142868041992, -30.312213897705078, -29.36678695678711, -28.106149673461914, -26.583637237548828, -24.86682891845703, -22.983501434326172, -21.00397300720215, -19.0693302154541, -17.33820343017578, -15.920051574707031, -14.675395965576172, -13.32399845123291, -14.206500053405762, -11.154162406921387, -9.971123695373535, -9.50800895690918, -11.889678001403809, -8.708210945129395, -0.0, -0.0, -0.0, -4.686432361602783, -0.0, -5.887032985687256, -0.0, 0.0, 0.0, 5.4508137702941895, 3.2956531047821045, 4.974302768707275, 4.609023094177246, 1.6137237548828125, 3.197323799133301, 0.6956979036331177, 0.0], [-22.729164123535156, -20.256975173950195, -18.621950149536133, -15.985346794128418, -15.784967422485352, -13.998748779296875, -13.441304206848145, -12.978339195251465, -12.447975158691406, 0.0, 0.0, -10.53649616241455, -11.28620433807373, -11.224663734436035, -11.089083671569824, -10.116511344909668, -9.608173370361328, -9.921430587768555, -10.175292015075684, -11.521252632141113, -11.717275619506836, -11.01087474822998, 0.0, -11.951312065124512, -17.054828643798828, -16.471073150634766, -15.645731925964355, -14.94442367553711, -18.34679412841797, -18.14780044555664, -22.009851455688477, -25.20221519470215, -28.370574951171875, -24.422271728515625, -25.264219284057617, -28.17807960510254, -25.67852020263672, -30.443513870239258, -31.641233444213867, -32.88759994506836, -31.416894912719727, -31.837535858154297, -32.035072326660156, -29.130876541137695, -28.357093811035156, -27.64452362060547, -25.6494197845459, -22.803115844726562, -23.518938064575195, -19.797056198120117, -20.136497497558594, -19.923315048217773, -17.121383666992188, -15.639884948730469, -14.766444206237793, -13.485453605651855, -12.753697395324707, -13.030633926391602, -8.920368194580078, -8.316848754882812, -6.393932342529297, 0.0, 0.0, 0.0, 0.0, -2.5368123054504395, 0.0, 0.0, 0.0, 3.851996421813965, 4.832467079162598, 4.60662317276001, 3.4663853645324707, 2.4216153621673584, 4.443277835845947, -0.21296967566013336, 2.1491963863372803, 0.0, -22.729164123535156, -20.256975173950195, -18.621950149536133, -15.985346794128418, -15.784967422485352, -13.998748779296875, -13.441304206848145, -12.978339195251465, -12.447975158691406, -0.0, -0.0, -10.53649616241455, -11.28620433807373, -11.224663734436035, -11.089083671569824, -10.116511344909668, -9.608173370361328, -9.921430587768555, -10.175292015075684, -11.521252632141113, -11.717275619506836, -11.01087474822998, -0.0, -11.951312065124512, -17.054828643798828, -16.471073150634766, -16.082204818725586, -17.5732364654541, -18.9034366607666, -19.963624954223633, -21.113262176513672, -22.726978302001953, -24.720535278320312, -26.822864532470703, -28.753084182739258, -30.26790428161621, -31.10870933532715, -31.453874588012695, -31.640289306640625, -32.190494537353516, -32.53865432739258, -32.58492660522461, -32.31782150268555, -31.691598892211914, -30.670881271362305, -29.325428009033203, -27.742435455322266, -25.964048385620117, -24.013900756835938, -21.954500198364258, -19.922128677368164, -18.215044021606445, -16.899507522583008, -15.74046802520752, -14.750446319580078, -13.485453605651855, -12.753697395324707, -13.030633926391602, -8.920368194580078, -8.316848754882812, -6.393932342529297, -0.0, -0.0, -0.0, -0.0, -2.5368123054504395, -0.0, -0.0, 0.0, 3.851996421813965, 4.832467079162598, 4.60662317276001, 3.4663853645324707, 2.4216153621673584, 4.443277835845947, -0.21296967566013336, 2.1491963863372803, 0.0], [0.0, -19.748977661132812, -17.702505111694336, -17.020355224609375, -14.641883850097656, -15.59319019317627, -13.583942413330078, -13.877715110778809, -12.372727394104004, -11.767992973327637, -10.917035102844238, -14.087039947509766, -13.375019073486328, -11.175069808959961, -12.002714157104492, 0.0, -8.051294326782227, -8.746441841125488, -13.10517692565918, 0.0, -13.456664085388184, -12.734824180603027, 0.0, -10.463664054870605, -14.283543586730957, -16.98950958251953, -16.37925910949707, -17.389564514160156, -20.36455535888672, -19.94294548034668, -23.40692710876465, -25.636159896850586, -24.99578857421875, -26.335561752319336, -28.432342529296875, -25.507936477661133, -26.410930633544922, -30.996387481689453, -28.083065032958984, -31.438631057739258, -32.96072769165039, -31.211496353149414, -32.35377883911133, -32.7739372253418, -30.057832717895508, -29.817930221557617, -25.54488182067871, -24.704442977905273, -22.963308334350586, -20.23483657836914, -18.291942596435547, -21.382801055908203, -20.552087783813477, -16.1923770904541, -15.129541397094727, -16.055761337280273, -15.892745971679688, -12.927671432495117, -10.476444244384766, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.8547234535217285, 2.3667385578155518, 3.6507315635681152, 3.4875850677490234, 2.5216784477233887, -0.022255398333072662, -1.363356113433838, 0.0, 0.0, -0.0, -19.748977661132812, -17.702505111694336, -17.020355224609375, -14.641883850097656, -15.59319019317627, -13.583942413330078, -13.877715110778809, -12.372727394104004, -11.767992973327637, -10.917035102844238, -14.087039947509766, -13.375019073486328, -11.175069808959961, -12.002714157104492, -0.0, -8.051294326782227, -8.746441841125488, -13.10517692565918, -0.0, -13.456664085388184, -12.734824180603027, -0.0, -10.463664054870605, -14.283543586730957, -16.98950958251953, -16.995040893554688, -18.719085693359375, -19.895315170288086, -20.903221130371094, -21.95464515686035, -23.305953979492188, -25.12974739074707, -27.148826599121094, -29.1191463470459, -30.841964721679688, -32.01869583129883, -32.704833984375, -33.127437591552734, -33.60310363769531, -33.917686462402344, -33.9831428527832, -33.717655181884766, -33.05142593383789, -31.973976135253906, -30.576900482177734, -28.94544792175293, -27.121135711669922, -25.133411407470703, -23.01856803894043, -20.915063858032227, -19.15892219543457, -17.882766723632812, -16.745210647583008, -15.274470329284668, -16.055761337280273, -15.892745971679688, -12.927671432495117, -10.476444244384766, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 4.8547234535217285, 2.3667385578155518, 3.6507315635681152, 3.4875850677490234, 2.5216784477233887, -0.022255398333072662, -1.363356113433838, 0.0, 0.0], [0.0, 0.0, -18.421539306640625, -17.53819465637207, -15.63786792755127, -14.898919105529785, -14.205981254577637, -12.67678165435791, -13.304363250732422, -12.515527725219727, -12.653164863586426, -11.652314186096191, 0.0, 0.0, 0.0, -12.179600715637207, -13.232487678527832, -10.136917114257812, -9.788446426391602, -11.21574592590332, -16.25674819946289, 0.0, -16.380069732666016, 0.0, -15.102344512939453, -18.034700393676758, -19.924610137939453, -20.434667587280273, -22.233692169189453, -22.839574813842773, -23.17934226989746, -26.404394149780273, -25.10403060913086, -28.50331687927246, -30.097517013549805, -30.516939163208008, -28.027816772460938, -27.544208526611328, -30.42568588256836, -34.277896881103516, -29.696178436279297, -29.70113754272461, -29.13496208190918, -32.89613723754883, -30.810436248779297, -28.93804931640625, -29.223098754882812, -25.77915382385254, -23.603015899658203, -22.201488494873047, -18.298137664794922, -20.706045150756836, -18.16632080078125, -17.295658111572266, -19.40407943725586, -16.827259063720703, -15.33950138092041, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.5332534313201904, 3.8013110160827637, 1.7366158962249756, 3.601829767227173, 2.6147444248199463, 2.404916524887085, 0.8700870275497437, 0.0, 0.0, 0.0, -0.0, -0.0, -18.421539306640625, -17.53819465637207, -15.63786792755127, -14.898919105529785, -14.205981254577637, -12.67678165435791, -13.304363250732422, -12.515527725219727, -12.653164863586426, -11.652314186096191, -0.0, -0.0, -0.0, -12.179600715637207, -13.232487678527832, -10.136917114257812, -9.788446426391602, -11.21574592590332, -16.25674819946289, -0.0, -16.380069732666016, -0.0, -15.102344512939453, -18.034700393676758, -20.040023803710938, -20.552770614624023, -20.83000946044922, -21.614999771118164, -22.812397003173828, -23.685840606689453, -25.417463302612305, -27.441240310668945, -29.350305557250977, -31.356727600097656, -33.02223587036133, -33.80739974975586, -34.37732696533203, -34.95155715942383, -35.303096771240234, -35.336368560791016, -35.0057258605957, -34.30569076538086, -33.21356964111328, -31.794525146484375, -30.11980628967285, -28.270811080932617, -26.243755340576172, -24.083620071411133, -21.959835052490234, -20.071802139282227, -18.624265670776367, -17.86602783203125, -18.18003273010254, -16.827259063720703, -15.33950138092041, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 2.5332534313201904, 3.8013110160827637, 1.7366158962249756, 3.601829767227173, 2.6147444248199463, 2.404916524887085, 0.8700870275497437, -0.0, -0.0, 0.0], [0.0, 0.0, 0.0, -18.75452423095703, -16.15443992614746, -13.565230369567871, -14.305213928222656, -13.552030563354492, -13.5167818069458, -13.404577255249023, -11.561878204345703, -10.55784797668457, -11.396157264709473, 0.0, 0.0, 0.0, -12.142239570617676, 0.0, 0.0, -17.208660125732422, -17.25973129272461, -21.572233200073242, 0.0, 0.0, 0.0, -19.869359970092773, -21.905128479003906, -20.560890197753906, -19.426204681396484, -22.82330322265625, -21.880041122436523, -23.968433380126953, -25.3037109375, -23.980562210083008, -26.011062622070312, -27.87149429321289, 0.0, 0.0, 0.0, 0.0, 0.0, -29.07522201538086, -29.906715393066406, -28.611671447753906, -27.974567413330078, -28.435964584350586, -30.58132553100586, -28.35437774658203, -24.819942474365234, -23.859031677246094, -21.92206573486328, -20.675214767456055, -20.802244186401367, -19.344100952148438, -17.72883415222168, 0.0, -12.890253067016602, -11.743377685546875, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.033250331878662, 3.445805549621582, 1.904765009880066, 3.649477243423462, 2.603976249694824, 1.505938172340393, 1.9741495847702026, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -18.75452423095703, -16.15443992614746, -13.565230369567871, -14.305213928222656, -13.552030563354492, -13.5167818069458, -13.404577255249023, -11.561878204345703, -10.55784797668457, -11.396157264709473, -0.0, -0.0, -0.0, -12.142239570617676, -0.0, -0.0, -17.208660125732422, -17.25973129272461, -21.572233200073242, -0.0, -0.0, -0.0, -19.869359970092773, -21.677061080932617, -21.638362884521484, -21.58192253112793, -21.820337295532227, -23.023883819580078, -24.203943252563477, -25.70754623413086, -27.625545501708984, -29.4748477935791, -31.617427825927734, -0.0, -0.0, -0.0, -0.0, -0.0, -36.42182540893555, -35.97536087036133, -35.21249771118164, -34.13312530517578, -32.76871109008789, -31.058713912963867, -29.227819442749023, -27.22205352783203, -25.09427261352539, -22.9427433013916, -20.961668014526367, -19.228761672973633, -18.13469696044922, -17.41771697998047, -0.0, -12.890253067016602, -11.743377685546875, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 3.033250331878662, 3.445805549621582, 1.904765009880066, 3.649477243423462, 2.603976249694824, 1.505938172340393, 1.9741495847702026, 0.0, 0.0, -0.0], [0.0, 0.0, -24.529748916625977, 0.0, -16.966033935546875, -15.381080627441406, -15.09132194519043, -12.502984046936035, -13.139899253845215, -12.926558494567871, -12.112789154052734, -11.864738464355469, -9.995370864868164, -11.28530216217041, 0.0, -2.9979002475738525, 0.0, 0.0, 0.0, 0.0, 0.0, -22.68024444580078, 0.0, 0.0, 0.0, -20.081451416015625, 0.0, 0.0, -19.222457885742188, -26.162860870361328, -26.120134353637695, -28.878957748413086, -26.65140724182129, -26.097211837768555, 0.0, 0.0, 0.0, -34.460391998291016, -32.85599899291992, -34.14374923706055, -33.749488830566406, 0.0, 0.0, -33.59160614013672, -29.055622100830078, -30.308820724487305, -26.88590431213379, -28.34969711303711, -25.20699119567871, -25.87327003479004, -24.48127555847168, -23.98373031616211, -20.015260696411133, 0.0, 0.0, 0.0, 0.0, 0.0, -12.976600646972656, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.147214412689209, 2.1797025203704834, 2.410221576690674, 2.4413695335388184, 1.871468186378479, 1.8750998973846436, 1.7399111986160278, 0.0, 0.0, 0.0, -0.0, -0.0, -24.529748916625977, -0.0, -16.966033935546875, -15.381080627441406, -15.09132194519043, -12.502984046936035, -13.139899253845215, -12.926558494567871, -12.112789154052734, -11.864738464355469, -9.995370864868164, -11.28530216217041, -0.0, -2.9979002475738525, -0.0, -0.0, -0.0, -0.0, -0.0, -22.68024444580078, -0.0, -0.0, -0.0, -20.081451416015625, -0.0, -0.0, -22.313451766967773, -22.15816879272461, -22.85364532470703, -24.02419662475586, -25.351318359375, -27.503265380859375, -0.0, -0.0, -0.0, -35.31726837158203, -36.228240966796875, -36.748470306396484, -36.843875885009766, -0.0, -0.0, -35.09126663208008, -34.093204498291016, -32.95994186401367, -31.547378540039062, -29.878053665161133, -28.084230422973633, -26.128215789794922, -23.89269256591797, -21.868282318115234, -19.94343376159668, -0.0, -0.0, -0.0, -0.0, -0.0, -12.976600646972656, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 2.147214412689209, 2.1797025203704834, 2.410221576690674, 2.4413695335388184, 1.871468186378479, 1.8750998973846436, 1.7399111986160278, 0.0, 0.0, 0.0], [-23.53605079650879, -25.229169845581055, -22.266708374023438, 0.0, -13.102795600891113, -15.65533447265625, -15.671486854553223, -13.689168930053711, -11.188983917236328, -13.181001663208008, -13.469688415527344, -12.355596542358398, -11.65560531616211, -12.336666107177734, 0.0, -5.04153299331665, -5.334616184234619, 0.0, 0.0, 0.0, 0.0, -21.482044219970703, 0.0, -22.190343856811523, -22.3304443359375, -21.18626594543457, -25.588647842407227, -24.740955352783203, -21.880151748657227, -22.587114334106445, -27.775394439697266, -28.390079498291016, -28.125192642211914, -27.389259338378906, -28.90975570678711, -33.36802291870117, -33.750465393066406, -34.62919616699219, -33.632110595703125, 0.0, -30.22058868408203, -30.59634780883789, -32.91020584106445, -31.380184173583984, -32.504085540771484, -32.16371536254883, -28.323352813720703, -26.458171844482422, -28.417463302612305, -25.560876846313477, -23.541044235229492, -25.27769660949707, -21.549283981323242, 0.0, 0.0, -16.116804122924805, -18.150211334228516, -16.696245193481445, -13.339723587036133, -11.550540924072266, -11.331225395202637, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.112953543663025, 0.45417386293411255, 1.7679599523544312, 1.944629192352295, 1.836685061454773, 1.4500936269760132, 0.0, 0.0, 0.0, 0.0, -23.53605079650879, -25.229169845581055, -22.266708374023438, -0.0, -13.102795600891113, -15.65533447265625, -15.671486854553223, -13.689168930053711, -11.188983917236328, -13.181001663208008, -13.469688415527344, -12.355596542358398, -11.65560531616211, -12.336666107177734, -0.0, -5.04153299331665, -5.334616184234619, -0.0, -0.0, -0.0, -0.0, -21.482044219970703, -0.0, -22.190343856811523, -22.3304443359375, -21.18626594543457, -25.17973518371582, -23.543731689453125, -22.936002731323242, -22.694416046142578, -22.931522369384766, -23.659421920776367, -25.204177856445312, -27.41005516052246, -29.91179656982422, -32.23033905029297, -34.042945861816406, -35.51039123535156, -36.22303009033203, -0.0, -36.272647857666016, -35.755741119384766, -35.02919006347656, -34.16416549682617, -33.21724319458008, -32.17510223388672, -31.070234298706055, -29.92812156677246, -28.80296516418457, -27.166608810424805, -24.923580169677734, -22.937116622924805, -21.04125213623047, -0.0, -0.0, -16.116804122924805, -18.150211334228516, -16.696245193481445, -13.339723587036133, -11.550540924072266, -11.331225395202637, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 1.112953543663025, 0.45417386293411255, 1.7679599523544312, 1.944629192352295, 1.836685061454773, 1.4500936269760132, 0.0, 0.0, 0.0, 0.0], [-25.928791046142578, -25.49570083618164, 0.0, 0.0, 0.0, -17.335115432739258, -14.549882888793945, -14.658622741699219, -13.599895477294922, -10.626775741577148, -13.269472122192383, -12.669453620910645, -13.26266098022461, -12.075387001037598, 0.0, -2.2234795093536377, -4.649759292602539, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -21.80158805847168, -24.713783264160156, -24.90161895751953, -23.271711349487305, -22.50244140625, 0.0, -26.433927536010742, -24.80486297607422, -25.54429054260254, -25.450645446777344, -26.929250717163086, 0.0, 0.0, 0.0, -32.04350662231445, -33.3579216003418, 0.0, -31.82300567626953, 0.0, -33.639312744140625, -30.38887596130371, -29.804006576538086, -27.91499900817871, -26.249351501464844, -30.391033172607422, -25.759326934814453, -28.67375373840332, -26.71251678466797, -23.35085105895996, 0.0, 0.0, -19.08078384399414, -16.441082000732422, -13.062536239624023, -13.437661170959473, -13.706379890441895, 0.0, 0.0, -12.50717544555664, 0.0, 0.0, 0.0, 0.0, 0.0, -1.8021490573883057, 1.3734487295150757, 1.4347220659255981, 0.7525447010993958, 0.8157225847244263, -0.24728737771511078, 0.0, 0.0, 0.0, 0.0, -25.928791046142578, -25.49570083618164, -0.0, -0.0, -0.0, -17.335115432739258, -14.549882888793945, -14.658622741699219, -13.599895477294922, -10.626775741577148, -13.269472122192383, -12.669453620910645, -13.26266098022461, -12.075387001037598, -0.0, -2.2234795093536377, -4.649759292602539, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -21.80158805847168, -24.713783264160156, -24.611303329467773, -24.073667526245117, -23.55616569519043, -0.0, -23.491302490234375, -23.592914581298828, -25.12957191467285, -27.573928833007812, -29.98444938659668, -0.0, -0.0, -0.0, -35.824893951416016, -35.75297164916992, -0.0, -34.75276184082031, -0.0, -33.101280212402344, -32.22842025756836, -31.284757614135742, -30.264266967773438, -29.623384475708008, -29.167383193969727, -27.750429153442383, -25.759719848632812, -23.785627365112305, -21.831071853637695, -0.0, -0.0, -19.08078384399414, -16.441082000732422, -13.062536239624023, -13.437661170959473, -13.706379890441895, -0.0, -0.0, -12.50717544555664, -0.0, -0.0, -0.0, -0.0, -0.0, -1.8021490573883057, 1.3734487295150757, 1.4347220659255981, 0.7525447010993958, 0.8157225847244263, -0.24728737771511078, -0.0, 0.0, 0.0, 0.0], [-26.265798568725586, -23.64655113220215, -23.794836044311523, -25.430259704589844, 0.0, 0.0, -15.366108894348145, -14.790103912353516, -14.282369613647461, -12.467055320739746, -12.76882553100586, -13.375000953674316, -12.513703346252441, -12.586000442504883, 0.0, 0.0, -6.317511558532715, -5.655208587646484, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.07314682006836, -24.747034072875977, -27.826889038085938, -25.461639404296875, 0.0, -28.107839584350586, -30.30242347717285, -27.893625259399414, -25.672801971435547, -28.857330322265625, 0.0, 0.0, 0.0, 0.0, -32.33933639526367, -29.85538101196289, -30.730234146118164, -31.85157012939453, -31.289148330688477, -29.445659637451172, -31.2211856842041, -28.294448852539062, -29.1184139251709, -28.70865249633789, -24.310068130493164, -28.34417724609375, -30.05079460144043, -26.31089973449707, 0.0, -21.183324813842773, -19.12472915649414, -19.59313201904297, -14.133212089538574, -15.268332481384277, -13.750908851623535, 0.0, 0.0, -15.655397415161133, 0.0, 0.0, 0.0, 0.0, -1.0794326066970825, 0.15544618666172028, 2.177062511444092, 1.213411569595337, 0.17252233624458313, 1.2477514743804932, 0.0, 0.0, 1.9119751453399658, 0.0, 4.807764530181885, -26.265798568725586, -23.64655113220215, -23.794836044311523, -25.430259704589844, -0.0, -0.0, -15.366108894348145, -14.790103912353516, -14.282369613647461, -12.467055320739746, -12.76882553100586, -13.375000953674316, -12.513703346252441, -12.586000442504883, -0.0, -0.0, -6.317511558532715, -5.655208587646484, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.07314682006836, -24.168405532836914, -24.09530258178711, -24.035324096679688, -0.0, -23.909589767456055, -24.28624153137207, -25.710464477539062, -27.87236976623535, -29.999561309814453, -0.0, -0.0, -0.0, -0.0, -34.84208679199219, -34.343711853027344, -33.709598541259766, -32.927059173583984, -32.069602966308594, -31.276599884033203, -30.465591430664062, -29.724571228027344, -29.32346534729004, -29.067346572875977, -28.05428695678711, -26.118532180786133, -23.845033645629883, -22.000730514526367, -0.0, -21.017353057861328, -19.12472915649414, -19.59313201904297, -14.133212089538574, -15.268332481384277, -13.750908851623535, -0.0, -0.0, -15.655397415161133, -0.0, -0.0, -0.0, -0.0, -1.0794326066970825, 0.15544618666172028, 2.177062511444092, 1.213411569595337, 0.17252233624458313, 1.2477514743804932, -0.0, 0.0, 1.9119751453399658, 0.0, 4.807764530181885], [-27.988670349121094, -24.11329460144043, -23.047773361206055, -24.708173751831055, -22.298110961914062, 0.0, -14.979432106018066, -14.98330020904541, -15.223124504089355, -13.077534675598145, -13.220932006835938, -12.754850387573242, -13.009855270385742, -13.749505996704102, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.38320541381836, -21.892885208129883, -26.95127296447754, -26.441783905029297, -29.816946029663086, -28.71381378173828, -32.34105682373047, -27.373044967651367, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -32.7600212097168, -30.667911529541016, -30.2723331451416, -29.863618850708008, -30.344274520874023, -30.37578582763672, -26.072677612304688, -25.704654693603516, -26.730266571044922, -25.62964630126953, -23.057458877563477, 0.0, -17.889307022094727, -19.66756248474121, -18.220361709594727, -18.026004791259766, -17.702476501464844, -14.281179428100586, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.1590158939361572, 1.0484250783920288, -2.0240983963012695, 1.0322355031967163, 1.2741254568099976, -1.6267935037612915, 0.0, 0.0, -0.76475590467453, 0.0, 3.9989585876464844, -27.988670349121094, -24.11329460144043, -23.047773361206055, -24.708173751831055, -22.298110961914062, -0.0, -14.979432106018066, -14.98330020904541, -15.223124504089355, -13.077534675598145, -13.220932006835938, -12.754850387573242, -13.009855270385742, -13.749505996704102, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.38320541381836, -22.771482467651367, -23.9063777923584, -24.379064559936523, -24.26344108581543, -24.430936813354492, -25.069658279418945, -26.02155303955078, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -31.98013687133789, -31.162813186645508, -30.453746795654297, -29.71125602722168, -29.257780075073242, -28.991849899291992, -28.565597534179688, -27.882165908813477, -26.368610382080078, -24.30882453918457, -22.52035140991211, -0.0, -18.496530532836914, -19.66756248474121, -18.220361709594727, -18.026004791259766, -17.702476501464844, -14.281179428100586, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -2.1590158939361572, 1.0484250783920288, -2.0240983963012695, 1.0322355031967163, 1.2741254568099976, -1.6267935037612915, -0.0, 0.0, -0.76475590467453, 0.0, 3.9989585876464844], [0.0, -21.073360443115234, -21.869434356689453, 0.0, -24.351661682128906, 0.0, 0.0, -15.03350830078125, -14.899449348449707, -13.751716613769531, -13.3507719039917, -12.82960033416748, -11.171512603759766, -11.711974143981934, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.441417694091797, -26.749597549438477, -25.774335861206055, -27.019634246826172, -33.91522979736328, -29.8839111328125, -33.31902313232422, -35.72884750366211, -34.68507385253906, 0.0, 0.0, 0.0, -36.799076080322266, -36.194828033447266, -35.65788269042969, -35.66639709472656, -31.972835540771484, 0.0, 0.0, -31.656808853149414, -29.51078224182129, -26.76097297668457, -26.76849365234375, -28.561677932739258, -28.246559143066406, 0.0, 0.0, 0.0, -22.442588806152344, -19.89582061767578, 0.0, 0.0, 0.0, -14.643697738647461, -17.281204223632812, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.4190579652786255, -0.5940303206443787, 0.012522957287728786, 1.2216036319732666, 0.0, 0.0, 0.20656509697437286, 0.0, 0.0, -0.0, -21.073360443115234, -21.869434356689453, -0.0, -24.351661682128906, -0.0, -0.0, -15.03350830078125, -14.899449348449707, -13.751716613769531, -13.3507719039917, -12.82960033416748, -11.171512603759766, -11.711974143981934, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.773340225219727, -25.270183563232422, -25.278274536132812, -25.196393966674805, -25.49333953857422, -26.25409698486328, -27.79157829284668, -29.377527236938477, -30.99569320678711, -0.0, -0.0, -0.0, -32.8022346496582, -32.28469467163086, -31.752567291259766, -31.097972869873047, -30.36237907409668, -0.0, -0.0, -28.53959083557129, -28.412113189697266, -28.123924255371094, -27.71926498413086, -26.486391067504883, -24.651100158691406, -0.0, -0.0, -0.0, -22.442588806152344, -19.89582061767578, -0.0, -0.0, -0.0, -14.643697738647461, -17.281204223632812, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, -1.4190579652786255, -0.5940303206443787, 0.012522957287728786, 1.2216036319732666, 0.0, -0.0, 0.20656509697437286, 0.0, 0.0], [0.0, -23.505985260009766, -22.911916732788086, -25.014480590820312, 0.0, 0.0, 0.0, 0.0, -16.225482940673828, -14.385210037231445, -13.362833023071289, -13.329279899597168, 0.0, 0.0, -13.37501049041748, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.579166412353516, -17.265005111694336, 0.0, 0.0, 0.0, 0.0, -27.221315383911133, 0.0, 0.0, 0.0, 0.0, -29.014144897460938, -32.98441696166992, 0.0, -32.62632751464844, -34.18778991699219, -36.19060516357422, -36.94390106201172, -34.397945404052734, -32.52710723876953, -34.468040466308594, -33.995819091796875, -30.264179229736328, 0.0, 0.0, 0.0, 0.0, 0.0, -30.37407684326172, -29.74418830871582, -25.306964874267578, -24.914398193359375, 0.0, 0.0, 0.0, 0.0, -15.740303039550781, -16.097036361694336, -14.83393383026123, -13.716641426086426, -13.842041015625, -13.30930233001709, -13.089815139770508, 0.0, 0.0, 0.0, -7.097030162811279, -7.746837139129639, -5.686393737792969, -3.2238707542419434, -1.930626392364502, 0.8062726259231567, 0.0, -1.3591175079345703, 1.116926908493042, 0.0, 0.0, -0.0, -23.505985260009766, -22.911916732788086, -25.014480590820312, -0.0, -0.0, -0.0, -0.0, -16.225482940673828, -14.385210037231445, -13.362833023071289, -13.329279899597168, -0.0, -0.0, -13.37501049041748, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.579166412353516, -17.265005111694336, -0.0, -0.0, -0.0, -0.0, -26.32524871826172, -0.0, -0.0, -0.0, -0.0, -26.917329788208008, -27.9378662109375, -0.0, -30.96453094482422, -32.10093307495117, -32.46167755126953, -32.06730270385742, -31.791852951049805, -31.339664459228516, -30.70592498779297, -30.143903732299805, -29.356678009033203, -0.0, -0.0, -0.0, -0.0, -0.0, -27.158349990844727, -25.872568130493164, -24.283140182495117, -22.730043411254883, -0.0, -0.0, -0.0, -0.0, -15.740303039550781, -16.097036361694336, -14.83393383026123, -13.716641426086426, -13.842041015625, -13.30930233001709, -13.089815139770508, -0.0, -0.0, -0.0, -7.097030162811279, -7.746837139129639, -5.686393737792969, -3.2238707542419434, -1.930626392364502, 0.8062726259231567, -0.0, -1.3591175079345703, 1.116926908493042, 0.0, 0.0], [0.0, -21.385635375976562, -21.42096710205078, -25.566938400268555, -23.62059783935547, 0.0, 0.0, 0.0, -13.807648658752441, -14.745488166809082, -14.472572326660156, 0.0, 0.0, -10.918655395507812, -8.997586250305176, 0.0, 0.0, 0.0, -19.766130447387695, -16.87173843383789, -18.39180564880371, -18.672014236450195, -19.030521392822266, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -31.57831382751465, 0.0, -33.75413513183594, -32.89617919921875, 0.0, -31.284793853759766, -31.497699737548828, -34.1458740234375, -34.195640563964844, 0.0, 0.0, -30.5647029876709, -33.66373825073242, -29.523775100708008, -30.25310707092285, -30.835935592651367, -29.138748168945312, -27.15484619140625, 0.0, -33.22505187988281, -29.97627067565918, 0.0, -25.603322982788086, -23.325571060180664, 0.0, 0.0, -17.311038970947266, -16.732654571533203, -16.36724853515625, -15.488886833190918, -15.249217987060547, -14.396438598632812, -13.721111297607422, -13.09874439239502, -12.283175468444824, -9.472187042236328, 0.0, -6.617805004119873, 0.0, -4.255013465881348, 0.0, 0.0, -1.4436825513839722, 0.0, -3.405818462371826, -3.1012816429138184, 0.0, 0.0, -0.0, -21.385635375976562, -21.42096710205078, -25.566938400268555, -23.62059783935547, -0.0, -0.0, -0.0, -13.807648658752441, -14.745488166809082, -14.472572326660156, -0.0, -0.0, -10.918655395507812, -8.997586250305176, -0.0, -0.0, -0.0, -19.766130447387695, -16.87173843383789, -18.39180564880371, -18.672014236450195, -19.030521392822266, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.34545135498047, -0.0, -27.086795806884766, -27.48997688293457, -0.0, -30.296493530273438, -31.378175735473633, -31.590438842773438, -31.33516502380371, -0.0, -0.0, -29.582612991333008, -28.808870315551758, -28.045988082885742, -27.068340301513672, -26.783655166625977, -27.066017150878906, -26.824148178100586, -0.0, -26.06003761291504, -24.958696365356445, -0.0, -22.279516220092773, -21.835508346557617, -0.0, -0.0, -17.311038970947266, -16.732654571533203, -16.36724853515625, -15.488886833190918, -15.249217987060547, -14.396438598632812, -13.721111297607422, -13.09874439239502, -12.283175468444824, -9.472187042236328, -0.0, -6.617805004119873, -0.0, -4.255013465881348, -0.0, -0.0, -1.4436825513839722, -0.0, -3.405818462371826, -3.1012816429138184, -0.0, -0.0], [0.0, -23.112346649169922, -20.07350730895996, 0.0, -22.037555694580078, -20.655515670776367, 0.0, 0.0, -12.927956581115723, 0.0, 0.0, 0.0, 0.0, -12.167776107788086, -11.872749328613281, 0.0, -18.983217239379883, -15.895635604858398, -16.97944450378418, -17.841997146606445, -18.736495971679688, -20.149559020996094, -21.65691375732422, -21.190542221069336, -24.79537010192871, -25.451618194580078, 0.0, 0.0, 0.0, 0.0, -32.75324630737305, -28.84712791442871, -28.629671096801758, -30.19548225402832, -30.65346908569336, -34.614017486572266, -32.93458938598633, -30.914546966552734, -33.51473617553711, -33.59299087524414, 0.0, -31.950576782226562, 0.0, -28.580671310424805, -31.322410583496094, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.88006591796875, -25.25263214111328, 0.0, 0.0, -18.48094940185547, -18.49477767944336, -17.414216995239258, -17.860933303833008, -15.769721031188965, -16.044151306152344, -15.885856628417969, -14.694282531738281, -13.804954528808594, -12.494975090026855, -11.74649715423584, -9.196429252624512, -7.97283411026001, 0.0, -6.466881275177002, 0.0, 0.0, 0.0, 0.0, -3.5007970333099365, -2.5899720191955566, 0.0, 0.0, -0.0, -23.112346649169922, -20.07350730895996, -0.0, -22.037555694580078, -20.655515670776367, -0.0, -0.0, -12.927956581115723, -0.0, -0.0, -0.0, -0.0, -12.167776107788086, -11.872749328613281, -0.0, -18.983217239379883, -15.895635604858398, -16.97944450378418, -17.841997146606445, -18.736495971679688, -20.149559020996094, -21.65691375732422, -21.190542221069336, -24.79537010192871, -25.451618194580078, -0.0, -0.0, -0.0, -0.0, -28.371105194091797, -27.684520721435547, -27.30315399169922, -27.28656768798828, -27.9823055267334, -29.356287002563477, -30.422897338867188, -30.649944305419922, -30.425172805786133, -30.012155532836914, -0.0, -28.371198654174805, -0.0, -26.428955078125, -25.584718704223633, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.866470336914062, -21.79983901977539, -0.0, -0.0, -18.48094940185547, -18.49477767944336, -17.414216995239258, -17.860933303833008, -15.769721031188965, -16.044151306152344, -15.885856628417969, -14.694282531738281, -13.804954528808594, -12.494975090026855, -11.74649715423584, -9.196429252624512, -7.97283411026001, -0.0, -6.466881275177002, -0.0, -0.0, -0.0, -0.0, -3.5007970333099365, -2.5899720191955566, -0.0, -0.0], [0.0, 0.0, -22.067575454711914, -22.553775787353516, 0.0, -21.45050048828125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.512124061584473, -9.747376441955566, -12.74802017211914, -12.270033836364746, -14.645712852478027, -16.079421997070312, -17.02249526977539, -18.538543701171875, -19.529272079467773, -20.775501251220703, -22.834884643554688, -23.405380249023438, -24.45384407043457, -26.458711624145508, -28.18143081665039, -29.85793113708496, 0.0, 0.0, -30.395097732543945, -31.38710594177246, -30.136138916015625, -27.775815963745117, 0.0, -30.7605037689209, -32.13699722290039, -29.33580780029297, 0.0, -31.761720657348633, -32.63151168823242, -31.99931526184082, -29.815372467041016, 0.0, 0.0, -25.20380401611328, 0.0, 0.0, 0.0, 0.0, 0.0, -25.313404083251953, -25.042308807373047, 0.0, -19.967559814453125, -19.15798568725586, -19.266883850097656, -18.917863845825195, -17.682767868041992, -17.336315155029297, -16.16582489013672, -15.7905855178833, -14.83113956451416, -14.094590187072754, -12.642369270324707, -11.953137397766113, -11.35828971862793, -8.928689956665039, -6.319665908813477, 0.0, 0.0, 0.0, -1.472010850906372, -4.121996879577637, -4.097885608673096, 0.0, 0.0, 0.0, -0.0, -0.0, -22.067575454711914, -22.553775787353516, -0.0, -21.45050048828125, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -9.512124061584473, -9.747376441955566, -12.74802017211914, -12.270033836364746, -14.645712852478027, -16.079421997070312, -17.02249526977539, -18.538543701171875, -19.529272079467773, -20.775501251220703, -22.834884643554688, -23.405380249023438, -24.45384407043457, -26.458711624145508, -27.788408279418945, -28.12224769592285, -0.0, -0.0, -29.211301803588867, -28.880849838256836, -28.45706558227539, -28.282323837280273, -0.0, -28.828081130981445, -29.586244583129883, -29.857942581176758, -0.0, -29.041614532470703, -28.330278396606445, -27.28989601135254, -26.16028594970703, -0.0, -0.0, -25.266536712646484, -0.0, -0.0, -0.0, -0.0, -0.0, -22.45716667175293, -21.573230743408203, -0.0, -20.23851776123047, -19.15798568725586, -19.266883850097656, -18.917863845825195, -17.682767868041992, -17.336315155029297, -16.16582489013672, -15.7905855178833, -14.83113956451416, -14.094590187072754, -12.642369270324707, -11.953137397766113, -11.35828971862793, -8.928689956665039, -6.319665908813477, -0.0, -0.0, -0.0, -1.472010850906372, -4.121996879577637, -4.097885608673096, -0.0, -0.0, -0.0], [0.0, 0.0, -21.399211883544922, -20.097047805786133, -21.664226531982422, -22.891956329345703, 0.0, 0.0, 0.0, 0.0, 0.0, -6.7173542976379395, -9.430017471313477, -11.367223739624023, -11.985631942749023, -13.988755226135254, -14.52952766418457, -15.52797794342041, -17.16020965576172, -18.5478515625, -19.63430404663086, -21.363908767700195, -22.4903564453125, -23.643760681152344, -25.114948272705078, -25.34311866760254, -26.99867820739746, -27.177734375, 0.0, 0.0, 0.0, -32.5383415222168, -32.266666412353516, -31.34954261779785, -32.479393005371094, 0.0, -32.218360900878906, -32.48931884765625, -30.145124435424805, -28.96761131286621, -29.073244094848633, -29.588111877441406, -28.402250289916992, -28.05559730529785, -25.902896881103516, -27.499862670898438, 0.0, 0.0, 0.0, 0.0, 0.0, -24.617477416992188, -22.398544311523438, 0.0, -19.119403839111328, -19.61273193359375, -19.25274658203125, -19.50357437133789, -18.792821884155273, -17.645326614379883, -17.235261917114258, -16.428449630737305, -16.079065322875977, -14.799360275268555, -13.143207550048828, -12.095032691955566, -10.577433586120605, -9.413898468017578, -7.531124591827393, 0.0, 0.0, 0.0, 0.0, -0.796707034111023, -4.773061752319336, 0.0, 0.0, 0.0, -0.0, -0.0, -21.399211883544922, -20.097047805786133, -21.664226531982422, -22.891956329345703, -0.0, -0.0, -0.0, -0.0, -0.0, -6.7173542976379395, -9.430017471313477, -11.367223739624023, -11.985631942749023, -13.988755226135254, -14.52952766418457, -15.52797794342041, -17.16020965576172, -18.5478515625, -19.63430404663086, -21.363908767700195, -22.4903564453125, -23.643760681152344, -25.114948272705078, -25.34311866760254, -27.04412269592285, -28.130964279174805, -0.0, -0.0, -0.0, -29.896738052368164, -29.671398162841797, -29.555835723876953, -29.594602584838867, -0.0, -29.385583877563477, -29.385175704956055, -28.97399139404297, -28.49924659729004, -27.55641746520996, -26.35076141357422, -25.162750244140625, -24.128305435180664, -23.75611686706543, -24.521255493164062, -0.0, -0.0, -0.0, -0.0, -0.0, -22.333642959594727, -21.415409088134766, -0.0, -19.548389434814453, -19.61273193359375, -19.25274658203125, -19.50357437133789, -18.792821884155273, -17.645326614379883, -17.235261917114258, -16.428449630737305, -16.079065322875977, -14.799360275268555, -13.143207550048828, -12.095032691955566, -10.577433586120605, -9.413898468017578, -7.531124591827393, -0.0, -0.0, -0.0, -0.0, -0.796707034111023, -4.773061752319336, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, -20.86674690246582, -20.220354080200195, -24.02383041381836, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.778518676757812, -8.105481147766113, -10.206127166748047, -12.779030799865723, -13.836347579956055, -15.489251136779785, -17.037879943847656, -17.992525100708008, -19.39963150024414, -21.367820739746094, -22.353557586669922, -23.873119354248047, -24.982988357543945, -26.470991134643555, -27.271739959716797, -28.144245147705078, -30.04962158203125, 0.0, -34.364200592041016, 0.0, 0.0, -34.73380661010742, -33.07085418701172, -29.530426025390625, -34.445037841796875, -34.51251220703125, 0.0, -30.461111068725586, -28.770965576171875, 0.0, -26.681943893432617, 0.0, 0.0, -29.009733200073242, 0.0, 0.0, 0.0, 0.0, 0.0, -24.47749900817871, 0.0, 0.0, -19.649938583374023, -19.69021987915039, -19.997636795043945, -19.819446563720703, -19.065837860107422, -18.386571884155273, -17.479707717895508, -17.130292892456055, -16.37828826904297, -14.808915138244629, -13.387768745422363, -12.619976043701172, -10.918930053710938, -9.567841529846191, -7.829272270202637, -7.234198570251465, 0.0, 0.0, 0.0, -4.240846157073975, -6.614037036895752, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -20.86674690246582, -20.220354080200195, -24.02383041381836, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -9.778518676757812, -8.105481147766113, -10.206127166748047, -12.779030799865723, -13.836347579956055, -15.489251136779785, -17.037879943847656, -17.992525100708008, -19.39963150024414, -21.367820739746094, -22.353557586669922, -23.873119354248047, -24.982988357543945, -26.470991134643555, -27.26974105834961, -28.12444305419922, -29.043331146240234, -0.0, -30.670814514160156, -0.0, -0.0, -30.67155647277832, -30.640430450439453, -30.463321685791016, -30.07457733154297, -29.63286018371582, -0.0, -28.349056243896484, -26.97298240661621, -0.0, -24.292469024658203, -0.0, -0.0, -24.05183219909668, -0.0, -0.0, -0.0, -0.0, -0.0, -21.962709426879883, -0.0, -0.0, -19.8419246673584, -19.69021987915039, -19.997636795043945, -19.819446563720703, -19.065837860107422, -18.386571884155273, -17.479707717895508, -17.130292892456055, -16.37828826904297, -14.808915138244629, -13.387768745422363, -12.619976043701172, -10.918930053710938, -9.567841529846191, -7.829272270202637, -7.234198570251465, -0.0, -0.0, -0.0, -4.240846157073975, -6.614037036895752, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -21.451589584350586, 0.0, -21.386621475219727, -12.659294128417969, -13.035399436950684, 0.0, 0.0, -11.432211875915527, -14.249699592590332, -10.257329940795898, -10.51319694519043, -11.34664535522461, -13.262845993041992, -14.86337947845459, -16.278350830078125, -18.040342330932617, -19.146116256713867, -21.209014892578125, -22.186662673950195, -23.393930435180664, -24.922990798950195, -26.14304542541504, -26.81940460205078, -27.72139549255371, -28.152145385742188, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -34.70682907104492, 0.0, 0.0, -29.633991241455078, -31.90113067626953, 0.0, -30.443758010864258, -31.975006103515625, -31.629972457885742, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.24043083190918, -19.275739669799805, -19.377656936645508, -19.98030662536621, -19.862539291381836, -18.69999122619629, -17.941816329956055, -17.027759552001953, -16.068387985229492, -14.841458320617676, -13.598825454711914, -12.149127960205078, -10.664977073669434, -9.833015441894531, -7.457169532775879, -8.707033157348633, -9.367579460144043, 0.0, 0.0, -4.580061435699463, -7.7863450050354, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -21.451589584350586, -0.0, -21.386621475219727, -12.659294128417969, -13.035399436950684, -0.0, -0.0, -11.432211875915527, -14.249699592590332, -10.257329940795898, -10.51319694519043, -11.34664535522461, -13.262845993041992, -14.86337947845459, -16.278350830078125, -18.040342330932617, -19.146116256713867, -21.209014892578125, -22.186662673950195, -23.393930435180664, -24.922990798950195, -26.14304542541504, -26.894350051879883, -27.958223342895508, -28.970775604248047, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -30.725130081176758, -0.0, -0.0, -28.078155517578125, -26.770906448364258, -0.0, -23.873947143554688, -22.794633865356445, -23.072011947631836, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.44868278503418, -19.275739669799805, -19.377656936645508, -19.98030662536621, -19.862539291381836, -18.69999122619629, -17.941816329956055, -17.027759552001953, -16.068387985229492, -14.841458320617676, -13.598825454711914, -12.149127960205078, -10.664977073669434, -9.833015441894531, -7.457169532775879, -8.707033157348633, -9.367579460144043, -0.0, -0.0, -4.580061435699463, -7.7863450050354, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.76587200164795, 0.0, -16.713747024536133, 0.0, -14.038135528564453, -10.898566246032715, -12.49447250366211, -11.951079368591309, -11.906451225280762, -13.288268089294434, -15.0907564163208, -16.852190017700195, -18.817533493041992, -20.46137046813965, -22.307065963745117, -23.519439697265625, -25.12816619873047, -25.84255027770996, -27.050067901611328, -27.340131759643555, -27.768306732177734, -27.907508850097656, 0.0, 0.0, 0.0, -34.00009536743164, -34.55060577392578, 0.0, 0.0, 0.0, 0.0, -34.047767639160156, -33.19401550292969, 0.0, -29.262327194213867, -30.270700454711914, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.313093185424805, -18.961654663085938, -20.055986404418945, -19.76070785522461, -19.725265502929688, -19.211742401123047, -18.442380905151367, -17.5345458984375, -17.030851364135742, -15.642047882080078, -14.698674201965332, -13.380416870117188, -11.706536293029785, -11.162408828735352, -10.103017807006836, -9.374273300170898, 0.0, -9.27939224243164, 0.0, 0.0, -8.263277053833008, -4.156493663787842, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.76587200164795, -0.0, -16.713747024536133, -0.0, -14.038135528564453, -10.898566246032715, -12.49447250366211, -11.951079368591309, -11.906451225280762, -13.288268089294434, -15.0907564163208, -16.852190017700195, -18.817533493041992, -20.46137046813965, -22.307065963745117, -23.519439697265625, -25.12816619873047, -25.84255027770996, -26.93132209777832, -27.720930099487305, -28.709495544433594, -29.860191345214844, -0.0, -0.0, -0.0, -32.54420471191406, -32.33283996582031, -0.0, -0.0, -0.0, -0.0, -28.071317672729492, -26.92601203918457, -0.0, -24.36968994140625, -23.33124351501465, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.637554168701172, -19.145126342773438, -20.055986404418945, -19.76070785522461, -19.725265502929688, -19.211742401123047, -18.442380905151367, -17.5345458984375, -17.030851364135742, -15.642047882080078, -14.698674201965332, -13.380416870117188, -11.706536293029785, -11.162408828735352, -10.103017807006836, -9.374273300170898, -0.0, -9.27939224243164, -0.0, -0.0, -8.263277053833008, -4.156493663787842, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.024306297302246, -13.92458724975586, 0.0, -12.321181297302246, -11.386147499084473, -13.253902435302734, -12.711675643920898, -11.483966827392578, -11.846456527709961, -13.102851867675781, -14.85759162902832, -16.957508087158203, -18.776357650756836, -20.909866333007812, -22.16317367553711, -24.2421875, -25.84404182434082, -26.496501922607422, -27.238189697265625, -27.991159439086914, -28.930850982666016, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.608924865722656, 0.0, -27.59147834777832, 0.0, 0.0, 0.0, 0.0, -25.251632690429688, 0.0, 0.0, 0.0, 0.0, 0.0, -17.57876968383789, -19.520856857299805, -19.09050178527832, -18.731006622314453, -18.60230255126953, -18.076175689697266, -17.41718101501465, -16.681310653686523, -15.960124969482422, -14.842828750610352, -13.665247917175293, -12.644659996032715, -11.626593589782715, -10.74563217163086, -10.780832290649414, -10.357161521911621, 0.0, -12.095128059387207, -11.91442584991455, 0.0, -6.8386359214782715, -4.671219348907471, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.024306297302246, -13.92458724975586, -0.0, -12.321181297302246, -11.386147499084473, -13.253902435302734, -12.711675643920898, -11.483966827392578, -11.846456527709961, -13.102851867675781, -14.85759162902832, -16.957508087158203, -18.776357650756836, -20.909866333007812, -22.16317367553711, -24.2421875, -25.84404182434082, -26.358051300048828, -27.24376106262207, -28.24857521057129, -29.43423843383789, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.27597427368164, -0.0, -25.36079978942871, -0.0, -0.0, -0.0, -0.0, -25.906604766845703, -0.0, -0.0, -0.0, -0.0, -0.0, -19.316617965698242, -19.384727478027344, -19.09050178527832, -18.731006622314453, -18.60230255126953, -18.076175689697266, -17.41718101501465, -16.681310653686523, -15.960124969482422, -14.842828750610352, -13.665247917175293, -12.644659996032715, -11.626593589782715, -10.74563217163086, -10.780832290649414, -10.357161521911621, -0.0, -12.095128059387207, -11.91442584991455, -0.0, -6.8386359214782715, -4.671219348907471, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.198127746582031, -13.634328842163086, -11.695575714111328, -11.049649238586426, -13.762558937072754, -11.031107902526855, -11.736265182495117, -13.012328147888184, -11.31724739074707, -11.404117584228516, -12.254137992858887, -14.862524032592773, -16.658294677734375, -19.263853073120117, -21.01104164123535, -22.769271850585938, -24.476001739501953, -25.681875228881836, -26.581518173217773, -27.140567779541016, -28.249605178833008, -29.500164031982422, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.521486282348633, 0.0, 0.0, 0.0, 0.0, -24.603912353515625, -22.492610931396484, 0.0, 0.0, 0.0, 0.0, 0.0, -17.899919509887695, -18.259084701538086, -17.407880783081055, -17.190053939819336, -17.232145309448242, -17.959945678710938, -15.285507202148438, -13.939056396484375, -12.876587867736816, -11.87861156463623, -11.725991249084473, -11.648064613342285, -12.740372657775879, -10.882024765014648, 0.0, 0.0, -13.143473625183105, -11.50753402709961, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.198127746582031, -13.634328842163086, -11.695575714111328, -11.049649238586426, -13.762558937072754, -11.031107902526855, -11.736265182495117, -13.012328147888184, -11.31724739074707, -11.404117584228516, -12.254137992858887, -14.862524032592773, -16.658294677734375, -19.263853073120117, -21.01104164123535, -22.769271850585938, -24.476001739501953, -25.566631317138672, -26.478290557861328, -27.570579528808594, -28.794755935668945, -30.097919464111328, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.848522186279297, -0.0, -0.0, -0.0, -0.0, -26.471317291259766, -24.773738861083984, -0.0, -0.0, -0.0, -0.0, -0.0, -18.157026290893555, -18.259084701538086, -17.407880783081055, -17.190053939819336, -17.232145309448242, -17.959945678710938, -15.285507202148438, -13.939056396484375, -12.876587867736816, -11.87861156463623, -11.725991249084473, -11.648064613342285, -12.740372657775879, -10.882024765014648, -0.0, -0.0, -13.143473625183105, -11.50753402709961, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.889312744140625, -11.52056884765625, -14.517189979553223, -14.534607887268066, -13.322279930114746, -12.989741325378418, -11.396099090576172, -11.27507495880127, -10.778944969177246, -10.436483383178711, -11.61591625213623, -14.402247428894043, -15.649728775024414, -19.796049118041992, -20.61962890625, -22.24064064025879, -23.52557945251465, -24.94478988647461, -26.18225860595703, -27.309358596801758, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.632722854614258, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.6019229888916, -15.450763702392578, -13.622286796569824, -13.457633018493652, -13.54349136352539, -13.172552108764648, -13.312685012817383, -9.855490684509277, -9.628140449523926, -11.357217788696289, -11.838375091552734, -10.650461196899414, -12.63283634185791, -12.534852981567383, -13.123205184936523, -11.013822555541992, -13.814467430114746, -15.73793888092041, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -9.889312744140625, -11.52056884765625, -14.517189979553223, -14.534607887268066, -13.322279930114746, -12.989741325378418, -11.396099090576172, -11.27507495880127, -10.778944969177246, -10.436483383178711, -11.61591625213623, -14.402247428894043, -15.649728775024414, -19.796049118041992, -20.61962890625, -22.24064064025879, -23.860414505004883, -25.434093475341797, -26.79452133178711, -27.989643096923828, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.900367736816406, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.981632232666016, -15.450763702392578, -13.622286796569824, -13.457633018493652, -13.54349136352539, -13.172552108764648, -13.312685012817383, -9.855490684509277, -9.628140449523926, -11.357217788696289, -11.838375091552734, -10.650461196899414, -12.63283634185791, -12.534852981567383, -13.123205184936523, -11.013822555541992, -13.814467430114746, -15.73793888092041, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.685946464538574, -12.373920440673828, -15.916841506958008, -15.256963729858398, -10.3023099899292, -12.843242645263672, -14.7562255859375, -12.999755859375, -11.27547836303711, -10.266155242919922, -9.51237678527832, 0.0, -14.066394805908203, -14.955439567565918, -17.27202796936035, -20.086284637451172, -21.696491241455078, -25.49213981628418, -23.21963119506836, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.684505462646484, 0.0, -26.86334228515625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.970779418945312, -11.698628425598145, -11.925288200378418, 0.0, -15.314167976379395, -16.664623260498047, -14.787477493286133, -9.627936363220215, -9.701170921325684, -11.431419372558594, -11.981460571289062, -13.0232572555542, -13.702581405639648, -13.75682544708252, -13.359580039978027, -14.032541275024414, -17.321332931518555, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.685946464538574, -12.373920440673828, -15.916841506958008, -15.256963729858398, -10.3023099899292, -12.843242645263672, -14.7562255859375, -12.999755859375, -11.27547836303711, -10.266155242919922, -9.51237678527832, -0.0, -14.066394805908203, -14.955439567565918, -17.27202796936035, -20.086284637451172, -22.542625427246094, -24.6825008392334, -26.113920211791992, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.49872589111328, -0.0, -26.21954345703125, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.993171691894531, -11.698628425598145, -11.925288200378418, -0.0, -15.314167976379395, -16.664623260498047, -14.787477493286133, -9.627936363220215, -9.701170921325684, -11.431419372558594, -11.981460571289062, -13.0232572555542, -13.702581405639648, -13.75682544708252, -13.359580039978027, -14.032541275024414, -17.321332931518555, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.155025482177734, 0.0, 0.0, 0.0, -14.037291526794434, -15.37520694732666, -14.444268226623535, -13.40821647644043, -12.164006233215332, -12.387275695800781, -14.27263069152832, -13.277630805969238, 0.0, -19.716001510620117, -18.826040267944336, -21.249595642089844, 0.0, -26.05529022216797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.639286041259766, -10.163858413696289, -9.407694816589355, 0.0, -11.772043228149414, 0.0, -10.482505798339844, -10.147644996643066, -11.992207527160645, -12.27137565612793, -14.330708503723145, -14.55774211883545, -13.838031768798828, -14.884020805358887, -15.248418807983398, -14.311949729919434, -13.87720012664795, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.155025482177734, -0.0, -0.0, -0.0, -14.037291526794434, -15.37520694732666, -14.444268226623535, -13.40821647644043, -12.164006233215332, -12.387275695800781, -14.27263069152832, -13.277630805969238, -0.0, -19.716001510620117, -18.826040267944336, -21.55461883544922, -0.0, -25.45447540283203, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.814242362976074, -10.163858413696289, -9.407694816589355, -0.0, -11.772043228149414, -0.0, -10.482505798339844, -10.147644996643066, -11.992207527160645, -12.27137565612793, -14.330708503723145, -14.55774211883545, -13.838031768798828, -14.884020805358887, -15.248418807983398, -14.311949729919434, -13.87720012664795, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.548418998718262, 0.0, 0.0, 0.0, 0.0, -13.658395767211914, -12.679450988769531, -11.384718894958496, -8.209432601928711, -9.970974922180176, -12.895389556884766, 0.0, -19.642498016357422, 0.0, -19.317264556884766, -18.677322387695312, -19.95880699157715, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.132306098937988, -13.651206016540527, 0.0, 0.0, 0.0, 0.0, -7.90250825881958, 0.0, 0.0, 0.0, -14.215675354003906, -16.343463897705078, 0.0, 0.0, 0.0, -11.439330101013184, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.548418998718262, -0.0, -0.0, -0.0, -0.0, -13.658395767211914, -12.679450988769531, -11.384718894958496, -8.209432601928711, -9.970974922180176, -12.895389556884766, -0.0, -19.642498016357422, -0.0, -19.317264556884766, -18.677322387695312, -19.95880699157715, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.132306098937988, -13.651206016540527, -0.0, -0.0, -0.0, -0.0, -7.90250825881958, -0.0, -0.0, -0.0, -14.215675354003906, -16.343463897705078, -0.0, -0.0, -0.0, -11.439330101013184, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.76700496673584, -12.75717830657959, -9.68898868560791, 0.0, -10.36646842956543, 0.0, -17.99945640563965, 0.0, -21.038387298583984, -19.97816276550293, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.775938034057617, -31.545934677124023, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.31380844116211, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.76700496673584, -12.75717830657959, -9.68898868560791, -0.0, -10.36646842956543, -0.0, -17.99945640563965, -0.0, -21.038387298583984, -19.97816276550293, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -29.775938034057617, -31.545934677124023, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.31380844116211, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.187346458435059, -10.481443405151367, -7.700968265533447, -9.466901779174805, -8.186568260192871, 0.0, 0.0, 0.0, -21.285554885864258, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.71820640563965, -27.542613983154297, -29.715530395507812, 0.0, -30.77251625061035, -31.503847122192383, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -9.187346458435059, -10.481443405151367, -7.700968265533447, -9.466901779174805, -8.186568260192871, -0.0, -0.0, -0.0, -21.285554885864258, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.71820640563965, -27.542613983154297, -29.715530395507812, -0.0, -30.77251625061035, -31.503847122192383, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.220361709594727, 0.0, 0.0, 0.0, 0.0, -24.094234466552734, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.58055877685547, -26.64284896850586, -26.745811462402344, -27.300172805786133, -28.248889923095703, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.220361709594727, -0.0, -0.0, -0.0, -0.0, -24.094234466552734, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.58055877685547, -26.64284896850586, -26.745811462402344, -27.300172805786133, -28.248889923095703, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.38100528717041, 0.0, 0.0, 0.0, 0.0, -21.15644645690918, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.280376434326172, -27.524198532104492, -25.910175323486328, -26.461400985717773, -26.313743591308594, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.38100528717041, -0.0, -0.0, -0.0, -0.0, -21.15644645690918, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.280376434326172, -27.524198532104492, -25.910175323486328, -26.461400985717773, -26.313743591308594, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.057973861694336, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.70781707763672, -24.438459396362305, -27.58793067932129, -28.3867130279541, -27.8092041015625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.057973861694336, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.70781707763672, -24.438459396362305, -27.58793067932129, -28.3867130279541, -27.8092041015625, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.413625717163086, -24.644166946411133, -29.626771926879883, -29.720233917236328, -30.073612213134766, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.413625717163086, -24.644166946411133, -29.626771926879883, -29.720233917236328, -30.073612213134766, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.355976104736328, -25.80002784729004, -26.25397300720215, -26.125202178955078, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.355976104736328, -25.80002784729004, -26.25397300720215, -26.125202178955078, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.538997650146484, -22.27385711669922, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.538997650146484, -22.27385711669922, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.214115142822266, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.214115142822266, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0]]}, {\"colorbar\": {\"title\": {\"text\": \"B<sub>0</sub> (Hz)\"}}, \"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.3333333333333333, \"rgb(230,0,0)\"], [0.6666666666666666, \"rgb(255,210,0)\"], [1.0, \"rgb(255,255,255)\"]], \"name\": \"comparison heatmap\", \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 17.636686325073242, 16.57578468322754, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 17.636686325073242, 16.57578468322754, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.6054303646087646, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.731563091278076, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -3.6054303646087646, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.731563091278076, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.14019811153411865, 0.24018770456314087, 3.260740280151367, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.396512985229492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.14019811153411865, 0.24018770456314087, 3.260740280151367, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.396512985229492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.22650784254074097, 0.6812031865119934, 3.917649984359741, 0.0, 2.7724173069000244, 5.42844295501709, 7.23814058303833, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.159482479095459, 6.0779805183410645, 6.557579040527344, 5.939545631408691, 7.231886386871338, 9.595331192016602, 7.873683452606201, 9.402271270751953, 5.785266876220703, 6.496130466461182, 7.4866862297058105, 4.230364799499512, 6.143450736999512, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.22650784254074097, 0.6812031865119934, 3.917649984359741, 0.0, 2.7724173069000244, 5.42844295501709, 7.23814058303833, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.159482479095459, 6.0779805183410645, 6.557579040527344, 5.939545631408691, 7.231886386871338, 9.595331192016602, 7.873683452606201, 9.402271270751953, 5.785266876220703, 6.496130466461182, 7.4866862297058105, 4.230364799499512, 6.143450736999512, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.33292901515960693, 1.6479480266571045, 3.295247793197632, 2.4828338623046875, 6.180263996124268, 0.0, 5.315324783325195, 6.118890285491943, 0.0, 0.0, 0.0, 0.0, 6.075611114501953, 4.881235122680664, 4.615417957305908, 4.081560134887695, 5.027890682220459, 5.483523368835449, 5.619515419006348, 6.351548671722412, 6.029160022735596, 5.282118320465088, 6.304962635040283, 6.280464172363281, 6.3389177322387695, 6.165802955627441, 7.213161468505859, 6.768268585205078, 6.3993024826049805, 6.411296367645264, 7.36885929107666, 7.513493061065674, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.33292901515960693, 1.6479480266571045, 3.295247793197632, 2.4828338623046875, 6.180263996124268, 0.0, 5.315324783325195, 6.118890285491943, 0.0, 0.0, 0.0, 0.0, 6.075611114501953, 4.881235122680664, 4.615417957305908, 4.081560134887695, 5.027890682220459, 5.483523368835449, 5.619515419006348, 6.351548671722412, 6.029160022735596, 5.282118320465088, 6.304962635040283, 6.280464172363281, 6.3389177322387695, 6.165802955627441, 7.213161468505859, 6.768268585205078, 6.3993024826049805, 6.411296367645264, 7.36885929107666, 7.513493061065674, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.9266557693481445, 4.28237247467041, 4.654541492462158, 6.519122123718262, 0.0, 6.961923122406006, 5.74747896194458, 4.078495979309082, 1.9911690950393677, 4.605457782745361, 3.8040201663970947, 3.8074159622192383, 3.5134952068328857, 3.085170269012451, 3.119018077850342, 2.798642158508301, 2.5624382495880127, 2.199075222015381, 0.0, 1.3147413730621338, 3.0678317546844482, 2.6567881107330322, 3.9733827114105225, 1.4878954887390137, 4.521012306213379, 6.298056125640869, 5.833628177642822, 2.5182414054870605, 4.528542995452881, 4.940316677093506, 5.049505710601807, 5.673017501831055, 5.103689670562744, 7.419971466064453, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.9266557693481445, 4.28237247467041, 4.654541492462158, 6.519122123718262, 0.0, 6.961923122406006, 5.74747896194458, 4.078495979309082, 1.9911690950393677, 4.605457782745361, 3.8040201663970947, 3.8074159622192383, 3.5134952068328857, 3.085170269012451, 3.119018077850342, 2.798642158508301, 2.5624382495880127, 2.199075222015381, 0.0, 1.3147413730621338, 3.0678317546844482, 2.6567881107330322, 3.9733827114105225, 1.4878954887390137, 4.521012306213379, 6.298056125640869, 5.833628177642822, 2.5182414054870605, 4.528542995452881, 4.940316677093506, 5.049505710601807, 5.673017501831055, 5.103689670562744, 7.419971466064453, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.5857937335968018, 0.0, 5.134319305419922, 3.751180410385132, 2.4461982250213623, 1.960828423500061, 3.9563779830932617, 4.917046546936035, 3.484173536300659, 4.530773162841797, 3.305957078933716, 2.47481107711792, 1.885109305381775, 1.508033275604248, 1.5654466152191162, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.3663889169692993, 0.0, 0.0, 0.0, 2.3021137714385986, 3.2283217906951904, 3.762903928756714, 5.367985725402832, 5.340299129486084, 4.656342506408691, 6.084432125091553, 7.477893352508545, 6.239458084106445, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.5857937335968018, 0.0, 5.134319305419922, 3.751180410385132, 2.4461982250213623, 1.960828423500061, 3.9563779830932617, 4.917046546936035, 3.484173536300659, 4.530773162841797, 3.305957078933716, 2.47481107711792, 1.885109305381775, 1.508033275604248, 1.5654466152191162, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.3663889169692993, 0.0, 0.0, 0.0, 2.3021137714385986, 3.2283217906951904, 3.762903928756714, 5.367985725402832, 5.340299129486084, 4.656342506408691, 6.084432125091553, 7.477893352508545, 6.239458084106445, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.797806739807129, 4.373803615570068, 4.615262508392334, 4.350788116455078, 3.5588457584381104, 2.739629030227661, 4.393668174743652, 0.788498044013977, 1.538886547088623, 0.7307926416397095, -0.3012065887451172, 3.2804386615753174, 5.174484729766846, 3.879221200942993, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.056036949157715, 0.0, 0.0, 0.0, 0.0, 0.0, 3.5162575244903564, 3.917863130569458, 3.192966938018799, 3.6991593837738037, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.797806739807129, 4.373803615570068, 4.615262508392334, 4.350788116455078, 3.5588457584381104, 2.739629030227661, 4.393668174743652, 0.788498044013977, 1.538886547088623, 0.7307926416397095, -0.3012065887451172, 3.2804386615753174, 5.174484729766846, 3.879221200942993, 0.0, -0.0, -0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.056036949157715, 0.0, 0.0, 0.0, 0.0, 0.0, 3.5162575244903564, 3.917863130569458, 3.192966938018799, 3.6991593837738037, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.393601417541504, 5.412086486816406, 3.640639066696167, 5.316936016082764, 3.1687660217285156, 4.958736896514893, 4.4518842697143555, 0.0, 0.5183811783790588, 1.451225757598877, 0.24977512657642365, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.266759872436523, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.0692944526672363, 1.8518027067184448, 2.8779430389404297, 4.720438480377197, 5.352139949798584, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.393601417541504, 5.412086486816406, 3.640639066696167, 5.316936016082764, 3.1687660217285156, 4.958736896514893, 4.4518842697143555, 0.0, 0.5183811783790588, 1.451225757598877, 0.24977512657642365, 0.0, -0.0, 0.0, 0.0, 0.0, -0.0, -6.266759872436523, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.0692944526672363, 1.8518027067184448, 2.8779430389404297, 4.720438480377197, 5.352139949798584, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.0203697681427, 5.420382976531982, 3.5329082012176514, 2.9215610027313232, 2.720815420150757, 2.075201988220215, 5.473824501037598, 0.0, 3.1336073875427246, 4.211184978485107, 0.7403291463851929, 3.0400571823120117, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.889450192451477, -3.5659306049346924, -3.863403558731079, -3.1483426094055176, -2.3995816707611084, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.4794306755065918, 0.0, 2.0296716690063477, 5.5990753173828125, 4.93634033203125, 1.9060280323028564, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.0203697681427, 5.420382976531982, 3.5329082012176514, 2.9215610027313232, 2.720815420150757, 2.075201988220215, 5.473824501037598, 0.0, 3.1336073875427246, 4.211184978485107, 0.7403291463851929, 3.0400571823120117, 0.0, 0.0, -0.0, 0.0, -0.0, -0.0, -1.889450192451477, -3.5659306049346924, -3.863403558731079, -3.1483426094055176, -2.3995816707611084, -0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.4794306755065918, 0.0, 2.0296716690063477, 5.5990753173828125, 4.93634033203125, 1.9060280323028564, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.0123138427734375, 2.054166316986084, 1.9972128868103027, 4.652099609375, 4.6102471351623535, 0.5692103505134583, -0.2801523506641388, 0.0, -2.325549364089966, 0.0, 0.0, 0.0, 6.049642086029053, 0.0, 0.0, 0.0, 0.0, 0.0, -0.11688907444477081, 0.5935766100883484, 0.5755524039268494, -1.9335418939590454, -0.17920100688934326, -0.30582740902900696, -0.13818946480751038, 1.311858892440796, 0.7296239137649536, -0.02338528260588646, -1.435851812362671, 1.5880820751190186, 3.0109353065490723, 0.0, -3.3111066818237305, 0.0, 0.0, 1.2982585430145264, 0.0, 0.0, 0.0, 0.0, 0.0, 3.0435476303100586, 4.431191444396973, 0.0, 6.487165927886963, 4.693593502044678, 5.632505416870117, 5.034214496612549, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.0123138427734375, 2.054166316986084, 1.9972128868103027, 4.652099609375, 4.6102471351623535, 0.5692103505134583, -0.2801523506641388, 0.0, -2.325549364089966, 0.0, 0.0, 0.0, 6.049642086029053, 0.0, 0.0, -0.0, -0.0, -0.0, -0.11688907444477081, 0.5935766100883484, 0.5755524039268494, -1.9335418939590454, -0.17920100688934326, -0.30582740902900696, -0.13818946480751038, 1.311858892440796, 0.7296239137649536, -0.02338528260588646, -1.435851812362671, 1.5880820751190186, 3.0109353065490723, -0.0, -3.3111066818237305, -0.0, 0.0, 1.2982585430145264, 0.0, 0.0, 0.0, 0.0, 0.0, 3.0435476303100586, 4.431191444396973, 0.0, 6.487165927886963, 4.693593502044678, 5.632505416870117, 5.034214496612549, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.8329066038131714, 1.5919232368469238, 1.3673852682113647, 0.11476929485797882, 0.0, 0.33142319321632385, 1.46552574634552, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.5762308239936829, -2.512503147125244, -1.6027735471725464, -2.470449447631836, -1.0408878326416016, -1.7286514043807983, -0.8266937732696533, -0.4920696020126343, -0.8755431175231934, -0.42599982023239136, -1.172313928604126, -1.2639029026031494, -0.9390923380851746, -1.2510980367660522, -1.4858564138412476, -0.9708076119422913, -0.7013932466506958, -0.32612714171409607, 0.05888941511511803, -1.2736656665802002, 0.7968998551368713, 0.9109076857566833, 1.41026771068573, 0.0, 0.0, 0.0, 0.0, 3.7912395000457764, 3.092698097229004, 5.844941139221191, 2.0187783241271973, 4.265120983123779, 5.475556373596191, 4.053206443786621, 2.8513805866241455, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.8329066038131714, 1.5919232368469238, 1.3673852682113647, 0.11476929485797882, 0.0, 0.33142319321632385, 1.46552574634552, -0.0, -0.0, 0.0, -0.0, -0.0, -0.0, 0.0, -0.0, -0.0, -0.0, -0.5762308239936829, -2.512503147125244, -1.6027735471725464, -2.470449447631836, -1.0408878326416016, -1.7286514043807983, -0.8266937732696533, -0.4920696020126343, -0.8755431175231934, -0.42599982023239136, -1.172313928604126, -1.2639029026031494, -0.9390923380851746, -1.2510980367660522, -1.4858564138412476, -0.9708076119422913, -0.7013932466506958, -0.32612714171409607, 0.05888941511511803, -1.2736656665802002, 0.7968998551368713, 0.9109076857566833, 1.41026771068573, 0.0, 0.0, 0.0, 0.0, 3.7912395000457764, 3.092698097229004, 5.844941139221191, 2.0187783241271973, 4.265120983123779, 5.475556373596191, 4.053206443786621, 2.8513805866241455, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.3680238723754883, 0.859292209148407, 2.6695122718811035, 2.9631316661834717, 1.3884572982788086, -0.6300414204597473, -1.460382342338562, 0.0, 0.0, 0.0, 0.0, 0.0, -5.446033954620361, -3.4115545749664307, -2.3114066123962402, -0.8470427989959717, -1.0731475353240967, -2.988755464553833, -0.559422492980957, -3.207592725753784, -2.1084554195404053, -2.367928981781006, -0.6963610649108887, -3.3187406063079834, 0.0, -0.8916966915130615, -0.47106173634529114, -0.8347128629684448, -1.1868085861206055, -1.4316383600234985, -1.1764500141143799, -1.282862663269043, -0.6774311661720276, -1.4868381023406982, -0.49066367745399475, -1.0005581378936768, -1.1110526323318481, -0.8209655284881592, -0.5775648951530457, -0.5554633736610413, -0.8703750967979431, -0.37516212463378906, 1.8632887601852417, 2.9748778343200684, 0.0, 0.0, 3.646150827407837, 5.5385284423828125, 5.8372578620910645, 6.489444255828857, 2.8086626529693604, 2.9242470264434814, 4.454265594482422, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.3680238723754883, 0.859292209148407, 2.6695122718811035, 2.9631316661834717, 1.3884572982788086, -0.6300414204597473, -1.460382342338562, 0.0, 0.0, 0.0, 0.0, -0.0, -5.446033954620361, -3.4115545749664307, -2.3114066123962402, -0.8470427989959717, -1.0731475353240967, -2.988755464553833, -0.559422492980957, -3.207592725753784, -2.1084554195404053, -2.367928981781006, -0.6963610649108887, -3.3187406063079834, -0.0, -0.8916966915130615, -0.47106173634529114, -0.8347128629684448, -1.1868085861206055, -1.4316383600234985, -1.1764500141143799, -1.282862663269043, -0.6774311661720276, -1.4868381023406982, -0.49066367745399475, -1.0005581378936768, -1.1110526323318481, -0.8209655284881592, -0.5775648951530457, -0.5554633736610413, -0.8703750967979431, -0.37516212463378906, 1.8632887601852417, 2.9748778343200684, 0.0, 0.0, 3.646150827407837, 5.5385284423828125, 5.8372578620910645, 6.489444255828857, 2.8086626529693604, 2.9242470264434814, 4.454265594482422, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.44967782497406, 0.15277528762817383, 0.8815264105796814, 0.0, 0.0, 1.6104230880737305, 4.729312419891357, 0.0, 0.0, 0.0, 0.0, 1.1745860576629639, 0.876920759677887, -1.2011091709136963, -2.553678512573242, -0.6276897192001343, -2.434609889984131, -2.0161585807800293, -1.417160153388977, -0.818691074848175, -1.8531213998794556, -4.302251815795898, -2.747453451156616, -2.7529289722442627, -3.60744571685791, -3.7251389026641846, -0.47665145993232727, -0.7721360325813293, -0.8740593194961548, -1.0407015085220337, -0.9242554903030396, -0.43680429458618164, -0.03438979387283325, -0.46951815485954285, -1.462560772895813, -1.252431869506836, -0.9426841735839844, -0.009599250741302967, -0.25016656517982483, -0.7570004463195801, 0.05568229407072067, -0.10565901547670364, -0.2439596801996231, -0.4399804174900055, 0.31025877594947815, 0.33451685309410095, 1.515985131263733, 0.0, 0.0, 0.0, 0.0, 0.0, 2.3972578048706055, 2.986539602279663, 5.718956470489502, 6.98223352432251, 3.389817953109741, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.44967782497406, 0.15277528762817383, 0.8815264105796814, 0.0, 0.0, 1.6104230880737305, 4.729312419891357, 0.0, -0.0, -0.0, 0.0, 1.1745860576629639, 0.876920759677887, -1.2011091709136963, -2.553678512573242, -0.6276897192001343, -2.434609889984131, -2.0161585807800293, -1.417160153388977, -0.818691074848175, -1.8531213998794556, -4.302251815795898, -2.747453451156616, -2.7529289722442627, -3.60744571685791, -3.7251389026641846, -0.47665145993232727, -0.7721360325813293, -0.8740593194961548, -1.0407015085220337, -0.9242554903030396, -0.43680429458618164, -0.03438979387283325, -0.46951815485954285, -1.462560772895813, -1.252431869506836, -0.9426841735839844, -0.009599250741302967, -0.25016656517982483, -0.7570004463195801, 0.05568229407072067, -0.10565901547670364, -0.2439596801996231, -0.4399804174900055, 0.31025877594947815, 0.33451685309410095, 1.515985131263733, 0.0, 0.0, 0.0, 0.0, 0.0, 2.3972578048706055, 2.986539602279663, 5.718956470489502, 6.98223352432251, 3.389817953109741, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.26756054162979126, 0.5113227367401123, 0.0, 0.0, 0.0, -2.4650650024414062, 0.0, 0.0, 0.0, 0.0, -4.794459819793701, 0.0, -3.6350576877593994, -2.0399231910705566, -2.031179428100586, -2.4307448863983154, 1.4801331758499146, -1.3919813632965088, -2.1087005138397217, -1.3870209455490112, -1.5091522932052612, -1.1147598028182983, -1.3242177963256836, -2.224590301513672, -3.1529979705810547, -5.333761215209961, -0.8807205557823181, -0.3091415762901306, -0.7863208055496216, -0.5414305925369263, -0.7814005017280579, -0.07051438093185425, -0.9684011340141296, -0.6351864337921143, -0.07982602715492249, -0.777888834476471, -0.3217983841896057, -0.6791261434555054, -0.8763273358345032, -0.3439078629016876, -0.3580842614173889, -0.2890310287475586, -0.8409906029701233, 0.06092303991317749, -0.2850939631462097, -0.21092553436756134, -0.0018302015960216522, -0.015599909238517284, 0.19559410214424133, 0.0, 0.0, 0.0, 0.0, 0.0, 3.0054101943969727, 2.6997432708740234, 3.284910202026367, 5.621175765991211, 2.5792741775512695, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.26756054162979126, 0.5113227367401123, 0.0, 0.0, 0.0, -2.4650650024414062, 0.0, 0.0, 0.0, -0.0, -4.794459819793701, -0.0, -3.6350576877593994, -2.0399231910705566, -2.031179428100586, -2.4307448863983154, 1.4801331758499146, -1.3919813632965088, -2.1087005138397217, -1.3870209455490112, -1.5091522932052612, -1.1147598028182983, -1.3242177963256836, -2.224590301513672, -3.1529979705810547, -5.333761215209961, -0.8807205557823181, -0.3091415762901306, -0.7863208055496216, -0.5414305925369263, -0.7814005017280579, -0.07051438093185425, -0.9684011340141296, -0.6351864337921143, -0.07982602715492249, -0.777888834476471, -0.3217983841896057, -0.6791261434555054, -0.8763273358345032, -0.3439078629016876, -0.3580842614173889, -0.2890310287475586, -0.8409906029701233, 0.06092303991317749, -0.2850939631462097, -0.21092553436756134, -0.0018302015960216522, -0.015599909238517284, 0.19559410214424133, 0.0, -0.0, -0.0, 0.0, 0.0, 3.0054101943969727, 2.6997432708740234, 3.284910202026367, 5.621175765991211, 2.5792741775512695, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.155937910079956, -0.28201258182525635, -0.597604513168335, -1.2623801231384277, 0.0, 0.0, -0.7474828958511353, 0.0, 0.0, 0.0, 0.17263291776180267, 0.0, -5.194499969482422, -2.376004219055176, -2.1361083984375, -2.302219867706299, -2.410039186477661, -1.667271375656128, -0.663642168045044, -1.1805559396743774, -1.3782823085784912, -1.8436349630355835, -2.161886215209961, -0.8198353052139282, -1.5898596048355103, 0.6044554710388184, 0.7188502550125122, -0.9538174867630005, -0.8629899621009827, -0.7103312611579895, -1.1156010627746582, -0.5926653146743774, -0.4321729838848114, -0.7575280666351318, -0.6907051801681519, -0.22337469458580017, 0.322309285402298, -0.6376094818115234, -0.6392635703086853, -0.40184175968170166, -0.2791900634765625, -0.23785045742988586, -0.289699912071228, -0.054948680102825165, -0.2885322868824005, -0.14769473671913147, -0.08634625375270844, 0.2719675898551941, -0.3818040192127228, -0.19247835874557495, -0.6247099041938782, 0.5193843245506287, -1.563072919845581, 0.0, 0.0, 0.0, 2.8557963371276855, 4.177346706390381, 0.0, 3.0808568000793457, 4.427241802215576, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 1.155937910079956, -0.28201258182525635, -0.597604513168335, -1.2623801231384277, -0.0, -0.0, -0.7474828958511353, 0.0, -0.0, 0.0, 0.17263291776180267, -0.0, -5.194499969482422, -2.376004219055176, -2.1361083984375, -2.302219867706299, -2.410039186477661, -1.667271375656128, -0.663642168045044, -1.1805559396743774, -1.3782823085784912, -1.8436349630355835, -2.161886215209961, -0.8198353052139282, -1.5898596048355103, 0.6044554710388184, 0.7188502550125122, -0.9538174867630005, -0.8629899621009827, -0.7103312611579895, -1.1156010627746582, -0.5926653146743774, -0.4321729838848114, -0.7575280666351318, -0.6907051801681519, -0.22337469458580017, 0.322309285402298, -0.6376094818115234, -0.6392635703086853, -0.40184175968170166, -0.2791900634765625, -0.23785045742988586, -0.289699912071228, -0.054948680102825165, -0.2885322868824005, -0.14769473671913147, -0.08634625375270844, 0.2719675898551941, -0.3818040192127228, -0.19247835874557495, -0.6247099041938782, 0.5193843245506287, -1.563072919845581, -0.0, 0.0, 0.0, 2.8557963371276855, 4.177346706390381, 0.0, 3.0808568000793457, 4.427241802215576, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.5165690183639526, 0.5100416541099548, -1.1653938293457031, -3.512545585632324, -1.7418140172958374, -0.6144406795501709, 0.0, 0.0, 0.0, 0.0, -1.1119612455368042, -3.359823226928711, -3.3236560821533203, -2.9960625171661377, -2.6828155517578125, -2.125986099243164, -2.4330763816833496, -2.212111711502075, -1.5706095695495605, -1.2050973176956177, -1.251175045967102, -1.7294692993164062, -1.7681074142456055, -1.1413403749465942, -0.9147980809211731, -0.5076744556427002, -0.6879634261131287, -0.2218310385942459, -0.9272681474685669, -1.1515201330184937, -0.275236040353775, -0.24888592958450317, -0.6908521056175232, -0.37686097621917725, -0.7185952067375183, -0.9276134967803955, -0.14701156318187714, -0.8939749002456665, -0.38222432136535645, 0.2221587896347046, 0.04517247527837753, -0.00346124148927629, -1.030287742614746, -0.5405792593955994, 0.15966840088367462, 0.1389702558517456, -0.37814366817474365, 0.46209263801574707, 0.002336112316697836, -0.06923751533031464, -0.417603462934494, -0.7295142412185669, -0.7179409265518188, -0.2201460599899292, 0.0, 0.0, 0.0, 0.0, 3.584566831588745, 0.0, 1.9800729751586914, 4.391569137573242, 4.069882869720459, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.5165690183639526, 0.5100416541099548, -1.1653938293457031, -3.512545585632324, -1.7418140172958374, -0.6144406795501709, -0.0, -0.0, -0.0, -0.0, -1.1119612455368042, -3.359823226928711, -3.3236560821533203, -2.9960625171661377, -2.6828155517578125, -2.125986099243164, -2.4330763816833496, -2.212111711502075, -1.5706095695495605, -1.2050973176956177, -1.251175045967102, -1.7294692993164062, -1.7681074142456055, -1.1413403749465942, -0.9147980809211731, -0.5076744556427002, -0.6879634261131287, -0.2218310385942459, -0.9272681474685669, -1.1515201330184937, -0.275236040353775, -0.24888592958450317, -0.6908521056175232, -0.37686097621917725, -0.7185952067375183, -0.9276134967803955, -0.14701156318187714, -0.8939749002456665, -0.38222432136535645, 0.2221587896347046, 0.04517247527837753, -0.00346124148927629, -1.030287742614746, -0.5405792593955994, 0.15966840088367462, 0.1389702558517456, -0.37814366817474365, 0.46209263801574707, 0.002336112316697836, -0.06923751533031464, -0.417603462934494, -0.7295142412185669, -0.7179409265518188, -0.2201460599899292, -0.0, -0.0, -0.0, 0.0, 3.584566831588745, 0.0, 1.9800729751586914, 4.391569137573242, 4.069882869720459, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5174341201782227, 1.6516929864883423, -0.6242079734802246, 0.0, 0.2973981201648712, 0.37756630778312683, 0.0, 0.0, 0.0, 0.0, -3.635169267654419, -3.5763096809387207, -3.3714120388031006, -2.998676061630249, -2.962806463241577, -3.082750082015991, -2.347177028656006, -2.045863389968872, -1.6986547708511353, -1.2664227485656738, -1.0201624631881714, -1.0235544443130493, -1.7175413370132446, -0.7353366017341614, -0.8588924407958984, -1.2101699113845825, -1.0478612184524536, -1.5111271142959595, -0.8051304817199707, -0.3811676502227783, -0.269599586725235, -0.08700727671384811, -0.8170804977416992, -0.8440367579460144, 0.40095552802085876, 0.7453929781913757, -0.5818103551864624, -0.8562020063400269, 0.21342730522155762, -0.09404383599758148, -0.08346305042505264, -0.1582612246274948, -0.7317858934402466, 0.20695872604846954, -0.024335836991667747, -0.3616432845592499, 0.7831229567527771, -0.1451377123594284, -0.15840989351272583, -0.10541676729917526, -0.24894577264785767, 0.01882561668753624, -0.2695341110229492, 0.1400550901889801, -0.24563927948474884, -0.24251671135425568, -0.3932092785835266, -1.8998603820800781, 0.0, 0.0, 4.263415813446045, 0.0, 2.316786527633667, 4.498852729797363, 5.357853412628174, 5.360635757446289, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.5174341201782227, 1.6516929864883423, -0.6242079734802246, -0.0, 0.2973981201648712, 0.37756630778312683, -0.0, -0.0, -0.0, -0.0, -3.635169267654419, -3.5763096809387207, -3.3714120388031006, -2.998676061630249, -2.962806463241577, -3.082750082015991, -2.347177028656006, -2.045863389968872, -1.6986547708511353, -1.2664227485656738, -1.0201624631881714, -1.0235544443130493, -1.7175413370132446, -0.7353366017341614, -0.8588924407958984, -1.2101699113845825, -1.0478612184524536, -1.5111271142959595, -0.8051304817199707, -0.3811676502227783, -0.269599586725235, -0.08700727671384811, -0.8170804977416992, -0.8440367579460144, 0.40095552802085876, 0.7453929781913757, -0.5818103551864624, -0.8562020063400269, 0.21342730522155762, -0.09404383599758148, -0.08346305042505264, -0.1582612246274948, -0.7317858934402466, 0.20695872604846954, -0.024335836991667747, -0.3616432845592499, 0.7831229567527771, -0.1451377123594284, -0.15840989351272583, -0.10541676729917526, -0.24894577264785767, 0.01882561668753624, -0.2695341110229492, 0.1400550901889801, -0.24563927948474884, -0.24251671135425568, -0.3932092785835266, -1.8998603820800781, -0.0, 0.0, 4.263415813446045, 0.0, 2.316786527633667, 4.498852729797363, 5.357853412628174, 5.360635757446289, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.6178293228149414, -0.9048885703086853, 0.0, 0.0, 2.213955879211426, 0.0, 0.0, 0.0, -0.5993927121162415, -3.5957791805267334, -3.683624029159546, -3.6578311920166016, -3.3815431594848633, -3.0958852767944336, -2.382215738296509, -2.5298633575439453, -2.5770277976989746, -1.7135015726089478, -1.764298439025879, -1.4156872034072876, -1.0727548599243164, -1.1185119152069092, -1.3588519096374512, -1.2696666717529297, -1.5647051334381104, -0.8552989959716797, -0.9864799380302429, -0.9263268113136292, 0.0014553029322996736, -0.4617297649383545, -0.5653929710388184, -0.6014876961708069, -0.19931437075138092, -0.015408285893499851, -0.9518915414810181, -0.24997290968894958, -0.08524513244628906, -0.0833258181810379, 0.5020483732223511, 0.009113998152315617, -0.4311891794204712, -0.2882261872291565, -0.17512324452400208, 0.09023015201091766, 0.2594742476940155, 0.032720036804676056, -0.40881994366645813, 0.4118274450302124, 0.6810048818588257, 0.9404945373535156, -0.9022237658500671, -0.13049112260341644, -0.1998097002506256, -0.617897093296051, 0.038197364658117294, 0.14052660763263702, -0.6542211174964905, -0.11078871041536331, 0.0, 0.0, 0.0, 1.5043505430221558, 0.0, 0.0, 3.990917205810547, 5.3270111083984375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -1.6178293228149414, -0.9048885703086853, -0.0, 0.0, 2.213955879211426, 0.0, 0.0, -0.0, -0.5993927121162415, -3.5957791805267334, -3.683624029159546, -3.6578311920166016, -3.3815431594848633, -3.0958852767944336, -2.382215738296509, -2.5298633575439453, -2.5770277976989746, -1.7135015726089478, -1.764298439025879, -1.4156872034072876, -1.0727548599243164, -1.1185119152069092, -1.3588519096374512, -1.2696666717529297, -1.5647051334381104, -0.8552989959716797, -0.9864799380302429, -0.9263268113136292, 0.0014553029322996736, -0.4617297649383545, -0.5653929710388184, -0.6014876961708069, -0.19931437075138092, -0.015408285893499851, -0.9518915414810181, -0.24997290968894958, -0.08524513244628906, -0.0833258181810379, 0.5020483732223511, 0.009113998152315617, -0.4311891794204712, -0.2882261872291565, -0.17512324452400208, 0.09023015201091766, 0.2594742476940155, 0.032720036804676056, -0.40881994366645813, 0.4118274450302124, 0.6810048818588257, 0.9404945373535156, -0.9022237658500671, -0.13049112260341644, -0.1998097002506256, -0.617897093296051, 0.038197364658117294, 0.14052660763263702, -0.6542211174964905, -0.11078871041536331, -0.0, 0.0, 0.0, 1.5043505430221558, 0.0, 0.0, 3.990917205810547, 5.3270111083984375, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.5295171737670898, -1.8324905633926392, 0.0, 0.0, -4.8184895515441895, 0.0, 0.0, 0.0, -2.8226237297058105, -3.4397425651550293, -3.967984437942505, -3.634516477584839, -2.847402572631836, -2.31897234916687, -3.0809266567230225, -2.91055965423584, -2.1799778938293457, -1.516945481300354, -1.5546619892120361, -1.703623652458191, -2.405573844909668, -1.2730000019073486, -1.1171547174453735, -0.9763280749320984, -0.9119887948036194, -1.531577467918396, -1.0759742259979248, -1.0335392951965332, -1.0787817239761353, -0.5182017087936401, -0.21252094209194183, -0.6157514452934265, -0.3279597759246826, -0.647737443447113, 0.20627270638942719, 0.1478467732667923, -0.056859973818063736, -0.2539899945259094, 0.3978809118270874, 0.20754465460777283, 0.21735385060310364, 0.027091240510344505, 0.339214026927948, 0.45264795422554016, 0.41021472215652466, 0.6850714087486267, 1.051210880279541, 0.6539543271064758, -0.5080692172050476, 0.39518409967422485, 0.40374499559402466, -0.4344028830528259, -0.20270936191082, -0.44019410014152527, 0.053989116102457047, 0.3548077940940857, -0.06902983784675598, 0.007509651593863964, -0.16081111133098602, 0.4601157307624817, 0.0, 0.0, 0.0, -0.5565848350524902, 0.0, 0.0, 4.460549831390381, 7.821489334106445, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -1.5295171737670898, -1.8324905633926392, -0.0, -0.0, -4.8184895515441895, 0.0, 0.0, -0.0, -2.8226237297058105, -3.4397425651550293, -3.967984437942505, -3.634516477584839, -2.847402572631836, -2.31897234916687, -3.0809266567230225, -2.91055965423584, -2.1799778938293457, -1.516945481300354, -1.5546619892120361, -1.703623652458191, -2.405573844909668, -1.2730000019073486, -1.1171547174453735, -0.9763280749320984, -0.9119887948036194, -1.531577467918396, -1.0759742259979248, -1.0335392951965332, -1.0787817239761353, -0.5182017087936401, -0.21252094209194183, -0.6157514452934265, -0.3279597759246826, -0.647737443447113, 0.20627270638942719, 0.1478467732667923, -0.056859973818063736, -0.2539899945259094, 0.3978809118270874, 0.20754465460777283, 0.21735385060310364, 0.027091240510344505, 0.339214026927948, 0.45264795422554016, 0.41021472215652466, 0.6850714087486267, 1.051210880279541, 0.6539543271064758, -0.5080692172050476, 0.39518409967422485, 0.40374499559402466, -0.4344028830528259, -0.20270936191082, -0.44019410014152527, 0.053989116102457047, 0.3548077940940857, -0.06902983784675598, 0.007509651593863964, -0.16081111133098602, 0.4601157307624817, 0.0, 0.0, 0.0, -0.5565848350524902, 0.0, 0.0, 4.460549831390381, 7.821489334106445, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.36260172724723816, -0.7341391444206238, 2.2536401748657227, -0.9844958782196045, -0.4146254062652588, -0.9317900538444519, 0.0, 0.0, 0.0, -2.89850115776062, -3.0440499782562256, -3.536900043487549, -2.6088674068450928, -3.1084184646606445, -3.325702428817749, -3.068605661392212, -2.4395627975463867, -2.1224398612976074, -2.6279211044311523, -1.5930777788162231, -1.2870579957962036, -1.8430652618408203, -1.74873948097229, -1.099177598953247, -2.187088966369629, -0.807687520980835, -0.44416457414627075, -0.3477737307548523, -1.209790825843811, -0.7077975273132324, -1.3706626892089844, -0.33011505007743835, 0.2210443913936615, -0.20339831709861755, 0.0954158678650856, -0.6149583458900452, -1.130061149597168, -0.29519903659820557, 0.7879237532615662, -0.002468323800712824, 0.5324571132659912, 0.38320019841194153, 0.8250689506530762, 0.4503432512283325, 0.4422045350074768, 1.20494544506073, 0.44266873598098755, 0.3220725953578949, 0.1307304948568344, 0.2709745168685913, -0.02697082795202732, 0.5219834446907043, 0.019887762144207954, 0.17040373384952545, 0.33997970819473267, -0.1594206541776657, -0.3712870180606842, 0.02384367026388645, -0.0316338911652565, 0.3103119432926178, 0.4563003480434418, 0.36454150080680847, 2.9473583698272705, 0.0, 0.0, 0.0, -1.083174705505371, 0.0, 0.0, 8.056095123291016, 5.287419319152832, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.36260172724723816, -0.7341391444206238, 2.2536401748657227, -0.9844958782196045, -0.4146254062652588, -0.9317900538444519, -0.0, -0.0, -0.0, -2.89850115776062, -3.0440499782562256, -3.536900043487549, -2.6088674068450928, -3.1084184646606445, -3.325702428817749, -3.068605661392212, -2.4395627975463867, -2.1224398612976074, -2.6279211044311523, -1.5930777788162231, -1.2870579957962036, -1.8430652618408203, -1.74873948097229, -1.099177598953247, -2.187088966369629, -0.807687520980835, -0.44416457414627075, -0.3477737307548523, -1.209790825843811, -0.7077975273132324, -1.3706626892089844, -0.33011505007743835, 0.2210443913936615, -0.20339831709861755, 0.0954158678650856, -0.6149583458900452, -1.130061149597168, -0.29519903659820557, 0.7879237532615662, -0.002468323800712824, 0.5324571132659912, 0.38320019841194153, 0.8250689506530762, 0.4503432512283325, 0.4422045350074768, 1.20494544506073, 0.44266873598098755, 0.3220725953578949, 0.1307304948568344, 0.2709745168685913, -0.02697082795202732, 0.5219834446907043, 0.019887762144207954, 0.17040373384952545, 0.33997970819473267, -0.1594206541776657, -0.3712870180606842, 0.02384367026388645, -0.0316338911652565, 0.3103119432926178, 0.4563003480434418, 0.36454150080680847, 2.9473583698272705, 0.0, 0.0, 0.0, -1.083174705505371, 0.0, 0.0, 8.056095123291016, 5.287419319152832, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -1.3663275241851807, -0.7722707986831665, 0.49663007259368896, -1.5861209630966187, 1.6345027685165405, 0.0, 0.0, 0.0, -2.4554593563079834, -3.6635806560516357, -3.0116052627563477, -3.538177967071533, -3.5840060710906982, -3.251553773880005, -3.5560739040374756, -3.024207353591919, -2.5545899868011475, -2.3309881687164307, -2.4173941612243652, -1.8925256729125977, -1.6195091009140015, -0.8659574389457703, -0.8553115725517273, -2.2669992446899414, -0.8074297308921814, -0.6914829015731812, 0.124815434217453, -0.23076744377613068, -0.9461573362350464, -0.541964590549469, -1.0582239627838135, -0.12177616357803345, -1.210491418838501, -0.9865743517875671, 0.14947623014450073, 0.19592410326004028, -0.4177299737930298, -0.3117274343967438, 0.010925237089395523, -0.06550565361976624, 0.19308656454086304, 0.27056172490119934, 0.8550186157226562, 0.3391435444355011, 0.027190785855054855, 0.016575241461396217, -0.05362642556428909, -0.3175104558467865, -0.12308380007743835, 0.049143437296152115, 0.23464079201221466, -0.4874425530433655, -0.06971234828233719, -0.5862559080123901, 0.09370681643486023, 0.3187553882598877, 0.2880062460899353, -0.08327358961105347, -0.09071187674999237, 0.12409447878599167, 1.459031105041504, -0.1156124398112297, -0.2560308873653412, 0.0, 0.0, 0.0, 0.0, 8.764065742492676, 0.0, 0.0, 5.751201629638672, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -1.3663275241851807, -0.7722707986831665, 0.49663007259368896, -1.5861209630966187, 1.6345027685165405, -0.0, -0.0, -0.0, -2.4554593563079834, -3.6635806560516357, -3.0116052627563477, -3.538177967071533, -3.5840060710906982, -3.251553773880005, -3.5560739040374756, -3.024207353591919, -2.5545899868011475, -2.3309881687164307, -2.4173941612243652, -1.8925256729125977, -1.6195091009140015, -0.8659574389457703, -0.8553115725517273, -2.2669992446899414, -0.8074297308921814, -0.6914829015731812, 0.124815434217453, -0.23076744377613068, -0.9461573362350464, -0.541964590549469, -1.0582239627838135, -0.12177616357803345, -1.210491418838501, -0.9865743517875671, 0.14947623014450073, 0.19592410326004028, -0.4177299737930298, -0.3117274343967438, 0.010925237089395523, -0.06550565361976624, 0.19308656454086304, 0.27056172490119934, 0.8550186157226562, 0.3391435444355011, 0.027190785855054855, 0.016575241461396217, -0.05362642556428909, -0.3175104558467865, -0.12308380007743835, 0.049143437296152115, 0.23464079201221466, -0.4874425530433655, -0.06971234828233719, -0.5862559080123901, 0.09370681643486023, 0.3187553882598877, 0.2880062460899353, -0.08327358961105347, -0.09071187674999237, 0.12409447878599167, 1.459031105041504, -0.1156124398112297, -0.2560308873653412, -0.0, -0.0, 0.0, 0.0, 8.764065742492676, 0.0, 0.0, 5.751201629638672, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, -3.563253402709961, -2.576934576034546, 0.0, 0.0, 0.1300382763147354, 1.8972241878509521, 0.0, 0.0, -5.854478359222412, -4.550668239593506, -4.078863143920898, -4.65127420425415, -3.4992566108703613, -2.922852039337158, -3.4417502880096436, -3.4187774658203125, -2.973146677017212, -2.8636202812194824, -2.4325602054595947, -2.0328969955444336, -1.7487398386001587, -1.7748750448226929, -1.7439969778060913, -1.494899034500122, -1.2281904220581055, -0.3720071017742157, -1.1205940246582031, -0.8890665173530579, -0.6216649413108826, 0.04934544116258621, -0.12496121972799301, 0.08197499066591263, -1.2335889339447021, -0.029552195221185684, -0.12968577444553375, 0.21464653313159943, 0.18443980813026428, 0.04703303426504135, -0.08759237080812454, 0.3503462076187134, -0.262626588344574, -0.2518180310726166, 0.5378555655479431, 0.5417298078536987, 0.5926139950752258, 0.7288081049919128, 0.18006886541843414, 0.918449878692627, 0.5811947584152222, -0.17176692187786102, -0.6292020082473755, 0.30798405408859253, 0.1562855988740921, 0.08656222373247147, -0.05254348739981651, 0.844101071357727, 0.4984918534755707, 1.2400286197662354, -0.19937781989574432, 0.333269864320755, 0.3899669051170349, 0.7646659016609192, -0.09814124554395676, -0.047899287194013596, -0.12194351851940155, 0.0, 0.0, 0.0, 6.2460479736328125, 0.0, 0.0, 5.938043117523193, 7.3133463859558105, 0.0, 0.0, -0.0, -0.0, -0.0, -3.563253402709961, -2.576934576034546, -0.0, 0.0, 0.1300382763147354, 1.8972241878509521, 0.0, -0.0, -5.854478359222412, -4.550668239593506, -4.078863143920898, -4.65127420425415, -3.4992566108703613, -2.922852039337158, -3.4417502880096436, -3.4187774658203125, -2.973146677017212, -2.8636202812194824, -2.4325602054595947, -2.0328969955444336, -1.7487398386001587, -1.7748750448226929, -1.7439969778060913, -1.494899034500122, -1.2281904220581055, -0.3720071017742157, -1.1205940246582031, -0.8890665173530579, -0.6216649413108826, 0.04934544116258621, -0.12496121972799301, 0.08197499066591263, -1.2335889339447021, -0.029552195221185684, -0.12968577444553375, 0.21464653313159943, 0.18443980813026428, 0.04703303426504135, -0.08759237080812454, 0.3503462076187134, -0.262626588344574, -0.2518180310726166, 0.5378555655479431, 0.5417298078536987, 0.5926139950752258, 0.7288081049919128, 0.18006886541843414, 0.918449878692627, 0.5811947584152222, -0.17176692187786102, -0.6292020082473755, 0.30798405408859253, 0.1562855988740921, 0.08656222373247147, -0.05254348739981651, 0.844101071357727, 0.4984918534755707, 1.2400286197662354, -0.19937781989574432, 0.333269864320755, 0.3899669051170349, 0.7646659016609192, -0.09814124554395676, -0.047899287194013596, -0.12194351851940155, -0.0, 0.0, 0.0, 6.2460479736328125, 0.0, 0.0, 5.938043117523193, 7.3133463859558105, 0.0, 0.0], [0.0, 0.0, 0.0, -2.8384475708007812, 0.0, 0.0, -0.4298512935638428, 0.0, 0.0, 0.0, 0.0, -5.944841384887695, -5.188261985778809, -4.949771881103516, -4.5031938552856445, -3.4578542709350586, -2.799639940261841, -3.3552680015563965, -3.483128547668457, -3.476149559020996, -2.166693925857544, -2.031310558319092, -2.4559643268585205, -1.57261061668396, -2.0840792655944824, -0.639658510684967, -0.8433517217636108, -0.6080654859542847, -1.3223556280136108, -0.3371089696884155, -0.24805320799350739, -0.8440955877304077, -0.6256881356239319, -0.876543402671814, 0.424796462059021, 0.32299867272377014, -0.8148321509361267, 0.5468360185623169, 0.3467632830142975, 0.20854923129081726, 0.6189655065536499, 0.531669557094574, 0.3680324852466583, -0.7549737095832825, 0.5156838893890381, 0.23255839943885803, 0.10000868886709213, 0.4269073009490967, -0.4479776620864868, 0.8203960061073303, 0.5247735977172852, 0.6803775429725647, 0.040863554924726486, 0.2854849696159363, 0.009486563503742218, 0.6126995086669922, 0.3216172158718109, 0.359514445066452, 0.0617285892367363, 0.5247185826301575, 0.7337047457695007, 0.1998441368341446, 0.19526146352291107, -0.2563411295413971, 0.6935067176818848, 0.10130773484706879, 0.46281179785728455, -0.08334989100694656, 0.16043134033679962, 0.0, 0.0, 0.0, 0.7781863212585449, 0.0, 0.0, 6.235336780548096, 6.7283148765563965, 0.0, -0.0, -0.0, -0.0, -2.8384475708007812, -0.0, -0.0, -0.4298512935638428, 0.0, 0.0, 0.0, -0.0, -5.944841384887695, -5.188261985778809, -4.949771881103516, -4.5031938552856445, -3.4578542709350586, -2.799639940261841, -3.3552680015563965, -3.483128547668457, -3.476149559020996, -2.166693925857544, -2.031310558319092, -2.4559643268585205, -1.57261061668396, -2.0840792655944824, -0.639658510684967, -0.8433517217636108, -0.6080654859542847, -1.3223556280136108, -0.3371089696884155, -0.24805320799350739, -0.8440955877304077, -0.6256881356239319, -0.876543402671814, 0.424796462059021, 0.32299867272377014, -0.8148321509361267, 0.5468360185623169, 0.3467632830142975, 0.20854923129081726, 0.6189655065536499, 0.531669557094574, 0.3680324852466583, -0.7549737095832825, 0.5156838893890381, 0.23255839943885803, 0.10000868886709213, 0.4269073009490967, -0.4479776620864868, 0.8203960061073303, 0.5247735977172852, 0.6803775429725647, 0.040863554924726486, 0.2854849696159363, 0.009486563503742218, 0.6126995086669922, 0.3216172158718109, 0.359514445066452, 0.0617285892367363, 0.5247185826301575, 0.7337047457695007, 0.1998441368341446, 0.19526146352291107, -0.2563411295413971, 0.6935067176818848, 0.10130773484706879, 0.46281179785728455, -0.08334989100694656, 0.16043134033679962, 0.0, 0.0, 0.0, 0.7781863212585449, 0.0, 0.0, 6.235336780548096, 6.7283148765563965, 0.0], [0.0, 0.0, -1.5899691581726074, 0.0, 0.0, 0.0, -2.124828815460205, 0.0, 0.0, 0.0, -6.365909576416016, -5.235391139984131, -4.156935691833496, -4.433414936065674, -4.108907699584961, -3.6894643306732178, -3.430882215499878, -3.555753469467163, -2.693446636199951, -3.620291233062744, -1.826474666595459, -3.0795023441314697, -2.145479679107666, -2.8174049854278564, -1.2516998052597046, -1.378082036972046, -1.7565664052963257, -1.0273336172103882, -0.8091980814933777, -0.5595195293426514, -1.185084342956543, -0.6990721225738525, -0.8865737318992615, -0.6591506004333496, -0.694415271282196, -0.39692574739456177, -0.4006558656692505, -0.19701765477657318, 0.1535634547472, 0.4021278917789459, 0.3275708556175232, 0.3462139368057251, 1.0892176628112793, 0.6483722925186157, 0.10236229747533798, 0.8850693106651306, -0.20655754208564758, 0.4442250728607178, 0.7902906537055969, 0.15206372737884521, 0.46566203236579895, 1.079866886138916, 1.0118119716644287, 0.18510989844799042, 1.4293432235717773, 0.6702369451522827, 0.21394546329975128, 0.09839396178722382, 0.1063389703631401, 0.4167107045650482, 0.4891275465488434, 0.08035947382450104, 0.44254404306411743, 0.3334759473800659, -0.3511708974838257, 0.06500842422246933, -0.0022770692594349384, 0.08117522299289703, -0.36084046959877014, 0.061879828572273254, 0.0, 0.0, 3.1472156047821045, 0.0, 0.0, 7.07028341293335, 5.752497673034668, 0.0, -0.0, -0.0, -1.5899691581726074, -0.0, -0.0, -0.0, -2.124828815460205, -0.0, -0.0, -0.0, -6.365909576416016, -5.235391139984131, -4.156935691833496, -4.433414936065674, -4.108907699584961, -3.6894643306732178, -3.430882215499878, -3.555753469467163, -2.693446636199951, -3.620291233062744, -1.826474666595459, -3.0795023441314697, -2.145479679107666, -2.8174049854278564, -1.2516998052597046, -1.378082036972046, -1.7565664052963257, -1.0273336172103882, -0.8091980814933777, -0.5595195293426514, -1.185084342956543, -0.6990721225738525, -0.8865737318992615, -0.6591506004333496, -0.694415271282196, -0.39692574739456177, -0.4006558656692505, -0.19701765477657318, 0.1535634547472, 0.4021278917789459, 0.3275708556175232, 0.3462139368057251, 1.0892176628112793, 0.6483722925186157, 0.10236229747533798, 0.8850693106651306, -0.20655754208564758, 0.4442250728607178, 0.7902906537055969, 0.15206372737884521, 0.46566203236579895, 1.079866886138916, 1.0118119716644287, 0.18510989844799042, 1.4293432235717773, 0.6702369451522827, 0.21394546329975128, 0.09839396178722382, 0.1063389703631401, 0.4167107045650482, 0.4891275465488434, 0.08035947382450104, 0.44254404306411743, 0.3334759473800659, -0.3511708974838257, 0.06500842422246933, -0.0022770692594349384, 0.08117522299289703, -0.36084046959877014, 0.061879828572273254, 0.0, 0.0, 3.1472156047821045, 0.0, 0.0, 7.07028341293335, 5.752497673034668, 0.0], [0.0, -5.259215831756592, -3.274538040161133, 0.0, 0.0, -3.0078601837158203, 0.0, 0.0, 0.0, -6.062231063842773, -5.938653945922852, -5.126132011413574, -4.797916412353516, -4.6319050788879395, -4.179871559143066, -4.484105110168457, -4.852449893951416, -3.654279947280884, -2.864710807800293, -1.9292120933532715, -2.9244086742401123, -2.1688544750213623, -2.4014124870300293, -1.9446974992752075, -1.2818132638931274, -2.177708625793457, -1.1407848596572876, -1.0284849405288696, -0.29012882709503174, -0.46121492981910706, -0.5810028910636902, -0.8883090019226074, -0.7686072587966919, -0.03283990919589996, -0.30033135414123535, 0.42004865407943726, 0.4928091764450073, 0.5556743144989014, 0.8631134033203125, -0.3350845277309418, -0.08763726055622101, 0.4128911793231964, 0.6168627142906189, 0.40963318943977356, 1.0439116954803467, 0.6903136968612671, 0.02276918664574623, 0.3839455544948578, 0.39508211612701416, 1.4073222875595093, 0.3053227961063385, 1.0605534315109253, 0.5584703683853149, 0.31537914276123047, 1.8725571632385254, 0.12080726772546768, -0.05918686091899872, 0.5278858542442322, 0.36450546979904175, 1.1994935274124146, -0.5573234558105469, 0.6091391444206238, 0.9509237408638, 0.18556933104991913, -0.16863486170768738, 0.5961484909057617, 0.3567073941230774, -0.12453117221593857, 0.5094311833381653, 0.1251739114522934, -0.6590092778205872, 0.0, 0.0, 0.0, 1.7322206497192383, 3.30690336227417, 5.4718427658081055, 7.301167011260986, -0.0, -5.259215831756592, -3.274538040161133, -0.0, -0.0, -3.0078601837158203, -0.0, -0.0, -0.0, -6.062231063842773, -5.938653945922852, -5.126132011413574, -4.797916412353516, -4.6319050788879395, -4.179871559143066, -4.484105110168457, -4.852449893951416, -3.654279947280884, -2.864710807800293, -1.9292120933532715, -2.9244086742401123, -2.1688544750213623, -2.4014124870300293, -1.9446974992752075, -1.2818132638931274, -2.177708625793457, -1.1407848596572876, -1.0284849405288696, -0.29012882709503174, -0.46121492981910706, -0.5810028910636902, -0.8883090019226074, -0.7686072587966919, -0.03283990919589996, -0.30033135414123535, 0.42004865407943726, 0.4928091764450073, 0.5556743144989014, 0.8631134033203125, -0.3350845277309418, -0.08763726055622101, 0.4128911793231964, 0.6168627142906189, 0.40963318943977356, 1.0439116954803467, 0.6903136968612671, 0.02276918664574623, 0.3839455544948578, 0.39508211612701416, 1.4073222875595093, 0.3053227961063385, 1.0605534315109253, 0.5584703683853149, 0.31537914276123047, 1.8725571632385254, 0.12080726772546768, -0.05918686091899872, 0.5278858542442322, 0.36450546979904175, 1.1994935274124146, -0.5573234558105469, 0.6091391444206238, 0.9509237408638, 0.18556933104991913, -0.16863486170768738, 0.5961484909057617, 0.3567073941230774, -0.12453117221593857, 0.5094311833381653, 0.1251739114522934, -0.6590092778205872, -0.0, 0.0, 0.0, 1.7322206497192383, 3.30690336227417, 5.4718427658081055, 7.301167011260986], [0.0, -2.090663433074951, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.892104148864746, -5.788191795349121, -5.2990336418151855, -4.752577781677246, -4.420960426330566, -3.0211124420166016, -4.305539608001709, -3.5006325244903564, -2.8738977909088135, -3.005173444747925, -2.709636688232422, -2.0415568351745605, -1.7825467586517334, -1.2751600742340088, 1.0453687906265259, -2.1599254608154297, -0.7244709134101868, -1.2109259366989136, -0.8933693170547485, -0.5808478593826294, -0.7130579948425293, -0.388508677482605, -0.01235091220587492, 0.0420498363673687, -0.06141198053956032, -0.26333463191986084, 0.34356170892715454, 0.35415080189704895, 0.8969833850860596, 0.10742377489805222, -0.8358954787254333, -0.2385837584733963, 0.42024263739585876, 0.3932530879974365, 1.2182917594909668, 0.5794162750244141, 0.6144634485244751, 0.36622297763824463, 0.5286568403244019, 0.11796559393405914, 0.4414600729942322, 0.35986554622650146, 1.1457610130310059, 0.7680850625038147, 0.2441098541021347, 0.25587427616119385, 0.802565336227417, 0.5602332949638367, 0.4182268977165222, 0.2610752582550049, 0.5855282545089722, 0.9017425179481506, 0.06399890035390854, 0.5452243685722351, 0.06825573742389679, 0.14376969635486603, 0.5550352334976196, 0.7048535346984863, 0.2066011130809784, 0.037617020308971405, 0.3002573251724243, 0.6881433129310608, 0.0, 0.0, 3.9577481746673584, 1.2955117225646973, 2.685305595397949, 1.4184707403182983, 4.553406715393066, -0.0, -2.090663433074951, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.892104148864746, -5.788191795349121, -5.2990336418151855, -4.752577781677246, -4.420960426330566, -3.0211124420166016, -4.305539608001709, -3.5006325244903564, -2.8738977909088135, -3.005173444747925, -2.709636688232422, -2.0415568351745605, -1.7825467586517334, -1.2751600742340088, 1.0453687906265259, -2.1599254608154297, -0.7244709134101868, -1.2109259366989136, -0.8933693170547485, -0.5808478593826294, -0.7130579948425293, -0.388508677482605, -0.01235091220587492, 0.0420498363673687, -0.06141198053956032, -0.26333463191986084, 0.34356170892715454, 0.35415080189704895, 0.8969833850860596, 0.10742377489805222, -0.8358954787254333, -0.2385837584733963, 0.42024263739585876, 0.3932530879974365, 1.2182917594909668, 0.5794162750244141, 0.6144634485244751, 0.36622297763824463, 0.5286568403244019, 0.11796559393405914, 0.4414600729942322, 0.35986554622650146, 1.1457610130310059, 0.7680850625038147, 0.2441098541021347, 0.25587427616119385, 0.802565336227417, 0.5602332949638367, 0.4182268977165222, 0.2610752582550049, 0.5855282545089722, 0.9017425179481506, 0.06399890035390854, 0.5452243685722351, 0.06825573742389679, 0.14376969635486603, 0.5550352334976196, 0.7048535346984863, 0.2066011130809784, 0.037617020308971405, 0.3002573251724243, 0.6881433129310608, 0.0, 0.0, 3.9577481746673584, 1.2955117225646973, 2.685305595397949, 1.4184707403182983, 4.553406715393066], [-0.26040151715278625, -4.243832111358643, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.138340473175049, -6.20285177230835, -5.540013790130615, -5.56534481048584, -4.903738021850586, -4.568188190460205, -3.853685140609741, -3.1303203105926514, -3.3700578212738037, -3.804553747177124, -2.810396909713745, -2.2813918590545654, -2.1973612308502197, -2.213740825653076, -1.4790141582489014, -1.7340971231460571, -1.3859262466430664, -1.0814642906188965, -1.2138475179672241, -0.9501714706420898, -1.5619688034057617, -0.8002704977989197, -0.633940577507019, -0.2879917025566101, 0.1816573143005371, -0.037121087312698364, 0.33817970752716064, 0.29799380898475647, -0.2870703637599945, 0.23330308496952057, -0.06128469482064247, -0.004723057150840759, -0.29414165019989014, 0.1582338958978653, -0.12515118718147278, -0.3145653009414673, 0.6857235431671143, 1.4123603105545044, 0.21605193614959717, 0.7851134538650513, 0.5929752588272095, 1.5647574663162231, 0.22667913138866425, 0.9192491769790649, 0.5669460892677307, 1.1199195384979248, 1.7334568500518799, 0.6485655307769775, 0.7780634164810181, 0.46913275122642517, 1.0945277214050293, 1.1433182954788208, 0.45819032192230225, 0.4762663245201111, 0.9203530550003052, 1.2831286191940308, 0.6277196407318115, 0.2590710520744324, 0.7725516557693481, 1.2748241424560547, 0.3792877197265625, 0.7203062772750854, -0.058709025382995605, 0.4113057851791382, 0.0, 0.0, 5.33615255355835, 1.8463274240493774, 2.8284831047058105, 5.777253150939941, -0.26040151715278625, -4.243832111358643, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.138340473175049, -6.20285177230835, -5.540013790130615, -5.56534481048584, -4.903738021850586, -4.568188190460205, -3.853685140609741, -3.1303203105926514, -3.3700578212738037, -3.804553747177124, -2.810396909713745, -2.2813918590545654, -2.1973612308502197, -2.213740825653076, -1.4790141582489014, -1.7340971231460571, -1.3859262466430664, -1.0814642906188965, -1.2138475179672241, -0.9501714706420898, -1.5619688034057617, -0.8002704977989197, -0.633940577507019, -0.2879917025566101, 0.1816573143005371, -0.037121087312698364, 0.33817970752716064, 0.29799380898475647, -0.2870703637599945, 0.23330308496952057, -0.06128469482064247, -0.004723057150840759, -0.29414165019989014, 0.1582338958978653, -0.12515118718147278, -0.3145653009414673, 0.6857235431671143, 1.4123603105545044, 0.21605193614959717, 0.7851134538650513, 0.5929752588272095, 1.5647574663162231, 0.22667913138866425, 0.9192491769790649, 0.5669460892677307, 1.1199195384979248, 1.7334568500518799, 0.6485655307769775, 0.7780634164810181, 0.46913275122642517, 1.0945277214050293, 1.1433182954788208, 0.45819032192230225, 0.4762663245201111, 0.9203530550003052, 1.2831286191940308, 0.6277196407318115, 0.2590710520744324, 0.7725516557693481, 1.2748241424560547, 0.3792877197265625, 0.7203062772750854, -0.058709025382995605, 0.4113057851791382, 0.0, 0.0, 5.33615255355835, 1.8463274240493774, 2.8284831047058105, 5.777253150939941], [0.49215126037597656, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.815412163734436, -5.369884490966797, -4.968352794647217, -4.789466381072998, -4.962853908538818, -4.537700653076172, -3.5953545570373535, -4.182040691375732, -3.50042986869812, -4.102777481079102, -3.096802234649658, -2.4548633098602295, -2.107058525085449, -1.0503063201904297, -2.8265881538391113, -1.7559351921081543, -1.2582193613052368, -0.5120563507080078, -1.4456409215927124, -0.7692815661430359, -0.9630131721496582, -0.3805304169654846, -0.7452850341796875, 0.04158914461731911, -0.4862845242023468, 0.02319767326116562, 0.06473469734191895, -0.4082683324813843, 0.25524330139160156, 0.09374325722455978, -0.08301670849323273, 0.8816333413124084, -0.13285516202449799, 0.5362600684165955, 0.7909189462661743, -0.09588184952735901, 0.5189533829689026, 1.0465290546417236, 0.8343017101287842, 0.7277024388313293, 0.352212518453598, 0.6685008406639099, 0.6649406552314758, 0.23025377094745636, 0.10259044170379639, 1.1192606687545776, -0.17677035927772522, 0.9130650162696838, 2.914794445037842, 0.615919828414917, 0.4331713914871216, 1.1198642253875732, 0.9197626113891602, 0.639762282371521, 1.107593059539795, 0.23400595784187317, 0.3556687533855438, 0.9019463658332825, 1.5974199771881104, 1.3400769233703613, 0.4322252869606018, 1.0130778551101685, 0.7716925740242004, 1.206277847290039, -0.10369932651519775, 0.0, 0.0, 5.4136457443237305, 1.645823359489441, 0.0, 5.398884296417236, 0.49215126037597656, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.815412163734436, -5.369884490966797, -4.968352794647217, -4.789466381072998, -4.962853908538818, -4.537700653076172, -3.5953545570373535, -4.182040691375732, -3.50042986869812, -4.102777481079102, -3.096802234649658, -2.4548633098602295, -2.107058525085449, -1.0503063201904297, -2.8265881538391113, -1.7559351921081543, -1.2582193613052368, -0.5120563507080078, -1.4456409215927124, -0.7692815661430359, -0.9630131721496582, -0.3805304169654846, -0.7452850341796875, 0.04158914461731911, -0.4862845242023468, 0.02319767326116562, 0.06473469734191895, -0.4082683324813843, 0.25524330139160156, 0.09374325722455978, -0.08301670849323273, 0.8816333413124084, -0.13285516202449799, 0.5362600684165955, 0.7909189462661743, -0.09588184952735901, 0.5189533829689026, 1.0465290546417236, 0.8343017101287842, 0.7277024388313293, 0.352212518453598, 0.6685008406639099, 0.6649406552314758, 0.23025377094745636, 0.10259044170379639, 1.1192606687545776, -0.17677035927772522, 0.9130650162696838, 2.914794445037842, 0.615919828414917, 0.4331713914871216, 1.1198642253875732, 0.9197626113891602, 0.639762282371521, 1.107593059539795, 0.23400595784187317, 0.3556687533855438, 0.9019463658332825, 1.5974199771881104, 1.3400769233703613, 0.4322252869606018, 1.0130778551101685, 0.7716925740242004, 1.206277847290039, -0.10369932651519775, -0.0, 0.0, 5.4136457443237305, 1.645823359489441, 0.0, 5.398884296417236], [-0.8445406556129456, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -4.506587505340576, -5.175778865814209, -5.157215595245361, -4.563044548034668, -4.292722702026367, -3.768446683883667, -4.160138130187988, -4.1820526123046875, -3.426772356033325, -4.420583724975586, -2.612969160079956, -2.4277548789978027, -1.878455400466919, -2.070117473602295, -1.561637282371521, -1.0535253286361694, -1.7842459678649902, -0.7934395670890808, -0.7970759868621826, -1.1423488855361938, -0.412254273891449, -0.5505694150924683, -0.2538989186286926, -0.8519878387451172, -0.15859843790531158, 0.1430061012506485, 0.240111842751503, -0.06253167986869812, -0.733109712600708, 0.0410730242729187, 2.200423002243042, 0.8172751665115356, 0.36200660467147827, 0.6569610238075256, 1.1168776750564575, -0.14508119225502014, 0.6037596464157104, 1.6706188917160034, 0.13767771422863007, 0.5636187791824341, 0.7890868782997131, 0.4380103647708893, 1.2074284553527832, 1.6219903230667114, 1.2601879835128784, 1.2462198734283447, -0.022633949294686317, -0.27745944261550903, 1.126900315284729, 0.8162315487861633, 1.2756435871124268, 0.646904706954956, 0.03047811985015869, 0.4126695990562439, 0.5291585326194763, 0.760983407497406, 1.9056657552719116, 0.507846474647522, 0.9010431170463562, 0.39612695574760437, 0.9935396909713745, 0.6786649823188782, 0.6685287952423096, 1.4942644834518433, 1.7697800397872925, -1.5616614818572998, 0.0, 0.0, 2.1422533988952637, 0.0, 5.8460235595703125, -0.8445406556129456, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -4.506587505340576, -5.175778865814209, -5.157215595245361, -4.563044548034668, -4.292722702026367, -3.768446683883667, -4.160138130187988, -4.1820526123046875, -3.426772356033325, -4.420583724975586, -2.612969160079956, -2.4277548789978027, -1.878455400466919, -2.070117473602295, -1.561637282371521, -1.0535253286361694, -1.7842459678649902, -0.7934395670890808, -0.7970759868621826, -1.1423488855361938, -0.412254273891449, -0.5505694150924683, -0.2538989186286926, -0.8519878387451172, -0.15859843790531158, 0.1430061012506485, 0.240111842751503, -0.06253167986869812, -0.733109712600708, 0.0410730242729187, 2.200423002243042, 0.8172751665115356, 0.36200660467147827, 0.6569610238075256, 1.1168776750564575, -0.14508119225502014, 0.6037596464157104, 1.6706188917160034, 0.13767771422863007, 0.5636187791824341, 0.7890868782997131, 0.4380103647708893, 1.2074284553527832, 1.6219903230667114, 1.2601879835128784, 1.2462198734283447, -0.022633949294686317, -0.27745944261550903, 1.126900315284729, 0.8162315487861633, 1.2756435871124268, 0.646904706954956, 0.03047811985015869, 0.4126695990562439, 0.5291585326194763, 0.760983407497406, 1.9056657552719116, 0.507846474647522, 0.9010431170463562, 0.39612695574760437, 0.9935396909713745, 0.6786649823188782, 0.6685287952423096, 1.4942644834518433, 1.7697800397872925, -1.5616614818572998, -0.0, 0.0, 2.1422533988952637, 0.0, 5.8460235595703125], [-1.14222252368927, 0.0, 0.0, 0.0, 0.0, 0.0, -2.766773223876953, -4.791025161743164, -5.0878448486328125, -4.856406211853027, -4.3563923835754395, -4.6094207763671875, -4.231894493103027, -4.772717475891113, -3.3743739128112793, -3.2413058280944824, -3.2983977794647217, -1.4880297183990479, -2.102790355682373, -2.033799648284912, -2.581468343734741, 0.5671525597572327, -1.6790342330932617, -1.69191575050354, -1.2715892791748047, -0.46616479754447937, -1.8792674541473389, -0.5587476491928101, -0.5108402371406555, -0.17905820906162262, -0.6026654243469238, -1.3542492389678955, 0.4440667927265167, 0.10456112027168274, -0.08743260055780411, -0.19457174837589264, 0.7368167638778687, -2.8602867126464844, 0.3260873258113861, 0.9117755889892578, 0.7292024493217468, 0.363045871257782, 0.7128902673721313, 0.7738277912139893, -1.154532790184021, 1.9312846660614014, 0.27736541628837585, 0.8021641373634338, 1.0342305898666382, 0.4846613109111786, 1.2611594200134277, 1.530660629272461, 2.0866079330444336, 1.291514277458191, 1.4743235111236572, 1.006478190422058, 1.922376275062561, 1.1847306489944458, 0.5146256685256958, 0.26870790123939514, 0.6463454961776733, 1.0024936199188232, 0.6614403128623962, 1.8022440671920776, 0.7851824760437012, 0.3928889036178589, 1.036954641342163, 0.8488864898681641, 0.9352677464485168, 0.6928114295005798, 0.5952866673469543, 0.655318558216095, 1.6134535074234009, 0.0, 0.0, 0.0, 0.0, 0.0, -1.14222252368927, -0.0, -0.0, -0.0, -0.0, -0.0, -2.766773223876953, -4.791025161743164, -5.0878448486328125, -4.856406211853027, -4.3563923835754395, -4.6094207763671875, -4.231894493103027, -4.772717475891113, -3.3743739128112793, -3.2413058280944824, -3.2983977794647217, -1.4880297183990479, -2.102790355682373, -2.033799648284912, -2.581468343734741, 0.5671525597572327, -1.6790342330932617, -1.69191575050354, -1.2715892791748047, -0.46616479754447937, -1.8792674541473389, -0.5587476491928101, -0.5108402371406555, -0.17905820906162262, -0.6026654243469238, -1.3542492389678955, 0.4440667927265167, 0.10456112027168274, -0.08743260055780411, -0.19457174837589264, 0.7368167638778687, -2.8602867126464844, 0.3260873258113861, 0.9117755889892578, 0.7292024493217468, 0.363045871257782, 0.7128902673721313, 0.7738277912139893, -1.154532790184021, 1.9312846660614014, 0.27736541628837585, 0.8021641373634338, 1.0342305898666382, 0.4846613109111786, 1.2611594200134277, 1.530660629272461, 2.0866079330444336, 1.291514277458191, 1.4743235111236572, 1.006478190422058, 1.922376275062561, 1.1847306489944458, 0.5146256685256958, 0.26870790123939514, 0.6463454961776733, 1.0024936199188232, 0.6614403128623962, 1.8022440671920776, 0.7851824760437012, 0.3928889036178589, 1.036954641342163, 0.8488864898681641, 0.9352677464485168, 0.6928114295005798, 0.5952866673469543, 0.655318558216095, 1.6134535074234009, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.207087516784668, -5.406168460845947, -5.048035621643066, -5.080365180969238, -4.408691883087158, -5.124788761138916, -4.35913610458374, -4.189718723297119, -3.580843925476074, -3.6678991317749023, -2.9148545265197754, -2.265672445297241, -2.6670846939086914, -2.2714803218841553, -2.495103597640991, -2.6439054012298584, -0.1696765124797821, -1.5733839273452759, -1.5992074012756348, -1.1563491821289062, 0.8854089975357056, -0.7267867922782898, -1.3565189838409424, -0.5356037616729736, -0.19385917484760284, 0.03649546578526497, -0.3268955647945404, -0.48574110865592957, 0.43233609199523926, -0.17970876395702362, 0.2578496038913727, -0.261442631483078, 1.5691090822219849, 2.7476320266723633, 0.5210310220718384, 1.3238128423690796, 0.8111286759376526, 1.5351449251174927, 0.08397509902715683, 0.7278567552566528, 1.0125247240066528, 0.9836695790290833, 1.2779839038848877, 0.6092194318771362, 1.0698199272155762, 0.8476253747940063, 1.226322889328003, 0.7262530326843262, 1.8055154085159302, 0.2873452603816986, 1.8078618049621582, 1.4843690395355225, 1.6581839323043823, 0.9465983510017395, 1.0753403902053833, 0.008187190629541874, 0.5714277029037476, 1.183659315109253, 1.2394942045211792, 0.7007806301116943, 1.5941405296325684, 2.3756625652313232, 1.534434199333191, 1.2044527530670166, 0.40528836846351624, 0.9525120854377747, 1.425902247428894, -0.0639071837067604, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.207087516784668, -5.406168460845947, -5.048035621643066, -5.080365180969238, -4.408691883087158, -5.124788761138916, -4.35913610458374, -4.189718723297119, -3.580843925476074, -3.6678991317749023, -2.9148545265197754, -2.265672445297241, -2.6670846939086914, -2.2714803218841553, -2.495103597640991, -2.6439054012298584, -0.1696765124797821, -1.5733839273452759, -1.5992074012756348, -1.1563491821289062, 0.8854089975357056, -0.7267867922782898, -1.3565189838409424, -0.5356037616729736, -0.19385917484760284, 0.03649546578526497, -0.3268955647945404, -0.48574110865592957, 0.43233609199523926, -0.17970876395702362, 0.2578496038913727, -0.261442631483078, 1.5691090822219849, 2.7476320266723633, 0.5210310220718384, 1.3238128423690796, 0.8111286759376526, 1.5351449251174927, 0.08397509902715683, 0.7278567552566528, 1.0125247240066528, 0.9836695790290833, 1.2779839038848877, 0.6092194318771362, 1.0698199272155762, 0.8476253747940063, 1.226322889328003, 0.7262530326843262, 1.8055154085159302, 0.2873452603816986, 1.8078618049621582, 1.4843690395355225, 1.6581839323043823, 0.9465983510017395, 1.0753403902053833, 0.008187190629541874, 0.5714277029037476, 1.183659315109253, 1.2394942045211792, 0.7007806301116943, 1.5941405296325684, 2.3756625652313232, 1.534434199333191, 1.2044527530670166, 0.40528836846351624, 0.9525120854377747, 1.425902247428894, -0.0639071837067604, -0.0, 0.0, 0.0, 0.0], [-6.671230316162109, 0.0, 0.0, 0.0, 0.0, -6.1258721351623535, -5.902795314788818, -6.677488327026367, -5.74603271484375, -4.380927085876465, -5.105159282684326, -5.0661187171936035, -4.390550136566162, -4.050637722015381, -3.8791470527648926, -3.0918784141540527, -3.252511501312256, -4.121817111968994, -2.4557905197143555, -1.5611462593078613, -5.123837471008301, -1.1530581712722778, -1.3871828317642212, -1.1772676706314087, -1.2657291889190674, -0.7919383645057678, -0.4358504116535187, -0.6813055872917175, -1.0240200757980347, -0.9848425388336182, -1.8111144304275513, 0.6445623636245728, -0.3730730414390564, -0.6510768532752991, -0.705268383026123, -0.2834891676902771, 0.8538552522659302, 0.10557059943675995, 0.17639005184173584, 1.2308011054992676, 0.9397010207176208, 1.5142676830291748, 0.741917073726654, 0.8642460703849792, 0.8112037777900696, 1.8631101846694946, 0.1443016231060028, 1.6735409498214722, 1.3805352449417114, 1.405504584312439, 1.5501608848571777, 0.5881472826004028, 1.3332786560058594, 1.2063133716583252, 1.2442326545715332, 1.038507342338562, 0.9451764225959778, 0.835609495639801, 1.715711236000061, 1.2526262998580933, 0.18946826457977295, 0.9114043712615967, 1.2394156455993652, 0.6712949872016907, 0.9496132731437683, 1.206261396408081, 0.8536783456802368, 1.3483490943908691, 0.8469263315200806, 1.393309473991394, -0.12247371673583984, 0.7294816374778748, 1.2204980850219727, 1.5809844732284546, 0.0, 0.0, 0.49809837341308594, 0.0, -6.671230316162109, -0.0, -0.0, -0.0, -0.0, -6.1258721351623535, -5.902795314788818, -6.677488327026367, -5.74603271484375, -4.380927085876465, -5.105159282684326, -5.0661187171936035, -4.390550136566162, -4.050637722015381, -3.8791470527648926, -3.0918784141540527, -3.252511501312256, -4.121817111968994, -2.4557905197143555, -1.5611462593078613, -5.123837471008301, -1.1530581712722778, -1.3871828317642212, -1.1772676706314087, -1.2657291889190674, -0.7919383645057678, -0.4358504116535187, -0.6813055872917175, -1.0240200757980347, -0.9848425388336182, -1.8111144304275513, 0.6445623636245728, -0.3730730414390564, -0.6510768532752991, -0.705268383026123, -0.2834891676902771, 0.8538552522659302, 0.10557059943675995, 0.17639005184173584, 1.2308011054992676, 0.9397010207176208, 1.5142676830291748, 0.741917073726654, 0.8642460703849792, 0.8112037777900696, 1.8631101846694946, 0.1443016231060028, 1.6735409498214722, 1.3805352449417114, 1.405504584312439, 1.5501608848571777, 0.5881472826004028, 1.3332786560058594, 1.2063133716583252, 1.2442326545715332, 1.038507342338562, 0.9451764225959778, 0.835609495639801, 1.715711236000061, 1.2526262998580933, 0.18946826457977295, 0.9114043712615967, 1.2394156455993652, 0.6712949872016907, 0.9496132731437683, 1.206261396408081, 0.8536783456802368, 1.3483490943908691, 0.8469263315200806, 1.393309473991394, -0.12247371673583984, 0.7294816374778748, 1.2204980850219727, 1.5809844732284546, 0.0, 0.0, 0.49809837341308594, 0.0], [0.0, 0.0, 0.0, 0.0, -8.520957946777344, -6.6681599617004395, -5.882058143615723, -5.800777435302734, -5.656996250152588, -4.527168273925781, -4.895630359649658, -5.248302936553955, -4.48301362991333, -3.648899555206299, -3.87269926071167, -2.7772648334503174, -3.3918142318725586, -2.6359524726867676, -2.344977617263794, -2.296269416809082, -2.001004695892334, -1.902155876159668, -1.6207414865493774, -1.1064043045043945, -1.4631872177124023, -0.9339083433151245, -0.9075841307640076, 0.0017839167267084122, -1.046829104423523, 0.014624289236962795, -0.7225680351257324, 0.003716025035828352, -0.324270099401474, -0.05392194539308548, 0.6009097695350647, 0.45818039774894714, 0.19561590254306793, -0.025342123582959175, 1.5666519403457642, 0.9008364677429199, 0.783094584941864, 0.6995989680290222, 1.039317011833191, 1.8832675218582153, 0.7509750723838806, 1.142667531967163, 0.8784376978874207, 0.5150106549263, 1.1915770769119263, 2.09586501121521, 1.2120368480682373, 0.9894297122955322, 1.6063597202301025, 2.009364604949951, 1.2123366594314575, 1.412989854812622, 2.603822946548462, 1.5022311210632324, 2.852295160293579, 0.8126465678215027, 2.1184916496276855, 1.5932308435440063, 1.2448004484176636, 1.5655584335327148, 1.4306175708770752, 0.5840070247650146, 0.40311428904533386, 1.4112974405288696, 1.6699812412261963, 1.5733531713485718, 0.5353510975837708, 0.49514734745025635, 0.9518884420394897, 1.463888168334961, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -8.520957946777344, -6.6681599617004395, -5.882058143615723, -5.800777435302734, -5.656996250152588, -4.527168273925781, -4.895630359649658, -5.248302936553955, -4.48301362991333, -3.648899555206299, -3.87269926071167, -2.7772648334503174, -3.3918142318725586, -2.6359524726867676, -2.344977617263794, -2.296269416809082, -2.001004695892334, -1.902155876159668, -1.6207414865493774, -1.1064043045043945, -1.4631872177124023, -0.9339083433151245, -0.9075841307640076, 0.0017839167267084122, -1.046829104423523, 0.014624289236962795, -0.7225680351257324, 0.003716025035828352, -0.324270099401474, -0.05392194539308548, 0.6009097695350647, 0.45818039774894714, 0.19561590254306793, -0.025342123582959175, 1.5666519403457642, 0.9008364677429199, 0.783094584941864, 0.6995989680290222, 1.039317011833191, 1.8832675218582153, 0.7509750723838806, 1.142667531967163, 0.8784376978874207, 0.5150106549263, 1.1915770769119263, 2.09586501121521, 1.2120368480682373, 0.9894297122955322, 1.6063597202301025, 2.009364604949951, 1.2123366594314575, 1.412989854812622, 2.603822946548462, 1.5022311210632324, 2.852295160293579, 0.8126465678215027, 2.1184916496276855, 1.5932308435440063, 1.2448004484176636, 1.5655584335327148, 1.4306175708770752, 0.5840070247650146, 0.40311428904533386, 1.4112974405288696, 1.6699812412261963, 1.5733531713485718, 0.5353510975837708, 0.49514734745025635, 0.9518884420394897, 1.463888168334961, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -6.783693313598633, -6.237268924713135, -6.393908977508545, -5.2848591804504395, -4.602505207061768, -4.264395236968994, -4.8729681968688965, -5.283533096313477, -4.814910411834717, -4.117316246032715, -3.251499891281128, -4.088929653167725, -3.788604497909546, -2.0689754486083984, -2.22265625, -1.984234094619751, -1.0589873790740967, -2.0023412704467773, -1.3258795738220215, -1.0270421504974365, -1.013671636581421, -0.0459296815097332, -0.5490002632141113, -1.4583908319473267, 0.19007495045661926, 0.029171431437134743, -0.2131301760673523, -2.85341477394104, -0.2481383979320526, 0.33055704832077026, -0.0030959746800363064, 1.4356693029403687, 0.5111137628555298, -0.1808232069015503, 0.6477706432342529, 1.4248589277267456, 1.510694146156311, 0.8806762099266052, 0.6641969680786133, 0.9187617897987366, -0.36267930269241333, 3.018075942993164, 1.5846619606018066, 1.0452485084533691, 0.8664393424987793, 1.5164768695831299, 1.381278157234192, 1.3399953842163086, 0.8820053339004517, 1.1116282939910889, 1.2684662342071533, 0.41892319917678833, 1.011122465133667, 1.4548404216766357, 1.1041911840438843, 0.746498167514801, 1.27801513671875, 1.4341813325881958, 0.5984596610069275, 0.3207376003265381, -0.10739263892173767, 0.7260454297065735, 0.8493528366088867, 0.8379026055335999, 1.1309077739715576, 1.343766212463379, 0.7657472491264343, 1.653396725654602, 0.9082596898078918, 0.6672329902648926, 0.0, 0.0, 3.3516812324523926, 4.120778560638428, -0.0, -0.0, -0.0, -0.0, -6.783693313598633, -6.237268924713135, -6.393908977508545, -5.2848591804504395, -4.602505207061768, -4.264395236968994, -4.8729681968688965, -5.283533096313477, -4.814910411834717, -4.117316246032715, -3.251499891281128, -4.088929653167725, -3.788604497909546, -2.0689754486083984, -2.22265625, -1.984234094619751, -1.0589873790740967, -2.0023412704467773, -1.3258795738220215, -1.0270421504974365, -1.013671636581421, -0.0459296815097332, -0.5490002632141113, -1.4583908319473267, 0.19007495045661926, 0.029171431437134743, -0.2131301760673523, -2.85341477394104, -0.2481383979320526, 0.33055704832077026, -0.0030959746800363064, 1.4356693029403687, 0.5111137628555298, -0.1808232069015503, 0.6477706432342529, 1.4248589277267456, 1.510694146156311, 0.8806762099266052, 0.6641969680786133, 0.9187617897987366, -0.36267930269241333, 3.018075942993164, 1.5846619606018066, 1.0452485084533691, 0.8664393424987793, 1.5164768695831299, 1.381278157234192, 1.3399953842163086, 0.8820053339004517, 1.1116282939910889, 1.2684662342071533, 0.41892319917678833, 1.011122465133667, 1.4548404216766357, 1.1041911840438843, 0.746498167514801, 1.27801513671875, 1.4341813325881958, 0.5984596610069275, 0.3207376003265381, -0.10739263892173767, 0.7260454297065735, 0.8493528366088867, 0.8379026055335999, 1.1309077739715576, 1.343766212463379, 0.7657472491264343, 1.653396725654602, 0.9082596898078918, 0.6672329902648926, 0.0, 0.0, 3.3516812324523926, 4.120778560638428], [0.0, -6.682403564453125, 0.0, 0.0, -6.046609878540039, -6.620970249176025, -6.193246364593506, -5.309722900390625, -4.695559501647949, -4.9507880210876465, -5.289231777191162, -3.1443772315979004, -3.635648012161255, -4.582879066467285, -3.879629373550415, -3.9036858081817627, -3.493701696395874, -2.8028934001922607, -2.218217372894287, -1.6826393604278564, -1.9383727312088013, -2.174717664718628, -1.099995732307434, -1.6675097942352295, -2.126279830932617, -0.4050585925579071, -0.12445162236690521, -0.4596847891807556, -1.871491551399231, -0.6279965043067932, 0.3820599913597107, 0.13962911069393158, 0.3237888216972351, 1.1224582195281982, -0.07475043088197708, 0.0965333804488182, 1.1466662883758545, 0.9010065197944641, 1.3064985275268555, 1.8688442707061768, 1.5151889324188232, 0.08163221925497055, 1.5370399951934814, 0.3321729004383087, 0.697918713092804, 4.472731113433838, 2.3052003383636475, 1.6277369260787964, 1.4137617349624634, 1.0738188028335571, 1.247788429260254, 1.2587356567382812, 1.7762459516525269, 1.001662254333496, 1.904232382774353, 1.519360899925232, 2.3297805786132812, 1.7501524686813354, 0.5853912830352783, 1.8011715412139893, 2.5150036811828613, 1.320478916168213, 0.7033630013465881, 1.8342946767807007, 1.159752368927002, 2.3249995708465576, 0.9062706232070923, 1.2107734680175781, 0.9400104284286499, 0.8735738396644592, 1.5417853593826294, 1.2383861541748047, 0.9908492565155029, 0.8410443663597107, 0.5561510920524597, 0.0, 3.425994396209717, 2.4928765296936035, -0.0, -6.682403564453125, -0.0, -0.0, -6.046609878540039, -6.620970249176025, -6.193246364593506, -5.309722900390625, -4.695559501647949, -4.9507880210876465, -5.289231777191162, -3.1443772315979004, -3.635648012161255, -4.582879066467285, -3.879629373550415, -3.9036858081817627, -3.493701696395874, -2.8028934001922607, -2.218217372894287, -1.6826393604278564, -1.9383727312088013, -2.174717664718628, -1.099995732307434, -1.6675097942352295, -2.126279830932617, -0.4050585925579071, -0.12445162236690521, -0.4596847891807556, -1.871491551399231, -0.6279965043067932, 0.3820599913597107, 0.13962911069393158, 0.3237888216972351, 1.1224582195281982, -0.07475043088197708, 0.0965333804488182, 1.1466662883758545, 0.9010065197944641, 1.3064985275268555, 1.8688442707061768, 1.5151889324188232, 0.08163221925497055, 1.5370399951934814, 0.3321729004383087, 0.697918713092804, 4.472731113433838, 2.3052003383636475, 1.6277369260787964, 1.4137617349624634, 1.0738188028335571, 1.247788429260254, 1.2587356567382812, 1.7762459516525269, 1.001662254333496, 1.904232382774353, 1.519360899925232, 2.3297805786132812, 1.7501524686813354, 0.5853912830352783, 1.8011715412139893, 2.5150036811828613, 1.320478916168213, 0.7033630013465881, 1.8342946767807007, 1.159752368927002, 2.3249995708465576, 0.9062706232070923, 1.2107734680175781, 0.9400104284286499, 0.8735738396644592, 1.5417853593826294, 1.2383861541748047, 0.9908492565155029, 0.8410443663597107, 0.5561510920524597, 0.0, 3.425994396209717, 2.4928765296936035], [-5.926933765411377, 0.0, 0.0, -5.290389060974121, -6.63771390914917, -5.761730194091797, -6.610811233520508, -5.3427734375, -5.14902925491333, -4.758484363555908, -5.862668037414551, -4.075985908508301, -5.3167805671691895, -5.072202205657959, -4.939826011657715, -3.2248079776763916, -3.0346739292144775, -2.9091570377349854, -2.4164133071899414, -2.153515577316284, -2.0225720405578613, -1.787064790725708, -1.4131685495376587, -1.5711970329284668, -0.47398608922958374, -0.5196024179458618, 0.2121880054473877, -0.20503930747509003, 0.36171242594718933, -0.48646947741508484, -0.5725328326225281, 0.06336399912834167, -0.07930467277765274, 0.6239894032478333, 0.4161463677883148, 3.0722718238830566, 1.9533697366714478, 1.9423484802246094, 1.4842957258224487, 1.4743913412094116, 1.0271246433258057, 0.9224101305007935, 1.3379359245300293, 1.1255582571029663, 0.9606201648712158, 1.8681703805923462, 0.6459379196166992, 0.34963327646255493, 0.9662491679191589, 1.1622960567474365, 1.5699338912963867, 1.4391653537750244, 1.6046375036239624, 1.2430827617645264, 1.7413125038146973, 1.3584328889846802, 2.083366632461548, 1.2984422445297241, 1.0938644409179688, 1.9091845750808716, 0.2506506145000458, 0.12323729693889618, 1.4167072772979736, 0.43009358644485474, 2.291942596435547, 0.9856728315353394, 3.905972957611084, 0.7937319874763489, 1.2072548866271973, 1.1486188173294067, -0.2649371922016144, 1.2955554723739624, 1.3640512228012085, 0.9627308249473572, 0.38386163115501404, 0.0, 0.0, 1.2944972515106201, -5.926933765411377, -0.0, -0.0, -5.290389060974121, -6.63771390914917, -5.761730194091797, -6.610811233520508, -5.3427734375, -5.14902925491333, -4.758484363555908, -5.862668037414551, -4.075985908508301, -5.3167805671691895, -5.072202205657959, -4.939826011657715, -3.2248079776763916, -3.0346739292144775, -2.9091570377349854, -2.4164133071899414, -2.153515577316284, -2.0225720405578613, -1.787064790725708, -1.4131685495376587, -1.5711970329284668, -0.47398608922958374, -0.5196024179458618, 0.2121880054473877, -0.20503930747509003, 0.36171242594718933, -0.48646947741508484, -0.5725328326225281, 0.06336399912834167, -0.07930467277765274, 0.6239894032478333, 0.4161463677883148, 3.0722718238830566, 1.9533697366714478, 1.9423484802246094, 1.4842957258224487, 1.4743913412094116, 1.0271246433258057, 0.9224101305007935, 1.3379359245300293, 1.1255582571029663, 0.9606201648712158, 1.8681703805923462, 0.6459379196166992, 0.34963327646255493, 0.9662491679191589, 1.1622960567474365, 1.5699338912963867, 1.4391653537750244, 1.6046375036239624, 1.2430827617645264, 1.7413125038146973, 1.3584328889846802, 2.083366632461548, 1.2984422445297241, 1.0938644409179688, 1.9091845750808716, 0.2506506145000458, 0.12323729693889618, 1.4167072772979736, 0.43009358644485474, 2.291942596435547, 0.9856728315353394, 3.905972957611084, 0.7937319874763489, 1.2072548866271973, 1.1486188173294067, -0.2649371922016144, 1.2955554723739624, 1.3640512228012085, 0.9627308249473572, 0.38386163115501404, 0.0, 0.0, 1.2944972515106201], [-6.564638137817383, 0.0, 0.0, -7.674037456512451, -6.383861064910889, -6.418886661529541, -5.837526321411133, -6.06303071975708, -5.279845714569092, -4.776978969573975, -5.312282562255859, -4.405956745147705, -4.468242168426514, -4.162454128265381, -4.455253601074219, -3.4867098331451416, -2.799346923828125, -3.1813673973083496, -2.048703908920288, -1.6146373748779297, -2.5042433738708496, -1.755934476852417, -1.5059940814971924, -1.6498348712921143, -0.8566303253173828, -1.114141821861267, -1.1762093305587769, -0.9763875007629395, 0.014802047982811928, -0.35593876242637634, -0.04332387074828148, 0.2892168164253235, -0.23969236016273499, -0.15348277986049652, 0.30318278074264526, 2.3455440998077393, 1.8406468629837036, 1.200875997543335, 3.549600124359131, 2.320575475692749, 1.8253356218338013, 1.3533024787902832, 1.7498499155044556, 3.806006908416748, 0.40849989652633667, 0.6219866871833801, 1.553112506866455, 1.4153140783309937, 1.0837178230285645, 1.5737719535827637, 0.8267110586166382, 1.465800166130066, 1.7420217990875244, 1.5331509113311768, 1.4929975271224976, -0.45942845940589905, 1.78797447681427, 1.525712013244629, 0.5699551105499268, 0.9599181413650513, 1.548195481300354, 1.0468984842300415, 0.22324895858764648, 1.313350796699524, -0.08314099162817001, 0.5631296634674072, 0.4476799964904785, 1.0336380004882812, 0.5455918908119202, 1.1053991317749023, 2.3859872817993164, 0.899102509021759, 1.8344138860702515, 0.021698692813515663, 1.6810208559036255, 0.0, 0.0, -0.5388503074645996, -6.564638137817383, -0.0, -0.0, -7.674037456512451, -6.383861064910889, -6.418886661529541, -5.837526321411133, -6.06303071975708, -5.279845714569092, -4.776978969573975, -5.312282562255859, -4.405956745147705, -4.468242168426514, -4.162454128265381, -4.455253601074219, -3.4867098331451416, -2.799346923828125, -3.1813673973083496, -2.048703908920288, -1.6146373748779297, -2.5042433738708496, -1.755934476852417, -1.5059940814971924, -1.6498348712921143, -0.8566303253173828, -1.114141821861267, -1.1762093305587769, -0.9763875007629395, 0.014802047982811928, -0.35593876242637634, -0.04332387074828148, 0.2892168164253235, -0.23969236016273499, -0.15348277986049652, 0.30318278074264526, 2.3455440998077393, 1.8406468629837036, 1.200875997543335, 3.549600124359131, 2.320575475692749, 1.8253356218338013, 1.3533024787902832, 1.7498499155044556, 3.806006908416748, 0.40849989652633667, 0.6219866871833801, 1.553112506866455, 1.4153140783309937, 1.0837178230285645, 1.5737719535827637, 0.8267110586166382, 1.465800166130066, 1.7420217990875244, 1.5331509113311768, 1.4929975271224976, -0.45942845940589905, 1.78797447681427, 1.525712013244629, 0.5699551105499268, 0.9599181413650513, 1.548195481300354, 1.0468984842300415, 0.22324895858764648, 1.313350796699524, -0.08314099162817001, 0.5631296634674072, 0.4476799964904785, 1.0336380004882812, 0.5455918908119202, 1.1053991317749023, 2.3859872817993164, 0.899102509021759, 1.8344138860702515, 0.021698692813515663, 1.6810208559036255, 0.0, 0.0, -0.5388503074645996], [-4.02097225189209, 0.0, 0.0, -6.944157123565674, -6.560880661010742, -6.166725158691406, -6.232755184173584, -5.583807945251465, -5.061535358428955, -3.520066261291504, -4.868887901306152, -6.635834217071533, -4.274506092071533, -4.01367712020874, -2.876249074935913, -3.6910111904144287, -2.9145450592041016, -3.152625560760498, -3.5825414657592773, -3.2367913722991943, -1.7283655405044556, -1.6809322834014893, -1.5414066314697266, -1.122223138809204, -1.010396957397461, -0.6998102068901062, 0.46526038646698, -0.7873568534851074, 0.3124927580356598, -0.5575276017189026, -0.35268762707710266, -0.7512398958206177, 0.5121543407440186, -0.17182816565036774, 0.2927475571632385, 1.628243327140808, 1.5337610244750977, 1.047593116760254, 2.8884246349334717, 2.9832746982574463, 2.329712390899658, 1.2062748670578003, 1.0551879405975342, 0.6598086357116699, 1.9513803720474243, 1.121992588043213, 0.05868982523679733, 1.020211935043335, 1.5933531522750854, 1.4948089122772217, 1.4731855392456055, 1.1313611268997192, 1.6334261894226074, 1.6369743347167969, 1.4011809825897217, 1.6415387392044067, 3.0677874088287354, 1.14543879032135, 0.7613935470581055, 2.143244981765747, 1.0292210578918457, 1.0470062494277954, 1.289719820022583, 0.9204963445663452, 1.2701915502548218, 0.23698951303958893, 0.6540666222572327, 1.1047570705413818, 1.063240885734558, 1.5396876335144043, 0.31590259075164795, 1.2323644161224365, 1.0021182298660278, 1.7735824584960938, 1.794538140296936, 0.0, 0.0, 3.6523208618164062, -4.02097225189209, -0.0, -0.0, -6.944157123565674, -6.560880661010742, -6.166725158691406, -6.232755184173584, -5.583807945251465, -5.061535358428955, -3.520066261291504, -4.868887901306152, -6.635834217071533, -4.274506092071533, -4.01367712020874, -2.876249074935913, -3.6910111904144287, -2.9145450592041016, -3.152625560760498, -3.5825414657592773, -3.2367913722991943, -1.7283655405044556, -1.6809322834014893, -1.5414066314697266, -1.122223138809204, -1.010396957397461, -0.6998102068901062, 0.46526038646698, -0.7873568534851074, 0.3124927580356598, -0.5575276017189026, -0.35268762707710266, -0.7512398958206177, 0.5121543407440186, -0.17182816565036774, 0.2927475571632385, 1.628243327140808, 1.5337610244750977, 1.047593116760254, 2.8884246349334717, 2.9832746982574463, 2.329712390899658, 1.2062748670578003, 1.0551879405975342, 0.6598086357116699, 1.9513803720474243, 1.121992588043213, 0.05868982523679733, 1.020211935043335, 1.5933531522750854, 1.4948089122772217, 1.4731855392456055, 1.1313611268997192, 1.6334261894226074, 1.6369743347167969, 1.4011809825897217, 1.6415387392044067, 3.0677874088287354, 1.14543879032135, 0.7613935470581055, 2.143244981765747, 1.0292210578918457, 1.0470062494277954, 1.289719820022583, 0.9204963445663452, 1.2701915502548218, 0.23698951303958893, 0.6540666222572327, 1.1047570705413818, 1.063240885734558, 1.5396876335144043, 0.31590259075164795, 1.2323644161224365, 1.0021182298660278, 1.7735824584960938, 1.794538140296936, 0.0, 0.0, 3.6523208618164062], [-5.3916473388671875, 0.0, 0.0, -7.029919624328613, -7.0074896812438965, -6.376174449920654, -6.7494425773620605, -6.145899295806885, -5.391329765319824, -4.944407939910889, -5.458641529083252, -5.151791095733643, -4.554181098937988, -3.0351364612579346, -4.017236709594727, -3.4926486015319824, -2.478343963623047, -2.9875996112823486, -3.3948426246643066, -1.9133583307266235, -2.155569076538086, -1.4310029745101929, -1.542296290397644, -1.2977473735809326, -1.136223554611206, -1.4438443183898926, -0.810231626033783, -0.4139883518218994, -0.24808025360107422, 0.06901945918798447, -0.010969525203108788, -0.4201405644416809, -0.26280322670936584, 0.7823852300643921, 0.7295577526092529, 0.45499682426452637, 1.8516017198562622, 2.9238858222961426, 0.41127172112464905, 1.6842151880264282, 1.7256410121917725, 3.272613763809204, 0.26045477390289307, 2.0138258934020996, 0.8331242799758911, 0.5746283531188965, 1.1988425254821777, 1.6718807220458984, 1.5994187593460083, 1.5073440074920654, 1.0013383626937866, 1.5483503341674805, 1.0801167488098145, 1.5908788442611694, 1.6102341413497925, 1.1507837772369385, 2.1460509300231934, 1.589428424835205, 1.1224621534347534, 1.8896459341049194, 1.2553339004516602, 0.9701593518257141, 1.4280890226364136, 0.9269370436668396, 0.9490880370140076, 1.3044321537017822, 1.1500614881515503, -0.47682565450668335, 1.0673580169677734, 1.4541449546813965, 1.4733433723449707, 1.1101222038269043, 1.4648371934890747, 1.289443850517273, 1.568418025970459, 2.7668814659118652, 0.0, 5.4282379150390625, -5.3916473388671875, -0.0, -0.0, -7.029919624328613, -7.0074896812438965, -6.376174449920654, -6.7494425773620605, -6.145899295806885, -5.391329765319824, -4.944407939910889, -5.458641529083252, -5.151791095733643, -4.554181098937988, -3.0351364612579346, -4.017236709594727, -3.4926486015319824, -2.478343963623047, -2.9875996112823486, -3.3948426246643066, -1.9133583307266235, -2.155569076538086, -1.4310029745101929, -1.542296290397644, -1.2977473735809326, -1.136223554611206, -1.4438443183898926, -0.810231626033783, -0.4139883518218994, -0.24808025360107422, 0.06901945918798447, -0.010969525203108788, -0.4201405644416809, -0.26280322670936584, 0.7823852300643921, 0.7295577526092529, 0.45499682426452637, 1.8516017198562622, 2.9238858222961426, 0.41127172112464905, 1.6842151880264282, 1.7256410121917725, 3.272613763809204, 0.26045477390289307, 2.0138258934020996, 0.8331242799758911, 0.5746283531188965, 1.1988425254821777, 1.6718807220458984, 1.5994187593460083, 1.5073440074920654, 1.0013383626937866, 1.5483503341674805, 1.0801167488098145, 1.5908788442611694, 1.6102341413497925, 1.1507837772369385, 2.1460509300231934, 1.589428424835205, 1.1224621534347534, 1.8896459341049194, 1.2553339004516602, 0.9701593518257141, 1.4280890226364136, 0.9269370436668396, 0.9490880370140076, 1.3044321537017822, 1.1500614881515503, -0.47682565450668335, 1.0673580169677734, 1.4541449546813965, 1.4733433723449707, 1.1101222038269043, 1.4648371934890747, 1.289443850517273, 1.568418025970459, 2.7668814659118652, 0.0, 5.4282379150390625], [-7.7694549560546875, 0.0, -7.184872627258301, -7.225433349609375, -6.8592143058776855, -5.514798164367676, -6.237273216247559, -5.879350185394287, -5.439218521118164, -5.387352466583252, -5.418024063110352, -5.502364635467529, -5.007240295410156, -4.38348388671875, -4.303313255310059, -3.9913268089294434, -3.0548226833343506, -2.860654592514038, -2.1267237663269043, -2.5053954124450684, -2.6236801147460938, -1.7564300298690796, -1.7953028678894043, -1.9258464574813843, -0.8341916799545288, -0.655251145362854, -0.3957614600658417, -1.203556776046753, -0.028283296152949333, -0.32218241691589355, 0.0758800283074379, 0.3263792097568512, 1.4309370517730713, 0.12743143737316132, 0.6198699474334717, 1.2282116413116455, 2.105959892272949, 2.065269947052002, 0.0, 0.8928747773170471, 0.4638800024986267, 0.6734888553619385, 2.014688491821289, 0.9371532201766968, 2.1110947132110596, 2.1360416412353516, 1.4761923551559448, 1.399403691291809, 1.6416902542114258, 1.5864657163619995, 1.7280405759811401, 1.6559715270996094, 1.3586705923080444, 1.1229907274246216, 1.077549934387207, 0.7466328740119934, 1.6316286325454712, 1.3875322341918945, 1.5016735792160034, 1.0324758291244507, 1.1053493022918701, 1.6026414632797241, 1.9871041774749756, 0.8272941708564758, 0.9149426817893982, 1.639298915863037, 0.2322096824645996, 1.426525354385376, 1.9702814817428589, 1.6130164861679077, 2.330568790435791, 1.7700597047805786, 1.2616961002349854, 1.5143539905548096, 2.2530839443206787, 0.0, 0.0, 0.0, -7.7694549560546875, -0.0, -7.184872627258301, -7.225433349609375, -6.8592143058776855, -5.514798164367676, -6.237273216247559, -5.879350185394287, -5.439218521118164, -5.387352466583252, -5.418024063110352, -5.502364635467529, -5.007240295410156, -4.38348388671875, -4.303313255310059, -3.9913268089294434, -3.0548226833343506, -2.860654592514038, -2.1267237663269043, -2.5053954124450684, -2.6236801147460938, -1.7564300298690796, -1.7953028678894043, -1.9258464574813843, -0.8341916799545288, -0.655251145362854, -0.3957614600658417, -1.203556776046753, -0.028283296152949333, -0.32218241691589355, 0.0758800283074379, 0.3263792097568512, 1.4309370517730713, 0.12743143737316132, 0.6198699474334717, 1.2282116413116455, 2.105959892272949, 2.065269947052002, 0.0, 0.8928747773170471, 0.4638800024986267, 0.6734888553619385, 2.014688491821289, 0.9371532201766968, 2.1110947132110596, 2.1360416412353516, 1.4761923551559448, 1.399403691291809, 1.6416902542114258, 1.5864657163619995, 1.7280405759811401, 1.6559715270996094, 1.3586705923080444, 1.1229907274246216, 1.077549934387207, 0.7466328740119934, 1.6316286325454712, 1.3875322341918945, 1.5016735792160034, 1.0324758291244507, 1.1053493022918701, 1.6026414632797241, 1.9871041774749756, 0.8272941708564758, 0.9149426817893982, 1.639298915863037, 0.2322096824645996, 1.426525354385376, 1.9702814817428589, 1.6130164861679077, 2.330568790435791, 1.7700597047805786, 1.2616961002349854, 1.5143539905548096, 2.2530839443206787, 0.0, 0.0, 0.0], [0.0, 0.0, -7.009642601013184, -7.12828254699707, -6.160747528076172, -6.3509016036987305, -5.961597919464111, -6.255426406860352, -5.662484645843506, -5.322412967681885, -5.523755073547363, -4.775195121765137, -4.501082897186279, -4.463378429412842, -4.085416793823242, -2.752455711364746, -4.055409908294678, -3.3493003845214844, -2.643279790878296, -2.543992519378662, -1.8904789686203003, -1.703465461730957, -2.1596455574035645, -0.8301427960395813, -0.9219788908958435, -0.8655467629432678, -0.7869461178779602, -0.4286784529685974, -0.8932432532310486, -1.5722599029541016, 1.0596768856048584, -0.09202688187360764, 2.6579504013061523, 0.6769688129425049, 0.8288809657096863, 1.1302624940872192, 1.6830518245697021, 1.389573574066162, -1.2824530601501465, 1.9401859045028687, 0.6669267416000366, 1.3310551643371582, 0.7652769684791565, 2.5045735836029053, 0.1272081732749939, 1.325903058052063, 1.713542103767395, 1.60491943359375, 1.1392838954925537, 0.8450741171836853, 1.273569107055664, 1.076490879058838, 1.4412448406219482, 1.252112865447998, 0.7409013509750366, 1.955116629600525, 1.3944549560546875, 1.0687810182571411, 1.0974477529525757, 0.6459574699401855, 1.6636191606521606, 0.6649672389030457, 2.124945640563965, 0.6029433012008667, 1.40408456325531, 0.9036414623260498, 0.7282984852790833, 0.37166139483451843, 1.965360164642334, 1.8942447900772095, 1.3509595394134521, 1.646303415298462, 0.8687345385551453, 1.258934497833252, 2.2079384326934814, 2.037686586380005, 0.0, 0.0, -0.0, -0.0, -7.009642601013184, -7.12828254699707, -6.160747528076172, -6.3509016036987305, -5.961597919464111, -6.255426406860352, -5.662484645843506, -5.322412967681885, -5.523755073547363, -4.775195121765137, -4.501082897186279, -4.463378429412842, -4.085416793823242, -2.752455711364746, -4.055409908294678, -3.3493003845214844, -2.643279790878296, -2.543992519378662, -1.8904789686203003, -1.703465461730957, -2.1596455574035645, -0.8301427960395813, -0.9219788908958435, -0.8655467629432678, -0.7869461178779602, -0.4286784529685974, -0.8932432532310486, -1.5722599029541016, 1.0596768856048584, -0.09202688187360764, 2.6579504013061523, 0.6769688129425049, 0.8288809657096863, 1.1302624940872192, 1.6830518245697021, 1.389573574066162, -1.2824530601501465, 1.9401859045028687, 0.6669267416000366, 1.3310551643371582, 0.7652769684791565, 2.5045735836029053, 0.1272081732749939, 1.325903058052063, 1.713542103767395, 1.60491943359375, 1.1392838954925537, 0.8450741171836853, 1.273569107055664, 1.076490879058838, 1.4412448406219482, 1.252112865447998, 0.7409013509750366, 1.955116629600525, 1.3944549560546875, 1.0687810182571411, 1.0974477529525757, 0.6459574699401855, 1.6636191606521606, 0.6649672389030457, 2.124945640563965, 0.6029433012008667, 1.40408456325531, 0.9036414623260498, 0.7282984852790833, 0.37166139483451843, 1.965360164642334, 1.8942447900772095, 1.3509595394134521, 1.646303415298462, 0.8687345385551453, 1.258934497833252, 2.2079384326934814, 2.037686586380005, 0.0, 0.0], [0.0, 0.0, -6.939818859100342, -6.815893173217773, -6.76461124420166, -7.21953821182251, -6.360994815826416, -6.076312065124512, -5.949526309967041, -5.980931758880615, -5.6766252517700195, -5.1499714851379395, -3.827744722366333, -4.662391662597656, -4.043499946594238, -3.4832112789154053, -3.2898271083831787, -2.546621322631836, -2.4695777893066406, -1.1425756216049194, -1.8446089029312134, -1.930533766746521, -0.9201294183731079, -0.8702701330184937, -1.0539389848709106, -0.18946297466754913, -1.6319341659545898, -0.7023202776908875, -0.26651033759117126, -0.643563985824585, -0.19558121263980865, 0.4996185600757599, 0.612744152545929, 0.5919770002365112, 0.6158459782600403, 1.1240484714508057, 0.8818452954292297, 0.24198894202709198, 1.3187867403030396, 2.348327875137329, 0.9213493466377258, 0.6125489473342896, -0.360177218914032, 1.2644270658493042, 1.2875573635101318, 1.335060954093933, 1.414228081703186, 1.7158852815628052, 2.230664014816284, 1.0745640993118286, 1.0586620569229126, 1.4473228454589844, 1.5138834714889526, 0.8654948472976685, 1.3289778232574463, 2.1285338401794434, 1.6454468965530396, 0.027295462787151337, 0.9136720299720764, 0.8334051370620728, 0.9481168985366821, 1.7563341856002808, 0.5810542106628418, 0.6276092529296875, 0.4553331434726715, 1.2376395463943481, 1.0726587772369385, 0.3301295340061188, 0.20412923395633698, 1.5806721448898315, 2.0423226356506348, 0.667843222618103, 1.719897985458374, 1.6199841499328613, 2.0512399673461914, 2.0164122581481934, 0.0, 0.0, -0.0, -0.0, -6.939818859100342, -6.815893173217773, -6.76461124420166, -7.21953821182251, -6.360994815826416, -6.076312065124512, -5.949526309967041, -5.980931758880615, -5.6766252517700195, -5.1499714851379395, -3.827744722366333, -4.662391662597656, -4.043499946594238, -3.4832112789154053, -3.2898271083831787, -2.546621322631836, -2.4695777893066406, -1.1425756216049194, -1.8446089029312134, -1.930533766746521, -0.9201294183731079, -0.8702701330184937, -1.0539389848709106, -0.18946297466754913, -1.6319341659545898, -0.7023202776908875, -0.26651033759117126, -0.643563985824585, -0.19558121263980865, 0.4996185600757599, 0.612744152545929, 0.5919770002365112, 0.6158459782600403, 1.1240484714508057, 0.8818452954292297, 0.24198894202709198, 1.3187867403030396, 2.348327875137329, 0.9213493466377258, 0.6125489473342896, -0.360177218914032, 1.2644270658493042, 1.2875573635101318, 1.335060954093933, 1.414228081703186, 1.7158852815628052, 2.230664014816284, 1.0745640993118286, 1.0586620569229126, 1.4473228454589844, 1.5138834714889526, 0.8654948472976685, 1.3289778232574463, 2.1285338401794434, 1.6454468965530396, 0.027295462787151337, 0.9136720299720764, 0.8334051370620728, 0.9481168985366821, 1.7563341856002808, 0.5810542106628418, 0.6276092529296875, 0.4553331434726715, 1.2376395463943481, 1.0726587772369385, 0.3301295340061188, 0.20412923395633698, 1.5806721448898315, 2.0423226356506348, 0.667843222618103, 1.719897985458374, 1.6199841499328613, 2.0512399673461914, 2.0164122581481934, 0.0, 0.0], [0.0, 0.0, -7.586891174316406, -7.060275554656982, -7.123691082000732, -7.450661659240723, -6.967705726623535, -6.461762428283691, -6.541092872619629, -5.837716102600098, -5.0119099617004395, -4.952086448669434, -5.803557872772217, -4.938953876495361, -2.4629719257354736, -2.9969518184661865, -3.046628952026367, -3.311539888381958, -2.3581974506378174, -3.433854341506958, -1.8603194952011108, -2.3839902877807617, -1.7093329429626465, -1.2563093900680542, -1.0504677295684814, -0.7915278673171997, -0.6268266439437866, 0.048114217817783356, -0.12746261060237885, -0.7664048671722412, -0.2509930729866028, 0.22835113108158112, -0.12758658826351166, 0.43044808506965637, 0.38889259099960327, 0.6839396953582764, 1.432624101638794, -0.08623196929693222, -0.510840892791748, 1.201884150505066, 0.8915037512779236, 1.489457368850708, 0.5685065984725952, 0.8486513495445251, 0.9768675565719604, 0.7145218849182129, 1.4186238050460815, 0.19970926642417908, 1.9190255403518677, 1.0981650352478027, 1.2337628602981567, 1.1330699920654297, 1.8199868202209473, 0.2714728116989136, 0.8715060949325562, 0.4128941297531128, 1.4283859729766846, 0.8993980288505554, 1.385322093963623, 1.017817497253418, 1.1200287342071533, 0.5412672162055969, 0.854238748550415, 0.5014718770980835, 1.1100939512252808, 0.3307260572910309, 0.571464478969574, 0.9686771631240845, 1.7088552713394165, 1.4331095218658447, 1.052613377571106, 0.6837802529335022, 1.4715099334716797, 1.846457600593567, 1.6779717206954956, 2.865612268447876, 0.0, 0.0, -0.0, -0.0, -7.586891174316406, -7.060275554656982, -7.123691082000732, -7.450661659240723, -6.967705726623535, -6.461762428283691, -6.541092872619629, -5.837716102600098, -5.0119099617004395, -4.952086448669434, -5.803557872772217, -4.938953876495361, -2.4629719257354736, -2.9969518184661865, -3.046628952026367, -3.311539888381958, -2.3581974506378174, -3.433854341506958, -1.8603194952011108, -2.3839902877807617, -1.7093329429626465, -1.2563093900680542, -1.0504677295684814, -0.7915278673171997, -0.6268266439437866, 0.048114217817783356, -0.12746261060237885, -0.7664048671722412, -0.2509930729866028, 0.22835113108158112, -0.12758658826351166, 0.43044808506965637, 0.38889259099960327, 0.6839396953582764, 1.432624101638794, -0.08623196929693222, -0.510840892791748, 1.201884150505066, 0.8915037512779236, 1.489457368850708, 0.5685065984725952, 0.8486513495445251, 0.9768675565719604, 0.7145218849182129, 1.4186238050460815, 0.19970926642417908, 1.9190255403518677, 1.0981650352478027, 1.2337628602981567, 1.1330699920654297, 1.8199868202209473, 0.2714728116989136, 0.8715060949325562, 0.4128941297531128, 1.4283859729766846, 0.8993980288505554, 1.385322093963623, 1.017817497253418, 1.1200287342071533, 0.5412672162055969, 0.854238748550415, 0.5014718770980835, 1.1100939512252808, 0.3307260572910309, 0.571464478969574, 0.9686771631240845, 1.7088552713394165, 1.4331095218658447, 1.052613377571106, 0.6837802529335022, 1.4715099334716797, 1.846457600593567, 1.6779717206954956, 2.865612268447876, 0.0, 0.0], [0.0, -7.291342735290527, -6.478186130523682, -8.108572006225586, -6.148937702178955, -7.445594787597656, -7.083888530731201, -6.652523040771484, -6.467573642730713, -5.608551502227783, -5.761333465576172, -5.398777961730957, -3.2332746982574463, -5.091519832611084, -5.2060675621032715, -2.7325685024261475, -3.892716884613037, -3.441742420196533, -2.6410858631134033, -1.8878854513168335, -2.752669095993042, -1.5356340408325195, -2.218395709991455, -1.4228063821792603, -1.1764683723449707, -0.7806190848350525, -1.1080012321472168, -1.0405097007751465, -0.8365747928619385, -0.3741368055343628, 0.22205404937267303, -0.5603275299072266, -0.7880050539970398, -0.04975036159157753, 0.19150836765766144, 0.4991755187511444, 0.7043393850326538, -0.2878502309322357, -0.9207687377929688, 1.1719890832901, 1.0452215671539307, 0.8689408302307129, 0.9423804879188538, 1.2522741556167603, 1.7040327787399292, 1.4237090349197388, 1.2775211334228516, 0.16218286752700806, 3.0679469108581543, 1.6499748229980469, 0.14263950288295746, 1.5805156230926514, 1.6140594482421875, 0.8618813753128052, 4.6418585777282715, 1.8483415842056274, 1.2474087476730347, 1.4117385149002075, 1.9572354555130005, 1.6296466588974, 1.2883660793304443, 0.7186682820320129, -0.7798269987106323, 1.0544060468673706, -0.35371696949005127, 1.1295750141143799, 1.0006937980651855, 0.2934311628341675, 0.20690535008907318, 2.5089304447174072, 0.3019799590110779, 0.7126208543777466, 1.460260272026062, 1.6447733640670776, 2.0205163955688477, 2.4657440185546875, 0.0, 0.0, -0.0, -7.291342735290527, -6.478186130523682, -8.108572006225586, -6.148937702178955, -7.445594787597656, -7.083888530731201, -6.652523040771484, -6.467573642730713, -5.608551502227783, -5.761333465576172, -5.398777961730957, -3.2332746982574463, -5.091519832611084, -5.2060675621032715, -2.7325685024261475, -3.892716884613037, -3.441742420196533, -2.6410858631134033, -1.8878854513168335, -2.752669095993042, -1.5356340408325195, -2.218395709991455, -1.4228063821792603, -1.1764683723449707, -0.7806190848350525, -1.1080012321472168, -1.0405097007751465, -0.8365747928619385, -0.3741368055343628, 0.22205404937267303, -0.5603275299072266, -0.7880050539970398, -0.04975036159157753, 0.19150836765766144, 0.4991755187511444, 0.7043393850326538, -0.2878502309322357, -0.9207687377929688, 1.1719890832901, 1.0452215671539307, 0.8689408302307129, 0.9423804879188538, 1.2522741556167603, 1.7040327787399292, 1.4237090349197388, 1.2775211334228516, 0.16218286752700806, 3.0679469108581543, 1.6499748229980469, 0.14263950288295746, 1.5805156230926514, 1.6140594482421875, 0.8618813753128052, 4.6418585777282715, 1.8483415842056274, 1.2474087476730347, 1.4117385149002075, 1.9572354555130005, 1.6296466588974, 1.2883660793304443, 0.7186682820320129, -0.7798269987106323, 1.0544060468673706, -0.35371696949005127, 1.1295750141143799, 1.0006937980651855, 0.2934311628341675, 0.20690535008907318, 2.5089304447174072, 0.3019799590110779, 0.7126208543777466, 1.460260272026062, 1.6447733640670776, 2.0205163955688477, 2.4657440185546875, 0.0, 0.0], [0.0, -7.027205467224121, -7.675710201263428, -7.795223712921143, -7.599521636962891, -8.219441413879395, -6.902561664581299, -7.014155387878418, -5.693807125091553, -6.9809489250183105, -5.2351837158203125, -6.276397705078125, -5.816927909851074, -3.7301831245422363, -3.835468292236328, -4.009716987609863, -4.068512916564941, -3.5662810802459717, -2.2430315017700195, -3.4860892295837402, -2.358410120010376, -2.0926575660705566, -1.8330720663070679, -1.841867208480835, -1.6841025352478027, -1.3914979696273804, -1.1114212274551392, -0.5173345804214478, -0.440634161233902, -2.1766204833984375, -0.5413083434104919, -0.6866958141326904, -0.21341735124588013, 0.0653763934969902, 0.36840519309043884, 1.038307547569275, 2.345000743865967, -0.10521305352449417, -1.846901774406433, 1.168623447418213, 1.3143254518508911, 1.0031495094299316, -0.8507952094078064, 0.6560735702514648, 0.9301636219024658, 1.451615571975708, 1.140773892402649, 0.25821396708488464, 1.1317925453186035, 0.9081658124923706, 2.021775722503662, 1.1869149208068848, 0.9752151370048523, 2.583448648452759, 1.3104721307754517, 0.38286033272743225, -0.0901913195848465, 1.8516727685928345, 1.1704281568527222, 0.5512864589691162, 0.6175656318664551, 0.30839622020721436, -0.32025569677352905, 1.1741234064102173, 1.4212639331817627, 1.0521420240402222, -0.008720116689801216, 0.6893437504768372, 0.5272261500358582, 1.0119138956069946, 0.7796292304992676, 1.0388721227645874, 1.641505241394043, 0.7913983464241028, 1.4968421459197998, 2.2809906005859375, 2.559863567352295, 0.0, -0.0, -7.027205467224121, -7.675710201263428, -7.795223712921143, -7.599521636962891, -8.219441413879395, -6.902561664581299, -7.014155387878418, -5.693807125091553, -6.9809489250183105, -5.2351837158203125, -6.276397705078125, -5.816927909851074, -3.7301831245422363, -3.835468292236328, -4.009716987609863, -4.068512916564941, -3.5662810802459717, -2.2430315017700195, -3.4860892295837402, -2.358410120010376, -2.0926575660705566, -1.8330720663070679, -1.841867208480835, -1.6841025352478027, -1.3914979696273804, -1.1114212274551392, -0.5173345804214478, -0.440634161233902, -2.1766204833984375, -0.5413083434104919, -0.6866958141326904, -0.21341735124588013, 0.0653763934969902, 0.36840519309043884, 1.038307547569275, 2.345000743865967, -0.10521305352449417, -1.846901774406433, 1.168623447418213, 1.3143254518508911, 1.0031495094299316, -0.8507952094078064, 0.6560735702514648, 0.9301636219024658, 1.451615571975708, 1.140773892402649, 0.25821396708488464, 1.1317925453186035, 0.9081658124923706, 2.021775722503662, 1.1869149208068848, 0.9752151370048523, 2.583448648452759, 1.3104721307754517, 0.38286033272743225, -0.0901913195848465, 1.8516727685928345, 1.1704281568527222, 0.5512864589691162, 0.6175656318664551, 0.30839622020721436, -0.32025569677352905, 1.1741234064102173, 1.4212639331817627, 1.0521420240402222, -0.008720116689801216, 0.6893437504768372, 0.5272261500358582, 1.0119138956069946, 0.7796292304992676, 1.0388721227645874, 1.641505241394043, 0.7913983464241028, 1.4968421459197998, 2.2809906005859375, 2.559863567352295, 0.0], [0.0, -8.430828094482422, -8.663541793823242, -7.662160873413086, -7.988882064819336, -6.660684585571289, -7.046274185180664, -6.6555352210998535, -6.9109601974487305, -6.064568519592285, -4.994185447692871, -5.620395660400391, -3.5233843326568604, -4.80859375, -5.444929599761963, -4.91581392288208, -4.8269243240356445, -3.8989100456237793, -1.926242470741272, -5.506590366363525, -1.7224607467651367, -1.1906747817993164, -1.6934112310409546, -1.9799630641937256, -1.100163221359253, -1.6180408000946045, -0.677535355091095, -0.3784051835536957, -0.6497566103935242, -1.2891020774841309, -0.3303793668746948, 0.17092539370059967, -0.34716740250587463, -0.07935840636491776, -0.23865237832069397, 0.6036249995231628, 3.732257604598999, 1.7945719957351685, -1.5869990587234497, 0.0, 2.8328452110290527, 1.715746283531189, 1.2741739749908447, 0.37663179636001587, 1.6303777694702148, 0.5074077844619751, 1.138519048690796, -0.01802050694823265, 1.349570393562317, 1.1237878799438477, 0.0558319091796875, 1.1806387901306152, 0.6565984487533569, 2.4506659507751465, 0.45472294092178345, 1.2872153520584106, 0.49055373668670654, 0.5237953662872314, 0.8795445561408997, 0.6220630407333374, 0.4825276732444763, 0.4770869314670563, 0.810009241104126, 0.4032767415046692, -0.31464719772338867, 0.9901593327522278, 0.8666841387748718, 0.4686409533023834, 0.6110959649085999, 0.7489106059074402, 0.9622799158096313, 0.2553018033504486, 1.0412181615829468, 1.1535757780075073, 2.0554094314575195, 2.4955053329467773, 5.005786895751953, 0.0, -0.0, -8.430828094482422, -8.663541793823242, -7.662160873413086, -7.988882064819336, -6.660684585571289, -7.046274185180664, -6.6555352210998535, -6.9109601974487305, -6.064568519592285, -4.994185447692871, -5.620395660400391, -3.5233843326568604, -4.80859375, -5.444929599761963, -4.91581392288208, -4.8269243240356445, -3.8989100456237793, -1.926242470741272, -5.506590366363525, -1.7224607467651367, -1.1906747817993164, -1.6934112310409546, -1.9799630641937256, -1.100163221359253, -1.6180408000946045, -0.677535355091095, -0.3784051835536957, -0.6497566103935242, -1.2891020774841309, -0.3303793668746948, 0.17092539370059967, -0.34716740250587463, -0.07935840636491776, -0.23865237832069397, 0.6036249995231628, 3.732257604598999, 1.7945719957351685, -1.5869990587234497, 0.0, 2.8328452110290527, 1.715746283531189, 1.2741739749908447, 0.37663179636001587, 1.6303777694702148, 0.5074077844619751, 1.138519048690796, -0.01802050694823265, 1.349570393562317, 1.1237878799438477, 0.0558319091796875, 1.1806387901306152, 0.6565984487533569, 2.4506659507751465, 0.45472294092178345, 1.2872153520584106, 0.49055373668670654, 0.5237953662872314, 0.8795445561408997, 0.6220630407333374, 0.4825276732444763, 0.4770869314670563, 0.810009241104126, 0.4032767415046692, -0.31464719772338867, 0.9901593327522278, 0.8666841387748718, 0.4686409533023834, 0.6110959649085999, 0.7489106059074402, 0.9622799158096313, 0.2553018033504486, 1.0412181615829468, 1.1535757780075073, 2.0554094314575195, 2.4955053329467773, 5.005786895751953, 0.0], [0.0, -8.822691917419434, -8.362264633178711, -8.849967002868652, -8.039069175720215, -7.957859516143799, -5.018380641937256, -6.679488658905029, -6.962361812591553, -6.74004602432251, -6.567410469055176, -5.731754302978516, -4.9812798500061035, -3.8130483627319336, -4.243339538574219, -5.019989013671875, -4.524000644683838, -3.656444787979126, -3.8015613555908203, -2.605785846710205, -3.0054526329040527, -3.8302643299102783, -2.669795513153076, -2.3684213161468506, -1.640476942062378, -0.8094284534454346, -0.9102410674095154, -0.9612338542938232, -0.8432784080505371, -0.6695201396942139, 1.259921669960022, 0.058341916650533676, -0.7156945466995239, -1.0778898000717163, 0.5487987995147705, 0.3541831374168396, 0.8904944658279419, 2.7616496086120605, 4.813386917114258, 3.516835927963257, 1.696600317955017, 1.2094708681106567, 0.8962445259094238, 1.486297369003296, 0.7091509103775024, 0.40042930841445923, 0.5760170221328735, 0.7198840975761414, 0.22267158329486847, 0.7090945839881897, 0.9278048276901245, 0.5606188774108887, 1.2717176675796509, 0.5208913087844849, 1.773858666419983, 2.120364189147949, 0.31392937898635864, 0.4045129418373108, 1.4030336141586304, 1.245732307434082, 0.6149767637252808, 0.8293740749359131, 0.327711820602417, 0.05816224217414856, 0.04860565811395645, -0.3933735489845276, 0.8251101970672607, 0.13465584814548492, 0.5425182580947876, 1.1074951887130737, 1.0682916641235352, 1.0434287786483765, 0.16102026402950287, 0.9710135459899902, 1.4127871990203857, 1.6758687496185303, 1.7880791425704956, 0.0, -0.0, -8.822691917419434, -8.362264633178711, -8.849967002868652, -8.039069175720215, -7.957859516143799, -5.018380641937256, -6.679488658905029, -6.962361812591553, -6.74004602432251, -6.567410469055176, -5.731754302978516, -4.9812798500061035, -3.8130483627319336, -4.243339538574219, -5.019989013671875, -4.524000644683838, -3.656444787979126, -3.8015613555908203, -2.605785846710205, -3.0054526329040527, -3.8302643299102783, -2.669795513153076, -2.3684213161468506, -1.640476942062378, -0.8094284534454346, -0.9102410674095154, -0.9612338542938232, -0.8432784080505371, -0.6695201396942139, 1.259921669960022, 0.058341916650533676, -0.7156945466995239, -1.0778898000717163, 0.5487987995147705, 0.3541831374168396, 0.8904944658279419, 2.7616496086120605, 4.813386917114258, 3.516835927963257, 1.696600317955017, 1.2094708681106567, 0.8962445259094238, 1.486297369003296, 0.7091509103775024, 0.40042930841445923, 0.5760170221328735, 0.7198840975761414, 0.22267158329486847, 0.7090945839881897, 0.9278048276901245, 0.5606188774108887, 1.2717176675796509, 0.5208913087844849, 1.773858666419983, 2.120364189147949, 0.31392937898635864, 0.4045129418373108, 1.4030336141586304, 1.245732307434082, 0.6149767637252808, 0.8293740749359131, 0.327711820602417, 0.05816224217414856, 0.04860565811395645, -0.3933735489845276, 0.8251101970672607, 0.13465584814548492, 0.5425182580947876, 1.1074951887130737, 1.0682916641235352, 1.0434287786483765, 0.16102026402950287, 0.9710135459899902, 1.4127871990203857, 1.6758687496185303, 1.7880791425704956, 0.0], [0.0, -6.872518062591553, -9.350743293762207, -8.990917205810547, -8.171034812927246, -7.871299743652344, -7.8221001625061035, -7.866946697235107, -6.727217674255371, -6.864588737487793, -6.0774126052856445, -6.688292980194092, -3.8413538932800293, -5.103777885437012, -5.2302069664001465, -3.935920238494873, -4.696584701538086, -4.282158374786377, -4.01853084564209, -3.558716058731079, -2.844416379928589, -1.7641690969467163, -1.1800665855407715, -2.1647891998291016, -0.8005144000053406, -0.4846237897872925, 0.002922042738646269, -1.336027979850769, -2.187897205352783, -1.4391602277755737, -0.6502895355224609, -0.6198648810386658, -2.3283979892730713, -0.917324960231781, 0.059332601726055145, 0.37372228503227234, 0.9065927267074585, 1.4435263872146606, 4.964815616607666, 2.9963362216949463, 1.1999844312667847, 1.1959322690963745, 0.5844073295593262, 0.15140661597251892, 0.6967048048973083, 0.7273775339126587, 0.541545033454895, 2.3402023315429688, 1.7801698446273804, 0.343272864818573, 0.9236055016517639, 0.6778839826583862, 1.468925952911377, 2.1862680912017822, 1.833509922027588, 0.8560405969619751, 0.579535961151123, 0.5696245431900024, 0.8606017231941223, 0.49223607778549194, 0.4743405878543854, 0.4915001690387726, 0.5881596803665161, 0.5432064533233643, 1.3217569589614868, -0.20634286105632782, 0.2895583212375641, -0.6103237867355347, -0.2644602954387665, -0.11455515772104263, 0.5970091223716736, 0.5717042684555054, 0.4949323236942291, 1.3267115354537964, 1.523577332496643, 1.3329864740371704, 1.4589238166809082, 0.0, -0.0, -6.872518062591553, -9.350743293762207, -8.990917205810547, -8.171034812927246, -7.871299743652344, -7.8221001625061035, -7.866946697235107, -6.727217674255371, -6.864588737487793, -6.0774126052856445, -6.688292980194092, -3.8413538932800293, -5.103777885437012, -5.2302069664001465, -3.935920238494873, -4.696584701538086, -4.282158374786377, -4.01853084564209, -3.558716058731079, -2.844416379928589, -1.7641690969467163, -1.1800665855407715, -2.1647891998291016, -0.8005144000053406, -0.4846237897872925, 0.002922042738646269, -1.336027979850769, -2.187897205352783, -1.4391602277755737, -0.6502895355224609, -0.6198648810386658, -2.3283979892730713, -0.917324960231781, 0.059332601726055145, 0.37372228503227234, 0.9065927267074585, 1.4435263872146606, 4.964815616607666, 2.9963362216949463, 1.1999844312667847, 1.1959322690963745, 0.5844073295593262, 0.15140661597251892, 0.6967048048973083, 0.7273775339126587, 0.541545033454895, 2.3402023315429688, 1.7801698446273804, 0.343272864818573, 0.9236055016517639, 0.6778839826583862, 1.468925952911377, 2.1862680912017822, 1.833509922027588, 0.8560405969619751, 0.579535961151123, 0.5696245431900024, 0.8606017231941223, 0.49223607778549194, 0.4743405878543854, 0.4915001690387726, 0.5881596803665161, 0.5432064533233643, 1.3217569589614868, -0.20634286105632782, 0.2895583212375641, -0.6103237867355347, -0.2644602954387665, -0.11455515772104263, 0.5970091223716736, 0.5717042684555054, 0.4949323236942291, 1.3267115354537964, 1.523577332496643, 1.3329864740371704, 1.4589238166809082, 0.0], [0.0, -9.510042190551758, -8.815271377563477, -9.051676750183105, -8.576929092407227, -9.148176193237305, -8.318795204162598, -7.58879280090332, -7.621758460998535, -7.409163475036621, -6.916208267211914, -6.4467267990112305, -5.703545570373535, -5.796448707580566, -6.076663494110107, -5.126081466674805, -4.482936382293701, -3.5565309524536133, -3.55745267868042, -3.174490213394165, -2.7140111923217773, -2.825671434402466, -3.3955416679382324, -2.304123640060425, -1.567665696144104, -0.6838334798812866, -2.082374095916748, -1.473835825920105, -0.7102259993553162, -1.3163459300994873, -0.6085220575332642, 0.1633312851190567, -0.3781939148902893, -0.07408780604600906, -0.09812680631875992, 0.08724615722894669, 0.6939521431922913, 0.8120961785316467, 2.5572667121887207, 1.240143060684204, 1.4926939010620117, 1.3421097993850708, 1.3573575019836426, 0.296652615070343, 0.9676920771598816, 0.8522301912307739, 0.6366671323776245, -1.697898268699646, 0.2128591388463974, 0.7161118388175964, 1.3594409227371216, -0.48606985807418823, 0.4292631149291992, 0.745988130569458, 1.2435060739517212, 0.859798789024353, 0.6460667252540588, 0.2449767291545868, 0.3005203902721405, 1.029488205909729, 0.33118781447410583, -0.08723442256450653, -0.13604457676410675, -0.012173143215477467, 1.3379837274551392, 1.0944631099700928, 0.3334749937057495, 0.04222150146961212, 0.19604837894439697, -1.0295569896697998, -0.02389119751751423, 1.2602026462554932, 0.30839791893959045, 0.4988856315612793, 1.2056052684783936, 1.417528748512268, 3.0973477363586426, 0.0, -0.0, -9.510042190551758, -8.815271377563477, -9.051676750183105, -8.576929092407227, -9.148176193237305, -8.318795204162598, -7.58879280090332, -7.621758460998535, -7.409163475036621, -6.916208267211914, -6.4467267990112305, -5.703545570373535, -5.796448707580566, -6.076663494110107, -5.126081466674805, -4.482936382293701, -3.5565309524536133, -3.55745267868042, -3.174490213394165, -2.7140111923217773, -2.825671434402466, -3.3955416679382324, -2.304123640060425, -1.567665696144104, -0.6838334798812866, -2.082374095916748, -1.473835825920105, -0.7102259993553162, -1.3163459300994873, -0.6085220575332642, 0.1633312851190567, -0.3781939148902893, -0.07408780604600906, -0.09812680631875992, 0.08724615722894669, 0.6939521431922913, 0.8120961785316467, 2.5572667121887207, 1.240143060684204, 1.4926939010620117, 1.3421097993850708, 1.3573575019836426, 0.296652615070343, 0.9676920771598816, 0.8522301912307739, 0.6366671323776245, -1.697898268699646, 0.2128591388463974, 0.7161118388175964, 1.3594409227371216, -0.48606985807418823, 0.4292631149291992, 0.745988130569458, 1.2435060739517212, 0.859798789024353, 0.6460667252540588, 0.2449767291545868, 0.3005203902721405, 1.029488205909729, 0.33118781447410583, -0.08723442256450653, -0.13604457676410675, -0.012173143215477467, 1.3379837274551392, 1.0944631099700928, 0.3334749937057495, 0.04222150146961212, 0.19604837894439697, -1.0295569896697998, -0.02389119751751423, 1.2602026462554932, 0.30839791893959045, 0.4988856315612793, 1.2056052684783936, 1.417528748512268, 3.0973477363586426, 0.0], [0.0, -9.729935646057129, -8.989297866821289, -9.05072021484375, -8.799030303955078, -9.058984756469727, -8.565457344055176, -8.256778717041016, -7.7018513679504395, -8.234811782836914, -7.330820083618164, -6.977338790893555, -6.151952266693115, -4.962457656860352, -4.996310234069824, -5.349209308624268, -5.141345500946045, -4.4486236572265625, -3.5475010871887207, -3.541593074798584, -3.1786093711853027, -3.0916366577148438, -2.69590425491333, -2.07954478263855, -1.8557652235031128, -0.4990418553352356, -2.3363537788391113, -2.1226511001586914, -0.6443239450454712, -1.2894206047058105, -0.37398892641067505, -1.6255344152450562, 0.21597979962825775, 0.10118969529867172, 2.542494058609009, 0.2765631675720215, 0.5744764804840088, 0.027011996135115623, 1.6872265338897705, 0.5921238660812378, 0.5792005062103271, 0.8090294003486633, 0.9206268787384033, 1.353311538696289, 0.2467016875743866, 0.6269665956497192, 0.29776543378829956, 0.9764044880867004, 0.9692310094833374, 1.1789945363998413, 0.402160108089447, 0.40846091508865356, 1.4401555061340332, 1.739952564239502, 0.3548993468284607, 0.5048555135726929, 0.43526288866996765, 1.1048420667648315, -0.3103918135166168, 0.7617435455322266, 1.2698545455932617, 0.4782480001449585, -0.4963821768760681, 0.7179174423217773, 0.597337007522583, 0.3827815353870392, 0.518317461013794, -0.3314971625804901, -0.4095838665962219, 0.792110800743103, -0.5110870599746704, -0.17636945843696594, 0.2781085968017578, 0.7908247709274292, 1.4556372165679932, 0.953831136226654, 0.3505840301513672, 0.0, -0.0, -9.729935646057129, -8.989297866821289, -9.05072021484375, -8.799030303955078, -9.058984756469727, -8.565457344055176, -8.256778717041016, -7.7018513679504395, -8.234811782836914, -7.330820083618164, -6.977338790893555, -6.151952266693115, -4.962457656860352, -4.996310234069824, -5.349209308624268, -5.141345500946045, -4.4486236572265625, -3.5475010871887207, -3.541593074798584, -3.1786093711853027, -3.0916366577148438, -2.69590425491333, -2.07954478263855, -1.8557652235031128, -0.4990418553352356, -2.3363537788391113, -2.1226511001586914, -0.6443239450454712, -1.2894206047058105, -0.37398892641067505, -1.6255344152450562, 0.21597979962825775, 0.10118969529867172, 2.542494058609009, 0.2765631675720215, 0.5744764804840088, 0.027011996135115623, 1.6872265338897705, 0.5921238660812378, 0.5792005062103271, 0.8090294003486633, 0.9206268787384033, 1.353311538696289, 0.2467016875743866, 0.6269665956497192, 0.29776543378829956, 0.9764044880867004, 0.9692310094833374, 1.1789945363998413, 0.402160108089447, 0.40846091508865356, 1.4401555061340332, 1.739952564239502, 0.3548993468284607, 0.5048555135726929, 0.43526288866996765, 1.1048420667648315, -0.3103918135166168, 0.7617435455322266, 1.2698545455932617, 0.4782480001449585, -0.4963821768760681, 0.7179174423217773, 0.597337007522583, 0.3827815353870392, 0.518317461013794, -0.3314971625804901, -0.4095838665962219, 0.792110800743103, -0.5110870599746704, -0.17636945843696594, 0.2781085968017578, 0.7908247709274292, 1.4556372165679932, 0.953831136226654, 0.3505840301513672, 0.0], [0.0, -9.84809684753418, -9.825389862060547, -8.851277351379395, -8.915518760681152, -8.9545259475708, -8.376962661743164, -8.431283950805664, -7.736725807189941, -7.318032264709473, -6.917245388031006, -6.881491661071777, -6.808046340942383, -5.848849773406982, -5.222324848175049, -4.399597644805908, -3.876345634460449, -1.905075192451477, -3.7754948139190674, -3.3568994998931885, -2.8284249305725098, -3.047682523727417, -2.528482437133789, -2.867974042892456, -1.831906795501709, -2.0627589225769043, -1.5084799528121948, -1.681980848312378, -1.1451624631881714, -0.9821429252624512, -1.0679548978805542, -0.9972268342971802, -0.2455756515264511, -1.7033642530441284, 0.8754879236221313, -0.13581115007400513, 0.5686826109886169, 0.20971746742725372, 1.3402560949325562, 0.6983956694602966, 0.32264748215675354, 0.7499604821205139, 1.4088557958602905, 0.9151840209960938, -0.03914220258593559, 0.9944851398468018, 1.1909379959106445, 0.9824327826499939, 0.2200108915567398, 1.6596713066101074, 1.0003703832626343, 0.6259022951126099, 0.10981185734272003, 1.267783761024475, 1.8088575601577759, 0.7588029503822327, 1.1355540752410889, 1.5710194110870361, 0.6062908172607422, 0.9591554999351501, -0.09380944073200226, 0.5287020802497864, -0.0503433495759964, 0.5487826466560364, -0.4152107238769531, 0.23487067222595215, -0.5687835812568665, -0.5190708041191101, -0.44261881709098816, 0.4406973719596863, 0.1461820751428604, 0.03201624006032944, 0.3289574980735779, 0.3726195693016052, -0.03126385807991028, 0.24223127961158752, -0.7077754735946655, 0.0, -0.0, -9.84809684753418, -9.825389862060547, -8.851277351379395, -8.915518760681152, -8.9545259475708, -8.376962661743164, -8.431283950805664, -7.736725807189941, -7.318032264709473, -6.917245388031006, -6.881491661071777, -6.808046340942383, -5.848849773406982, -5.222324848175049, -4.399597644805908, -3.876345634460449, -1.905075192451477, -3.7754948139190674, -3.3568994998931885, -2.8284249305725098, -3.047682523727417, -2.528482437133789, -2.867974042892456, -1.831906795501709, -2.0627589225769043, -1.5084799528121948, -1.681980848312378, -1.1451624631881714, -0.9821429252624512, -1.0679548978805542, -0.9972268342971802, -0.2455756515264511, -1.7033642530441284, 0.8754879236221313, -0.13581115007400513, 0.5686826109886169, 0.20971746742725372, 1.3402560949325562, 0.6983956694602966, 0.32264748215675354, 0.7499604821205139, 1.4088557958602905, 0.9151840209960938, -0.03914220258593559, 0.9944851398468018, 1.1909379959106445, 0.9824327826499939, 0.2200108915567398, 1.6596713066101074, 1.0003703832626343, 0.6259022951126099, 0.10981185734272003, 1.267783761024475, 1.8088575601577759, 0.7588029503822327, 1.1355540752410889, 1.5710194110870361, 0.6062908172607422, 0.9591554999351501, -0.09380944073200226, 0.5287020802497864, -0.0503433495759964, 0.5487826466560364, -0.4152107238769531, 0.23487067222595215, -0.5687835812568665, -0.5190708041191101, -0.44261881709098816, 0.4406973719596863, 0.1461820751428604, 0.03201624006032944, 0.3289574980735779, 0.3726195693016052, -0.03126385807991028, 0.24223127961158752, -0.7077754735946655, -0.0], [0.0, -9.374674797058105, -10.645832061767578, -9.955503463745117, -9.946052551269531, -9.182902336120605, -9.178797721862793, -8.232922554016113, -7.466667652130127, -7.182268142700195, -7.002236843109131, -7.3327860832214355, -6.696320533752441, -6.4420013427734375, -3.8786609172821045, -5.695989608764648, -5.276689052581787, -2.178102970123291, -4.612179279327393, -4.321689605712891, -2.1414363384246826, -2.280766725540161, -1.9222935438156128, -2.3894081115722656, -2.4587132930755615, 0.37146493792533875, -0.5320367217063904, -1.6858044862747192, 1.0063179731369019, -0.3219083845615387, -1.576943039894104, -1.2663427591323853, -0.3811151087284088, 0.27581048011779785, -1.098222255706787, -1.159171223640442, -0.4247869551181793, 0.18030977249145508, 0.4074225425720215, 0.37473592162132263, 0.6863909959793091, 0.5686426162719727, 0.1178029477596283, -0.0374714694917202, -0.2894633710384369, 0.2696899473667145, 1.0969609022140503, 1.1231805086135864, 0.6706438660621643, 0.24412263929843903, 0.8028345108032227, 1.069031834602356, 1.6215873956680298, 3.710379123687744, 0.7456599473953247, 0.14211609959602356, 0.7221865057945251, 1.5030139684677124, -0.12772136926651, 1.1133511066436768, -0.017687885090708733, 0.4141356945037842, 0.19805292785167694, 0.4538274109363556, -0.311379075050354, 0.10319197177886963, -0.2810530364513397, -1.608878493309021, 0.6211587190628052, -0.6755295991897583, -1.3355625867843628, 0.24557790160179138, -0.5920616388320923, -0.31421127915382385, 0.6368353366851807, 0.8127878904342651, 0.20045310258865356, 0.0, -0.0, -9.374674797058105, -10.645832061767578, -9.955503463745117, -9.946052551269531, -9.182902336120605, -9.178797721862793, -8.232922554016113, -7.466667652130127, -7.182268142700195, -7.002236843109131, -7.3327860832214355, -6.696320533752441, -6.4420013427734375, -3.8786609172821045, -5.695989608764648, -5.276689052581787, -2.178102970123291, -4.612179279327393, -4.321689605712891, -2.1414363384246826, -2.280766725540161, -1.9222935438156128, -2.3894081115722656, -2.4587132930755615, 0.37146493792533875, -0.5320367217063904, -1.6858044862747192, 1.0063179731369019, -0.3219083845615387, -1.576943039894104, -1.2663427591323853, -0.3811151087284088, 0.27581048011779785, -1.098222255706787, -1.159171223640442, -0.4247869551181793, 0.18030977249145508, 0.4074225425720215, 0.37473592162132263, 0.6863909959793091, 0.5686426162719727, 0.1178029477596283, -0.0374714694917202, -0.2894633710384369, 0.2696899473667145, 1.0969609022140503, 1.1231805086135864, 0.6706438660621643, 0.24412263929843903, 0.8028345108032227, 1.069031834602356, 1.6215873956680298, 3.710379123687744, 0.7456599473953247, 0.14211609959602356, 0.7221865057945251, 1.5030139684677124, -0.12772136926651, 1.1133511066436768, -0.017687885090708733, 0.4141356945037842, 0.19805292785167694, 0.4538274109363556, -0.311379075050354, 0.10319197177886963, -0.2810530364513397, -1.608878493309021, 0.6211587190628052, -0.6755295991897583, -1.3355625867843628, 0.24557790160179138, -0.5920616388320923, -0.31421127915382385, 0.6368353366851807, 0.8127878904342651, 0.20045310258865356, 0.0], [0.0, -10.437288284301758, -9.728740692138672, -9.549036979675293, -10.502057075500488, -10.578512191772461, -9.768181800842285, -9.130597114562988, -8.802937507629395, -8.249068260192871, -8.238037109375, -7.148815631866455, -7.11557674407959, -5.228080749511719, -5.793333053588867, -4.992245674133301, -5.358684062957764, -4.771544933319092, -3.2842488288879395, -3.785395860671997, -3.212406635284424, -2.9692037105560303, -4.01664924621582, -3.6438324451446533, -0.9155413508415222, -1.4792048931121826, -3.5850679874420166, -2.4146151542663574, -1.4261947870254517, -1.7964575290679932, -1.7187656164169312, -0.99752277135849, -1.4875671863555908, 0.033995818346738815, -0.9378492832183838, -0.07455658912658691, 0.15386147797107697, 0.5519468188285828, 0.22439555823802948, -0.2692849636077881, 0.41075074672698975, 0.6892375946044922, -1.1083874702453613, -0.31203973293304443, 1.1349767446517944, 0.579736590385437, 0.637313723564148, 1.7811315059661865, 0.8874591588973999, 0.6858930587768555, 1.4885280132293701, -1.2010594606399536, 1.8690857887268066, 1.3981049060821533, 1.9783531427383423, 0.8347375392913818, 0.7476144433021545, -2.2939565181732178, 0.015464846976101398, 0.42652544379234314, -0.5399152040481567, 0.08496362715959549, 0.14926020801067352, -0.5403452515602112, -0.30115726590156555, -1.3357046842575073, -0.6043356657028198, -1.0571519136428833, -0.6241690516471863, -0.3433837294578552, -1.3475341796875, -1.3383276462554932, -1.591213583946228, -0.112652488052845, -0.13034623861312866, -0.3914305567741394, 0.25427111983299255, 0.0, -0.0, -10.437288284301758, -9.728740692138672, -9.549036979675293, -10.502057075500488, -10.578512191772461, -9.768181800842285, -9.130597114562988, -8.802937507629395, -8.249068260192871, -8.238037109375, -7.148815631866455, -7.11557674407959, -5.228080749511719, -5.793333053588867, -4.992245674133301, -5.358684062957764, -4.771544933319092, -3.2842488288879395, -3.785395860671997, -3.212406635284424, -2.9692037105560303, -4.01664924621582, -3.6438324451446533, -0.9155413508415222, -1.4792048931121826, -3.5850679874420166, -2.4146151542663574, -1.4261947870254517, -1.7964575290679932, -1.7187656164169312, -0.99752277135849, -1.4875671863555908, 0.033995818346738815, -0.9378492832183838, -0.07455658912658691, 0.15386147797107697, 0.5519468188285828, 0.22439555823802948, -0.2692849636077881, 0.41075074672698975, 0.6892375946044922, -1.1083874702453613, -0.31203973293304443, 1.1349767446517944, 0.579736590385437, 0.637313723564148, 1.7811315059661865, 0.8874591588973999, 0.6858930587768555, 1.4885280132293701, -1.2010594606399536, 1.8690857887268066, 1.3981049060821533, 1.9783531427383423, 0.8347375392913818, 0.7476144433021545, -2.2939565181732178, 0.015464846976101398, 0.42652544379234314, -0.5399152040481567, 0.08496362715959549, 0.14926020801067352, -0.5403452515602112, -0.30115726590156555, -1.3357046842575073, -0.6043356657028198, -1.0571519136428833, -0.6241690516471863, -0.3433837294578552, -1.3475341796875, -1.3383276462554932, -1.591213583946228, -0.112652488052845, -0.13034623861312866, -0.3914305567741394, 0.25427111983299255, 0.0], [0.0, -13.039732933044434, -11.7936372756958, -11.440526962280273, -10.613371849060059, -9.572164535522461, -9.4803466796875, -8.56363582611084, -9.00701904296875, -8.034568786621094, -7.706775665283203, -6.7893853187561035, -7.159631729125977, -7.126634120941162, -6.261380672454834, -5.504849433898926, -5.177148818969727, -5.035503387451172, -5.566242694854736, -3.4479081630706787, -4.780200481414795, -3.0621964931488037, -1.9889460802078247, -4.954235553741455, -1.502342939376831, -1.2163805961608887, -1.944640040397644, -3.7003612518310547, -0.7168455123901367, -1.1850149631500244, -0.011702435091137886, 1.5347827672958374, -0.7578235268592834, -0.9927811622619629, -0.9006527662277222, -0.5464153289794922, 0.21709224581718445, 0.31355780363082886, -0.2303491234779358, -0.15921945869922638, 0.13678298890590668, -0.6736112236976624, 0.26669156551361084, -0.7049146294593811, -0.7805935144424438, -0.05046148598194122, -0.4536479115486145, -0.7456393837928772, -0.753322958946228, 0.9986890554428101, 0.7730598449707031, 0.93825763463974, 0.9696824550628662, 0.8460245728492737, 1.1966158151626587, -1.0982381105422974, 2.044414520263672, -0.2837263345718384, 0.7858977913856506, 0.1823384314775467, 0.8226967453956604, 0.06893407553434372, -0.02675447054207325, -0.2843557298183441, -0.68723464012146, -0.09662679582834244, -0.6838370561599731, -0.33311358094215393, -0.7891401052474976, -0.7884532809257507, -1.5872564315795898, -2.028733015060425, -0.8381573557853699, -1.1214625835418701, -1.8175790309906006, -1.7098164558410645, -3.378598928451538, 0.0, -0.0, -13.039732933044434, -11.7936372756958, -11.440526962280273, -10.613371849060059, -9.572164535522461, -9.4803466796875, -8.56363582611084, -9.00701904296875, -8.034568786621094, -7.706775665283203, -6.7893853187561035, -7.159631729125977, -7.126634120941162, -6.261380672454834, -5.504849433898926, -5.177148818969727, -5.035503387451172, -5.566242694854736, -3.4479081630706787, -4.780200481414795, -3.0621964931488037, -1.9889460802078247, -4.954235553741455, -1.502342939376831, -1.2163805961608887, -1.944640040397644, -3.7003612518310547, -0.7168455123901367, -1.1850149631500244, -0.011702435091137886, 1.5347827672958374, -0.7578235268592834, -0.9927811622619629, -0.9006527662277222, -0.5464153289794922, 0.21709224581718445, 0.31355780363082886, -0.2303491234779358, -0.15921945869922638, 0.13678298890590668, -0.6736112236976624, 0.26669156551361084, -0.7049146294593811, -0.7805935144424438, -0.05046148598194122, -0.4536479115486145, -0.7456393837928772, -0.753322958946228, 0.9986890554428101, 0.7730598449707031, 0.93825763463974, 0.9696824550628662, 0.8460245728492737, 1.1966158151626587, -1.0982381105422974, 2.044414520263672, -0.2837263345718384, 0.7858977913856506, 0.1823384314775467, 0.8226967453956604, 0.06893407553434372, -0.02675447054207325, -0.2843557298183441, -0.68723464012146, -0.09662679582834244, -0.6838370561599731, -0.33311358094215393, -0.7891401052474976, -0.7884532809257507, -1.5872564315795898, -2.028733015060425, -0.8381573557853699, -1.1214625835418701, -1.8175790309906006, -1.7098164558410645, -3.378598928451538, -0.0], [0.0, -13.05366325378418, -12.838912010192871, -10.959488868713379, -10.12888240814209, -10.462052345275879, -9.866371154785156, -8.80121898651123, -9.621195793151855, -8.362127304077148, -8.544472694396973, -8.189483642578125, -7.218790531158447, -7.002076148986816, -5.504753112792969, -7.412550449371338, -5.407065391540527, -4.488973617553711, -5.478629112243652, -4.525357723236084, -5.5887908935546875, -2.994110584259033, -5.607313632965088, -2.4020938873291016, -2.4400453567504883, -2.945922613143921, -1.6818606853485107, -0.555541455745697, -0.23795846104621887, -2.860673189163208, -1.4017481803894043, -0.42847880721092224, -1.6259788274765015, -0.660077691078186, -0.33761632442474365, -0.6244252920150757, -1.3909797668457031, -0.5695697069168091, -0.6445943713188171, -0.8722292184829712, -0.4251690208911896, 0.31850358843803406, -0.3252013325691223, -0.42249754071235657, -0.12215255945920944, -0.24129605293273926, 0.16407504677772522, -0.24285124242305756, 0.41519400477409363, -0.20644354820251465, 1.0430080890655518, 1.8582864999771118, 1.4141775369644165, 0.3020870089530945, -0.25115296244621277, 0.6600662469863892, 2.0531511306762695, 0.3437468111515045, 0.7340415716171265, -0.153135284781456, 0.3458634614944458, 0.09729664772748947, -0.13740672171115875, 0.08465500921010971, 0.08956439793109894, -0.46209070086479187, -0.8264551162719727, -0.660016655921936, -1.7496155500411987, -0.25787630677223206, -1.047910451889038, -2.6443381309509277, -0.9293509125709534, -0.7683680653572083, -1.6970646381378174, -1.6740248203277588, -2.5125837326049805, 0.0, -0.0, -13.05366325378418, -12.838912010192871, -10.959488868713379, -10.12888240814209, -10.462052345275879, -9.866371154785156, -8.80121898651123, -9.621195793151855, -8.362127304077148, -8.544472694396973, -8.189483642578125, -7.218790531158447, -7.002076148986816, -5.504753112792969, -7.412550449371338, -5.407065391540527, -4.488973617553711, -5.478629112243652, -4.525357723236084, -5.5887908935546875, -2.994110584259033, -5.607313632965088, -2.4020938873291016, -2.4400453567504883, -2.945922613143921, -1.6818606853485107, -0.555541455745697, -0.23795846104621887, -2.860673189163208, -1.4017481803894043, -0.42847880721092224, -1.6259788274765015, -0.660077691078186, -0.33761632442474365, -0.6244252920150757, -1.3909797668457031, -0.5695697069168091, -0.6445943713188171, -0.8722292184829712, -0.4251690208911896, 0.31850358843803406, -0.3252013325691223, -0.42249754071235657, -0.12215255945920944, -0.24129605293273926, 0.16407504677772522, -0.24285124242305756, 0.41519400477409363, -0.20644354820251465, 1.0430080890655518, 1.8582864999771118, 1.4141775369644165, 0.3020870089530945, -0.25115296244621277, 0.6600662469863892, 2.0531511306762695, 0.3437468111515045, 0.7340415716171265, -0.153135284781456, 0.3458634614944458, 0.09729664772748947, -0.13740672171115875, 0.08465500921010971, 0.08956439793109894, -0.46209070086479187, -0.8264551162719727, -0.660016655921936, -1.7496155500411987, -0.25787630677223206, -1.047910451889038, -2.6443381309509277, -0.9293509125709534, -0.7683680653572083, -1.6970646381378174, -1.6740248203277588, -2.5125837326049805, -0.0], [0.0, -13.742500305175781, -13.767746925354004, -11.834783554077148, -10.895552635192871, -8.279831886291504, -10.043993949890137, -9.974005699157715, -9.322218894958496, -9.476539611816406, -8.317901611328125, -9.065834999084473, -7.624202728271484, -7.118839740753174, -6.2839741706848145, -5.353394508361816, -5.711122035980225, -4.730706691741943, -3.747117042541504, -3.3809778690338135, -4.598814964294434, -2.669947624206543, -3.7922887802124023, -3.682802438735962, -2.629403591156006, -1.1804794073104858, -1.7945083379745483, -2.292205810546875, -1.7592538595199585, -1.3842887878417969, -4.184225082397461, -1.2577561140060425, -0.698224663734436, -1.407097339630127, -1.8449780941009521, -1.671485185623169, -1.1868629455566406, -0.850247859954834, -0.4630962908267975, -0.34085628390312195, -0.7164307236671448, -0.4156656265258789, -0.9723688960075378, -0.5502538681030273, -0.2844234108924866, -0.7052949666976929, 0.6277188658714294, 0.4711277484893799, 1.1270860433578491, -0.6568443179130554, 0.31582948565483093, -0.05723905935883522, 0.4456958770751953, -0.955817461013794, 1.0590828657150269, -0.5079278349876404, -0.6283712983131409, -0.15506674349308014, -0.05267448350787163, -0.43424952030181885, 0.8293024301528931, 0.21667978167533875, -0.29570072889328003, -0.9515976905822754, -0.16885344684123993, -0.5868496894836426, -0.7219728827476501, -0.497769832611084, -0.9712187051773071, -1.882758378982544, -1.153120517730713, -1.5619688034057617, -1.0005521774291992, -1.0674841403961182, -1.0178667306900024, -2.6659743785858154, -3.024702548980713, 0.0, -0.0, -13.742500305175781, -13.767746925354004, -11.834783554077148, -10.895552635192871, -8.279831886291504, -10.043993949890137, -9.974005699157715, -9.322218894958496, -9.476539611816406, -8.317901611328125, -9.065834999084473, -7.624202728271484, -7.118839740753174, -6.2839741706848145, -5.353394508361816, -5.711122035980225, -4.730706691741943, -3.747117042541504, -3.3809778690338135, -4.598814964294434, -2.669947624206543, -3.7922887802124023, -3.682802438735962, -2.629403591156006, -1.1804794073104858, -1.7945083379745483, -2.292205810546875, -1.7592538595199585, -1.3842887878417969, -4.184225082397461, -1.2577561140060425, -0.698224663734436, -1.407097339630127, -1.8449780941009521, -1.671485185623169, -1.1868629455566406, -0.850247859954834, -0.4630962908267975, -0.34085628390312195, -0.7164307236671448, -0.4156656265258789, -0.9723688960075378, -0.5502538681030273, -0.2844234108924866, -0.7052949666976929, 0.6277188658714294, 0.4711277484893799, 1.1270860433578491, -0.6568443179130554, 0.31582948565483093, -0.05723905935883522, 0.4456958770751953, -0.955817461013794, 1.0590828657150269, -0.5079278349876404, -0.6283712983131409, -0.15506674349308014, -0.05267448350787163, -0.43424952030181885, 0.8293024301528931, 0.21667978167533875, -0.29570072889328003, -0.9515976905822754, -0.16885344684123993, -0.5868496894836426, -0.7219728827476501, -0.497769832611084, -0.9712187051773071, -1.882758378982544, -1.153120517730713, -1.5619688034057617, -1.0005521774291992, -1.0674841403961182, -1.0178667306900024, -2.6659743785858154, -3.024702548980713, -0.0], [0.0, -15.753708839416504, -13.359984397888184, -12.461895942687988, -11.506185531616211, -10.9039306640625, -10.494147300720215, -10.01399040222168, -9.538301467895508, -9.858465194702148, -9.022259712219238, -7.747003555297852, -6.407898426055908, -7.501936435699463, -6.962833404541016, -6.336763858795166, -5.817250728607178, -4.63455867767334, -5.040119171142578, -4.695518493652344, -4.523955821990967, -2.767479658126831, -3.18839955329895, -2.996095895767212, -3.124685287475586, -2.213716983795166, -1.9608256816864014, -1.322585940361023, -1.6985764503479004, -1.1971986293792725, -2.1637706756591797, -1.1876673698425293, -1.2759519815444946, -0.7148752808570862, -1.387392282485962, -1.5712978839874268, -0.8761031031608582, -0.5480632185935974, -0.3972250521183014, -0.6733208894729614, -0.7285259962081909, -1.3510892391204834, -0.8132922649383545, -0.321589857339859, -0.7599529027938843, -0.2350219339132309, -0.6517168283462524, -0.017351141199469566, -1.6721527576446533, 0.028963493183255196, 0.8836522102355957, 0.9215142726898193, -0.02114994265139103, -2.216243267059326, -0.9827909469604492, 1.1836059093475342, -0.886712908744812, -0.5360313653945923, 0.822360634803772, -0.3297335207462311, 0.6261380314826965, 0.3551241159439087, -1.0535894632339478, -0.11032021045684814, 0.0, -1.3388948440551758, -1.16361403465271, -2.554098606109619, -1.3344063758850098, -1.30256986618042, -0.7850713729858398, -1.5223808288574219, -0.9805784821510315, -1.453516960144043, -3.105361223220825, -2.926164388656616, -4.363710403442383, 0.0, -0.0, -15.753708839416504, -13.359984397888184, -12.461895942687988, -11.506185531616211, -10.9039306640625, -10.494147300720215, -10.01399040222168, -9.538301467895508, -9.858465194702148, -9.022259712219238, -7.747003555297852, -6.407898426055908, -7.501936435699463, -6.962833404541016, -6.336763858795166, -5.817250728607178, -4.63455867767334, -5.040119171142578, -4.695518493652344, -4.523955821990967, -2.767479658126831, -3.18839955329895, -2.996095895767212, -3.124685287475586, -2.213716983795166, -1.9608256816864014, -1.322585940361023, -1.6985764503479004, -1.1971986293792725, -2.1637706756591797, -1.1876673698425293, -1.2759519815444946, -0.7148752808570862, -1.387392282485962, -1.5712978839874268, -0.8761031031608582, -0.5480632185935974, -0.3972250521183014, -0.6733208894729614, -0.7285259962081909, -1.3510892391204834, -0.8132922649383545, -0.321589857339859, -0.7599529027938843, -0.2350219339132309, -0.6517168283462524, -0.017351141199469566, -1.6721527576446533, 0.028963493183255196, 0.8836522102355957, 0.9215142726898193, -0.02114994265139103, -2.216243267059326, -0.9827909469604492, 1.1836059093475342, -0.886712908744812, -0.5360313653945923, 0.822360634803772, -0.3297335207462311, 0.6261380314826965, 0.3551241159439087, -1.0535894632339478, -0.11032021045684814, -0.0, -1.3388948440551758, -1.16361403465271, -2.554098606109619, -1.3344063758850098, -1.30256986618042, -0.7850713729858398, -1.5223808288574219, -0.9805784821510315, -1.453516960144043, -3.105361223220825, -2.926164388656616, -4.363710403442383, -0.0], [0.0, -16.355609893798828, -13.747337341308594, -12.695016860961914, -12.01173210144043, -11.976179122924805, -11.483832359313965, -10.334505081176758, -9.61029052734375, -8.281295776367188, -9.180792808532715, -7.864101409912109, -7.9538397789001465, -6.229466915130615, -6.674722671508789, -5.749129295349121, -5.764064311981201, -4.7270379066467285, -4.13429069519043, -4.710429668426514, -3.6758010387420654, -4.146903991699219, -3.987639904022217, -3.792862892150879, -2.2138662338256836, -2.156153440475464, -2.5677433013916016, -2.639634370803833, -3.154132843017578, -1.7948943376541138, -3.028573751449585, -1.5785914659500122, -2.8402371406555176, -1.8996134996414185, -0.6797490119934082, -1.3150312900543213, -0.47944018244743347, -1.8112086057662964, -0.9645589590072632, -0.41171470284461975, -0.6729006171226501, -0.39955252408981323, -0.7940170168876648, 1.5373587608337402, -2.2835047245025635, -0.26089829206466675, -1.241329312324524, -0.011247940361499786, -0.2184402346611023, -0.15089036524295807, 2.5887703895568848, 0.3110041618347168, -0.6544909477233887, 0.8014161586761475, -1.588698148727417, -1.1696103811264038, -0.5369929075241089, -1.359910488128662, -1.0752894878387451, -0.023616060614585876, 0.5241272449493408, -0.5390818119049072, -0.15920782089233398, -1.2556260824203491, 0.10895043611526489, -0.7213354110717773, -0.9482869505882263, -0.4823080599308014, -0.9139502048492432, 0.5674079656600952, -0.9065103530883789, -1.052746057510376, -1.2129714488983154, -1.5571104288101196, -0.3358563184738159, -5.074620246887207, 0.0, 0.0, -0.0, -16.355609893798828, -13.747337341308594, -12.695016860961914, -12.01173210144043, -11.976179122924805, -11.483832359313965, -10.334505081176758, -9.61029052734375, -8.281295776367188, -9.180792808532715, -7.864101409912109, -7.9538397789001465, -6.229466915130615, -6.674722671508789, -5.749129295349121, -5.764064311981201, -4.7270379066467285, -4.13429069519043, -4.710429668426514, -3.6758010387420654, -4.146903991699219, -3.987639904022217, -3.792862892150879, -2.2138662338256836, -2.156153440475464, -2.5677433013916016, -2.639634370803833, -3.154132843017578, -1.7948943376541138, -3.028573751449585, -1.5785914659500122, -2.8402371406555176, -1.8996134996414185, -0.6797490119934082, -1.3150312900543213, -0.47944018244743347, -1.8112086057662964, -0.9645589590072632, -0.41171470284461975, -0.6729006171226501, -0.39955252408981323, -0.7940170168876648, 1.5373587608337402, -2.2835047245025635, -0.26089829206466675, -1.241329312324524, -0.011247940361499786, -0.2184402346611023, -0.15089036524295807, 2.5887703895568848, 0.3110041618347168, -0.6544909477233887, 0.8014161586761475, -1.588698148727417, -1.1696103811264038, -0.5369929075241089, -1.359910488128662, -1.0752894878387451, -0.023616060614585876, 0.5241272449493408, -0.5390818119049072, -0.15920782089233398, -1.2556260824203491, 0.10895043611526489, -0.7213354110717773, -0.9482869505882263, -0.4823080599308014, -0.9139502048492432, 0.5674079656600952, -0.9065103530883789, -1.052746057510376, -1.2129714488983154, -1.5571104288101196, -0.3358563184738159, -5.074620246887207, -0.0, -0.0], [0.0, -13.634842872619629, -13.874897956848145, -12.636122703552246, -11.38238525390625, -11.330500602722168, -10.728373527526855, -10.501839637756348, -9.760305404663086, -10.589214324951172, -8.500614166259766, -8.83446216583252, -7.552007675170898, -7.6171650886535645, -7.697798728942871, -6.350751876831055, -5.9497809410095215, -5.781403541564941, -4.875090599060059, -4.783616065979004, -4.330018997192383, -3.17571759223938, -4.163681507110596, -3.500155210494995, -2.4943082332611084, -5.041472911834717, -2.704555034637451, -2.3320608139038086, -1.7587846517562866, -2.746293783187866, -1.777716040611267, -2.264427423477173, -2.624175548553467, -2.6513118743896484, -2.335089921951294, -3.529254674911499, -3.181182861328125, -2.1808431148529053, -1.0925700664520264, -1.296798825263977, -1.5998965501785278, -0.9858357310295105, -0.19784283638000488, -1.7992581129074097, -1.7002230882644653, -0.6167886853218079, -1.002806544303894, -2.19437575340271, -1.0782451629638672, 0.17592103779315948, -1.313881278038025, -0.2351023256778717, -0.17676717042922974, 0.3308869004249573, 0.59274822473526, 0.14088371396064758, 0.11754269897937775, -0.3418610692024231, -0.8269425630569458, -0.17147797346115112, -0.6173199415206909, -0.5186739563941956, 0.529995322227478, -0.5996403098106384, -0.3660632073879242, -1.9096981287002563, -0.9784632921218872, -2.433483123779297, -1.336288332939148, -1.8499406576156616, -1.1780047416687012, -2.249209403991699, -1.3066155910491943, -1.7761812210083008, -2.1261606216430664, -3.603644847869873, -1.9520416259765625, 0.0, -0.0, -13.634842872619629, -13.874897956848145, -12.636122703552246, -11.38238525390625, -11.330500602722168, -10.728373527526855, -10.501839637756348, -9.760305404663086, -10.589214324951172, -8.500614166259766, -8.83446216583252, -7.552007675170898, -7.6171650886535645, -7.697798728942871, -6.350751876831055, -5.9497809410095215, -5.781403541564941, -4.875090599060059, -4.783616065979004, -4.330018997192383, -3.17571759223938, -4.163681507110596, -3.500155210494995, -2.4943082332611084, -5.041472911834717, -2.704555034637451, -2.3320608139038086, -1.7587846517562866, -2.746293783187866, -1.777716040611267, -2.264427423477173, -2.624175548553467, -2.6513118743896484, -2.335089921951294, -3.529254674911499, -3.181182861328125, -2.1808431148529053, -1.0925700664520264, -1.296798825263977, -1.5998965501785278, -0.9858357310295105, -0.19784283638000488, -1.7992581129074097, -1.7002230882644653, -0.6167886853218079, -1.002806544303894, -2.19437575340271, -1.0782451629638672, 0.17592103779315948, -1.313881278038025, -0.2351023256778717, -0.17676717042922974, 0.3308869004249573, 0.59274822473526, 0.14088371396064758, 0.11754269897937775, -0.3418610692024231, -0.8269425630569458, -0.17147797346115112, -0.6173199415206909, -0.5186739563941956, 0.529995322227478, -0.5996403098106384, -0.3660632073879242, -1.9096981287002563, -0.9784632921218872, -2.433483123779297, -1.336288332939148, -1.8499406576156616, -1.1780047416687012, -2.249209403991699, -1.3066155910491943, -1.7761812210083008, -2.1261606216430664, -3.603644847869873, -1.9520416259765625, -0.0], [0.0, -15.761527061462402, -13.721333503723145, -13.747121810913086, -12.40719985961914, -11.32931137084961, -11.233772277832031, -10.96654987335205, -10.604753494262695, -10.48692798614502, -8.67463493347168, -8.716143608093262, -7.708743572235107, -8.109535217285156, -7.747742176055908, -6.327476501464844, -5.769465923309326, -5.888984203338623, -5.488931179046631, -5.159583568572998, -4.44564962387085, -3.6009740829467773, -4.404715061187744, -3.2036101818084717, -1.6861982345581055, -3.630410671234131, -3.2948758602142334, -2.375410556793213, -2.487388849258423, -2.6961874961853027, -2.934234619140625, -2.9303576946258545, -0.7073392271995544, -2.1800761222839355, -2.5291261672973633, -2.1580517292022705, -1.7975484132766724, -2.4205994606018066, -2.247138738632202, -2.109424114227295, -2.07814621925354, -1.9117517471313477, -1.5086898803710938, -0.8276528120040894, -1.237657904624939, -2.1159658432006836, -1.8129726648330688, -2.3805768489837646, 0.04955577850341797, -2.518134832382202, -0.6439207792282104, 0.6787415742874146, 1.1634459495544434, -0.4874612092971802, -1.1811141967773438, -0.6825523376464844, -0.3684324324131012, 0.3377886414527893, 0.2220844328403473, -0.9242100715637207, -1.1171345710754395, -0.8607244491577148, -0.9360457062721252, -0.6690118312835693, 0.041863277554512024, -1.000281572341919, -0.8354770541191101, -2.912374258041382, -1.1491855382919312, -1.3052103519439697, -1.5917751789093018, -1.3337849378585815, -2.8246095180511475, -1.9496843814849854, -2.891547203063965, -2.7565746307373047, -5.410232067108154, 0.0, -0.0, -15.761527061462402, -13.721333503723145, -13.747121810913086, -12.40719985961914, -11.32931137084961, -11.233772277832031, -10.96654987335205, -10.604753494262695, -10.48692798614502, -8.67463493347168, -8.716143608093262, -7.708743572235107, -8.109535217285156, -7.747742176055908, -6.327476501464844, -5.769465923309326, -5.888984203338623, -5.488931179046631, -5.159583568572998, -4.44564962387085, -3.6009740829467773, -4.404715061187744, -3.2036101818084717, -1.6861982345581055, -3.630410671234131, -3.2948758602142334, -2.375410556793213, -2.487388849258423, -2.6961874961853027, -2.934234619140625, -2.9303576946258545, -0.7073392271995544, -2.1800761222839355, -2.5291261672973633, -2.1580517292022705, -1.7975484132766724, -2.4205994606018066, -2.247138738632202, -2.109424114227295, -2.07814621925354, -1.9117517471313477, -1.5086898803710938, -0.8276528120040894, -1.237657904624939, -2.1159658432006836, -1.8129726648330688, -2.3805768489837646, 0.04955577850341797, -2.518134832382202, -0.6439207792282104, 0.6787415742874146, 1.1634459495544434, -0.4874612092971802, -1.1811141967773438, -0.6825523376464844, -0.3684324324131012, 0.3377886414527893, 0.2220844328403473, -0.9242100715637207, -1.1171345710754395, -0.8607244491577148, -0.9360457062721252, -0.6690118312835693, 0.041863277554512024, -1.000281572341919, -0.8354770541191101, -2.912374258041382, -1.1491855382919312, -1.3052103519439697, -1.5917751789093018, -1.3337849378585815, -2.8246095180511475, -1.9496843814849854, -2.891547203063965, -2.7565746307373047, -5.410232067108154, -0.0], [0.0, -13.298293113708496, -13.784645080566406, -13.064289093017578, -12.164056777954102, -12.072129249572754, -10.861413955688477, -10.542922019958496, -10.219106674194336, -9.065967559814453, -9.991507530212402, -8.313800811767578, -8.575521469116211, -8.039634704589844, -7.20388650894165, -6.725714683532715, -6.528202056884766, -5.703640460968018, -5.773746967315674, -4.7151780128479, -4.164777755737305, -4.790241718292236, -4.814623832702637, -1.2383228540420532, -3.8856759071350098, -2.1533877849578857, -3.3295443058013916, -3.1107192039489746, -3.101832151412964, -3.184446334838867, -1.3093105554580688, -2.8325157165527344, -2.6254773139953613, -3.858252763748169, -2.6407012939453125, -2.3610920906066895, -1.8546639680862427, -2.802324056625366, -2.8219964504241943, -3.0416204929351807, -3.3164868354797363, -2.344696283340454, -2.18171763420105, -2.396608829498291, -2.050675392150879, -1.610343098640442, -1.7172375917434692, -1.3676872253417969, -0.6988182663917542, -0.43103086948394775, -0.6695635318756104, -1.4139951467514038, 1.1619064807891846, -1.1243305206298828, -1.0205134153366089, 0.12201010435819626, -0.4074186682701111, -0.3953694999217987, -0.8025871515274048, -0.7742139101028442, -0.08591242134571075, -0.7309866547584534, -0.38733023405075073, -0.2888544499874115, -0.40332967042922974, -1.2419953346252441, -2.223090887069702, -0.4202403426170349, -0.3518316447734833, -1.3923014402389526, -1.5063802003860474, -1.5190210342407227, -1.9964113235473633, -1.9379268884658813, -1.5529773235321045, -3.042213201522827, -3.4631059169769287, 0.0, -0.0, -13.298293113708496, -13.784645080566406, -13.064289093017578, -12.164056777954102, -12.072129249572754, -10.861413955688477, -10.542922019958496, -10.219106674194336, -9.065967559814453, -9.991507530212402, -8.313800811767578, -8.575521469116211, -8.039634704589844, -7.20388650894165, -6.725714683532715, -6.528202056884766, -5.703640460968018, -5.773746967315674, -4.7151780128479, -4.164777755737305, -4.790241718292236, -4.814623832702637, -1.2383228540420532, -3.8856759071350098, -2.1533877849578857, -3.3295443058013916, -3.1107192039489746, -3.101832151412964, -3.184446334838867, -1.3093105554580688, -2.8325157165527344, -2.6254773139953613, -3.858252763748169, -2.6407012939453125, -2.3610920906066895, -1.8546639680862427, -2.802324056625366, -2.8219964504241943, -3.0416204929351807, -3.3164868354797363, -2.344696283340454, -2.18171763420105, -2.396608829498291, -2.050675392150879, -1.610343098640442, -1.7172375917434692, -1.3676872253417969, -0.6988182663917542, -0.43103086948394775, -0.6695635318756104, -1.4139951467514038, 1.1619064807891846, -1.1243305206298828, -1.0205134153366089, 0.12201010435819626, -0.4074186682701111, -0.3953694999217987, -0.8025871515274048, -0.7742139101028442, -0.08591242134571075, -0.7309866547584534, -0.38733023405075073, -0.2888544499874115, -0.40332967042922974, -1.2419953346252441, -2.223090887069702, -0.4202403426170349, -0.3518316447734833, -1.3923014402389526, -1.5063802003860474, -1.5190210342407227, -1.9964113235473633, -1.9379268884658813, -1.5529773235321045, -3.042213201522827, -3.4631059169769287, -0.0], [0.0, 0.0, -14.153395652770996, -13.588159561157227, -12.590845108032227, -11.768301963806152, -11.94157886505127, -11.113516807556152, -10.665796279907227, -9.920260429382324, -10.101404190063477, -10.227842330932617, -8.329815864562988, -7.673168659210205, -7.164046764373779, -7.049796104431152, -6.936500072479248, -5.816702842712402, -5.624948024749756, -5.227816581726074, -4.3586883544921875, -3.918761968612671, -5.078762531280518, -3.884345531463623, -3.7166380882263184, -4.5935516357421875, -2.91363525390625, -2.871540069580078, -3.429826259613037, -1.459625244140625, -2.285050630569458, -2.5764825344085693, -2.030337333679199, -3.5934317111968994, -3.194615602493286, -3.2248215675354004, -3.184727907180786, -2.892230272293091, -3.006791353225708, -3.131063222885132, -2.640976905822754, -2.7279512882232666, -2.8652257919311523, -1.6652007102966309, -2.3418402671813965, -3.7257490158081055, -1.8459594249725342, -0.927931547164917, -2.4437108039855957, -1.6577492952346802, -1.0237536430358887, -0.417033314704895, 0.7337321639060974, -3.748234987258911, -0.8107758164405823, -0.3264523148536682, 1.5666230916976929, -0.8889137506484985, -0.43823879957199097, -0.5551778078079224, -0.6775675415992737, -0.23258686065673828, -0.4922652244567871, 0.6912699937820435, -0.28618109226226807, -1.1900635957717896, -0.8156294822692871, 0.5537899732589722, -1.6695984601974487, -1.3929333686828613, -1.4074630737304688, -1.1340739727020264, -2.52341365814209, -2.0849251747131348, -2.0721330642700195, -4.287958145141602, -4.257962226867676, 0.0, -0.0, -0.0, -14.153395652770996, -13.588159561157227, -12.590845108032227, -11.768301963806152, -11.94157886505127, -11.113516807556152, -10.665796279907227, -9.920260429382324, -10.101404190063477, -10.227842330932617, -8.329815864562988, -7.673168659210205, -7.164046764373779, -7.049796104431152, -6.936500072479248, -5.816702842712402, -5.624948024749756, -5.227816581726074, -4.3586883544921875, -3.918761968612671, -5.078762531280518, -3.884345531463623, -3.7166380882263184, -4.5935516357421875, -2.91363525390625, -2.871540069580078, -3.429826259613037, -1.459625244140625, -2.285050630569458, -2.5764825344085693, -2.030337333679199, -3.5934317111968994, -3.194615602493286, -3.2248215675354004, -3.184727907180786, -2.892230272293091, -3.006791353225708, -3.131063222885132, -2.640976905822754, -2.7279512882232666, -2.8652257919311523, -1.6652007102966309, -2.3418402671813965, -3.7257490158081055, -1.8459594249725342, -0.927931547164917, -2.4437108039855957, -1.6577492952346802, -1.0237536430358887, -0.417033314704895, 0.7337321639060974, -3.748234987258911, -0.8107758164405823, -0.3264523148536682, 1.5666230916976929, -0.8889137506484985, -0.43823879957199097, -0.5551778078079224, -0.6775675415992737, -0.23258686065673828, -0.4922652244567871, 0.6912699937820435, -0.28618109226226807, -1.1900635957717896, -0.8156294822692871, 0.5537899732589722, -1.6695984601974487, -1.3929333686828613, -1.4074630737304688, -1.1340739727020264, -2.52341365814209, -2.0849251747131348, -2.0721330642700195, -4.287958145141602, -4.257962226867676, -0.0], [0.0, 0.0, -13.857038497924805, -13.584308624267578, -12.742870330810547, -12.364385604858398, -11.440520286560059, -11.00326156616211, -10.578187942504883, -9.182758331298828, -8.222495079040527, -8.49498462677002, -8.684927940368652, -7.61807107925415, -6.5922698974609375, -6.405733585357666, -6.827949047088623, -6.326333999633789, -5.688014507293701, -5.235637187957764, -5.05059289932251, -4.0443854331970215, -4.193240642547607, -5.3833537101745605, -2.3811705112457275, -5.422827243804932, -3.59773588180542, -2.3734917640686035, -3.907055616378784, -2.0069704055786133, -2.8220999240875244, -2.6674532890319824, -3.3243584632873535, -2.829010009765625, -3.6487185955047607, -2.9117367267608643, -3.4295055866241455, -3.58906888961792, -2.9965062141418457, -3.750166893005371, -2.6744542121887207, -3.4437525272369385, -4.072912693023682, -2.332901954650879, -3.396045446395874, -1.7423558235168457, -3.583430767059326, -2.5852596759796143, -2.393723964691162, -1.5023813247680664, -1.4369288682937622, -0.274827241897583, -0.9439073204994202, -1.1631131172180176, -0.9194597601890564, -0.6968419551849365, -1.5332763195037842, -1.457568645477295, -0.45471733808517456, 0.527172327041626, -0.7181142568588257, -0.6015892624855042, -1.3854378461837769, -0.22636228799819946, -0.8514706492424011, -0.9821885228157043, -0.7074772715568542, -1.5300509929656982, -0.862281084060669, -1.2552592754364014, -2.0325286388397217, -2.9974918365478516, -2.006718635559082, -1.4942210912704468, -1.6188244819641113, -1.4338079690933228, -2.2799665927886963, 0.0, -0.0, -0.0, -13.857038497924805, -13.584308624267578, -12.742870330810547, -12.364385604858398, -11.440520286560059, -11.00326156616211, -10.578187942504883, -9.182758331298828, -8.222495079040527, -8.49498462677002, -8.684927940368652, -7.61807107925415, -6.5922698974609375, -6.405733585357666, -6.827949047088623, -6.326333999633789, -5.688014507293701, -5.235637187957764, -5.05059289932251, -4.0443854331970215, -4.193240642547607, -5.3833537101745605, -2.3811705112457275, -5.422827243804932, -3.59773588180542, -2.3734917640686035, -3.907055616378784, -2.0069704055786133, -2.8220999240875244, -2.6674532890319824, -3.3243584632873535, -2.829010009765625, -3.6487185955047607, -2.9117367267608643, -3.4295055866241455, -3.58906888961792, -2.9965062141418457, -3.750166893005371, -2.6744542121887207, -3.4437525272369385, -4.072912693023682, -2.332901954650879, -3.396045446395874, -1.7423558235168457, -3.583430767059326, -2.5852596759796143, -2.393723964691162, -1.5023813247680664, -1.4369288682937622, -0.274827241897583, -0.9439073204994202, -1.1631131172180176, -0.9194597601890564, -0.6968419551849365, -1.5332763195037842, -1.457568645477295, -0.45471733808517456, 0.527172327041626, -0.7181142568588257, -0.6015892624855042, -1.3854378461837769, -0.22636228799819946, -0.8514706492424011, -0.9821885228157043, -0.7074772715568542, -1.5300509929656982, -0.862281084060669, -1.2552592754364014, -2.0325286388397217, -2.9974918365478516, -2.006718635559082, -1.4942210912704468, -1.6188244819641113, -1.4338079690933228, -2.2799665927886963, -0.0], [0.0, 0.0, -16.27840805053711, -12.871597290039062, -13.044683456420898, -12.668863296508789, -11.251734733581543, -10.788385391235352, -10.340115547180176, -10.309359550476074, -9.388733863830566, -8.687463760375977, -8.37477970123291, -10.624776840209961, -7.21339750289917, -6.7829084396362305, -6.468572616577148, -6.148983955383301, -5.9219512939453125, -6.356268405914307, -4.896615505218506, -3.131209135055542, -6.4325714111328125, -4.629902362823486, -3.783574104309082, -5.519670009613037, -4.61714506149292, -3.4383058547973633, -3.9171664714813232, -5.2783732414245605, -3.3055260181427, -3.867611885070801, -3.782580614089966, -4.180948734283447, -5.084934711456299, -3.9426984786987305, -4.353510856628418, -4.608559608459473, -4.851917743682861, -5.122779369354248, -4.247834205627441, -4.83656644821167, -3.6283371448516846, -3.3483269214630127, -3.642603874206543, -2.1696887016296387, -3.811497926712036, -3.048516273498535, -2.1760506629943848, -1.9921125173568726, -1.8166638612747192, -0.8999536037445068, -0.9250211715698242, 0.46276018023490906, -1.3585879802703857, 0.1345052570104599, -2.839787721633911, -0.7853200435638428, 0.2735683023929596, -0.20019228756427765, -0.3758145272731781, -1.390390157699585, -1.1449434757232666, -0.9679931402206421, -0.2781776487827301, -0.7535530924797058, -1.221005916595459, -1.125347375869751, -1.0082913637161255, -1.6234021186828613, -2.0140223503112793, -1.4051568508148193, -2.5576462745666504, -1.7715563774108887, -2.62593674659729, -2.3246850967407227, 0.0, 0.0, -0.0, -0.0, -16.27840805053711, -12.871597290039062, -13.044683456420898, -12.668863296508789, -11.251734733581543, -10.788385391235352, -10.340115547180176, -10.309359550476074, -9.388733863830566, -8.687463760375977, -8.37477970123291, -10.624776840209961, -7.21339750289917, -6.7829084396362305, -6.468572616577148, -6.148983955383301, -5.9219512939453125, -6.356268405914307, -4.896615505218506, -3.131209135055542, -6.4325714111328125, -4.629902362823486, -3.783574104309082, -5.519670009613037, -4.61714506149292, -3.4383058547973633, -3.9171664714813232, -5.2783732414245605, -3.3055260181427, -3.867611885070801, -3.782580614089966, -4.180948734283447, -5.084934711456299, -3.9426984786987305, -4.353510856628418, -4.608559608459473, -4.851917743682861, -5.122779369354248, -4.247834205627441, -4.83656644821167, -3.6283371448516846, -3.3483269214630127, -3.642603874206543, -2.1696887016296387, -3.811497926712036, -3.048516273498535, -2.1760506629943848, -1.9921125173568726, -1.8166638612747192, -0.8999536037445068, -0.9250211715698242, 0.46276018023490906, -1.3585879802703857, 0.1345052570104599, -2.839787721633911, -0.7853200435638428, 0.2735683023929596, -0.20019228756427765, -0.3758145272731781, -1.390390157699585, -1.1449434757232666, -0.9679931402206421, -0.2781776487827301, -0.7535530924797058, -1.221005916595459, -1.125347375869751, -1.0082913637161255, -1.6234021186828613, -2.0140223503112793, -1.4051568508148193, -2.5576462745666504, -1.7715563774108887, -2.62593674659729, -2.3246850967407227, -0.0, -0.0], [0.0, 0.0, -16.11495018005371, -16.62653350830078, -14.454346656799316, -12.426200866699219, -11.765470504760742, -11.155352592468262, -10.334335327148438, -9.512181282043457, -8.4728364944458, -8.64858341217041, -7.942030906677246, -7.732630252838135, -7.6239423751831055, -6.324156284332275, -7.1420488357543945, -6.503865718841553, -6.284562587738037, -5.306981563568115, -5.00577449798584, -4.1427998542785645, -4.45658540725708, -4.784897327423096, -4.886622428894043, -4.434231758117676, -4.097560882568359, -5.417515277862549, -4.830665111541748, -4.432700157165527, -4.749417781829834, -5.125672817230225, -5.009016990661621, -5.567043304443359, -2.22002911567688, -6.082637310028076, -5.73190975189209, -4.774828910827637, -5.219485759735107, -5.750686168670654, -6.9508233070373535, -5.815971374511719, -4.1219353675842285, -6.3415727615356445, -3.305159091949463, -3.012924909591675, -4.9151930809021, -3.382890224456787, -2.643369674682617, -2.957886219024658, -2.819845676422119, -2.796422004699707, -2.4068117141723633, -2.1124796867370605, -1.2104636430740356, -1.0545014142990112, -1.3381593227386475, -1.399406909942627, -1.802020788192749, -0.9641630053520203, 0.24220921099185944, -0.44026073813438416, -0.9500784873962402, -3.6748263835906982, -0.6640525460243225, -0.9415860176086426, -0.6956138610839844, -0.6700852513313293, -2.702890634536743, -1.513054370880127, -1.540325403213501, -2.3680689334869385, -2.7996764183044434, -2.920976161956787, -2.689152240753174, -2.566793918609619, 0.0, 0.0, -0.0, -0.0, -16.11495018005371, -16.62653350830078, -14.454346656799316, -12.426200866699219, -11.765470504760742, -11.155352592468262, -10.334335327148438, -9.512181282043457, -8.4728364944458, -8.64858341217041, -7.942030906677246, -7.732630252838135, -7.6239423751831055, -6.324156284332275, -7.1420488357543945, -6.503865718841553, -6.284562587738037, -5.306981563568115, -5.00577449798584, -4.1427998542785645, -4.45658540725708, -4.784897327423096, -4.886622428894043, -4.434231758117676, -4.097560882568359, -5.417515277862549, -4.830665111541748, -4.432700157165527, -4.749417781829834, -5.125672817230225, -5.009016990661621, -5.567043304443359, -2.22002911567688, -6.082637310028076, -5.73190975189209, -4.774828910827637, -5.219485759735107, -5.750686168670654, -6.9508233070373535, -5.815971374511719, -4.1219353675842285, -6.3415727615356445, -3.305159091949463, -3.012924909591675, -4.9151930809021, -3.382890224456787, -2.643369674682617, -2.957886219024658, -2.819845676422119, -2.796422004699707, -2.4068117141723633, -2.1124796867370605, -1.2104636430740356, -1.0545014142990112, -1.3381593227386475, -1.399406909942627, -1.802020788192749, -0.9641630053520203, 0.24220921099185944, -0.44026073813438416, -0.9500784873962402, -3.6748263835906982, -0.6640525460243225, -0.9415860176086426, -0.6956138610839844, -0.6700852513313293, -2.702890634536743, -1.513054370880127, -1.540325403213501, -2.3680689334869385, -2.7996764183044434, -2.920976161956787, -2.689152240753174, -2.566793918609619, -0.0, -0.0], [0.0, 0.0, -15.475395202636719, -15.788495063781738, -13.002035140991211, -12.626708984375, -12.15356159210205, -10.177613258361816, -10.240315437316895, -10.234564781188965, -9.999369621276855, -9.37509822845459, -8.095274925231934, -7.497943878173828, -7.1972551345825195, -7.186100959777832, -7.28801155090332, -6.453225612640381, -7.141443252563477, -5.630224227905273, -6.051596164703369, -4.244450569152832, -5.281502723693848, -5.62248420715332, -4.911019325256348, -5.688567161560059, -3.894109010696411, -5.7518744468688965, -5.185086250305176, -5.813305377960205, -3.063371419906616, -3.3589048385620117, -4.0902791023254395, -6.621174335479736, -5.505384922027588, -5.994071960449219, -5.819118976593018, -6.570411205291748, -6.936631679534912, -5.828861236572266, -5.837551116943359, -6.035828590393066, -5.557216167449951, -6.030176162719727, -5.000777721405029, -5.185189247131348, -3.3005380630493164, -3.5658679008483887, -4.371754169464111, -5.348591327667236, -2.0135762691497803, -4.029781818389893, -2.4882264137268066, -2.7383108139038086, -1.6639420986175537, -1.5820693969726562, -0.4193776845932007, -0.9951508641242981, -1.3662668466567993, -0.30986520648002625, -1.3700007200241089, -1.2390809059143066, -1.5173455476760864, -0.9819456934928894, -0.5143698453903198, -0.3505174219608307, -1.4796552658081055, -1.2270787954330444, -1.2783832550048828, -1.6635886430740356, -2.2144341468811035, -2.5121073722839355, -2.459855556488037, -2.8428802490234375, -2.362795114517212, -4.341470718383789, 0.0, 0.0, -0.0, -0.0, -15.475395202636719, -15.788495063781738, -13.002035140991211, -12.626708984375, -12.15356159210205, -10.177613258361816, -10.240315437316895, -10.234564781188965, -9.999369621276855, -9.37509822845459, -8.095274925231934, -7.497943878173828, -7.1972551345825195, -7.186100959777832, -7.28801155090332, -6.453225612640381, -7.141443252563477, -5.630224227905273, -6.051596164703369, -4.244450569152832, -5.281502723693848, -5.62248420715332, -4.911019325256348, -5.688567161560059, -3.894109010696411, -5.7518744468688965, -5.185086250305176, -5.813305377960205, -3.063371419906616, -3.3589048385620117, -4.0902791023254395, -6.621174335479736, -5.505384922027588, -5.994071960449219, -5.819118976593018, -6.570411205291748, -6.936631679534912, -5.828861236572266, -5.837551116943359, -6.035828590393066, -5.557216167449951, -6.030176162719727, -5.000777721405029, -5.185189247131348, -3.3005380630493164, -3.5658679008483887, -4.371754169464111, -5.348591327667236, -2.0135762691497803, -4.029781818389893, -2.4882264137268066, -2.7383108139038086, -1.6639420986175537, -1.5820693969726562, -0.4193776845932007, -0.9951508641242981, -1.3662668466567993, -0.30986520648002625, -1.3700007200241089, -1.2390809059143066, -1.5173455476760864, -0.9819456934928894, -0.5143698453903198, -0.3505174219608307, -1.4796552658081055, -1.2270787954330444, -1.2783832550048828, -1.6635886430740356, -2.2144341468811035, -2.5121073722839355, -2.459855556488037, -2.8428802490234375, -2.362795114517212, -4.341470718383789, -0.0, -0.0], [0.0, 0.0, -13.371076583862305, -15.437833786010742, -13.766400337219238, -12.279336929321289, -12.487905502319336, -10.779961585998535, -10.53039836883545, -10.492243766784668, -9.953640937805176, -8.972153663635254, -8.309009552001953, -7.990537643432617, -7.553283214569092, -7.22066068649292, -6.925294399261475, -6.993047714233398, -5.939161777496338, -6.803213596343994, -5.01719856262207, -4.135429859161377, -5.436732769012451, -5.943148136138916, -5.16350793838501, -6.342820644378662, -5.403602123260498, -5.3818864822387695, -5.070862770080566, -3.76067852973938, -5.996000289916992, -5.469380855560303, -6.930958271026611, -6.489738464355469, -7.33847713470459, -6.467950820922852, -7.419900417327881, -6.332889080047607, -6.842744827270508, -6.663834095001221, -6.2579193115234375, -7.757071018218994, -7.559548377990723, -7.085860729217529, -5.33349084854126, -7.108191013336182, -5.5644659996032715, -5.128303050994873, -5.805333137512207, -2.832188129425049, -3.116926670074463, -4.196204662322998, -2.4125874042510986, -2.705069065093994, -3.4903922080993652, -2.079026699066162, -1.5766749382019043, -0.9566040635108948, -2.0062007904052734, -1.883434534072876, -1.23624849319458, -1.2687065601348877, -1.758871078491211, -0.8963389992713928, -1.4368712902069092, -1.474126935005188, -1.192489743232727, -1.6999801397323608, -1.357161045074463, -1.6152739524841309, -2.395754814147949, -2.425750970840454, -2.6653990745544434, -2.50616455078125, -3.3669607639312744, -4.187380790710449, 0.0, 0.0, -0.0, -0.0, -13.371076583862305, -15.437833786010742, -13.766400337219238, -12.279336929321289, -12.487905502319336, -10.779961585998535, -10.53039836883545, -10.492243766784668, -9.953640937805176, -8.972153663635254, -8.309009552001953, -7.990537643432617, -7.553283214569092, -7.22066068649292, -6.925294399261475, -6.993047714233398, -5.939161777496338, -6.803213596343994, -5.01719856262207, -4.135429859161377, -5.436732769012451, -5.943148136138916, -5.16350793838501, -6.342820644378662, -5.403602123260498, -5.3818864822387695, -5.070862770080566, -3.76067852973938, -5.996000289916992, -5.469380855560303, -6.930958271026611, -6.489738464355469, -7.33847713470459, -6.467950820922852, -7.419900417327881, -6.332889080047607, -6.842744827270508, -6.663834095001221, -6.2579193115234375, -7.757071018218994, -7.559548377990723, -7.085860729217529, -5.33349084854126, -7.108191013336182, -5.5644659996032715, -5.128303050994873, -5.805333137512207, -2.832188129425049, -3.116926670074463, -4.196204662322998, -2.4125874042510986, -2.705069065093994, -3.4903922080993652, -2.079026699066162, -1.5766749382019043, -0.9566040635108948, -2.0062007904052734, -1.883434534072876, -1.23624849319458, -1.2687065601348877, -1.758871078491211, -0.8963389992713928, -1.4368712902069092, -1.474126935005188, -1.192489743232727, -1.6999801397323608, -1.357161045074463, -1.6152739524841309, -2.395754814147949, -2.425750970840454, -2.6653990745544434, -2.50616455078125, -3.3669607639312744, -4.187380790710449, -0.0, -0.0], [0.0, 0.0, 0.0, -14.298624038696289, -13.731950759887695, -12.337967872619629, -11.836771965026855, -11.56066608428955, -9.886544227600098, -10.614490509033203, -9.929764747619629, -9.20394515991211, -9.812784194946289, -7.489834308624268, -7.893588542938232, -7.099474906921387, -7.281493186950684, -5.7876739501953125, -5.7308149337768555, -6.156589984893799, -4.920413494110107, -6.714941024780273, -7.085896015167236, -5.097021102905273, -5.585608959197998, -6.149837493896484, -6.084028244018555, -5.593285083770752, -5.9711995124816895, -6.665430068969727, -4.433351516723633, -6.41314697265625, -5.825394630432129, -6.946520805358887, -10.163741111755371, -8.129288673400879, -7.780677318572998, -8.403822898864746, -9.07603645324707, -8.39016056060791, -7.69692325592041, -7.501311779022217, -7.759724140167236, -7.057124614715576, -5.205780029296875, -6.380771160125732, -7.592749118804932, -4.832565784454346, -7.858895301818848, -6.528906345367432, -3.1421308517456055, -4.194405555725098, -3.920868396759033, -2.6658987998962402, -2.9185447692871094, -3.091170310974121, -2.363508939743042, -1.3226827383041382, -1.9615637063980103, -1.3453967571258545, -2.0294365882873535, -1.6048439741134644, -1.4087224006652832, -1.3505336046218872, -1.3001974821090698, -1.2222357988357544, -1.0757789611816406, -1.3096811771392822, -1.8308683633804321, -2.0610218048095703, -2.41279673576355, -2.7810258865356445, -3.0946643352508545, -3.4041378498077393, -5.876386642456055, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -14.298624038696289, -13.731950759887695, -12.337967872619629, -11.836771965026855, -11.56066608428955, -9.886544227600098, -10.614490509033203, -9.929764747619629, -9.20394515991211, -9.812784194946289, -7.489834308624268, -7.893588542938232, -7.099474906921387, -7.281493186950684, -5.7876739501953125, -5.7308149337768555, -6.156589984893799, -4.920413494110107, -6.714941024780273, -7.085896015167236, -5.097021102905273, -5.585608959197998, -6.149837493896484, -6.084028244018555, -5.593285083770752, -5.9711995124816895, -6.665430068969727, -4.433351516723633, -6.41314697265625, -5.825394630432129, -6.946520805358887, -10.163741111755371, -8.129288673400879, -7.780677318572998, -8.403822898864746, -9.07603645324707, -8.39016056060791, -7.69692325592041, -7.501311779022217, -7.759724140167236, -7.057124614715576, -5.205780029296875, -6.380771160125732, -7.592749118804932, -4.832565784454346, -7.858895301818848, -6.528906345367432, -3.1421308517456055, -4.194405555725098, -3.920868396759033, -2.6658987998962402, -2.9185447692871094, -3.091170310974121, -2.363508939743042, -1.3226827383041382, -1.9615637063980103, -1.3453967571258545, -2.0294365882873535, -1.6048439741134644, -1.4087224006652832, -1.3505336046218872, -1.3001974821090698, -1.2222357988357544, -1.0757789611816406, -1.3096811771392822, -1.8308683633804321, -2.0610218048095703, -2.41279673576355, -2.7810258865356445, -3.0946643352508545, -3.4041378498077393, -5.876386642456055, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, -14.65716552734375, -13.409883499145508, -12.908373832702637, -12.10499095916748, -11.0685396194458, -10.466840744018555, -10.557107925415039, -8.175259590148926, -9.436460494995117, -7.638595104217529, -7.931583881378174, -7.747890472412109, -7.46233606338501, -7.362406253814697, -6.8952412605285645, -6.827524185180664, -6.8653483390808105, -6.309691429138184, -6.489971160888672, -7.46860933303833, -6.0611748695373535, -7.019620418548584, -6.3293070793151855, -6.824563503265381, -6.1276164054870605, -7.22630500793457, -6.530369758605957, -7.443938255310059, -7.609547138214111, -7.948001861572266, -7.756309986114502, -9.675921440124512, -10.113265037536621, -10.535459518432617, -9.108528137207031, -9.818097114562988, -9.177661895751953, -9.797795295715332, -8.783942222595215, -8.837459564208984, -9.321317672729492, -8.674576759338379, -7.967540740966797, -7.024996757507324, -7.547885417938232, -7.325891494750977, -4.428369998931885, -6.126968860626221, -5.401983737945557, -3.915114402770996, -5.967577934265137, -3.9975104331970215, -3.308640718460083, -2.934351682662964, -2.8460869789123535, -1.9458361864089966, -1.6552307605743408, -1.5038872957229614, -2.156414747238159, -0.42999833822250366, -1.3114746809005737, -1.325408697128296, -1.7688153982162476, -1.886029601097107, -1.9092726707458496, -1.815575122833252, -3.366532802581787, -2.842909336090088, -1.6839195489883423, -3.4555680751800537, -4.321186542510986, -4.18570613861084, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -14.65716552734375, -13.409883499145508, -12.908373832702637, -12.10499095916748, -11.0685396194458, -10.466840744018555, -10.557107925415039, -8.175259590148926, -9.436460494995117, -7.638595104217529, -7.931583881378174, -7.747890472412109, -7.46233606338501, -7.362406253814697, -6.8952412605285645, -6.827524185180664, -6.8653483390808105, -6.309691429138184, -6.489971160888672, -7.46860933303833, -6.0611748695373535, -7.019620418548584, -6.3293070793151855, -6.824563503265381, -6.1276164054870605, -7.22630500793457, -6.530369758605957, -7.443938255310059, -7.609547138214111, -7.948001861572266, -7.756309986114502, -9.675921440124512, -10.113265037536621, -10.535459518432617, -9.108528137207031, -9.818097114562988, -9.177661895751953, -9.797795295715332, -8.783942222595215, -8.837459564208984, -9.321317672729492, -8.674576759338379, -7.967540740966797, -7.024996757507324, -7.547885417938232, -7.325891494750977, -4.428369998931885, -6.126968860626221, -5.401983737945557, -3.915114402770996, -5.967577934265137, -3.9975104331970215, -3.308640718460083, -2.934351682662964, -2.8460869789123535, -1.9458361864089966, -1.6552307605743408, -1.5038872957229614, -2.156414747238159, -0.42999833822250366, -1.3114746809005737, -1.325408697128296, -1.7688153982162476, -1.886029601097107, -1.9092726707458496, -1.815575122833252, -3.366532802581787, -2.842909336090088, -1.6839195489883423, -3.4555680751800537, -4.321186542510986, -4.18570613861084, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, -16.70891571044922, -14.413360595703125, -12.93032455444336, -12.48063850402832, -11.864401817321777, -10.947809219360352, -10.444720268249512, -10.031363487243652, -9.277644157409668, -9.109589576721191, -8.04798698425293, -8.786221504211426, -7.850198745727539, -7.051792621612549, -6.453502655029297, -6.096530437469482, -4.5404582023620605, -6.6673102378845215, -5.5285797119140625, -4.956704616546631, -5.5266852378845215, -6.988313674926758, -6.9043073654174805, -7.257235527038574, -7.617779731750488, -9.310599327087402, -5.6388139724731445, -7.595278739929199, -9.714067459106445, -8.916914939880371, -9.635127067565918, -7.723989963531494, -11.114044189453125, -10.066627502441406, -11.21209716796875, -10.28494930267334, -10.253510475158691, -10.25800895690918, -10.040932655334473, -9.845274925231934, -9.526025772094727, -9.17199993133545, -10.10135269165039, -8.353984832763672, -7.552994728088379, -10.826059341430664, -7.262378692626953, -6.657324314117432, -5.053040981292725, -6.47938871383667, -6.365275859832764, -4.180905818939209, -3.5074615478515625, -2.928816556930542, -4.259703159332275, -3.2796878814697266, -2.3253607749938965, -1.533423900604248, -1.3851536512374878, -1.7131695747375488, -2.09218692779541, -1.153585433959961, -1.4045212268829346, -1.4192875623703003, -1.629219651222229, -2.146343469619751, -2.184755325317383, -3.106219530105591, -3.1122710704803467, -3.690053701400757, -4.51891565322876, -6.564457416534424, 0.0, 0.0, -2.890331506729126, -0.0, -0.0, -0.0, -16.70891571044922, -14.413360595703125, -12.93032455444336, -12.48063850402832, -11.864401817321777, -10.947809219360352, -10.444720268249512, -10.031363487243652, -9.277644157409668, -9.109589576721191, -8.04798698425293, -8.786221504211426, -7.850198745727539, -7.051792621612549, -6.453502655029297, -6.096530437469482, -4.5404582023620605, -6.6673102378845215, -5.5285797119140625, -4.956704616546631, -5.5266852378845215, -6.988313674926758, -6.9043073654174805, -7.257235527038574, -7.617779731750488, -9.310599327087402, -5.6388139724731445, -7.595278739929199, -9.714067459106445, -8.916914939880371, -9.635127067565918, -7.723989963531494, -11.114044189453125, -10.066627502441406, -11.21209716796875, -10.28494930267334, -10.253510475158691, -10.25800895690918, -10.040932655334473, -9.845274925231934, -9.526025772094727, -9.17199993133545, -10.10135269165039, -8.353984832763672, -7.552994728088379, -10.826059341430664, -7.262378692626953, -6.657324314117432, -5.053040981292725, -6.47938871383667, -6.365275859832764, -4.180905818939209, -3.5074615478515625, -2.928816556930542, -4.259703159332275, -3.2796878814697266, -2.3253607749938965, -1.533423900604248, -1.3851536512374878, -1.7131695747375488, -2.09218692779541, -1.153585433959961, -1.4045212268829346, -1.4192875623703003, -1.629219651222229, -2.146343469619751, -2.184755325317383, -3.106219530105591, -3.1122710704803467, -3.690053701400757, -4.51891565322876, -6.564457416534424, -0.0, -0.0, -2.890331506729126], [-15.904386520385742, 0.0, 0.0, -14.898716926574707, -13.775846481323242, -12.772387504577637, -11.984670639038086, -11.649788856506348, -10.506595611572266, -11.023802757263184, -10.558952331542969, -9.892841339111328, -8.657294273376465, -7.800882816314697, -8.63603401184082, -5.988286018371582, -6.49173641204834, -6.408040523529053, -5.9624409675598145, -5.941344261169434, -7.106613636016846, -7.976408004760742, -6.819662094116211, -5.583681106567383, -5.537598609924316, -8.501558303833008, -8.062750816345215, -8.605438232421875, -8.545567512512207, -8.570030212402344, -5.522328853607178, -8.847572326660156, -9.063572883605957, -10.070962905883789, -11.201147079467773, -11.304341316223145, -11.603986740112305, -11.239283561706543, -10.824055671691895, -12.017916679382324, -12.473092079162598, -12.374025344848633, -10.994415283203125, -10.46841812133789, -11.377840042114258, -10.37224292755127, -11.87423038482666, -9.997030258178711, -8.54037094116211, -7.794164657592773, -9.978951454162598, -6.472295761108398, -8.883042335510254, -5.4195332527160645, -4.644050598144531, -4.513479709625244, -3.5504021644592285, -2.995325803756714, -2.832765817642212, -2.7007689476013184, -1.4907008409500122, -1.8748103380203247, -2.222813367843628, -2.0079030990600586, -1.5872207880020142, -1.0439863204956055, -1.7487647533416748, -1.7729524374008179, -1.5560925006866455, -2.4933104515075684, -2.1246702671051025, -3.267272710800171, -3.8359220027923584, -2.091385841369629, 0.0, 0.0, 0.0, -0.04817638546228409, -15.904386520385742, -0.0, -0.0, -14.898716926574707, -13.775846481323242, -12.772387504577637, -11.984670639038086, -11.649788856506348, -10.506595611572266, -11.023802757263184, -10.558952331542969, -9.892841339111328, -8.657294273376465, -7.800882816314697, -8.63603401184082, -5.988286018371582, -6.49173641204834, -6.408040523529053, -5.9624409675598145, -5.941344261169434, -7.106613636016846, -7.976408004760742, -6.819662094116211, -5.583681106567383, -5.537598609924316, -8.501558303833008, -8.062750816345215, -8.605438232421875, -8.545567512512207, -8.570030212402344, -5.522328853607178, -8.847572326660156, -9.063572883605957, -10.070962905883789, -11.201147079467773, -11.304341316223145, -11.603986740112305, -11.239283561706543, -10.824055671691895, -12.017916679382324, -12.473092079162598, -12.374025344848633, -10.994415283203125, -10.46841812133789, -11.377840042114258, -10.37224292755127, -11.87423038482666, -9.997030258178711, -8.54037094116211, -7.794164657592773, -9.978951454162598, -6.472295761108398, -8.883042335510254, -5.4195332527160645, -4.644050598144531, -4.513479709625244, -3.5504021644592285, -2.995325803756714, -2.832765817642212, -2.7007689476013184, -1.4907008409500122, -1.8748103380203247, -2.222813367843628, -2.0079030990600586, -1.5872207880020142, -1.0439863204956055, -1.7487647533416748, -1.7729524374008179, -1.5560925006866455, -2.4933104515075684, -2.1246702671051025, -3.267272710800171, -3.8359220027923584, -2.091385841369629, -0.0, -0.0, -0.0, -0.04817638546228409], [-17.30003547668457, -17.404909133911133, 0.0, -13.60557746887207, -14.270918846130371, -13.362203598022461, -12.678065299987793, -11.281465530395508, -10.972561836242676, -9.679831504821777, -12.397848129272461, -9.386679649353027, -9.363269805908203, -8.393760681152344, -7.748685359954834, -7.738872528076172, -6.968378067016602, -7.131901264190674, -6.953780174255371, -6.836553573608398, -6.522346496582031, -7.386101722717285, -6.719448089599609, -7.113292694091797, -7.361760139465332, -7.785654544830322, -8.047847747802734, -8.0515775680542, -8.782033920288086, -9.497483253479004, -9.523192405700684, -11.021846771240234, -13.562352180480957, -12.067034721374512, -10.776538848876953, -11.79287052154541, -13.537506103515625, -12.123659133911133, -11.242016792297363, -13.0665864944458, -12.335734367370605, -10.570666313171387, -12.420076370239258, -12.282411575317383, -14.528040885925293, -9.920058250427246, -9.301594734191895, -12.964334487915039, -10.266510963439941, -8.509939193725586, -8.895203590393066, -6.706762790679932, -7.799339771270752, -5.792898178100586, -5.254899978637695, -4.955830097198486, -4.06679630279541, -3.9247443675994873, -3.1174099445343018, -3.1278152465820312, -2.4180212020874023, -2.1406078338623047, -2.3265891075134277, -1.5762345790863037, -1.872080683708191, -1.6636887788772583, -1.5374555587768555, -2.21966814994812, -2.396869421005249, -2.9683449268341064, -2.8792123794555664, -3.3583061695098877, -4.460575103759766, -5.477791786193848, 0.0, 0.0, 0.0, -1.275294303894043, -17.30003547668457, -17.404909133911133, -0.0, -13.60557746887207, -14.270918846130371, -13.362203598022461, -12.678065299987793, -11.281465530395508, -10.972561836242676, -9.679831504821777, -12.397848129272461, -9.386679649353027, -9.363269805908203, -8.393760681152344, -7.748685359954834, -7.738872528076172, -6.968378067016602, -7.131901264190674, -6.953780174255371, -6.836553573608398, -6.522346496582031, -7.386101722717285, -6.719448089599609, -7.113292694091797, -7.361760139465332, -7.785654544830322, -8.047847747802734, -8.0515775680542, -8.782033920288086, -9.497483253479004, -9.523192405700684, -11.021846771240234, -13.562352180480957, -12.067034721374512, -10.776538848876953, -11.79287052154541, -13.537506103515625, -12.123659133911133, -11.242016792297363, -13.0665864944458, -12.335734367370605, -10.570666313171387, -12.420076370239258, -12.282411575317383, -14.528040885925293, -9.920058250427246, -9.301594734191895, -12.964334487915039, -10.266510963439941, -8.509939193725586, -8.895203590393066, -6.706762790679932, -7.799339771270752, -5.792898178100586, -5.254899978637695, -4.955830097198486, -4.06679630279541, -3.9247443675994873, -3.1174099445343018, -3.1278152465820312, -2.4180212020874023, -2.1406078338623047, -2.3265891075134277, -1.5762345790863037, -1.872080683708191, -1.6636887788772583, -1.5374555587768555, -2.21966814994812, -2.396869421005249, -2.9683449268341064, -2.8792123794555664, -3.3583061695098877, -4.460575103759766, -5.477791786193848, -0.0, -0.0, -0.0, -1.275294303894043], [-17.67823600769043, 0.0, 0.0, 0.0, -14.596875190734863, -13.766337394714355, -13.154281616210938, -12.196297645568848, -12.087709426879883, -11.014104843139648, -10.466713905334473, -10.596540451049805, -9.807607650756836, -9.006521224975586, -8.134129524230957, -7.517187118530273, -7.3506975173950195, -7.086439609527588, -7.309606075286865, -7.515061378479004, -8.119823455810547, -7.444098472595215, -7.91415548324585, -7.959113121032715, -7.468135356903076, -8.286766052246094, -7.8894853591918945, -9.234451293945312, -9.39847183227539, -9.519441604614258, -10.979602813720703, -11.272082328796387, -13.198965072631836, -12.633049011230469, -12.412714004516602, -12.858735084533691, -13.992279052734375, -14.157964706420898, -13.671850204467773, -13.901446342468262, -13.908544540405273, -14.390607833862305, -13.226126670837402, -13.540072441101074, -12.20196533203125, -12.83388900756836, -11.066293716430664, -11.180761337280273, -11.00695514678955, -9.644859313964844, -8.137622833251953, -7.395127296447754, -7.936041355133057, -6.636852264404297, -4.640378475189209, -4.624012470245361, -4.146999835968018, -4.577469825744629, -4.277139663696289, -3.8220036029815674, -3.2846529483795166, -1.708983063697815, -2.2424802780151367, -1.7030302286148071, -2.0967726707458496, -2.15516996383667, -2.0077619552612305, -1.7629616260528564, -3.1644351482391357, -2.7409706115722656, -2.8264122009277344, -3.5565967559814453, -5.420977592468262, -5.830126762390137, 0.0, 0.0, -2.0197794437408447, 0.42645519971847534, -17.67823600769043, -0.0, -0.0, -0.0, -14.596875190734863, -13.766337394714355, -13.154281616210938, -12.196297645568848, -12.087709426879883, -11.014104843139648, -10.466713905334473, -10.596540451049805, -9.807607650756836, -9.006521224975586, -8.134129524230957, -7.517187118530273, -7.3506975173950195, -7.086439609527588, -7.309606075286865, -7.515061378479004, -8.119823455810547, -7.444098472595215, -7.91415548324585, -7.959113121032715, -7.468135356903076, -8.286766052246094, -7.8894853591918945, -9.234451293945312, -9.39847183227539, -9.519441604614258, -10.979602813720703, -11.272082328796387, -13.198965072631836, -12.633049011230469, -12.412714004516602, -12.858735084533691, -13.992279052734375, -14.157964706420898, -13.671850204467773, -13.901446342468262, -13.908544540405273, -14.390607833862305, -13.226126670837402, -13.540072441101074, -12.20196533203125, -12.83388900756836, -11.066293716430664, -11.180761337280273, -11.00695514678955, -9.644859313964844, -8.137622833251953, -7.395127296447754, -7.936041355133057, -6.636852264404297, -4.640378475189209, -4.624012470245361, -4.146999835968018, -4.577469825744629, -4.277139663696289, -3.8220036029815674, -3.2846529483795166, -1.708983063697815, -2.2424802780151367, -1.7030302286148071, -2.0967726707458496, -2.15516996383667, -2.0077619552612305, -1.7629616260528564, -3.1644351482391357, -2.7409706115722656, -2.8264122009277344, -3.5565967559814453, -5.420977592468262, -5.830126762390137, -0.0, -0.0, -2.0197794437408447, 0.42645519971847534], [-18.603515625, -16.123146057128906, 0.0, 0.0, -16.043142318725586, -13.543163299560547, -12.988479614257812, -12.222597122192383, -11.543686866760254, -11.077325820922852, -10.745311737060547, -9.694783210754395, -8.976768493652344, -8.208620071411133, -8.589324951171875, -8.11495590209961, -7.391691207885742, -7.719106197357178, -7.6481499671936035, -8.309347152709961, -7.336121559143066, -7.650646209716797, -8.968062400817871, -8.070563316345215, -7.476958274841309, -8.847389221191406, -8.58299732208252, -8.903141021728516, -11.038110733032227, -10.505789756774902, -11.79728889465332, -11.97843074798584, -14.409418106079102, -13.579330444335938, -14.532575607299805, -14.598987579345703, -14.66857624053955, -14.950102806091309, -15.922662734985352, -15.68569564819336, -14.874433517456055, -14.331094741821289, -15.834197998046875, -14.060452461242676, -11.552730560302734, -14.171777725219727, -10.483405113220215, -14.00032901763916, -11.395115852355957, -11.240330696105957, -10.011853218078613, -11.006633758544922, -6.9235920906066895, -7.334006309509277, -6.971909046173096, -5.776237964630127, -5.124608993530273, -4.233353137969971, -3.9400947093963623, -4.145482063293457, -3.916917562484741, -2.8573315143585205, -2.4390454292297363, -2.1553025245666504, -2.3869264125823975, -1.8410618305206299, -2.2297492027282715, -2.5120503902435303, -3.7507264614105225, -2.977935791015625, -3.6143651008605957, -3.6730754375457764, -4.9225640296936035, 0.0, 0.0, 0.0, 0.2645912170410156, 1.383831262588501, -18.603515625, -16.123146057128906, -0.0, -0.0, -16.043142318725586, -13.543163299560547, -12.988479614257812, -12.222597122192383, -11.543686866760254, -11.077325820922852, -10.745311737060547, -9.694783210754395, -8.976768493652344, -8.208620071411133, -8.589324951171875, -8.11495590209961, -7.391691207885742, -7.719106197357178, -7.6481499671936035, -8.309347152709961, -7.336121559143066, -7.650646209716797, -8.968062400817871, -8.070563316345215, -7.476958274841309, -8.847389221191406, -8.58299732208252, -8.903141021728516, -11.038110733032227, -10.505789756774902, -11.79728889465332, -11.97843074798584, -14.409418106079102, -13.579330444335938, -14.532575607299805, -14.598987579345703, -14.66857624053955, -14.950102806091309, -15.922662734985352, -15.68569564819336, -14.874433517456055, -14.331094741821289, -15.834197998046875, -14.060452461242676, -11.552730560302734, -14.171777725219727, -10.483405113220215, -14.00032901763916, -11.395115852355957, -11.240330696105957, -10.011853218078613, -11.006633758544922, -6.9235920906066895, -7.334006309509277, -6.971909046173096, -5.776237964630127, -5.124608993530273, -4.233353137969971, -3.9400947093963623, -4.145482063293457, -3.916917562484741, -2.8573315143585205, -2.4390454292297363, -2.1553025245666504, -2.3869264125823975, -1.8410618305206299, -2.2297492027282715, -2.5120503902435303, -3.7507264614105225, -2.977935791015625, -3.6143651008605957, -3.6730754375457764, -4.9225640296936035, -0.0, -0.0, 0.0, 0.2645912170410156, 1.383831262588501], [-18.35822105407715, -17.542734146118164, -18.313636779785156, 0.0, -15.412616729736328, -13.64138126373291, -13.094738960266113, -12.50529670715332, -11.330649375915527, -10.777846336364746, -10.698410034179688, -10.089585304260254, -9.225492477416992, -9.43667984008789, -7.799301624298096, -7.728183746337891, -7.460205078125, -7.921230792999268, -7.689756870269775, -8.201571464538574, -8.013006210327148, -7.7244157791137695, -7.968091011047363, -8.40847110748291, -9.732834815979004, -9.618927955627441, -9.412590980529785, -10.502073287963867, -10.758623123168945, -11.285143852233887, -13.42537784576416, -15.12514591217041, -13.773518562316895, -15.287683486938477, -16.452112197875977, -16.508804321289062, -16.298051834106445, -17.45661735534668, -16.22679901123047, -17.287057876586914, -17.305749893188477, -17.39116859436035, -16.868112564086914, -17.416650772094727, -14.682092666625977, -15.679375648498535, -14.843400955200195, -13.107834815979004, -13.12977123260498, -11.457178115844727, -10.559025764465332, -9.714216232299805, -8.73154354095459, -9.116960525512695, -5.834964752197266, -5.923341751098633, -5.903308391571045, -4.886212348937988, -4.963534832000732, -4.203405857086182, -2.953054904937744, -2.029536247253418, -2.0679221153259277, -2.9015092849731445, -2.2743988037109375, -2.420016050338745, -2.3197197914123535, -3.309109687805176, -3.4943947792053223, -3.794689178466797, -3.5612618923187256, -3.6775083541870117, -4.794461727142334, 0.0, 0.0, 0.0, 1.2504770755767822, 1.6413497924804688, -18.35822105407715, -17.542734146118164, -18.313636779785156, -0.0, -15.412616729736328, -13.64138126373291, -13.094738960266113, -12.50529670715332, -11.330649375915527, -10.777846336364746, -10.698410034179688, -10.089585304260254, -9.225492477416992, -9.43667984008789, -7.799301624298096, -7.728183746337891, -7.460205078125, -7.921230792999268, -7.689756870269775, -8.201571464538574, -8.013006210327148, -7.7244157791137695, -7.968091011047363, -8.40847110748291, -9.732834815979004, -9.618927955627441, -9.412590980529785, -10.502073287963867, -10.758623123168945, -11.285143852233887, -13.42537784576416, -15.12514591217041, -13.773518562316895, -15.287683486938477, -16.452112197875977, -16.508804321289062, -16.298051834106445, -17.45661735534668, -16.22679901123047, -17.287057876586914, -17.305749893188477, -17.39116859436035, -16.868112564086914, -17.416650772094727, -14.682092666625977, -15.679375648498535, -14.843400955200195, -13.107834815979004, -13.12977123260498, -11.457178115844727, -10.559025764465332, -9.714216232299805, -8.73154354095459, -9.116960525512695, -5.834964752197266, -5.923341751098633, -5.903308391571045, -4.886212348937988, -4.963534832000732, -4.203405857086182, -2.953054904937744, -2.029536247253418, -2.0679221153259277, -2.9015092849731445, -2.2743988037109375, -2.420016050338745, -2.3197197914123535, -3.309109687805176, -3.4943947792053223, -3.794689178466797, -3.5612618923187256, -3.6775083541870117, -4.794461727142334, -0.0, 0.0, 0.0, 1.2504770755767822, 1.6413497924804688], [-18.397294998168945, -14.450234413146973, -16.617656707763672, 0.0, -16.299619674682617, -14.149206161499023, -13.43392276763916, -12.115768432617188, -11.762029647827148, -11.473237037658691, -10.50076961517334, -9.732148170471191, -10.524884223937988, -9.559782981872559, -8.920660018920898, -8.124354362487793, -7.874081611633301, -7.4626312255859375, -7.745090961456299, -8.090124130249023, -8.548145294189453, -9.040178298950195, -8.736799240112305, -8.118721008300781, -9.348958015441895, -9.689255714416504, -9.616669654846191, -11.064547538757324, -13.379691123962402, -11.786770820617676, -12.690993309020996, -13.307465553283691, -16.46873664855957, -18.261985778808594, -18.01250457763672, -17.759689331054688, -18.22451400756836, -16.678455352783203, -19.527740478515625, -18.303831100463867, -17.219640731811523, -20.163177490234375, -18.344486236572266, -18.52362823486328, -16.761798858642578, -16.89944839477539, -15.567692756652832, -15.172662734985352, -14.345171928405762, -13.830449104309082, -11.620780944824219, -9.828807830810547, -8.182169914245605, -9.29341983795166, -8.626371383666992, -6.464630126953125, -6.487654209136963, -4.399201393127441, -5.728600978851318, -4.2604594230651855, -4.1302618980407715, -3.601137638092041, -3.4884133338928223, -2.812905788421631, -2.0253500938415527, -2.435393810272217, -2.3072805404663086, -3.041243076324463, -3.3029415607452393, -3.571664333343506, -2.8319308757781982, -3.5869901180267334, 0.0, 0.0, 0.0, 0.0, 2.6890158653259277, 2.9112610816955566, -18.397294998168945, -14.450234413146973, -16.617656707763672, -0.0, -16.299619674682617, -14.149206161499023, -13.43392276763916, -12.115768432617188, -11.762029647827148, -11.473237037658691, -10.50076961517334, -9.732148170471191, -10.524884223937988, -9.559782981872559, -8.920660018920898, -8.124354362487793, -7.874081611633301, -7.4626312255859375, -7.745090961456299, -8.090124130249023, -8.548145294189453, -9.040178298950195, -8.736799240112305, -8.118721008300781, -9.348958015441895, -9.689255714416504, -9.616669654846191, -11.064547538757324, -13.379691123962402, -11.786770820617676, -12.690993309020996, -13.307465553283691, -16.46873664855957, -18.261985778808594, -18.01250457763672, -17.759689331054688, -18.22451400756836, -16.678455352783203, -19.527740478515625, -18.303831100463867, -17.219640731811523, -20.163177490234375, -18.344486236572266, -18.52362823486328, -16.761798858642578, -16.89944839477539, -15.567692756652832, -15.172662734985352, -14.345171928405762, -13.830449104309082, -11.620780944824219, -9.828807830810547, -8.182169914245605, -9.29341983795166, -8.626371383666992, -6.464630126953125, -6.487654209136963, -4.399201393127441, -5.728600978851318, -4.2604594230651855, -4.1302618980407715, -3.601137638092041, -3.4884133338928223, -2.812905788421631, -2.0253500938415527, -2.435393810272217, -2.3072805404663086, -3.041243076324463, -3.3029415607452393, -3.571664333343506, -2.8319308757781982, -3.5869901180267334, -0.0, -0.0, 0.0, 0.0, 2.6890158653259277, 2.9112610816955566], [-18.612796783447266, -18.140804290771484, -15.499256134033203, 0.0, 0.0, -17.653839111328125, -12.672285079956055, -12.764026641845703, -11.616586685180664, -10.771117210388184, -9.952347755432129, -9.818984985351562, -9.32048225402832, -9.76774787902832, -9.842434883117676, -8.016837120056152, -8.715116500854492, -8.777009963989258, -8.214516639709473, -7.958351135253906, -9.214470863342285, -9.187950134277344, -8.309806823730469, -9.911591529846191, -9.147807121276855, -10.352182388305664, -11.060382843017578, -11.247825622558594, -12.729791641235352, -14.435464859008789, -14.337136268615723, -15.24974536895752, -16.925128936767578, -16.94356346130371, -18.204429626464844, -19.917726516723633, -18.997751235961914, -20.77528190612793, 0.0, -20.01919937133789, -20.7332763671875, -22.240205764770508, -20.400527954101562, -19.93328857421875, -17.492752075195312, -15.51225471496582, -17.95782470703125, -16.602537155151367, -15.669605255126953, -13.87205696105957, -12.687111854553223, -13.106247901916504, -9.556913375854492, -8.912205696105957, -9.121541976928711, -7.099125862121582, -6.876964092254639, -5.936336040496826, -4.910141468048096, -5.194688320159912, -4.536206245422363, -3.9392056465148926, -2.9422409534454346, -3.8483121395111084, -3.2979185581207275, -2.5705113410949707, -2.404543161392212, -2.914881706237793, -3.1956586837768555, -2.8127613067626953, -2.8784823417663574, 0.0, 0.0, 0.0, 0.0, 2.9508135318756104, 2.0805413722991943, 1.0783027410507202, -18.612796783447266, -18.140804290771484, -15.499256134033203, -0.0, -0.0, -17.653839111328125, -12.672285079956055, -12.764026641845703, -11.616586685180664, -10.771117210388184, -9.952347755432129, -9.818984985351562, -9.32048225402832, -9.76774787902832, -9.842434883117676, -8.016837120056152, -8.715116500854492, -8.777009963989258, -8.214516639709473, -7.958351135253906, -9.214470863342285, -9.187950134277344, -8.309806823730469, -9.911591529846191, -9.147807121276855, -10.352182388305664, -11.060382843017578, -11.247825622558594, -12.729791641235352, -14.435464859008789, -14.337136268615723, -15.24974536895752, -16.925128936767578, -16.94356346130371, -18.204429626464844, -19.917726516723633, -18.997751235961914, -20.77528190612793, -0.0, -20.01919937133789, -20.7332763671875, -22.240205764770508, -20.400527954101562, -19.93328857421875, -17.492752075195312, -15.51225471496582, -17.95782470703125, -16.602537155151367, -15.669605255126953, -13.87205696105957, -12.687111854553223, -13.106247901916504, -9.556913375854492, -8.912205696105957, -9.121541976928711, -7.099125862121582, -6.876964092254639, -5.936336040496826, -4.910141468048096, -5.194688320159912, -4.536206245422363, -3.9392056465148926, -2.9422409534454346, -3.8483121395111084, -3.2979185581207275, -2.5705113410949707, -2.404543161392212, -2.914881706237793, -3.1956586837768555, -2.8127613067626953, -2.8784823417663574, -0.0, -0.0, 0.0, 0.0, 2.9508135318756104, 2.0805413722991943, 1.0783027410507202], [-19.97134017944336, -17.137170791625977, -17.0274658203125, 0.0, 0.0, 0.0, -12.748315811157227, -12.076009750366211, -11.989212036132812, -11.572100639343262, -10.662186622619629, -10.173725128173828, -9.785455703735352, -9.694350242614746, -9.584135055541992, -9.389383316040039, -8.733327865600586, -8.356302261352539, -7.273211479187012, -8.871965408325195, -8.298444747924805, -8.987351417541504, -9.827713966369629, -9.730470657348633, -9.817904472351074, -12.298340797424316, -11.726099014282227, -12.313030242919922, -13.371552467346191, -14.653525352478027, -15.473934173583984, -17.316640853881836, -19.859933853149414, -22.34453582763672, -20.71841049194336, -20.72958755493164, -21.035978317260742, -21.18111228942871, 0.0, 0.0, -19.283851623535156, -21.71919822692871, -25.125179290771484, -21.851238250732422, -19.005477905273438, -20.383790969848633, -19.102354049682617, -17.999113082885742, -16.8872013092041, -14.361148834228516, -14.490527153015137, -11.971521377563477, -11.291431427001953, -9.326983451843262, -9.28680419921875, -8.160609245300293, -7.054318428039551, -7.6180644035339355, -6.104803562164307, -5.606754779815674, -4.93641471862793, -4.833314895629883, -4.377358436584473, -4.353885650634766, -4.313689231872559, -3.211216926574707, -4.302340984344482, -3.4457693099975586, -2.9022669792175293, -2.5083067417144775, 0.0, 0.0, 0.0, 0.0, 4.106642246246338, 2.3182923793792725, 2.701862335205078, 1.296964168548584, -19.97134017944336, -17.137170791625977, -17.0274658203125, -0.0, -0.0, -0.0, -12.748315811157227, -12.076009750366211, -11.989212036132812, -11.572100639343262, -10.662186622619629, -10.173725128173828, -9.785455703735352, -9.694350242614746, -9.584135055541992, -9.389383316040039, -8.733327865600586, -8.356302261352539, -7.273211479187012, -8.871965408325195, -8.298444747924805, -8.987351417541504, -9.827713966369629, -9.730470657348633, -9.817904472351074, -12.298340797424316, -11.726099014282227, -12.313030242919922, -13.371552467346191, -14.653525352478027, -15.473934173583984, -17.316640853881836, -19.859933853149414, -22.34453582763672, -20.71841049194336, -20.72958755493164, -21.035978317260742, -21.18111228942871, -0.0, -0.0, -19.283851623535156, -21.71919822692871, -25.125179290771484, -21.851238250732422, -19.005477905273438, -20.383790969848633, -19.102354049682617, -17.999113082885742, -16.8872013092041, -14.361148834228516, -14.490527153015137, -11.971521377563477, -11.291431427001953, -9.326983451843262, -9.28680419921875, -8.160609245300293, -7.054318428039551, -7.6180644035339355, -6.104803562164307, -5.606754779815674, -4.93641471862793, -4.833314895629883, -4.377358436584473, -4.353885650634766, -4.313689231872559, -3.211216926574707, -4.302340984344482, -3.4457693099975586, -2.9022669792175293, -2.5083067417144775, -0.0, -0.0, 0.0, 0.0, 4.106642246246338, 2.3182923793792725, 2.701862335205078, 1.296964168548584], [-18.827077865600586, -21.294546127319336, -17.5567569732666, -18.93704605102539, 0.0, 0.0, -11.02353286743164, -11.088897705078125, -11.376786231994629, -11.350726127624512, -10.629571914672852, -10.545866966247559, -9.855175971984863, -10.158461570739746, -10.171172142028809, -9.196507453918457, -9.121957778930664, -9.080476760864258, -9.165168762207031, -9.402825355529785, -9.408479690551758, -9.930834770202637, -10.601045608520508, -10.342084884643555, -11.427300453186035, -11.706341743469238, -12.009825706481934, -11.248230934143066, -14.280132293701172, -16.74977684020996, -17.104001998901367, -18.52618408203125, -19.58407974243164, -20.818815231323242, -20.709033966064453, -22.581382751464844, -23.64192771911621, -23.336254119873047, 0.0, -23.81488800048828, -24.641454696655273, -23.560104370117188, -23.796167373657227, -22.746946334838867, -22.431665420532227, -20.06116485595703, -20.45429229736328, -18.264055252075195, -17.7603702545166, -16.70893096923828, -16.69662094116211, -14.159114837646484, -12.679649353027344, -11.705082893371582, -10.243366241455078, -8.885297775268555, -7.470144748687744, -7.080077171325684, -5.180516719818115, -5.783252716064453, -5.498950481414795, -5.179515361785889, -4.479107856750488, -5.756089210510254, -4.697513103485107, -4.3800225257873535, -4.4396491050720215, -2.7647500038146973, -2.073216438293457, 0.0, 0.0, 0.0, 0.0, 3.9129583835601807, 3.14815354347229, 1.6879726648330688, 2.4644384384155273, 2.5578112602233887, -18.827077865600586, -21.294546127319336, -17.5567569732666, -18.93704605102539, -0.0, -0.0, -11.02353286743164, -11.088897705078125, -11.376786231994629, -11.350726127624512, -10.629571914672852, -10.545866966247559, -9.855175971984863, -10.158461570739746, -10.171172142028809, -9.196507453918457, -9.121957778930664, -9.080476760864258, -9.165168762207031, -9.402825355529785, -9.408479690551758, -9.930834770202637, -10.601045608520508, -10.342084884643555, -11.427300453186035, -11.706341743469238, -12.009825706481934, -11.248230934143066, -14.501452445983887, -16.273273468017578, -17.05107307434082, -18.411169052124023, -19.477312088012695, -20.666645050048828, -20.926101684570312, -22.406978607177734, -23.308483123779297, -23.294275283813477, -0.0, -23.806652069091797, -24.36500358581543, -23.575687408447266, -23.59502410888672, -22.671642303466797, -22.2164363861084, -20.334081649780273, -20.215293884277344, -18.411029815673828, -17.762117385864258, -16.641151428222656, -16.21442985534668, -14.096665382385254, -12.711165428161621, -11.586346626281738, -10.243366241455078, -8.885297775268555, -7.470144748687744, -7.080077171325684, -5.180516719818115, -5.783252716064453, -5.498950481414795, -5.179515361785889, -4.479107856750488, -5.756089210510254, -4.697513103485107, -4.3800225257873535, -4.4396491050720215, -2.7647500038146973, -2.073216438293457, -0.0, 0.0, 0.0, 0.0, 3.9129583835601807, 3.14815354347229, 1.6879726648330688, 2.4644384384155273, 2.5578112602233887], [-19.866853713989258, -18.915821075439453, -17.35738182067871, -18.36035919189453, 0.0, 0.0, 0.0, -10.455971717834473, -11.062499046325684, -10.595404624938965, -10.655926704406738, -10.492679595947266, -10.2748441696167, -9.908785820007324, -10.097389221191406, -9.35899829864502, -9.433679580688477, -9.086614608764648, -9.170812606811523, -8.425823211669922, -10.182958602905273, -10.931526184082031, -10.105203628540039, -11.700138092041016, -12.647253036499023, -12.515898704528809, -13.042257308959961, -14.259117126464844, -15.206273078918457, -16.382522583007812, -18.238384246826172, -18.904767990112305, -20.097671508789062, -24.960660934448242, -24.37482261657715, -24.23568344116211, -24.314157485961914, -24.34702491760254, -24.051029205322266, -27.272367477416992, -26.453960418701172, -26.707740783691406, -26.557567596435547, -25.671838760375977, -23.882535934448242, -24.004425048828125, -21.416276931762695, -19.33452796936035, -18.881183624267578, -17.446420669555664, -16.08061408996582, -13.87421989440918, -10.597280502319336, -12.397310256958008, -10.117948532104492, -9.178427696228027, -9.437783241271973, -9.346699714660645, -6.7407002449035645, -6.895068168640137, -6.443206310272217, -3.524137020111084, -5.1471991539001465, -4.831267356872559, -4.5469441413879395, -4.782678604125977, -4.432136058807373, -4.193354606628418, -1.781529426574707, 0.0, 2.0580270290374756, 0.0, 0.0, 5.419589519500732, 3.2689287662506104, 2.726748466491699, 2.0167834758758545, -0.5666675567626953, -19.866853713989258, -18.915821075439453, -17.35738182067871, -18.36035919189453, -0.0, -0.0, -0.0, -10.455971717834473, -11.062499046325684, -10.595404624938965, -10.655926704406738, -10.492679595947266, -10.2748441696167, -9.908785820007324, -10.097389221191406, -9.35899829864502, -9.433679580688477, -9.086614608764648, -9.170812606811523, -8.425823211669922, -10.182958602905273, -10.931526184082031, -10.105203628540039, -11.700138092041016, -12.647253036499023, -12.515898704528809, -13.042257308959961, -14.259117126464844, -15.343955993652344, -16.7135009765625, -17.975757598876953, -19.31595230102539, -20.580223083496094, -21.742332458496094, -22.661657333374023, -23.68976593017578, -24.507619857788086, -24.980722427368164, -25.36425018310547, -25.605205535888672, -25.723846435546875, -25.417724609375, -25.02291488647461, -24.300493240356445, -23.43177032470703, -22.236452102661133, -21.222064971923828, -19.95301055908203, -18.858278274536133, -17.73197364807129, -16.597990036010742, -15.046582221984863, -13.578532218933105, -12.354286193847656, -10.117948532104492, -9.178427696228027, -9.437783241271973, -9.346699714660645, -6.7407002449035645, -6.895068168640137, -6.443206310272217, -3.524137020111084, -5.1471991539001465, -4.831267356872559, -4.5469441413879395, -4.782678604125977, -4.432136058807373, -4.193354606628418, -1.781529426574707, 0.0, 2.0580270290374756, 0.0, 0.0, 5.419589519500732, 3.2689287662506104, 2.726748466491699, 2.0167834758758545, -0.5666675567626953], [-19.647310256958008, -18.637462615966797, -17.19075584411621, -16.806324005126953, -15.726107597351074, 0.0, 0.0, -12.714160919189453, -9.931760787963867, -10.573987007141113, -10.867431640625, -10.036782264709473, -10.182971954345703, -10.452604293823242, -10.009858131408691, -10.260960578918457, -10.25859260559082, -10.06196117401123, -9.775652885437012, -9.990947723388672, -10.83462905883789, -10.677010536193848, -11.133576393127441, -11.905941009521484, -12.345410346984863, -13.564962387084961, -13.325234413146973, -16.348255157470703, -16.297237396240234, -17.09842872619629, -19.621963500976562, -20.44444465637207, -20.99835777282715, -23.826169967651367, -24.75054168701172, -26.075159072875977, -27.365419387817383, -27.621665954589844, -28.308481216430664, -27.76247215270996, -28.670167922973633, -29.373811721801758, -27.985034942626953, -26.962995529174805, -25.717199325561523, -24.8657169342041, -23.61435317993164, -21.020627975463867, -20.42983055114746, -19.765043258666992, -18.608272552490234, -14.127006530761719, -14.33944320678711, -12.090646743774414, -12.196527481079102, -10.836705207824707, -8.343314170837402, -8.768166542053223, -7.104929447174072, -7.274586200714111, -6.22620153427124, -6.586963653564453, -5.552457809448242, -5.8020148277282715, -6.943928241729736, -1.1563796997070312, -2.205233573913574, -0.6069709658622742, 1.7584810256958008, 0.0, 2.1583893299102783, 0.0, 6.559638500213623, 3.7521047592163086, 3.7136688232421875, 3.596301555633545, 1.9878133535385132, 1.8645662069320679, -19.647310256958008, -18.637462615966797, -17.19075584411621, -16.806324005126953, -15.726107597351074, -0.0, -0.0, -12.714160919189453, -9.931760787963867, -10.573987007141113, -10.867431640625, -10.036782264709473, -10.182971954345703, -10.452604293823242, -10.009858131408691, -10.260960578918457, -10.25859260559082, -10.06196117401123, -9.775652885437012, -9.990947723388672, -10.83462905883789, -10.677010536193848, -11.133576393127441, -11.905941009521484, -12.345410346984863, -13.564962387084961, -13.325234413146973, -16.348255157470703, -16.235136032104492, -17.370880126953125, -18.75645637512207, -20.207563400268555, -21.6102294921875, -22.899795532226562, -24.029600143432617, -24.9953556060791, -25.8201961517334, -26.47126007080078, -26.92626953125, -27.192237854003906, -27.20974349975586, -26.977895736694336, -26.485279083251953, -25.74687385559082, -24.785091400146484, -23.678409576416016, -22.474822998046875, -21.237384796142578, -19.99413299560547, -18.707059860229492, -17.34502601623535, -15.90808391571045, -14.328753471374512, -12.415770530700684, -12.196527481079102, -10.836705207824707, -8.343314170837402, -8.768166542053223, -7.104929447174072, -7.274586200714111, -6.22620153427124, -6.586963653564453, -5.552457809448242, -5.8020148277282715, -6.943928241729736, -1.1563796997070312, -2.205233573913574, -0.6069709658622742, 1.7584810256958008, 0.0, 2.1583893299102783, 0.0, 6.559638500213623, 3.7521047592163086, 3.7136688232421875, 3.596301555633545, 1.9878133535385132, 1.8645662069320679], [-18.222774505615234, -18.141815185546875, -17.074810028076172, -16.31389045715332, -15.153326988220215, -12.166692733764648, 0.0, 0.0, -10.872013092041016, -11.928094863891602, -10.717002868652344, -10.694218635559082, -10.711352348327637, -11.332231521606445, -9.611553192138672, -10.243314743041992, -10.662028312683105, -10.428694725036621, -10.730100631713867, -11.065380096435547, -11.664060592651367, -11.590205192565918, -11.271734237670898, -12.494819641113281, -13.406145095825195, -14.127342224121094, -14.721698760986328, -14.930819511413574, -16.488971710205078, -17.086591720581055, -19.972084045410156, -21.38440704345703, -23.84755516052246, -24.88404655456543, -27.123104095458984, -29.16598129272461, -28.3413028717041, -30.020095825195312, -29.731441497802734, -30.39076805114746, -31.933032989501953, -29.823694229125977, -29.39865493774414, -29.323434829711914, -28.010271072387695, -24.103769302368164, -24.41121482849121, -22.544099807739258, -21.264490127563477, -21.273941040039062, -17.45428466796875, -16.549795150756836, -14.449740409851074, -14.586761474609375, -11.832124710083008, -11.340017318725586, -9.880157470703125, -9.182782173156738, -8.920133590698242, -7.186948299407959, -8.650290489196777, -6.933536529541016, -6.235667705535889, -5.246774673461914, -3.808237075805664, 0.0, -2.6984453201293945, -3.4819672107696533, -0.9557288885116577, 0.0, 0.0, 6.3730034828186035, 5.998733997344971, 4.094493389129639, 3.103607654571533, 3.0484485626220703, 1.0227583646774292, -0.03340508043766022, -18.222774505615234, -18.141815185546875, -17.074810028076172, -16.31389045715332, -15.153326988220215, -12.166692733764648, -0.0, -0.0, -10.872013092041016, -11.928094863891602, -10.717002868652344, -10.694218635559082, -10.711352348327637, -11.332231521606445, -9.611553192138672, -10.243314743041992, -10.662028312683105, -10.428694725036621, -10.730100631713867, -11.065380096435547, -11.664060592651367, -11.590205192565918, -11.271734237670898, -12.494819641113281, -13.406145095825195, -14.127342224121094, -14.721698760986328, -14.930819511413574, -16.599266052246094, -18.02393913269043, -19.549009323120117, -21.11420249938965, -22.645221710205078, -24.032339096069336, -25.233049392700195, -26.268680572509766, -27.158023834228516, -27.885286331176758, -28.4053897857666, -28.68696403503418, -28.693321228027344, -28.437454223632812, -27.91752052307129, -27.14499282836914, -26.14817237854004, -24.996816635131836, -23.74476432800293, -22.45330047607422, -21.10479164123535, -19.702157974243164, -18.23944854736328, -16.784934997558594, -15.383912086486816, -14.348892211914062, -11.832124710083008, -11.340017318725586, -9.880157470703125, -9.182782173156738, -8.920133590698242, -7.186948299407959, -8.650290489196777, -6.933536529541016, -6.235667705535889, -5.246774673461914, -3.808237075805664, -0.0, -2.6984453201293945, -3.4819672107696533, -0.9557288885116577, -0.0, 0.0, 6.3730034828186035, 5.998733997344971, 4.094493389129639, 3.103607654571533, 3.0484485626220703, 1.0227583646774292, -0.03340508043766022], [-21.729249954223633, -18.510271072387695, -17.358531951904297, -16.285757064819336, -15.820466995239258, -13.070164680480957, -14.074459075927734, 0.0, 0.0, -11.17604923248291, -12.476346015930176, -10.419889450073242, -10.934405326843262, -10.003987312316895, -10.833211898803711, -10.367615699768066, -10.311980247497559, -11.151829719543457, -10.740106582641602, -10.595290184020996, -10.653462409973145, -11.465888023376465, -12.21313190460205, -12.215055465698242, -14.06960391998291, -14.379067420959473, -14.76832103729248, -14.28127384185791, -17.728391647338867, -17.50555419921875, -18.87702178955078, -22.4766845703125, -25.195859909057617, -26.58759307861328, -28.314706802368164, -28.924579620361328, -30.336549758911133, -31.889713287353516, -32.02622604370117, -32.44651794433594, -33.145973205566406, -29.369997024536133, -25.629371643066406, -29.770526885986328, -28.03754234313965, -23.02667236328125, -20.410907745361328, -22.826358795166016, -23.192312240600586, -20.531587600708008, -19.5081729888916, -18.18564224243164, -15.581873893737793, -14.311185836791992, -13.422226905822754, -12.025516510009766, -10.811969757080078, -9.607322692871094, -9.350255012512207, -7.4496917724609375, -7.470978736877441, -6.665092945098877, -4.564301013946533, -3.9776976108551025, -5.8260908126831055, -5.591324806213379, 0.0, -4.166645526885986, -1.5672788619995117, 0.0, 0.0, 5.815134525299072, 5.026247501373291, 3.316650867462158, 4.301219940185547, 3.084174394607544, 2.1906981468200684, 0.8880151510238647, -21.729249954223633, -18.510271072387695, -17.358531951904297, -16.285757064819336, -15.820466995239258, -13.070164680480957, -14.074459075927734, -0.0, -0.0, -11.17604923248291, -12.476346015930176, -10.419889450073242, -10.934405326843262, -10.003987312316895, -10.833211898803711, -10.367615699768066, -10.311980247497559, -11.151829719543457, -10.740106582641602, -10.595290184020996, -10.653462409973145, -11.465888023376465, -12.21313190460205, -12.215055465698242, -14.06960391998291, -14.379067420959473, -14.76832103729248, -14.28127384185791, -17.67671775817871, -18.854177474975586, -20.359169006347656, -22.015682220458984, -23.660049438476562, -25.11246109008789, -26.38528823852539, -27.49455451965332, -28.439125061035156, -29.218000411987305, -29.79277229309082, -30.104368209838867, -30.10780906677246, -29.836111068725586, -29.30011558532715, -28.500301361083984, -27.46710777282715, -26.270727157592773, -24.985645294189453, -23.628459930419922, -22.191720962524414, -20.701902389526367, -19.19588851928711, -17.712177276611328, -16.199378967285156, -14.408836364746094, -13.422226905822754, -12.025516510009766, -10.811969757080078, -9.607322692871094, -9.350255012512207, -7.4496917724609375, -7.470978736877441, -6.665092945098877, -4.564301013946533, -3.9776976108551025, -5.8260908126831055, -5.591324806213379, -0.0, -4.166645526885986, -1.5672788619995117, -0.0, 0.0, 5.815134525299072, 5.026247501373291, 3.316650867462158, 4.301219940185547, 3.084174394607544, 2.1906981468200684, 0.8880151510238647], [-19.29503631591797, -18.14592170715332, -17.687578201293945, -16.717378616333008, -15.22275161743164, -13.282976150512695, -15.813812255859375, -13.643924713134766, 0.0, 0.0, -13.153002738952637, -11.606858253479004, -11.745895385742188, -10.730169296264648, -9.464747428894043, -10.02001667022705, -10.566446304321289, -10.582684516906738, -10.190827369689941, 0.0, -11.151612281799316, -10.690729141235352, -12.436929702758789, -13.905972480773926, -14.6508207321167, -15.52142333984375, -15.51169490814209, -17.473031997680664, -18.422983169555664, -21.210298538208008, -23.306949615478516, -23.33868980407715, -28.253686904907227, -27.813108444213867, -30.1390323638916, -27.410932540893555, -27.627119064331055, -31.128915786743164, -33.9511604309082, -34.98944854736328, -32.973976135253906, -30.112781524658203, -26.443687438964844, -26.083221435546875, -25.21714210510254, -23.638174057006836, -23.999046325683594, -26.984107971191406, -24.82941246032715, -22.428014755249023, -22.159753799438477, -19.64730453491211, -16.664560317993164, -17.06854820251465, -13.343246459960938, -12.297477722167969, -12.045684814453125, -9.935454368591309, -9.694809913635254, -8.73952579498291, -7.275977611541748, -6.433071136474609, -6.92582368850708, -6.135809421539307, -1.7024191617965698, -1.944650411605835, 0.0, -3.2483155727386475, 0.0, 0.0, 3.867356777191162, 5.469147682189941, 5.132040500640869, 3.3710129261016846, 3.4367668628692627, 2.3516335487365723, 1.3308274745941162, 0.0, -19.29503631591797, -18.14592170715332, -17.687578201293945, -16.717378616333008, -15.22275161743164, -13.282976150512695, -15.813812255859375, -13.643924713134766, -0.0, -0.0, -13.153002738952637, -11.606858253479004, -11.745895385742188, -10.730169296264648, -9.464747428894043, -10.02001667022705, -10.566446304321289, -10.582684516906738, -10.190827369689941, -0.0, -11.151612281799316, -10.690729141235352, -12.436929702758789, -13.905972480773926, -14.6508207321167, -15.52142333984375, -15.51169490814209, -17.473031997680664, -18.36298942565918, -19.70525360107422, -21.206605911254883, -22.88151741027832, -24.593591690063477, -26.15818977355957, -27.495847702026367, -28.64887237548828, -29.62028694152832, -30.43295669555664, -31.0649471282959, -31.43478012084961, -31.466337203979492, -31.187360763549805, -30.614124298095703, -29.77558708190918, -28.707517623901367, -27.473817825317383, -26.148061752319336, -24.73527717590332, -23.249448776245117, -21.717281341552734, -20.155378341674805, -18.584918975830078, -17.185243606567383, -16.447492599487305, -13.343246459960938, -12.297477722167969, -12.045684814453125, -9.935454368591309, -9.694809913635254, -8.73952579498291, -7.275977611541748, -6.433071136474609, -6.92582368850708, -6.135809421539307, -1.7024191617965698, -1.944650411605835, -0.0, -3.2483155727386475, -0.0, 0.0, 3.867356777191162, 5.469147682189941, 5.132040500640869, 3.3710129261016846, 3.4367668628692627, 2.3516335487365723, 1.3308274745941162, 0.0], [0.0, -20.987201690673828, -17.218429565429688, -17.720659255981445, -15.045980453491211, -14.182672500610352, -12.900174140930176, -12.843196868896484, -13.035323143005371, 0.0, 0.0, -12.038533210754395, -10.643994331359863, 0.0, -11.41773796081543, -10.073822021484375, -9.663623809814453, 0.0, -12.462645530700684, 0.0, 0.0, -12.81260871887207, -13.737499237060547, -16.00402069091797, -15.7249174118042, -16.58312225341797, -16.557985305786133, -16.732492446899414, -19.816139221191406, -21.22223472595215, -20.914661407470703, -23.281646728515625, -27.426191329956055, -24.36787986755371, -24.47340202331543, -26.093692779541016, -29.129247665405273, -35.015201568603516, -35.29105758666992, -33.35549545288086, -29.583587646484375, -30.531490325927734, -28.04566764831543, -28.615591049194336, -26.106130599975586, -25.809986114501953, -23.67186164855957, -26.99113655090332, -26.64996910095215, -25.037458419799805, -22.449172973632812, -18.812280654907227, -18.32059097290039, -15.497907638549805, -14.023141860961914, -13.676608085632324, -13.688117980957031, -11.156454086303711, -11.754544258117676, -9.58625602722168, -8.789169311523438, -6.7463226318359375, -7.041501045227051, -8.856904983520508, -3.5594608783721924, -1.7464662790298462, 0.0, 0.0, 0.0, 0.0, 5.025275230407715, 4.6951093673706055, 3.302976131439209, 4.869594097137451, 2.5086095333099365, 2.2883410453796387, -0.5180621147155762, 0.0, -0.0, -20.987201690673828, -17.218429565429688, -17.720659255981445, -15.045980453491211, -14.182672500610352, -12.900174140930176, -12.843196868896484, -13.035323143005371, -0.0, -0.0, -12.038533210754395, -10.643994331359863, -0.0, -11.41773796081543, -10.073822021484375, -9.663623809814453, -0.0, -12.462645530700684, -0.0, -0.0, -12.81260871887207, -13.737499237060547, -16.00402069091797, -15.7249174118042, -16.58312225341797, -16.557985305786133, -16.732492446899414, -19.557373046875, -20.57469367980957, -22.012596130371094, -23.680917739868164, -25.406034469604492, -27.068937301635742, -28.51157569885254, -29.693635940551758, -30.675498962402344, -31.48463249206543, -32.1539192199707, -32.666133880615234, -32.80411911010742, -32.48710250854492, -31.841543197631836, -30.950101852416992, -29.8424072265625, -28.565095901489258, -27.19974708557129, -25.762577056884766, -24.25978660583496, -22.711044311523438, -21.113008499145508, -19.397939682006836, -17.63324546813965, -15.669121742248535, -14.023141860961914, -13.676608085632324, -13.688117980957031, -11.156454086303711, -11.754544258117676, -9.58625602722168, -8.789169311523438, -6.7463226318359375, -7.041501045227051, -8.856904983520508, -3.5594608783721924, -1.7464662790298462, -0.0, -0.0, -0.0, 0.0, 5.025275230407715, 4.6951093673706055, 3.302976131439209, 4.869594097137451, 2.5086095333099365, 2.2883410453796387, -0.5180621147155762, -0.0], [0.0, -20.225069046020508, -17.472145080566406, -16.633092880249023, -15.15123462677002, -16.532590866088867, -14.408025741577148, -13.085502624511719, -12.01829719543457, -12.955109596252441, 0.0, 0.0, -11.349974632263184, -8.022953033447266, -9.223176956176758, -10.403928756713867, -10.981709480285645, -10.472599983215332, -10.736246109008789, -12.104992866516113, -15.246973037719727, -12.083342552185059, -15.839882850646973, -15.7210111618042, -17.749267578125, -14.724961280822754, -19.136695861816406, -18.95062255859375, -19.3438663482666, -22.57637596130371, -22.952573776245117, -22.790199279785156, -27.826622009277344, -25.006635665893555, -26.724613189697266, -27.639863967895508, -29.73127555847168, -30.953516006469727, -31.7945499420166, -31.944156646728516, -30.765684127807617, -33.111427307128906, -29.865154266357422, -29.368995666503906, -28.1182918548584, -26.661882400512695, -31.452518463134766, -28.97934341430664, -26.82471466064453, -23.547536849975586, -23.845680236816406, -21.045297622680664, -18.731842041015625, -16.15384864807129, -16.21363639831543, -14.445175170898438, -13.754247665405273, -13.261768341064453, -11.595464706420898, 0.0, 0.0, 0.0, 0.0, -7.5930352210998535, -6.343379020690918, 0.0, 0.0, -3.11336088180542, 0.0, 0.0, 4.088511943817139, 3.323943853378296, 3.373713493347168, 2.8926219940185547, 2.4493651390075684, 2.2383484840393066, 0.0, 0.0, -0.0, -20.225069046020508, -17.472145080566406, -16.633092880249023, -15.15123462677002, -16.532590866088867, -14.408025741577148, -13.085502624511719, -12.01829719543457, -12.955109596252441, -0.0, -0.0, -11.349974632263184, -8.022953033447266, -9.223176956176758, -10.403928756713867, -10.981709480285645, -10.472599983215332, -10.736246109008789, -12.104992866516113, -15.246973037719727, -12.083342552185059, -15.839882850646973, -15.7210111618042, -17.749267578125, -14.724961280822754, -19.136695861816406, -18.95062255859375, -19.555217742919922, -21.22699737548828, -22.810773849487305, -24.4349422454834, -26.11178207397461, -27.789257049560547, -29.33799934387207, -30.614919662475586, -31.610631942749023, -32.38155746459961, -33.01848602294922, -33.7463493347168, -34.0810546875, -33.66617202758789, -32.929744720458984, -31.975940704345703, -30.80752182006836, -29.494125366210938, -28.11602783203125, -26.676897048950195, -25.17609977722168, -23.626588821411133, -21.990930557250977, -20.237186431884766, -18.350866317749023, -16.35348129272461, -16.21363639831543, -14.445175170898438, -13.754247665405273, -13.261768341064453, -11.595464706420898, -0.0, -0.0, -0.0, -0.0, -7.5930352210998535, -6.343379020690918, -0.0, -0.0, -3.11336088180542, 0.0, 0.0, 4.088511943817139, 3.323943853378296, 3.373713493347168, 2.8926219940185547, 2.4493651390075684, 2.2383484840393066, -0.0, -0.0], [0.0, 0.0, -14.8689546585083, -15.912918090820312, -15.031193733215332, -15.52226734161377, -13.963736534118652, -13.613082885742188, -12.851457595825195, -12.000128746032715, -11.808526039123535, -11.042667388916016, 0.0, 0.0, 0.0, -11.232903480529785, -11.527002334594727, -11.289938926696777, -10.887198448181152, 0.0, -15.896364212036133, -13.404993057250977, -16.57509994506836, -16.505653381347656, -17.504358291625977, -17.684886932373047, -19.69003677368164, -19.812185287475586, -20.86208152770996, -22.72005271911621, -24.93122100830078, -26.58024024963379, -28.87751579284668, -25.231327056884766, -27.636260986328125, -30.446393966674805, -32.41552734375, -30.246871948242188, -32.28886032104492, -32.843265533447266, -32.83916091918945, -32.46174240112305, -31.520870208740234, -31.508699417114258, -29.483501434326172, -29.45194435119629, -31.446142196655273, -31.506593704223633, -27.690105438232422, -26.99936294555664, -24.405641555786133, -22.633991241455078, -17.544029235839844, -17.962663650512695, -15.871574401855469, -15.79996109008789, -14.722185134887695, -15.589118003845215, 0.0, 0.0, 0.0, -9.47042465209961, -9.402088165283203, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.2601583003997803, 2.8176145553588867, 4.105351448059082, 2.464109182357788, 2.672128200531006, 1.1820032596588135, 0.0, 0.0, 0.0, -0.0, -0.0, -14.8689546585083, -15.912918090820312, -15.031193733215332, -15.52226734161377, -13.963736534118652, -13.613082885742188, -12.851457595825195, -12.000128746032715, -11.808526039123535, -11.042667388916016, -0.0, -0.0, -0.0, -11.232903480529785, -11.527002334594727, -11.289938926696777, -10.887198448181152, -0.0, -15.896364212036133, -13.404993057250977, -16.57509994506836, -16.505653381347656, -17.504358291625977, -17.684886932373047, -19.69003677368164, -19.812185287475586, -20.805505752563477, -22.113739013671875, -23.567733764648438, -25.11419105529785, -26.72366714477539, -28.366979598999023, -29.978919982910156, -31.399568557739258, -32.40242004394531, -33.17723083496094, -33.92298889160156, -34.63896560668945, -34.90160369873047, -34.54158020019531, -33.818790435791016, -32.808414459228516, -31.569705963134766, -30.23413848876953, -28.86524200439453, -27.452457427978516, -25.993696212768555, -24.474559783935547, -22.86389923095703, -21.15156364440918, -19.322477340698242, -17.53375244140625, -15.871574401855469, -15.79996109008789, -14.722185134887695, -15.589118003845215, -0.0, -0.0, -0.0, -9.47042465209961, -9.402088165283203, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 3.2601583003997803, 2.8176145553588867, 4.105351448059082, 2.464109182357788, 2.672128200531006, 1.1820032596588135, 0.0, 0.0, -0.0], [-22.29736328125, 0.0, 0.0, -17.60724449157715, -15.938912391662598, -15.187337875366211, -14.16089916229248, -13.866385459899902, -12.365945816040039, -13.510133743286133, -11.35655403137207, -11.626502990722656, -11.011425971984863, 0.0, 0.0, -11.232847213745117, -13.52629280090332, -11.429471015930176, -12.367385864257812, -17.5736141204834, -16.193628311157227, 0.0, -19.04558753967285, -16.8309326171875, -19.11304473876953, -16.691692352294922, -20.586715698242188, -21.037635803222656, -21.871170043945312, -23.951295852661133, -26.104219436645508, -27.505727767944336, -24.248449325561523, -27.32257080078125, -28.977764129638672, -30.990951538085938, -32.00613021850586, -31.825105667114258, 0.0, 0.0, -34.17374801635742, -34.66889572143555, -32.60519790649414, -31.817995071411133, -29.922903060913086, -30.084850311279297, -32.24709701538086, -26.707517623901367, -25.160795211791992, -27.361011505126953, -27.170917510986328, -23.691617965698242, -21.97614860534668, -17.692527770996094, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.0308139324188232, 0.797488272190094, 2.7990846633911133, 1.378914713859558, 2.6809728145599365, 0.752608060836792, 0.0, 0.0, 0.0, -22.29736328125, -0.0, -0.0, -17.60724449157715, -15.938912391662598, -15.187337875366211, -14.16089916229248, -13.866385459899902, -12.365945816040039, -13.510133743286133, -11.35655403137207, -11.626502990722656, -11.011425971984863, -0.0, -0.0, -11.232847213745117, -13.52629280090332, -11.429471015930176, -12.367385864257812, -17.5736141204834, -16.193628311157227, -0.0, -19.04558753967285, -16.8309326171875, -19.11304473876953, -16.691692352294922, -20.586715698242188, -21.037635803222656, -21.79155921936035, -22.986663818359375, -24.288724899291992, -25.72246742248535, -27.263776779174805, -28.868572235107422, -30.53544807434082, -32.0164909362793, -33.119102478027344, -34.01689910888672, -0.0, -0.0, -35.10247039794922, -34.92742156982422, -34.42692947387695, -33.364261627197266, -32.10713195800781, -30.788673400878906, -29.46160888671875, -28.095623016357422, -26.701841354370117, -25.28169822692871, -23.76529312133789, -22.078107833862305, -20.12920379638672, -17.670978546142578, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 3.0308139324188232, 0.797488272190094, 2.7990846633911133, 1.378914713859558, 2.6809728145599365, 0.752608060836792, 0.0, 0.0, 0.0], [0.0, -25.514524459838867, -22.573266983032227, 0.0, -16.294586181640625, -16.252185821533203, -17.348901748657227, -15.054996490478516, -13.796834945678711, -12.996424674987793, -10.585589408874512, -12.411527633666992, -11.557096481323242, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.883512496948242, 0.0, -22.669240951538086, -20.092819213867188, 0.0, -17.39252471923828, -22.674121856689453, -23.120508193969727, -20.93817901611328, -22.804523468017578, -24.92957305908203, -26.337759017944336, -28.740257263183594, -24.01549530029297, -26.991003036499023, -29.436046600341797, -28.64333152770996, -28.415081024169922, -33.759735107421875, 0.0, 0.0, -34.001304626464844, -33.64864730834961, -32.102508544921875, -33.139404296875, -31.64034080505371, -31.025630950927734, -29.383241653442383, -26.541467666625977, -23.94542121887207, -23.54212760925293, -26.954875946044922, -22.724525451660156, -20.85765838623047, -19.728729248046875, -15.2023286819458, 0.0, 0.0, -13.599905014038086, -10.913307189941406, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.5228670835494995, 2.318382740020752, 2.155080795288086, 0.9164208769798279, 1.1599369049072266, 1.733474612236023, 0.2282353937625885, 0.0, 0.0, 0.0, -0.0, -25.514524459838867, -22.573266983032227, -0.0, -16.294586181640625, -16.252185821533203, -17.348901748657227, -15.054996490478516, -13.796834945678711, -12.996424674987793, -10.585589408874512, -12.411527633666992, -11.557096481323242, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.883512496948242, -0.0, -22.669240951538086, -20.092819213867188, -0.0, -17.39252471923828, -22.674121856689453, -23.120508193969727, -20.93817901611328, -22.632450103759766, -23.829442977905273, -24.936403274536133, -26.258800506591797, -27.76312255859375, -29.33539581298828, -30.929346084594727, -32.43587875366211, -33.62614440917969, -34.542137145996094, -0.0, -0.0, -35.25576400756836, -35.00762176513672, -34.42795181274414, -33.51787185668945, -32.392032623291016, -31.18193244934082, -29.928823471069336, -28.60206413269043, -27.262189865112305, -26.026630401611328, -24.67769432067871, -22.99131202697754, -21.14741325378418, -19.29644775390625, -15.2023286819458, -0.0, -0.0, -13.599905014038086, -10.913307189941406, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.5228670835494995, 2.318382740020752, 2.155080795288086, 0.9164208769798279, 1.1599369049072266, 1.733474612236023, 0.2282353937625885, 0.0, 0.0, 0.0], [0.0, -24.056804656982422, 0.0, 0.0, -14.147107124328613, -16.320308685302734, -15.9352388381958, -17.59695053100586, -13.569578170776367, -13.048733711242676, -12.107217788696289, -12.2887601852417, -13.777103424072266, -12.438339233398438, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.920854568481445, 0.0, -20.43640899658203, -25.246822357177734, -25.951927185058594, -25.561092376708984, -25.043943405151367, -25.328031539916992, -26.46335792541504, -29.32765769958496, -26.90969467163086, -27.872732162475586, -31.18889808654785, -32.510555267333984, -30.38587188720703, -33.10667419433594, 0.0, 0.0, -34.771942138671875, -32.72894287109375, -31.159664154052734, -33.969337463378906, -33.51943588256836, -30.138978958129883, -31.386985778808594, -29.926862716674805, -26.894189834594727, -25.3031005859375, -27.709455490112305, -27.20269203186035, -22.003385543823242, -20.238525390625, -16.179988861083984, 0.0, 0.0, 0.0, -10.883264541625977, -13.808725357055664, 0.0, -10.695937156677246, -11.074136734008789, 0.0, 0.0, 0.0, 0.0, 0.0, 0.1513495296239853, 1.4385719299316406, 3.2092809677124023, 1.621907114982605, 1.4918878078460693, 0.9589635729789734, 0.0, 0.0, 0.0, 0.0, -0.0, -24.056804656982422, -0.0, -0.0, -14.147107124328613, -16.320308685302734, -15.9352388381958, -17.59695053100586, -13.569578170776367, -13.048733711242676, -12.107217788696289, -12.2887601852417, -13.777103424072266, -12.438339233398438, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.920854568481445, -0.0, -20.43640899658203, -25.246822357177734, -25.951927185058594, -25.561092376708984, -24.219003677368164, -24.463611602783203, -25.43362808227539, -26.74772071838379, -28.23111915588379, -29.81397247314453, -31.40323829650879, -32.698692321777344, -33.755130767822266, -34.6969108581543, -0.0, -0.0, -34.9971923828125, -34.72332000732422, -34.12049865722656, -33.27399444580078, -32.458011627197266, -31.479251861572266, -30.326265335083008, -29.02630043029785, -27.636615753173828, -26.68438720703125, -25.590150833129883, -23.825902938842773, -21.95818328857422, -19.934621810913086, -16.179988861083984, -0.0, -0.0, -0.0, -10.883264541625977, -13.808725357055664, -0.0, -10.695937156677246, -11.074136734008789, -0.0, -0.0, -0.0, 0.0, 0.0, 0.1513495296239853, 1.4385719299316406, 3.2092809677124023, 1.621907114982605, 1.4918878078460693, 0.9589635729789734, 0.0, 0.0, 0.0, 0.0], [-22.809358596801758, -23.163131713867188, -19.820493698120117, 0.0, 0.0, -16.78494644165039, -15.62502670288086, -15.032190322875977, -15.041064262390137, -14.061756134033203, -13.550447463989258, -12.968873023986816, -12.531534194946289, -12.807778358459473, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.37630271911621, -22.951725006103516, 0.0, -22.002328872680664, 0.0, -27.551620483398438, -28.833324432373047, -26.427337646484375, -27.467998504638672, -32.1733283996582, -32.11625671386719, 0.0, -33.8822135925293, -33.578521728515625, 0.0, 0.0, -34.20133972167969, -34.2943000793457, -32.92424392700195, -29.75615692138672, -29.776439666748047, -29.781932830810547, -29.851009368896484, -28.114925384521484, -26.69351577758789, -29.49755859375, -27.467653274536133, -23.891706466674805, -20.800806045532227, 0.0, -17.878273010253906, -16.472999572753906, -16.607927322387695, -12.492691040039062, -11.393576622009277, 0.0, 0.0, -12.748621940612793, -14.363980293273926, 0.0, 0.0, 0.0, 0.0, 0.0, -0.48360762000083923, -0.4383029639720917, 0.7627675533294678, 0.0694928765296936, 0.0, 0.0, 0.0, -2.6784183979034424, 0.0, -22.809358596801758, -23.163131713867188, -19.820493698120117, -0.0, -0.0, -16.78494644165039, -15.62502670288086, -15.032190322875977, -15.041064262390137, -14.061756134033203, -13.550447463989258, -12.968873023986816, -12.531534194946289, -12.807778358459473, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.37630271911621, -22.951725006103516, -0.0, -22.498321533203125, -0.0, -25.91877555847168, -27.291479110717773, -28.68177604675293, -30.266908645629883, -32.008358001708984, -33.02119827270508, -0.0, -34.32069778442383, -34.66650390625, -0.0, -0.0, -34.076927185058594, -33.58795928955078, -32.86355209350586, -32.32588195800781, -31.707275390625, -30.66669464111328, -29.453664779663086, -28.293575286865234, -27.225723266601562, -25.9600772857666, -24.434324264526367, -22.70611000061035, -20.61155891418457, -0.0, -17.878273010253906, -16.472999572753906, -16.607927322387695, -12.492691040039062, -11.393576622009277, -0.0, -0.0, -12.748621940612793, -14.363980293273926, -0.0, -0.0, 0.0, 0.0, 0.0, -0.48360762000083923, -0.4383029639720917, 0.7627675533294678, 0.0694928765296936, 0.0, 0.0, -0.0, -2.6784183979034424, 0.0], [-25.138235092163086, -23.524179458618164, -21.325153350830078, 0.0, 0.0, 0.0, -13.537497520446777, -15.386693954467773, -15.053302764892578, -13.5855073928833, -13.691889762878418, -12.30746078491211, -13.319872856140137, -13.672422409057617, 0.0, 0.0, -8.642682075500488, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.614091873168945, -23.07846450805664, -22.82818031311035, -24.991548538208008, 0.0, 0.0, -30.8524112701416, -29.82163429260254, -26.448707580566406, 0.0, -33.54384231567383, 0.0, 0.0, -31.080638885498047, -33.82240295410156, -29.950210571289062, -27.921327590942383, -32.34514236450195, -30.06426429748535, -34.1711311340332, -31.23308753967285, -32.91630554199219, -31.616708755493164, -32.264244079589844, -28.8319149017334, -27.879600524902344, -31.514562606811523, -28.62314224243164, -25.154163360595703, -22.87238311767578, 0.0, -19.643943786621094, -14.821935653686523, -14.345246315002441, -13.664654731750488, -13.64107608795166, -13.591729164123535, 0.0, -14.902722358703613, 0.0, 0.0, 0.0, 0.0, 0.0, -0.9414496421813965, -0.2541959285736084, -0.08639533817768097, -0.48350346088409424, 0.4504033327102661, 0.0, 0.0, 0.0, 0.0, 6.715995788574219, -25.138235092163086, -23.524179458618164, -21.325153350830078, -0.0, -0.0, -0.0, -13.537497520446777, -15.386693954467773, -15.053302764892578, -13.5855073928833, -13.691889762878418, -12.30746078491211, -13.319872856140137, -13.672422409057617, -0.0, -0.0, -8.642682075500488, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.614091873168945, -23.07846450805664, -22.82818031311035, -24.991548538208008, -0.0, -0.0, -26.582704544067383, -27.95047950744629, -29.198862075805664, -0.0, -32.191436767578125, -0.0, -0.0, -33.704994201660156, -33.48809814453125, -33.428077697753906, -33.30577850341797, -33.15721893310547, -32.805423736572266, -32.129756927490234, -31.670618057250977, -31.4193115234375, -30.777528762817383, -29.566204071044922, -28.55776023864746, -27.634000778198242, -26.346492767333984, -24.91134262084961, -23.52207374572754, -22.232254028320312, -0.0, -19.643943786621094, -14.821935653686523, -14.345246315002441, -13.664654731750488, -13.64107608795166, -13.591729164123535, -0.0, -14.902722358703613, -0.0, -0.0, -0.0, -0.0, -0.0, -0.9414496421813965, -0.2541959285736084, -0.08639533817768097, -0.48350346088409424, 0.4504033327102661, 0.0, -0.0, -0.0, 0.0, 6.715995788574219], [-25.23065185546875, -23.781530380249023, -22.840106964111328, 0.0, 0.0, 0.0, -16.184457778930664, -15.85274600982666, -15.259528160095215, -13.54428768157959, -11.71980094909668, -13.536775588989258, -13.725391387939453, -10.610679626464844, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -21.990745544433594, -24.233293533325195, -22.97823143005371, -23.93817138671875, -25.609298706054688, -27.07465171813965, -29.217313766479492, -27.532663345336914, -32.275474548339844, -27.178619384765625, -28.233200073242188, -33.35662841796875, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -31.226280212402344, -33.1513786315918, -31.778079986572266, -29.749679565429688, -28.29288673400879, -31.172590255737305, -27.42328453063965, -30.34311866760254, -26.402950286865234, -27.79460334777832, -25.11744499206543, 0.0, 0.0, -20.577960968017578, -18.989700317382812, -17.34266471862793, -15.436175346374512, -14.56065845489502, 0.0, 0.0, -12.261449813842773, 0.0, 0.0, 0.0, 0.0, 0.0, -0.8085665702819824, -1.4107303619384766, 0.1529553234577179, 0.10394639521837234, 0.12266188859939575, 0.0, 0.0, -0.921435534954071, 1.605143666267395, 4.2415852546691895, -25.23065185546875, -23.781530380249023, -22.840106964111328, -0.0, -0.0, -0.0, -16.184457778930664, -15.85274600982666, -15.259528160095215, -13.54428768157959, -11.71980094909668, -13.536775588989258, -13.725391387939453, -10.610679626464844, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -21.990745544433594, -24.233293533325195, -22.97823143005371, -23.93817138671875, -25.609298706054688, -26.395612716674805, -26.361312866210938, -27.400005340576172, -28.668182373046875, -29.843713760375977, -31.050697326660156, -32.28931427001953, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -31.602914810180664, -30.802587509155273, -30.479827880859375, -30.553640365600586, -30.18905258178711, -29.064960479736328, -28.389816284179688, -27.68608856201172, -26.48518180847168, -25.104602813720703, -23.853923797607422, -0.0, -0.0, -20.577960968017578, -18.989700317382812, -17.34266471862793, -15.436175346374512, -14.56065845489502, -0.0, -0.0, -12.261449813842773, -0.0, -0.0, -0.0, -0.0, -0.0, -0.8085665702819824, -1.4107303619384766, 0.1529553234577179, 0.10394639521837234, 0.12266188859939575, 0.0, -0.0, -0.921435534954071, 1.605143666267395, 4.2415852546691895], [-21.500431060791016, -20.383440017700195, -19.551984786987305, -21.532848358154297, 0.0, 0.0, 0.0, -16.97543716430664, -15.703368186950684, -13.369253158569336, -13.81079387664795, -13.291267395019531, -12.41933822631836, -11.237468719482422, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.873361587524414, -23.269319534301758, -26.130849838256836, -26.508962631225586, -26.970834732055664, 0.0, -27.13886833190918, -32.447975158691406, -29.525175094604492, -30.893543243408203, -31.698083877563477, -34.856632232666016, -34.69241714477539, -33.221858978271484, -33.58975601196289, -34.084049224853516, -30.422786712646484, -32.61400604248047, -32.82488250732422, -34.11007308959961, -34.809871673583984, 0.0, -30.858373641967773, -28.422832489013672, -26.444995880126953, -30.044761657714844, -28.325387954711914, -29.834623336791992, 0.0, 0.0, -22.927650451660156, -21.209476470947266, -18.105127334594727, -17.590600967407227, -16.483598709106445, -15.268598556518555, -17.83187484741211, 0.0, -11.98520278930664, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.969210624694824, -1.0648298263549805, -0.2623901069164276, -2.6644530296325684, 0.0, -1.4237321615219116, -1.8898413181304932, -1.9056950807571411, 0.0, -21.500431060791016, -20.383440017700195, -19.551984786987305, -21.532848358154297, -0.0, -0.0, -0.0, -16.97543716430664, -15.703368186950684, -13.369253158569336, -13.81079387664795, -13.291267395019531, -12.41933822631836, -11.237468719482422, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.873361587524414, -23.269319534301758, -26.130849838256836, -26.508962631225586, -26.658973693847656, -0.0, -28.182373046875, -29.38549041748047, -30.416654586791992, -31.400827407836914, -32.45098114013672, -32.92692184448242, -32.58979034423828, -32.0160026550293, -31.441879272460938, -30.8211612701416, -30.2296199798584, -30.057188034057617, -29.87775421142578, -29.486007690429688, -29.009607315063477, -0.0, -28.995317459106445, -28.285728454589844, -27.677797317504883, -26.945770263671875, -26.018508911132812, -24.901865005493164, -0.0, -0.0, -22.927650451660156, -21.209476470947266, -18.105127334594727, -17.590600967407227, -16.483598709106445, -15.268598556518555, -17.83187484741211, -0.0, -11.98520278930664, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -2.969210624694824, -1.0648298263549805, -0.2623901069164276, -2.6644530296325684, -0.0, -1.4237321615219116, -1.8898413181304932, -1.9056950807571411, -0.0], [-22.9249210357666, -22.120346069335938, 0.0, -24.234342575073242, 0.0, 0.0, 0.0, 0.0, -15.81086254119873, -14.828901290893555, -15.123973846435547, -13.502059936523438, -10.900736808776855, 0.0, -12.709129333496094, 0.0, 0.0, 0.0, 0.0, 0.0, -16.695816040039062, 0.0, 0.0, 0.0, -24.618881225585938, -23.604053497314453, -26.456411361694336, -26.422306060791016, 0.0, -26.893999099731445, -26.124902725219727, -27.930532455444336, -29.99580955505371, -31.57903480529785, -31.743331909179688, -32.340450286865234, -34.120750427246094, -34.75603103637695, -30.993804931640625, -31.555843353271484, -31.39073371887207, -32.82476806640625, -32.204872131347656, -33.05141830444336, -34.08363342285156, 0.0, 0.0, -26.350440979003906, -26.93352699279785, -30.59603500366211, -29.283832550048828, 0.0, 0.0, 0.0, 0.0, 0.0, -16.08316421508789, -16.34089469909668, -16.994688034057617, 0.0, 0.0, -13.479639053344727, -12.488016128540039, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.109232425689697, -2.9483776092529297, -1.4084362983703613, -0.3393706679344177, 0.0, -3.1919806003570557, -3.2341837882995605, 0.0, 0.0, -22.9249210357666, -22.120346069335938, -0.0, -24.234342575073242, -0.0, -0.0, -0.0, -0.0, -15.81086254119873, -14.828901290893555, -15.123973846435547, -13.502059936523438, -10.900736808776855, -0.0, -12.709129333496094, -0.0, -0.0, -0.0, -0.0, -0.0, -16.695816040039062, -0.0, -0.0, -0.0, -24.618881225585938, -23.604053497314453, -26.456411361694336, -26.422306060791016, -0.0, -27.755661010742188, -28.6800537109375, -29.813703536987305, -30.886159896850586, -31.727005004882812, -32.38145065307617, -32.36977767944336, -31.721609115600586, -30.90292739868164, -30.038684844970703, -29.29642677307129, -28.455032348632812, -27.87899398803711, -27.757051467895508, -27.671382904052734, -27.29510498046875, -0.0, -0.0, -27.0196590423584, -26.801786422729492, -26.227108001708984, -25.330623626708984, -0.0, -0.0, -0.0, -0.0, -0.0, -16.08316421508789, -16.34089469909668, -16.994688034057617, -0.0, -0.0, -13.479639053344727, -12.488016128540039, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.109232425689697, -2.9483776092529297, -1.4084362983703613, -0.3393706679344177, -0.0, -3.1919806003570557, -3.2341837882995605, -0.0, -0.0], [-26.044160842895508, -24.529529571533203, -23.14383316040039, -24.58011245727539, -24.522415161132812, 0.0, 0.0, 0.0, -14.76397705078125, -15.737028121948242, -13.174643516540527, -10.512433052062988, 0.0, 0.0, -11.935832023620605, 0.0, 0.0, 0.0, -15.888814926147461, -17.458036422729492, -18.16488265991211, -15.928157806396484, -18.488500595092773, -21.32021141052246, -22.110641479492188, 0.0, -26.278806686401367, -27.02870750427246, 0.0, 0.0, -28.918615341186523, -29.49398422241211, -31.35491180419922, -30.680742263793945, -32.28010559082031, -34.19850158691406, -34.76837158203125, -34.41680908203125, -33.11528015136719, -30.867788314819336, -34.411407470703125, -35.39882278442383, -32.186553955078125, -32.048057556152344, -32.66830825805664, 0.0, -25.763952255249023, 0.0, 0.0, -29.929691314697266, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.196779251098633, -16.670209884643555, -15.933694839477539, -15.0184965133667, -14.015596389770508, -14.104851722717285, -13.152813911437988, -13.980788230895996, 0.0, 0.0, 0.0, -6.398199558258057, 0.0, -6.399814605712891, -5.246278762817383, -1.3155932426452637, -3.4922282695770264, 0.0, -3.8125431537628174, -5.081548690795898, 0.0, 0.0, -26.044160842895508, -24.529529571533203, -23.14383316040039, -24.58011245727539, -24.522415161132812, -0.0, -0.0, -0.0, -14.76397705078125, -15.737028121948242, -13.174643516540527, -10.512433052062988, -0.0, -0.0, -11.935832023620605, -0.0, -0.0, -0.0, -15.888814926147461, -17.458036422729492, -18.16488265991211, -15.928157806396484, -18.488500595092773, -21.32021141052246, -22.110641479492188, -0.0, -26.278806686401367, -27.02870750427246, -0.0, -0.0, -29.049774169921875, -30.005191802978516, -30.93648338317871, -31.623626708984375, -31.918214797973633, -31.603973388671875, -30.75530242919922, -29.715728759765625, -28.58769989013672, -27.709716796875, -26.807628631591797, -26.041948318481445, -25.657655715942383, -25.510692596435547, -25.545883178710938, -0.0, -25.627511978149414, -0.0, -0.0, -25.58431053161621, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.196779251098633, -16.670209884643555, -15.933694839477539, -15.0184965133667, -14.015596389770508, -14.104851722717285, -13.152813911437988, -13.980788230895996, -0.0, -0.0, -0.0, -6.398199558258057, -0.0, -6.399814605712891, -5.246278762817383, -1.3155932426452637, -3.4922282695770264, -0.0, -3.8125431537628174, -5.081548690795898, -0.0, -0.0], [0.0, -24.570117950439453, -24.331737518310547, 0.0, -21.368709564208984, -20.97770118713379, 0.0, 0.0, 0.0, -13.045082092285156, -14.688126564025879, 0.0, -10.736946105957031, 0.0, -13.53637409210205, -12.730557441711426, -16.605670928955078, -15.871163368225098, -16.26175308227539, -17.841209411621094, -18.613372802734375, -19.65750503540039, -20.243207931518555, -21.804054260253906, -23.28569793701172, -22.56110191345215, -24.41815757751465, 0.0, 0.0, 0.0, -29.38169288635254, -30.249217987060547, -31.22814178466797, -29.341474533081055, -33.01613235473633, -34.75019836425781, -33.68553161621094, -33.98125076293945, -32.90461730957031, -30.219764709472656, -33.53896713256836, -33.82646560668945, -35.38520431518555, -32.29507827758789, -29.802875518798828, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.169414520263672, 0.0, 0.0, 0.0, -18.290996551513672, -18.243745803833008, -17.700592041015625, -17.0362606048584, -17.141050338745117, -15.438019752502441, -15.438270568847656, -13.948210716247559, -13.942341804504395, -12.656939506530762, -12.582063674926758, -11.415777206420898, -9.47765064239502, 0.0, 0.0, 0.0, 0.0, 0.0, -5.4528279304504395, -4.905107498168945, -6.772224426269531, 0.0, 0.0, -0.0, -24.570117950439453, -24.331737518310547, -0.0, -21.368709564208984, -20.97770118713379, -0.0, -0.0, -0.0, -13.045082092285156, -14.688126564025879, -0.0, -10.736946105957031, -0.0, -13.53637409210205, -12.730557441711426, -16.605670928955078, -15.871163368225098, -16.26175308227539, -17.841209411621094, -18.613372802734375, -19.65750503540039, -20.243207931518555, -21.804054260253906, -23.28569793701172, -22.56110191345215, -24.41815757751465, -0.0, -0.0, -0.0, -29.089860916137695, -30.010133743286133, -30.728408813476562, -31.225330352783203, -31.377859115600586, -30.888269424438477, -29.938899993896484, -28.823060989379883, -27.850374221801758, -26.796533584594727, -25.54102325439453, -24.410720825195312, -23.734718322753906, -23.545738220214844, -23.836593627929688, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.72614097595215, -0.0, -0.0, -0.0, -18.290996551513672, -18.243745803833008, -17.700592041015625, -17.0362606048584, -17.141050338745117, -15.438019752502441, -15.438270568847656, -13.948210716247559, -13.942341804504395, -12.656939506530762, -12.582063674926758, -11.415777206420898, -9.47765064239502, -0.0, -0.0, -0.0, -0.0, -0.0, -5.4528279304504395, -4.905107498168945, -6.772224426269531, -0.0, -0.0], [0.0, -24.011396408081055, -21.0921573638916, 0.0, -24.54743194580078, -22.332775115966797, -18.674911499023438, 0.0, 0.0, 0.0, 0.0, 0.0, -11.064697265625, 0.0, -13.062246322631836, -12.999739646911621, -13.193939208984375, -16.0501708984375, -16.908252716064453, -18.26970672607422, -19.229459762573242, -19.89569091796875, -20.768983840942383, -22.476167678833008, -22.634565353393555, -23.728811264038086, -24.798925399780273, 0.0, 0.0, 0.0, -26.9288272857666, -29.70254135131836, -29.00067901611328, -30.834484100341797, 0.0, -30.698911666870117, -34.274776458740234, -33.1292724609375, -30.590255737304688, -29.755786895751953, -31.62042999267578, -33.88672637939453, -32.976600646972656, 0.0, 0.0, -25.092790603637695, -23.781330108642578, 0.0, 0.0, 0.0, 0.0, -25.562538146972656, 0.0, 0.0, -19.49393653869629, -19.560270309448242, -18.66463279724121, -18.867673873901367, -18.004199981689453, -16.884544372558594, -16.747421264648438, -16.59049415588379, -15.419724464416504, -15.0424222946167, -14.000434875488281, -12.31666374206543, -10.85230541229248, 0.0, -7.564879417419434, -5.704494953155518, 0.0, 0.0, 0.0, -4.731870174407959, -5.658993721008301, 0.0, 0.0, 0.0, -0.0, -24.011396408081055, -21.0921573638916, -0.0, -24.54743194580078, -22.332775115966797, -18.674911499023438, -0.0, -0.0, -0.0, -0.0, -0.0, -11.064697265625, -0.0, -13.062246322631836, -12.999739646911621, -13.193939208984375, -16.0501708984375, -16.908252716064453, -18.26970672607422, -19.229459762573242, -19.89569091796875, -20.768983840942383, -22.476167678833008, -22.634565353393555, -23.728811264038086, -24.798925399780273, -0.0, -0.0, -0.0, -28.97120475769043, -29.950403213500977, -30.68126106262207, -31.08670425415039, -0.0, -30.584360122680664, -29.77901840209961, -28.73465919494629, -27.788890838623047, -26.46242904663086, -25.077659606933594, -23.6485652923584, -22.718666076660156, -0.0, -0.0, -22.861623764038086, -23.683258056640625, -0.0, -0.0, -0.0, -0.0, -22.293970108032227, -0.0, -0.0, -19.49393653869629, -19.560270309448242, -18.66463279724121, -18.867673873901367, -18.004199981689453, -16.884544372558594, -16.747421264648438, -16.59049415588379, -15.419724464416504, -15.0424222946167, -14.000434875488281, -12.31666374206543, -10.85230541229248, -0.0, -7.564879417419434, -5.704494953155518, -0.0, -0.0, -0.0, -4.731870174407959, -5.658993721008301, -0.0, -0.0, -0.0], [0.0, -20.92562484741211, -20.563819885253906, 0.0, 0.0, -23.781007766723633, -22.42314910888672, 0.0, 0.0, 0.0, 0.0, 0.0, -11.07157039642334, -13.066997528076172, -13.60396671295166, -12.608663558959961, -14.894913673400879, -15.64030647277832, -17.367528915405273, -18.141468048095703, -19.12305450439453, -20.191370010375977, -21.45792579650879, -22.487512588500977, -22.998092651367188, -24.118318557739258, -24.434406280517578, -25.649221420288086, 0.0, 0.0, -28.484148025512695, -30.367881774902344, -28.396760940551758, -29.989070892333984, -30.529834747314453, 0.0, -29.540828704833984, -32.939640045166016, -31.776859283447266, -29.938201904296875, -31.718225479125977, -30.482845306396484, -30.537412643432617, 0.0, -25.538415908813477, -26.651592254638672, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.25227165222168, -19.583959579467773, -19.667306900024414, -19.737512588500977, -18.354907989501953, -17.918222427368164, -17.784896850585938, -17.608196258544922, -16.222900390625, -15.417314529418945, -14.755597114562988, -13.972886085510254, -12.232041358947754, -9.836797714233398, -9.749183654785156, -7.988246917724609, 0.0, 0.0, 0.0, -2.195024013519287, -2.213566780090332, 0.0, 0.0, 0.0, -0.0, -20.92562484741211, -20.563819885253906, -0.0, -0.0, -23.781007766723633, -22.42314910888672, -0.0, -0.0, -0.0, -0.0, -0.0, -11.07157039642334, -13.066997528076172, -13.60396671295166, -12.608663558959961, -14.894913673400879, -15.64030647277832, -17.367528915405273, -18.141468048095703, -19.12305450439453, -20.191370010375977, -21.45792579650879, -22.487512588500977, -22.998092651367188, -24.118318557739258, -24.434406280517578, -25.649221420288086, -0.0, -0.0, -28.993850708007812, -30.03830909729004, -30.781856536865234, -31.09234619140625, -30.9990291595459, -0.0, -29.788145065307617, -28.944747924804688, -27.918413162231445, -26.6394100189209, -25.220449447631836, -23.717267990112305, -22.66066551208496, -0.0, -21.786521911621094, -22.479999542236328, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.25227165222168, -19.583959579467773, -19.667306900024414, -19.737512588500977, -18.354907989501953, -17.918222427368164, -17.784896850585938, -17.608196258544922, -16.222900390625, -15.417314529418945, -14.755597114562988, -13.972886085510254, -12.232041358947754, -9.836797714233398, -9.749183654785156, -7.988246917724609, -0.0, -0.0, -0.0, -2.195024013519287, -2.213566780090332, -0.0, -0.0, -0.0], [0.0, -18.498693466186523, 0.0, 0.0, 0.0, -21.36155891418457, -23.080005645751953, 0.0, 0.0, 0.0, 0.0, -13.533296585083008, -10.946239471435547, -13.605496406555176, -11.577624320983887, -14.185824394226074, -14.70766544342041, -15.955007553100586, -16.163339614868164, -17.77984619140625, -19.11504364013672, -21.03659439086914, -21.858308792114258, -23.022220611572266, -23.62828826904297, -24.70608901977539, -25.07437515258789, -26.446184158325195, -27.370397567749023, 0.0, -31.962678909301758, -29.19246482849121, -29.059486389160156, -31.88187599182129, 0.0, -31.980865478515625, -32.510841369628906, -34.07899856567383, -33.77443313598633, -32.24635314941406, -32.276519775390625, -32.01167297363281, -26.961238861083984, -28.78710174560547, 0.0, 0.0, -25.69709587097168, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.087200164794922, -18.63437843322754, -19.766759872436523, -19.716291427612305, -19.762784957885742, -19.37381362915039, -19.362714767456055, -18.379377365112305, -17.59309959411621, -17.17474937438965, -16.18471336364746, -15.330183982849121, -13.50920581817627, -12.279009819030762, -11.172769546508789, 0.0, 0.0, 0.0, 0.0, 0.0, -3.8055410385131836, -3.356034994125366, 0.0, 0.0, 0.0, -0.0, -18.498693466186523, -0.0, -0.0, -0.0, -21.36155891418457, -23.080005645751953, -0.0, -0.0, -0.0, -0.0, -13.533296585083008, -10.946239471435547, -13.605496406555176, -11.577624320983887, -14.185824394226074, -14.70766544342041, -15.955007553100586, -16.163339614868164, -17.77984619140625, -19.11504364013672, -21.03659439086914, -21.858308792114258, -23.022220611572266, -23.62828826904297, -24.70608901977539, -25.07437515258789, -26.446184158325195, -27.221237182617188, -0.0, -29.151994705200195, -30.28819465637207, -30.78892707824707, -30.8299560546875, -0.0, -30.713645935058594, -30.070043563842773, -29.452268600463867, -28.433944702148438, -27.178083419799805, -25.61091423034668, -24.03238296508789, -23.030963897705078, -22.419071197509766, -0.0, -0.0, -22.91050910949707, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.214181900024414, -18.63437843322754, -19.766759872436523, -19.716291427612305, -19.762784957885742, -19.37381362915039, -19.362714767456055, -18.379377365112305, -17.59309959411621, -17.17474937438965, -16.18471336364746, -15.330183982849121, -13.50920581817627, -12.279009819030762, -11.172769546508789, -0.0, -0.0, -0.0, -0.0, -0.0, -3.8055410385131836, -3.356034994125366, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -22.809307098388672, -20.80375099182129, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.777928352355957, -12.065624237060547, -13.707443237304688, -14.23994255065918, -15.287914276123047, -16.64009666442871, -17.86821174621582, -18.738351821899414, -19.893918991088867, -21.433761596679688, -22.582721710205078, -23.60042953491211, -25.02536392211914, -25.37996482849121, -26.51752471923828, -26.316896438598633, 0.0, -29.59987449645996, -29.81850242614746, 0.0, -32.76620864868164, 0.0, 0.0, 0.0, 0.0, -33.57099914550781, -33.41428756713867, -34.15656661987305, -30.05358123779297, -27.441024780273438, -28.60110855102539, -28.020360946655273, -26.68404197692871, -26.86695671081543, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.147624969482422, -19.556644439697266, -20.277387619018555, -20.288339614868164, -19.793842315673828, -20.511953353881836, -19.875133514404297, -19.056232452392578, -18.968259811401367, -17.818559646606445, -16.490861892700195, -15.007741928100586, -13.507119178771973, -12.323304176330566, -10.265392303466797, 0.0, 0.0, 0.0, 0.0, 0.0, -3.71931529045105, -5.058015823364258, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.809307098388672, -20.80375099182129, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.777928352355957, -12.065624237060547, -13.707443237304688, -14.23994255065918, -15.287914276123047, -16.64009666442871, -17.86821174621582, -18.738351821899414, -19.893918991088867, -21.433761596679688, -22.582721710205078, -23.60042953491211, -25.02536392211914, -25.37996482849121, -26.51752471923828, -26.634912490844727, -0.0, -29.30849838256836, -30.47633171081543, -0.0, -30.696063995361328, -0.0, -0.0, -0.0, -0.0, -29.481369018554688, -27.95694923400879, -26.166292190551758, -24.737552642822266, -23.82232093811035, -23.246219635009766, -22.98379135131836, -22.974531173706055, -23.138925552368164, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.26140785217285, -19.556644439697266, -20.277387619018555, -20.288339614868164, -19.793842315673828, -20.511953353881836, -19.875133514404297, -19.056232452392578, -18.968259811401367, -17.818559646606445, -16.490861892700195, -15.007741928100586, -13.507119178771973, -12.323304176330566, -10.265392303466797, -0.0, -0.0, -0.0, -0.0, -0.0, -3.71931529045105, -5.058015823364258, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -23.461563110351562, -23.656681060791016, 0.0, 0.0, 0.0, -16.036949157714844, -14.585031509399414, -11.270604133605957, -12.851046562194824, -13.342489242553711, -13.399133682250977, -13.422436714172363, -14.729598045349121, -15.826699256896973, -17.493440628051758, -18.669078826904297, -20.606266021728516, -21.561996459960938, -22.910703659057617, -23.637969970703125, -24.889951705932617, -25.422924041748047, -26.59221649169922, -26.665557861328125, 0.0, 0.0, -29.73099136352539, 0.0, -36.287418365478516, 0.0, 0.0, 0.0, 0.0, 0.0, -31.112258911132812, -29.712705612182617, -29.648792266845703, -30.337066650390625, -31.304290771484375, -27.258338928222656, 0.0, 0.0, -23.980287551879883, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.76499366760254, -20.644975662231445, -20.61104965209961, -20.98955535888672, -20.621381759643555, -20.203189849853516, -19.4748477935791, -19.185741424560547, -18.145736694335938, -16.58507537841797, -15.334071159362793, -13.294448852539062, -12.384647369384766, -11.563565254211426, 0.0, 0.0, 0.0, 0.0, 0.0, -7.583338260650635, -5.30366325378418, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.461563110351562, -23.656681060791016, -0.0, -0.0, -0.0, -16.036949157714844, -14.585031509399414, -11.270604133605957, -12.851046562194824, -13.342489242553711, -13.399133682250977, -13.422436714172363, -14.729598045349121, -15.826699256896973, -17.493440628051758, -18.669078826904297, -20.606266021728516, -21.561996459960938, -22.910703659057617, -23.637969970703125, -24.889951705932617, -25.422924041748047, -26.59221649169922, -26.903121948242188, -0.0, -0.0, -30.384546279907227, -0.0, -30.71224021911621, -0.0, -0.0, -0.0, -0.0, -0.0, -29.13949966430664, -27.392972946166992, -25.87213897705078, -24.784196853637695, -24.102222442626953, -23.71091079711914, -0.0, -0.0, -23.659107208251953, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.76499366760254, -20.644975662231445, -20.61104965209961, -20.98955535888672, -20.621381759643555, -20.203189849853516, -19.4748477935791, -19.185741424560547, -18.145736694335938, -16.58507537841797, -15.334071159362793, -13.294448852539062, -12.384647369384766, -11.563565254211426, -0.0, -0.0, -0.0, -0.0, -0.0, -7.583338260650635, -5.30366325378418, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.917093276977539, -16.825082778930664, -13.50862979888916, -10.142090797424316, -13.21466064453125, -12.78957748413086, -13.187915802001953, -13.571269989013672, -14.646676063537598, -15.929206848144531, -17.68386459350586, -19.330232620239258, -21.049678802490234, -22.582767486572266, -23.76188087463379, -25.122846603393555, -25.388118743896484, -26.22534942626953, -27.082244873046875, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -32.18240737915039, 0.0, -27.47871971130371, 0.0, 0.0, 0.0, -25.128787994384766, -26.442068099975586, 0.0, 0.0, 0.0, 0.0, 0.0, -19.706100463867188, -20.58219337463379, -20.41533851623535, -20.300159454345703, -20.532197952270508, -20.44989013671875, -19.98545265197754, -19.432676315307617, -18.57979965209961, -17.26860809326172, -16.203466415405273, -14.74213695526123, -13.702025413513184, -12.480512619018555, -10.659645080566406, 0.0, 0.0, 0.0, 0.0, 0.0, -6.612919807434082, -5.546131610870361, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.917093276977539, -16.825082778930664, -13.50862979888916, -10.142090797424316, -13.21466064453125, -12.78957748413086, -13.187915802001953, -13.571269989013672, -14.646676063537598, -15.929206848144531, -17.68386459350586, -19.330232620239258, -21.049678802490234, -22.582767486572266, -23.76188087463379, -25.122846603393555, -25.388118743896484, -26.22534942626953, -27.08207893371582, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.874120712280273, -0.0, -25.720064163208008, -0.0, -0.0, -0.0, -24.361093521118164, -24.274600982666016, -0.0, -0.0, -0.0, -0.0, -0.0, -20.216508865356445, -20.58219337463379, -20.41533851623535, -20.300159454345703, -20.532197952270508, -20.44989013671875, -19.98545265197754, -19.432676315307617, -18.57979965209961, -17.26860809326172, -16.203466415405273, -14.74213695526123, -13.702025413513184, -12.480512619018555, -10.659645080566406, -0.0, -0.0, -0.0, -0.0, -0.0, -6.612919807434082, -5.546131610870361, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.740683555603027, -14.687342643737793, -13.44302749633789, -14.886849403381348, -14.091326713562012, -12.574193000793457, -13.182738304138184, -12.897419929504395, -13.26569938659668, -14.006263732910156, -15.362196922302246, -17.113550186157227, -19.277591705322266, -20.80742073059082, -22.186246871948242, -23.546585083007812, -25.218896865844727, -26.043928146362305, -26.68010139465332, -26.66441535949707, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -31.921903610229492, 0.0, -30.00830078125, 0.0, 0.0, 0.0, -22.94900131225586, -23.833112716674805, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.809654235839844, -20.535690307617188, -19.875686645507812, -19.993860244750977, -19.0054988861084, -21.663652420043945, 0.0, -14.869636535644531, -14.886072158813477, -14.975625991821289, -14.031014442443848, -13.139680862426758, -12.534919738769531, -8.94095516204834, 0.0, 0.0, 0.0, -12.929994583129883, -9.666788101196289, -6.812874794006348, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.740683555603027, -14.687342643737793, -13.44302749633789, -14.886849403381348, -14.091326713562012, -12.574193000793457, -13.182738304138184, -12.897419929504395, -13.26569938659668, -14.006263732910156, -15.362196922302246, -17.113550186157227, -19.277591705322266, -20.80742073059082, -22.186246871948242, -23.546585083007812, -25.218896865844727, -26.043928146362305, -26.665342330932617, -27.537878036499023, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -30.32054328918457, -0.0, -26.71120834350586, -0.0, -0.0, -0.0, -25.225343704223633, -25.186094284057617, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.809654235839844, -20.535690307617188, -19.875686645507812, -19.993860244750977, -19.0054988861084, -21.663652420043945, -0.0, -14.869636535644531, -14.886072158813477, -14.975625991821289, -14.031014442443848, -13.139680862426758, -12.534919738769531, -8.94095516204834, -0.0, -0.0, -0.0, -12.929994583129883, -9.666788101196289, -6.812874794006348, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.388033866882324, -15.441963195800781, -14.378623008728027, -14.61151123046875, -14.75584888458252, -12.651664733886719, -13.185528755187988, -13.468313217163086, -12.817886352539062, -12.690585136413574, -13.106829643249512, -14.546809196472168, -16.265323638916016, -19.344482421875, -19.972627639770508, -22.311487197875977, -23.337230682373047, -24.35115623474121, -25.489608764648438, -26.050268173217773, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.361520767211914, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.038803100585938, -19.429731369018555, 0.0, -16.326934814453125, -16.036340713500977, -16.63456916809082, 0.0, -12.736664772033691, -13.22037124633789, -13.098459243774414, -13.259492874145508, -13.895975112915039, 0.0, -12.180329322814941, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.388033866882324, -15.441963195800781, -14.378623008728027, -14.61151123046875, -14.75584888458252, -12.651664733886719, -13.185528755187988, -13.468313217163086, -12.817886352539062, -12.690585136413574, -13.106829643249512, -14.546809196472168, -16.265323638916016, -19.344482421875, -19.972627639770508, -22.311487197875977, -23.337230682373047, -24.35115623474121, -25.673437118530273, -26.72918128967285, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.721847534179688, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.038803100585938, -19.429731369018555, -0.0, -16.326934814453125, -16.036340713500977, -16.63456916809082, -0.0, -12.736664772033691, -13.22037124633789, -13.098459243774414, -13.259492874145508, -13.895975112915039, -0.0, -12.180329322814941, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.81022071838379, -27.309633255004883, 0.0, -11.000245094299316, -13.38193416595459, -16.322166442871094, -13.549742698669434, 0.0, -13.965497970581055, -15.307373046875, -14.247261047363281, -13.217835426330566, -13.067105293273926, -11.567339897155762, -11.539414405822754, -14.807074546813965, -16.709138870239258, -17.63150978088379, -19.71712875366211, -21.389747619628906, -21.83539581298828, -23.97273063659668, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -39.22486877441406, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.654414176940918, 0.0, -14.727954864501953, -14.928056716918945, -16.191303253173828, -16.65532112121582, -12.350608825683594, -11.425816535949707, -11.280807495117188, -12.009535789489746, -12.42034912109375, -13.160611152648926, -13.969690322875977, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.81022071838379, -27.309633255004883, -0.0, -11.000245094299316, -13.38193416595459, -16.322166442871094, -13.549742698669434, -0.0, -13.965497970581055, -15.307373046875, -14.247261047363281, -13.217835426330566, -13.067105293273926, -11.567339897155762, -11.539414405822754, -14.807074546813965, -16.709138870239258, -17.63150978088379, -19.71712875366211, -21.389747619628906, -21.83539581298828, -24.254316329956055, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -32.46874237060547, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.654414176940918, -0.0, -14.727954864501953, -14.928056716918945, -16.191303253173828, -16.65532112121582, -12.350608825683594, -11.425816535949707, -11.280807495117188, -12.009535789489746, -12.42034912109375, -13.160611152648926, -13.969690322875977, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.737092971801758, -20.91340446472168, -16.526321411132812, -14.232769012451172, 0.0, 0.0, 0.0, -15.358016967773438, -14.087881088256836, -15.569866180419922, -13.709218978881836, -12.094430923461914, -10.907705307006836, -11.081960678100586, -16.840187072753906, -16.328201293945312, -17.483224868774414, -18.568727493286133, -21.789838790893555, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.924083709716797, -16.08081817626953, -15.608309745788574, -15.40868854522705, -9.942973136901855, -11.66358757019043, -12.168312072753906, -12.187085151672363, -12.286483764648438, -13.54024600982666, -14.570439338684082, -13.161172866821289, -15.084463119506836, -11.749261856079102, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.737092971801758, -20.91340446472168, -16.526321411132812, -14.232769012451172, -0.0, -0.0, -0.0, -15.358016967773438, -14.087881088256836, -15.569866180419922, -13.709218978881836, -12.094430923461914, -10.907705307006836, -11.081960678100586, -16.840187072753906, -16.328201293945312, -17.483224868774414, -18.568727493286133, -21.789838790893555, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.924083709716797, -16.08081817626953, -15.608309745788574, -15.40868854522705, -9.942973136901855, -11.66358757019043, -12.168312072753906, -12.187085151672363, -12.286483764648438, -13.54024600982666, -14.570439338684082, -13.161172866821289, -15.084463119506836, -11.749261856079102, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.836389541625977, 0.0, 0.0, 0.0, -16.99456024169922, -16.52269744873047, -17.300228118896484, -11.806903839111328, -11.480405807495117, -12.836905479431152, -12.282265663146973, -16.174171447753906, -17.649545669555664, -18.978565216064453, -20.053436279296875, -19.42810821533203, -21.890966415405273, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.592952728271484, -12.013630867004395, -12.866684913635254, -12.522713661193848, -12.6222562789917, 0.0, 0.0, -13.480766296386719, -14.967741966247559, -17.156095504760742, -16.788665771484375, 0.0, -18.217586517333984, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.836389541625977, -0.0, -0.0, -0.0, -16.99456024169922, -16.52269744873047, -17.300228118896484, -11.806903839111328, -11.480405807495117, -12.836905479431152, -12.282265663146973, -16.174171447753906, -17.649545669555664, -18.978565216064453, -20.053436279296875, -19.42810821533203, -22.113622665405273, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.592952728271484, -12.013630867004395, -12.866684913635254, -12.522713661193848, -12.6222562789917, -0.0, -0.0, -13.480766296386719, -14.967741966247559, -17.156095504760742, -16.788665771484375, -0.0, -18.217586517333984, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.194493293762207, -10.379388809204102, -11.683971405029297, -10.756223678588867, 0.0, -15.723637580871582, -14.098050117492676, 0.0, -22.51275062561035, -18.85204315185547, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -34.22637176513672, 0.0, 0.0, 0.0, -28.409284591674805, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.512991905212402, -17.365760803222656, -15.58388614654541, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.194493293762207, -10.379388809204102, -11.683971405029297, -10.756223678588867, -0.0, -15.723637580871582, -14.098050117492676, -0.0, -22.51275062561035, -18.85204315185547, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -34.05699920654297, -0.0, -0.0, -0.0, -28.750944137573242, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.512991905212402, -17.365760803222656, -15.58388614654541, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.506804466247559, -12.316868782043457, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -32.017181396484375, -30.983274459838867, -28.120759963989258, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.80797004699707, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.506804466247559, -12.316868782043457, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -32.017181396484375, -30.983274459838867, -28.120759963989258, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.80797004699707, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.054281234741211, -14.513423919677734, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.825780868530273, -28.358501434326172, -29.322635650634766, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.302425384521484, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.054281234741211, -14.513423919677734, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.825780868530273, -28.358501434326172, -29.322635650634766, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.302425384521484, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.24878215789795, -10.818119049072266, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.76556396484375, -24.848024368286133, -25.12359046936035, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -21.358808517456055, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.24878215789795, -10.818119049072266, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.76556396484375, -24.848024368286133, -25.12359046936035, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -21.358808517456055, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.92416000366211, -27.239044189453125, -26.870100021362305, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.92416000366211, -27.239044189453125, -26.870100021362305, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.521516799926758, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.521516799926758, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0]]}, {\"colorbar\": {\"title\": {\"text\": \"B<sub>0</sub> (Hz)\"}}, \"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.3333333333333333, \"rgb(230,0,0)\"], [0.6666666666666666, \"rgb(255,210,0)\"], [1.0, \"rgb(255,255,255)\"]], \"name\": \"comparison heatmap\", \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 13.888554573059082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 13.888554573059082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 12.936906814575195, 15.142813682556152, 15.37894344329834, 12.819026947021484, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 12.936906814575195, 15.142813682556152, 15.37894344329834, 12.819026947021484, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 12.745701789855957, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 12.745701789855957, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.034546375274658, 0.0, 0.0, 0.0, 0.0, 10.227598190307617, 10.123236656188965, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.034546375274658, 0.0, 0.0, 0.0, 0.0, 10.227598190307617, 10.123236656188965, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.2589619159698486, 1.888104796409607, 0.0, 1.2655067443847656, 1.119844913482666, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.808061122894287, 8.394735336303711, 0.0, 0.0, 0.0, 11.475990295410156, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.2589619159698486, 1.888104796409607, 0.0, 1.2655067443847656, 1.119844913482666, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.808061122894287, 8.394735336303711, 0.0, 0.0, 0.0, 11.475990295410156, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5285759568214417, 1.5589162111282349, 3.521920680999756, 5.20359468460083, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.199588775634766, 6.945910930633545, 8.374185562133789, 7.821402549743652, 9.276713371276855, 9.09167766571045, 7.442110061645508, 7.157607078552246, 8.965181350708008, 8.961400032043457, 7.0052313804626465, 4.348233699798584, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5285759568214417, 1.5589162111282349, 3.521920680999756, 5.20359468460083, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.199588775634766, 6.945910930633545, 8.374185562133789, 7.821402549743652, 9.276713371276855, 9.09167766571045, 7.442110061645508, 7.157607078552246, 8.965181350708008, 8.961400032043457, 7.0052313804626465, 4.348233699798584, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.3571172952651978, 2.6926019191741943, 4.6558332443237305, 0.0, 7.798217296600342, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.86633038520813, 5.415731430053711, 2.8193302154541016, 4.895267009735107, 7.040090084075928, 6.282114505767822, 5.043661594390869, 6.876728534698486, 6.419947624206543, 6.529754638671875, 5.40814733505249, 5.976042747497559, 6.8362135887146, 6.687675476074219, 6.761521339416504, 6.265591621398926, 5.871891498565674, 6.401405334472656, 6.640430927276611, 7.225942611694336, 9.605871200561523, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -1.3571172952651978, 2.6926019191741943, 4.6558332443237305, 0.0, 7.798217296600342, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.86633038520813, 5.415731430053711, 2.8193302154541016, 4.895267009735107, 7.040090084075928, 6.282114505767822, 5.043661594390869, 6.876728534698486, 6.419947624206543, 6.529754638671875, 5.40814733505249, 5.976042747497559, 6.8362135887146, 6.687675476074219, 6.761521339416504, 6.265591621398926, 5.871891498565674, 6.401405334472656, 6.640430927276611, 7.225942611694336, 9.605871200561523, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.9123529195785522, 1.806760311126709, 0.0, 0.0, 6.941438674926758, 0.0, 8.126141548156738, 0.0, 4.314778804779053, 5.758121490478516, 4.72692346572876, 3.159705400466919, 4.160089492797852, 3.50000262260437, 1.6429903507232666, 2.611424446105957, 4.341375350952148, 2.526777982711792, 3.788926362991333, 4.479292869567871, 3.066035747528076, 0.0, 0.0, 6.0075602531433105, 4.908441543579102, 4.627430438995361, 7.098214626312256, 4.469549179077148, 4.903204917907715, 5.696014881134033, 4.185292720794678, 5.249809741973877, 6.848641395568848, 8.209607124328613, 4.524230003356934, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.9123529195785522, 1.806760311126709, 0.0, 0.0, 6.941438674926758, 0.0, 8.126141548156738, 0.0, 4.314778804779053, 5.758121490478516, 4.72692346572876, 3.159705400466919, 4.160089492797852, 3.50000262260437, 1.6429903507232666, 2.611424446105957, 4.341375350952148, 2.526777982711792, 3.788926362991333, 4.479292869567871, 3.066035747528076, 0.0, 0.0, 6.0075602531433105, 4.908441543579102, 4.627430438995361, 7.098214626312256, 4.469549179077148, 4.903204917907715, 5.696014881134033, 4.185292720794678, 5.249809741973877, 6.848641395568848, 8.209607124328613, 4.524230003356934, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.773061752319336, 5.268355369567871, 5.890433311462402, 1.7343261241912842, 4.050814628601074, 3.0758705139160156, 5.756180286407471, 2.915175676345825, 3.3110289573669434, 0.0, 2.2766737937927246, 0.0, 5.199783802032471, 0.0, 6.088670253753662, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.829176187515259, 1.3737026453018188, 3.218177080154419, 0.0, 2.855027675628662, 5.575257301330566, 5.765437602996826, 5.469160079956055, 5.816267490386963, 7.182384490966797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.773061752319336, 5.268355369567871, 5.890433311462402, 1.7343261241912842, 4.050814628601074, 3.0758705139160156, 5.756180286407471, 2.915175676345825, 3.3110289573669434, 0.0, 2.2766737937927246, 0.0, 5.199783802032471, 0.0, 6.088670253753662, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.829176187515259, 1.3737026453018188, 3.218177080154419, 0.0, 2.855027675628662, 5.575257301330566, 5.765437602996826, 5.469160079956055, 5.816267490386963, 7.182384490966797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.3951504230499268, 0.0, 0.0, 0.0, 0.0, 4.546746730804443, 5.367809772491455, 5.749739646911621, 3.3307952880859375, 4.591202735900879, 3.123497486114502, 2.850287914276123, 0.0, 0.0, 0.0, 0.0, 0.0, 3.27018141746521, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.4219026565551758, 0.0, 0.0, 0.0, 0.0, 0.0, 4.038346767425537, 3.2195162773132324, 3.7728841304779053, 5.110694408416748, 8.433714866638184, 9.69461441040039, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.3951504230499268, 0.0, 0.0, 0.0, 0.0, 4.546746730804443, 5.367809772491455, 5.749739646911621, 3.3307952880859375, 4.591202735900879, 3.123497486114502, 2.850287914276123, 0.0, 0.0, 0.0, 0.0, 0.0, 3.27018141746521, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.4219026565551758, 0.0, 0.0, 0.0, 0.0, 0.0, 4.038346767425537, 3.2195162773132324, 3.7728841304779053, 5.110694408416748, 8.433714866638184, 9.69461441040039, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.116314888000488, 5.197838306427002, 7.632838249206543, 6.0216875076293945, 3.9622461795806885, 4.582754135131836, 3.5736474990844727, 2.435871124267578, 3.561696767807007, 4.956915378570557, 0.0, 5.145241737365723, 5.063893795013428, 3.779742956161499, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.9517815113067627, 5.25252628326416, 5.6078691482543945, 6.545984268188477, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.116314888000488, 5.197838306427002, 7.632838249206543, 6.0216875076293945, 3.9622461795806885, 4.582754135131836, 3.5736474990844727, 2.435871124267578, 3.561696767807007, 4.956915378570557, 0.0, 5.145241737365723, 5.063893795013428, 3.779742956161499, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, -0.0, 0.0, 0.0, -0.0, -0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.9517815113067627, 5.25252628326416, 5.6078691482543945, 6.545984268188477, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.27014684677124, 2.956974506378174, 5.9997334480285645, 2.8548550605773926, 5.205745697021484, 0.0, 2.7221410274505615, 2.308314323425293, 6.054502964019775, 6.26136589050293, 3.58614182472229, 2.9287924766540527, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.6380881071090698, -1.6079270839691162, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.6736183166503906, 0.0, 0.0, 2.018293857574463, 6.074472904205322, 4.400040149688721, 5.671645164489746, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.27014684677124, 2.956974506378174, 5.9997334480285645, 2.8548550605773926, 5.205745697021484, 0.0, 2.7221410274505615, 2.308314323425293, 6.054502964019775, 6.26136589050293, 3.58614182472229, 2.9287924766540527, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -1.6380881071090698, -1.6079270839691162, -0.0, 0.0, 0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.6736183166503906, 0.0, 0.0, 2.018293857574463, 6.074472904205322, 4.400040149688721, 5.671645164489746, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.3173270225524902, 3.922008991241455, 4.603394031524658, 4.1805267333984375, 1.9107950925827026, -0.09674910455942154, -0.14394016563892365, -0.3126770257949829, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5335017442703247, 0.4063911736011505, 0.5610316395759583, 1.6830074787139893, 2.58384108543396, 0.7991732954978943, 0.9692395329475403, -1.6321581602096558, 1.5236079692840576, 0.6099699139595032, -1.5841093063354492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.574476718902588, 0.0, 0.0, 0.0, 0.0, 0.19557662308216095, 1.8962939977645874, 0.0, 0.0, 5.730986595153809, 7.280658721923828, 5.7885332107543945, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.3173270225524902, 3.922008991241455, 4.603394031524658, 4.1805267333984375, 1.9107950925827026, -0.09674910455942154, -0.14394016563892365, -0.3126770257949829, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5335017442703247, 0.4063911736011505, 0.5610316395759583, 1.6830074787139893, 2.58384108543396, 0.7991732954978943, 0.9692395329475403, -1.6321581602096558, 1.5236079692840576, 0.6099699139595032, -1.5841093063354492, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 2.574476718902588, 0.0, 0.0, 0.0, 0.0, 0.19557662308216095, 1.8962939977645874, 0.0, 0.0, 5.730986595153809, 7.280658721923828, 5.7885332107543945, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.7454787492752075, 3.8603436946868896, 3.3056139945983887, 3.406463861465454, -0.5786122679710388, 2.9565653800964355, -0.30537718534469604, -0.26818186044692993, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.9827507734298706, -0.6509292721748352, 0.43542689085006714, -0.9019590616226196, -0.5898120403289795, 0.38226574659347534, -1.4582371711730957, 0.003150690346956253, 0.010067271068692207, -0.5716630220413208, -0.985876739025116, -1.5499953031539917, -1.0641372203826904, -1.1395734548568726, -0.9497243762016296, -0.9058337807655334, -0.4970901906490326, -0.7007859945297241, -0.07189008593559265, -0.3557896316051483, -0.22756090760231018, 1.0180875062942505, 0.0, 0.0, 0.0, 0.0, 3.054408073425293, 4.114501476287842, 5.268080711364746, 7.041148662567139, 2.290541172027588, 4.994748115539551, 4.94277286529541, 6.7206525802612305, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.7454787492752075, 3.8603436946868896, 3.3056139945983887, 3.406463861465454, -0.5786122679710388, 2.9565653800964355, -0.30537718534469604, -0.26818186044692993, -0.0, -0.0, -0.0, 0.0, -0.0, -0.0, 0.0, -0.0, -0.0, 0.0, 0.9827507734298706, -0.6509292721748352, 0.43542689085006714, -0.9019590616226196, -0.5898120403289795, 0.38226574659347534, -1.4582371711730957, 0.003150690346956253, 0.010067271068692207, -0.5716630220413208, -0.985876739025116, -1.5499953031539917, -1.0641372203826904, -1.1395734548568726, -0.9497243762016296, -0.9058337807655334, -0.4970901906490326, -0.7007859945297241, -0.07189008593559265, -0.3557896316051483, -0.22756090760231018, 1.0180875062942505, 0.0, 0.0, -0.0, 0.0, 3.054408073425293, 4.114501476287842, 5.268080711364746, 7.041148662567139, 2.290541172027588, 4.994748115539551, 4.94277286529541, 6.7206525802612305, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.2899200916290283, 1.4070093631744385, 0.9005667567253113, 0.09198170155286789, 0.0, 0.0, 2.4409329891204834, 0.0, 0.0, 0.0, 0.0, 0.0, 0.6678841710090637, -2.507075309753418, -3.6342501640319824, 0.47872745990753174, -0.7164739370346069, -1.4594374895095825, -3.4580535888671875, -0.4199143052101135, -0.5215503573417664, -3.669419527053833, -3.018907308578491, -2.1666877269744873, -3.5448997020721436, 0.0, -0.6131579875946045, -0.41337770223617554, -0.7544291019439697, -0.23818223178386688, -0.2698732614517212, -0.8961520195007324, -0.7009950280189514, -1.4029878377914429, -0.9809844493865967, -0.6415320634841919, -0.9570977687835693, -0.6259121298789978, -0.5685332417488098, -0.22152839601039886, 0.07329373806715012, 0.44109898805618286, 0.7159742712974548, -0.11169855296611786, 0.0, 0.0, 0.0, 0.0, 4.3494181632995605, 1.4699809551239014, 0.0, 4.7536139488220215, 5.050308704376221, 5.71013069152832, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 3.2899200916290283, 1.4070093631744385, 0.9005667567253113, 0.09198170155286789, 0.0, -0.0, 2.4409329891204834, -0.0, -0.0, -0.0, 0.0, 0.0, 0.6678841710090637, -2.507075309753418, -3.6342501640319824, 0.47872745990753174, -0.7164739370346069, -1.4594374895095825, -3.4580535888671875, -0.4199143052101135, -0.5215503573417664, -3.669419527053833, -3.018907308578491, -2.1666877269744873, -3.5448997020721436, -0.0, -0.6131579875946045, -0.41337770223617554, -0.7544291019439697, -0.23818223178386688, -0.2698732614517212, -0.8961520195007324, -0.7009950280189514, -1.4029878377914429, -0.9809844493865967, -0.6415320634841919, -0.9570977687835693, -0.6259121298789978, -0.5685332417488098, -0.22152839601039886, 0.07329373806715012, 0.44109898805618286, 0.7159742712974548, -0.11169855296611786, -0.0, 0.0, 0.0, 0.0, 4.3494181632995605, 1.4699809551239014, 0.0, 4.7536139488220215, 5.050308704376221, 5.71013069152832, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.6914373636245728, 0.6475582718849182, 0.8945376873016357, 2.1843883991241455, 0.0, 0.07674921303987503, 1.6128602027893066, 0.0, 0.0, -2.065863609313965, 0.0, 0.17777980864048004, 0.0, -0.5574741959571838, -1.9510884284973145, -0.40569421648979187, -2.152111053466797, -1.8050719499588013, -0.9175924062728882, -1.1856718063354492, -0.7795655131340027, -3.076554775238037, -4.24587869644165, -2.2943997383117676, -1.8618906736373901, -3.44608736038208, -0.8165655732154846, -0.36793458461761475, -1.1570886373519897, -0.6447649002075195, -0.9944543838500977, -1.0216448307037354, -0.9480488896369934, -0.32456350326538086, -0.8566824793815613, -0.3358340561389923, -0.19720183312892914, -0.726241946220398, 0.6308674812316895, 0.1611676812171936, 0.2249872088432312, 0.3136952519416809, -0.46484294533729553, -0.3575558662414551, 0.23200969398021698, -0.8185539245605469, 0.0, 0.0, 0.0, 0.0, -1.1647002696990967, -3.680962324142456, 0.0, 2.80965256690979, 5.15950345993042, 3.7944095134735107, 4.711246967315674, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -1.6914373636245728, 0.6475582718849182, 0.8945376873016357, 2.1843883991241455, 0.0, 0.07674921303987503, 1.6128602027893066, 0.0, -0.0, -2.065863609313965, 0.0, 0.17777980864048004, -0.0, -0.5574741959571838, -1.9510884284973145, -0.40569421648979187, -2.152111053466797, -1.8050719499588013, -0.9175924062728882, -1.1856718063354492, -0.7795655131340027, -3.076554775238037, -4.24587869644165, -2.2943997383117676, -1.8618906736373901, -3.44608736038208, -0.8165655732154846, -0.36793458461761475, -1.1570886373519897, -0.6447649002075195, -0.9944543838500977, -1.0216448307037354, -0.9480488896369934, -0.32456350326538086, -0.8566824793815613, -0.3358340561389923, -0.19720183312892914, -0.726241946220398, 0.6308674812316895, 0.1611676812171936, 0.2249872088432312, 0.3136952519416809, -0.46484294533729553, -0.3575558662414551, 0.23200969398021698, -0.8185539245605469, -0.0, 0.0, 0.0, 0.0, -1.1647002696990967, -3.680962324142456, 0.0, 2.80965256690979, 5.15950345993042, 3.7944095134735107, 4.711246967315674, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.24617914855480194, 0.8105483651161194, -1.657513976097107, -3.603877544403076, 0.0, -1.4766099452972412, 0.0, 0.0, 0.0, -0.2855258584022522, 0.07606668025255203, 0.0, -1.605546474456787, -1.8761911392211914, -1.7032266855239868, -1.4700299501419067, -2.127584934234619, -1.3437052965164185, -1.3361674547195435, -1.7235541343688965, -0.4519152343273163, -0.2332315295934677, -1.34908127784729, -3.9836719036102295, -3.267427682876587, -2.5754873752593994, -0.25272268056869507, -0.5980977416038513, -0.36507725715637207, -0.5491223335266113, -0.49599823355674744, -0.33848440647125244, 0.5502961277961731, 0.3854150176048279, 0.65130615234375, -0.9728361964225769, -0.4374932646751404, -0.414909303188324, 0.2587617039680481, -0.3099064230918884, 0.13486626744270325, -0.4287220537662506, -0.08231782168149948, -0.09942729771137238, -0.33823683857917786, -0.024994278326630592, -0.5025273561477661, 0.454760879278183, 0.0, 0.0, 0.0, 0.0, 0.0, 4.387532711029053, 2.3027729988098145, 3.3402018547058105, 7.314271926879883, 5.987186431884766, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.24617914855480194, 0.8105483651161194, -1.657513976097107, -3.603877544403076, 0.0, -1.4766099452972412, 0.0, 0.0, -0.0, -0.2855258584022522, 0.07606668025255203, -0.0, -1.605546474456787, -1.8761911392211914, -1.7032266855239868, -1.4700299501419067, -2.127584934234619, -1.3437052965164185, -1.3361674547195435, -1.7235541343688965, -0.4519152343273163, -0.2332315295934677, -1.34908127784729, -3.9836719036102295, -3.267427682876587, -2.5754873752593994, -0.25272268056869507, -0.5980977416038513, -0.36507725715637207, -0.5491223335266113, -0.49599823355674744, -0.33848440647125244, 0.5502961277961731, 0.3854150176048279, 0.65130615234375, -0.9728361964225769, -0.4374932646751404, -0.414909303188324, 0.2587617039680481, -0.3099064230918884, 0.13486626744270325, -0.4287220537662506, -0.08231782168149948, -0.09942729771137238, -0.33823683857917786, -0.024994278326630592, -0.5025273561477661, 0.454760879278183, 0.0, 0.0, -0.0, -0.0, -0.0, 4.387532711029053, 2.3027729988098145, 3.3402018547058105, 7.314271926879883, 5.987186431884766, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.7292402386665344, -0.32569068670272827, -0.6525672674179077, -0.9528734087944031, 0.0, -0.7723019123077393, 0.7056217193603516, 0.0, 0.0, -1.7843587398529053, 0.0, -2.0475950241088867, -3.2224652767181396, -1.7509406805038452, -2.2798097133636475, -1.765262484550476, -1.4497239589691162, -1.6843559741973877, -2.058804750442505, -0.9579222202301025, -1.6463162899017334, -0.772523045539856, -2.065890312194824, -1.038649320602417, -1.0270304679870605, -0.7555227875709534, 1.0586334466934204, -0.44874244928359985, -0.09747129678726196, -0.24185867607593536, -0.40984445810317993, -0.33371707797050476, -0.8174349069595337, -0.6959138512611389, 0.29481810331344604, 0.013947530649602413, -0.047530923038721085, 0.16711512207984924, -0.04868950694799423, 0.07577062398195267, -0.003532710252329707, -0.23800604045391083, -0.12309859693050385, 0.0025595366023480892, 0.09862694144248962, 0.5800315737724304, 0.02603200450539589, -0.5686711072921753, -0.21034522354602814, -0.9792945981025696, -0.020007960498332977, 0.9986571669578552, 0.0, 0.0, 0.0, 0.0, 0.629287600517273, 4.786780834197998, 7.56294059753418, 4.209648132324219, 3.8416223526000977, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.7292402386665344, -0.32569068670272827, -0.6525672674179077, -0.9528734087944031, -0.0, -0.7723019123077393, 0.7056217193603516, 0.0, -0.0, -1.7843587398529053, -0.0, -2.0475950241088867, -3.2224652767181396, -1.7509406805038452, -2.2798097133636475, -1.765262484550476, -1.4497239589691162, -1.6843559741973877, -2.058804750442505, -0.9579222202301025, -1.6463162899017334, -0.772523045539856, -2.065890312194824, -1.038649320602417, -1.0270304679870605, -0.7555227875709534, 1.0586334466934204, -0.44874244928359985, -0.09747129678726196, -0.24185867607593536, -0.40984445810317993, -0.33371707797050476, -0.8174349069595337, -0.6959138512611389, 0.29481810331344604, 0.013947530649602413, -0.047530923038721085, 0.16711512207984924, -0.04868950694799423, 0.07577062398195267, -0.003532710252329707, -0.23800604045391083, -0.12309859693050385, 0.0025595366023480892, 0.09862694144248962, 0.5800315737724304, 0.02603200450539589, -0.5686711072921753, -0.21034522354602814, -0.9792945981025696, -0.020007960498332977, 0.9986571669578552, 0.0, 0.0, 0.0, 0.0, 0.629287600517273, 4.786780834197998, 7.56294059753418, 4.209648132324219, 3.8416223526000977, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.9371651411056519, -2.7728488445281982, -1.57282292842865, -0.8385944366455078, 0.0, 1.7565650939941406, 0.9433023929595947, 0.0, 0.0, 0.0, -1.257711410522461, -1.8582020998001099, -2.0398640632629395, -2.4552273750305176, -2.1811697483062744, -2.2861948013305664, -2.2227818965911865, -2.4920103549957275, -1.8085049390792847, -1.298241376876831, -1.2444746494293213, -1.3953425884246826, -2.117680072784424, -1.517183780670166, -1.5046204328536987, -1.6845489740371704, -0.9064000248908997, -0.40516388416290283, 0.5299901962280273, -0.8829320669174194, -0.4654679000377655, 0.22986151278018951, -0.30115556716918945, -0.2622995376586914, 0.14239150285720825, -0.21419723331928253, -0.11409365385770798, 0.010256064124405384, -0.6138793230056763, 0.38630908727645874, 0.04383566975593567, 0.24819931387901306, -2.7027409076690674, 0.07338578253984451, 0.23989254236221313, 0.2569948732852936, -0.33452290296554565, 0.17565716803073883, -0.3703908920288086, -0.054451778531074524, 0.4892502427101135, -0.740714967250824, -0.07781413197517395, 0.07383859157562256, 0.0, 0.0, 0.0, 0.0, 4.5396552085876465, 0.0, 3.3580965995788574, 4.150459289550781, 4.944570541381836, 5.403233051300049, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.9371651411056519, -2.7728488445281982, -1.57282292842865, -0.8385944366455078, -0.0, 1.7565650939941406, 0.9433023929595947, 0.0, -0.0, -0.0, -1.257711410522461, -1.8582020998001099, -2.0398640632629395, -2.4552273750305176, -2.1811697483062744, -2.2861948013305664, -2.2227818965911865, -2.4920103549957275, -1.8085049390792847, -1.298241376876831, -1.2444746494293213, -1.3953425884246826, -2.117680072784424, -1.517183780670166, -1.5046204328536987, -1.6845489740371704, -0.9064000248908997, -0.40516388416290283, 0.5299901962280273, -0.8829320669174194, -0.4654679000377655, 0.22986151278018951, -0.30115556716918945, -0.2622995376586914, 0.14239150285720825, -0.21419723331928253, -0.11409365385770798, 0.010256064124405384, -0.6138793230056763, 0.38630908727645874, 0.04383566975593567, 0.24819931387901306, -2.7027409076690674, 0.07338578253984451, 0.23989254236221313, 0.2569948732852936, -0.33452290296554565, 0.17565716803073883, -0.3703908920288086, -0.054451778531074524, 0.4892502427101135, -0.740714967250824, -0.07781413197517395, 0.07383859157562256, 0.0, -0.0, 0.0, 0.0, 4.5396552085876465, 0.0, 3.3580965995788574, 4.150459289550781, 4.944570541381836, 5.403233051300049, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5227197408676147, -2.546973943710327, 0.0, 0.0, -0.0060342042706906796, 0.0, 0.0, 0.0, -0.2040976583957672, -3.265970230102539, -2.676722288131714, -2.2801694869995117, -2.3638434410095215, -2.0146727561950684, -2.0445680618286133, -1.9188318252563477, -1.415602207183838, -2.0395450592041016, -1.6524535417556763, -1.4720606803894043, -1.0940642356872559, -0.8017176389694214, -0.4539646506309509, -0.6655290722846985, -0.7676558494567871, -1.5901449918746948, -0.4961346983909607, -0.7438061237335205, -0.1337510198354721, -0.9446143507957458, -0.2386465072631836, -0.3650969862937927, -0.3377615213394165, 0.09720218926668167, -0.16002295911312103, 0.25683826208114624, 0.1359694004058838, 0.3268248736858368, -0.11531373858451843, -1.0942188501358032, 0.23989781737327576, -0.036446165293455124, 0.3191516697406769, 0.2874543368816376, -0.2620164155960083, 0.1827726811170578, 0.10050229728221893, -0.09870430082082748, 0.3192184865474701, 0.007279468700289726, -0.31218716502189636, 0.4684015214443207, -0.8040325045585632, -0.43143340945243835, -0.09494536370038986, 0.0, 0.0, 0.0, 0.0, 5.577102184295654, 0.0, 4.828930854797363, 4.461886405944824, 2.1256446838378906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.5227197408676147, -2.546973943710327, -0.0, -0.0, -0.0060342042706906796, 0.0, 0.0, -0.0, -0.2040976583957672, -3.265970230102539, -2.676722288131714, -2.2801694869995117, -2.3638434410095215, -2.0146727561950684, -2.0445680618286133, -1.9188318252563477, -1.415602207183838, -2.0395450592041016, -1.6524535417556763, -1.4720606803894043, -1.0940642356872559, -0.8017176389694214, -0.4539646506309509, -0.6655290722846985, -0.7676558494567871, -1.5901449918746948, -0.4961346983909607, -0.7438061237335205, -0.1337510198354721, -0.9446143507957458, -0.2386465072631836, -0.3650969862937927, -0.3377615213394165, 0.09720218926668167, -0.16002295911312103, 0.25683826208114624, 0.1359694004058838, 0.3268248736858368, -0.11531373858451843, -1.0942188501358032, 0.23989781737327576, -0.036446165293455124, 0.3191516697406769, 0.2874543368816376, -0.2620164155960083, 0.1827726811170578, 0.10050229728221893, -0.09870430082082748, 0.3192184865474701, 0.007279468700289726, -0.31218716502189636, 0.4684015214443207, -0.8040325045585632, -0.43143340945243835, -0.09494536370038986, -0.0, -0.0, 0.0, 0.0, 5.577102184295654, 0.0, 4.828930854797363, 4.461886405944824, 2.1256446838378906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.4835785925388336, 0.5470897555351257, 1.9965630769729614, 0.0, 0.0, -0.8004510998725891, 0.0, 0.0, 0.0, -1.1238082647323608, -2.531463146209717, -3.103161096572876, -2.666445255279541, -2.769256114959717, -2.8806941509246826, -3.8270151615142822, -2.689694404602051, -2.064422130584717, -1.7389940023422241, -1.979212999343872, -1.638842225074768, -1.133768916130066, -1.481845736503601, -1.2641681432724, -0.45306286215782166, -0.6292338371276855, -0.6118226647377014, -0.7076877951622009, -0.7055650949478149, 0.37940892577171326, -1.0673860311508179, -0.1771896630525589, 0.24930915236473083, 0.6278050541877747, 0.17230457067489624, 0.5007250308990479, -0.280374675989151, 0.1626599282026291, 0.30240532755851746, 0.06269153207540512, 0.08830771595239639, 0.31581375002861023, 0.2486722618341446, 0.33849993348121643, 0.9049825072288513, 0.32496437430381775, -0.3206864893436432, 0.5475177764892578, 0.30063533782958984, 0.9195894598960876, 0.7446527481079102, -0.33563104271888733, 0.7841101288795471, -0.6316096782684326, -0.5214920043945312, -0.3873901665210724, -0.1876041293144226, -0.5329821109771729, -2.4243576526641846, 0.0, 0.0, 0.0, 3.383225679397583, 0.0, 0.473685085773468, 2.9580719470977783, 4.1590986251831055, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.4835785925388336, 0.5470897555351257, 1.9965630769729614, -0.0, -0.0, -0.8004510998725891, 0.0, -0.0, -0.0, -1.1238082647323608, -2.531463146209717, -3.103161096572876, -2.666445255279541, -2.769256114959717, -2.8806941509246826, -3.8270151615142822, -2.689694404602051, -2.064422130584717, -1.7389940023422241, -1.979212999343872, -1.638842225074768, -1.133768916130066, -1.481845736503601, -1.2641681432724, -0.45306286215782166, -0.6292338371276855, -0.6118226647377014, -0.7076877951622009, -0.7055650949478149, 0.37940892577171326, -1.0673860311508179, -0.1771896630525589, 0.24930915236473083, 0.6278050541877747, 0.17230457067489624, 0.5007250308990479, -0.280374675989151, 0.1626599282026291, 0.30240532755851746, 0.06269153207540512, 0.08830771595239639, 0.31581375002861023, 0.2486722618341446, 0.33849993348121643, 0.9049825072288513, 0.32496437430381775, -0.3206864893436432, 0.5475177764892578, 0.30063533782958984, 0.9195894598960876, 0.7446527481079102, -0.33563104271888733, 0.7841101288795471, -0.6316096782684326, -0.5214920043945312, -0.3873901665210724, -0.1876041293144226, -0.5329821109771729, -2.4243576526641846, -0.0, 0.0, 0.0, 3.383225679397583, 0.0, 0.473685085773468, 2.9580719470977783, 4.1590986251831055, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 2.1722843647003174, -0.372063547372818, -2.4204607009887695, 0.0, 0.0, -0.7856345772743225, 0.0, 0.0, 0.0, -3.3445088863372803, -3.435532569885254, -3.274545907974243, -2.805298089981079, -2.995011329650879, -2.7350893020629883, -2.705885410308838, -1.8714790344238281, -2.1904923915863037, -1.6815725564956665, -1.489487886428833, -1.4387943744659424, -1.8956542015075684, -1.0317978858947754, -1.2653589248657227, -0.6982608437538147, -1.1478848457336426, -0.9070508480072021, -0.6482962369918823, -0.4468366503715515, -1.2056081295013428, -0.5410522222518921, 0.0073854960501194, 0.11732792109251022, -0.1911870688199997, 0.2846510708332062, 0.9663037657737732, 0.5287221074104309, 0.5706243515014648, 0.31999433040618896, -0.2490437775850296, 0.08488011360168457, -0.7486972808837891, 0.2516930401325226, 0.4208095073699951, -1.287277340888977, -0.028020963072776794, 0.2620333135128021, 0.07256820797920227, 0.5716414451599121, 0.47604653239250183, -0.8116790056228638, 0.04221368208527565, 0.24367836117744446, 0.41863664984703064, 0.39915090799331665, 0.35530227422714233, -0.15218879282474518, 0.45604702830314636, -0.10992148518562317, -0.21361702680587769, 0.5337427854537964, 0.0, 0.0, 0.0, 0.0, -1.2259107828140259, 1.826041340827942, 2.378955841064453, 2.9379091262817383, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 2.1722843647003174, -0.372063547372818, -2.4204607009887695, 0.0, 0.0, -0.7856345772743225, -0.0, -0.0, -0.0, -3.3445088863372803, -3.435532569885254, -3.274545907974243, -2.805298089981079, -2.995011329650879, -2.7350893020629883, -2.705885410308838, -1.8714790344238281, -2.1904923915863037, -1.6815725564956665, -1.489487886428833, -1.4387943744659424, -1.8956542015075684, -1.0317978858947754, -1.2653589248657227, -0.6982608437538147, -1.1478848457336426, -0.9070508480072021, -0.6482962369918823, -0.4468366503715515, -1.2056081295013428, -0.5410522222518921, 0.0073854960501194, 0.11732792109251022, -0.1911870688199997, 0.2846510708332062, 0.9663037657737732, 0.5287221074104309, 0.5706243515014648, 0.31999433040618896, -0.2490437775850296, 0.08488011360168457, -0.7486972808837891, 0.2516930401325226, 0.4208095073699951, -1.287277340888977, -0.028020963072776794, 0.2620333135128021, 0.07256820797920227, 0.5716414451599121, 0.47604653239250183, -0.8116790056228638, 0.04221368208527565, 0.24367836117744446, 0.41863664984703064, 0.39915090799331665, 0.35530227422714233, -0.15218879282474518, 0.45604702830314636, -0.10992148518562317, -0.21361702680587769, 0.5337427854537964, 0.0, -0.0, -0.0, -0.0, -1.2259107828140259, 1.826041340827942, 2.378955841064453, 2.9379091262817383, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -1.0252039432525635, -1.7322739362716675, 0.0, 0.0, -1.8102306127548218, 0.0, 0.0, 0.0, -3.860948324203491, -4.0653791427612305, -3.516484260559082, -3.7777175903320312, -3.040616989135742, -2.4987804889678955, -1.6577415466308594, -2.6203997135162354, -2.1218271255493164, -2.1840803623199463, -1.983923077583313, -1.6079305410385132, -2.092928409576416, -1.463436245918274, -0.8739002346992493, -1.2703977823257446, -0.5761160850524902, -2.5623092651367188, -0.3701111376285553, 0.24766534566879272, -0.6327999830245972, -0.18320991098880768, -1.5425065755844116, -0.5870131254196167, 0.037165023386478424, -0.2633642852306366, -0.23045054078102112, 1.073806881904602, 0.18734309077262878, -0.3479960262775421, -0.029073791578412056, 0.26557865738868713, 0.05032174289226532, 0.04254567250609398, 0.6056485772132874, 0.46663424372673035, 0.38016071915626526, 0.2862298786640167, -8.477446681354195e-05, -0.06110426411032677, 0.1267496645450592, -0.06490185111761093, -0.5688453912734985, 0.22188706696033478, 0.3439485728740692, 0.12314549833536148, 1.0505791902542114, 0.4090656638145447, 0.23879817128181458, 0.35267341136932373, 1.1741868257522583, 1.0127570629119873, 0.4068623483181, -0.2850812077522278, 0.0, 0.0, 0.0, 0.5858650207519531, 0.0, 3.2801382541656494, 4.228029251098633, 5.926358222961426, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0252039432525635, -1.7322739362716675, -0.0, -0.0, -1.8102306127548218, -0.0, -0.0, -0.0, -3.860948324203491, -4.0653791427612305, -3.516484260559082, -3.7777175903320312, -3.040616989135742, -2.4987804889678955, -1.6577415466308594, -2.6203997135162354, -2.1218271255493164, -2.1840803623199463, -1.983923077583313, -1.6079305410385132, -2.092928409576416, -1.463436245918274, -0.8739002346992493, -1.2703977823257446, -0.5761160850524902, -2.5623092651367188, -0.3701111376285553, 0.24766534566879272, -0.6327999830245972, -0.18320991098880768, -1.5425065755844116, -0.5870131254196167, 0.037165023386478424, -0.2633642852306366, -0.23045054078102112, 1.073806881904602, 0.18734309077262878, -0.3479960262775421, -0.029073791578412056, 0.26557865738868713, 0.05032174289226532, 0.04254567250609398, 0.6056485772132874, 0.46663424372673035, 0.38016071915626526, 0.2862298786640167, -8.477446681354195e-05, -0.06110426411032677, 0.1267496645450592, -0.06490185111761093, -0.5688453912734985, 0.22188706696033478, 0.3439485728740692, 0.12314549833536148, 1.0505791902542114, 0.4090656638145447, 0.23879817128181458, 0.35267341136932373, 1.1741868257522583, 1.0127570629119873, 0.4068623483181, -0.2850812077522278, -0.0, 0.0, 0.0, 0.5858650207519531, 0.0, 3.2801382541656494, 4.228029251098633, 5.926358222961426, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -0.6417664289474487, -2.8056249618530273, 1.4202897548675537, 0.0, 0.7727558612823486, 0.0, 0.0, 0.0, -4.608638763427734, -4.359991073608398, -3.7882440090179443, -3.1104750633239746, -3.2763590812683105, -2.753851890563965, -2.838510036468506, -2.560030460357666, -2.6867072582244873, -2.382941722869873, -2.1230573654174805, -1.5451323986053467, -1.768039584159851, -1.3740878105163574, -2.3225958347320557, -1.0791878700256348, -1.3137656450271606, -1.4485865831375122, -0.33935919404029846, -0.42534327507019043, -0.4180399179458618, -0.34651851654052734, -0.30089041590690613, -0.8671318292617798, -0.21836940944194794, 0.3574749231338501, 0.5349563956260681, 0.6020900011062622, 0.701499879360199, 0.3511429727077484, 0.5566766858100891, -0.3703394830226898, 0.5139651298522949, 0.05335889011621475, 1.1154263019561768, 0.6599963307380676, 0.4441835284233093, 0.16718828678131104, 0.05941862612962723, 1.1120554208755493, 0.7996950149536133, 0.7637583613395691, 0.20038147270679474, 0.05294810235500336, 0.37587970495224, -0.16696448624134064, 0.3485237956047058, 0.05294276773929596, 0.38337671756744385, -0.07755551487207413, 0.31196483969688416, 0.20090286433696747, -0.12263406068086624, 0.3596981167793274, 0.30084434151649475, 0.0, 0.0, 0.0, 0.0, 0.0, 1.2088720798492432, 2.693979501724243, 4.889972686767578, 7.700939178466797, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.6417664289474487, -2.8056249618530273, 1.4202897548675537, 0.0, 0.7727558612823486, -0.0, -0.0, -0.0, -4.608638763427734, -4.359991073608398, -3.7882440090179443, -3.1104750633239746, -3.2763590812683105, -2.753851890563965, -2.838510036468506, -2.560030460357666, -2.6867072582244873, -2.382941722869873, -2.1230573654174805, -1.5451323986053467, -1.768039584159851, -1.3740878105163574, -2.3225958347320557, -1.0791878700256348, -1.3137656450271606, -1.4485865831375122, -0.33935919404029846, -0.42534327507019043, -0.4180399179458618, -0.34651851654052734, -0.30089041590690613, -0.8671318292617798, -0.21836940944194794, 0.3574749231338501, 0.5349563956260681, 0.6020900011062622, 0.701499879360199, 0.3511429727077484, 0.5566766858100891, -0.3703394830226898, 0.5139651298522949, 0.05335889011621475, 1.1154263019561768, 0.6599963307380676, 0.4441835284233093, 0.16718828678131104, 0.05941862612962723, 1.1120554208755493, 0.7996950149536133, 0.7637583613395691, 0.20038147270679474, 0.05294810235500336, 0.37587970495224, -0.16696448624134064, 0.3485237956047058, 0.05294276773929596, 0.38337671756744385, -0.07755551487207413, 0.31196483969688416, 0.20090286433696747, -0.12263406068086624, 0.3596981167793274, 0.30084434151649475, 0.0, 0.0, 0.0, 0.0, 0.0, 1.2088720798492432, 2.693979501724243, 4.889972686767578, 7.700939178466797, 0.0, 0.0], [0.0, 0.0, 0.0, -0.6468130946159363, -2.315122604370117, 0.0, 0.6700657606124878, -0.25996267795562744, 0.0, 0.0, 0.0, -4.886897087097168, -4.422885894775391, -3.6886162757873535, -3.1246941089630127, -3.6595699787139893, -3.5484209060668945, -2.8837625980377197, -2.7595841884613037, -1.7936502695083618, -2.871432304382324, -2.6253769397735596, -1.3496642112731934, -2.5349133014678955, -0.9863477945327759, -1.7855706214904785, -1.319009780883789, -0.7380715012550354, -0.13438689708709717, -1.131361722946167, 0.08763016760349274, -0.6880309581756592, 0.8857421278953552, -0.11570408940315247, -1.12148118019104, -0.7803378701210022, -0.10370155423879623, 0.6804617643356323, 0.501209557056427, 0.29732710123062134, 0.8195777535438538, 0.06447778642177582, 0.05426948517560959, 0.4844230115413666, 0.5606786012649536, 0.03379731997847557, 0.9697974324226379, 0.5070528984069824, 0.8145350217819214, 0.5742673873901367, 0.6908460855484009, 0.559725284576416, 0.4302332401275635, 0.18972478806972504, -0.42130494117736816, 0.5863518714904785, 0.35289135575294495, 0.39236703515052795, 0.49469923973083496, 0.35661226511001587, 0.5971346497535706, 0.23271463811397552, 0.5379171371459961, 0.10228250175714493, 0.4909093379974365, 0.29701605439186096, 0.40374645590782166, 1.615827202796936, 1.0827547311782837, 0.0, 0.0, 0.0, 0.7232027649879456, 1.964974045753479, 5.442384719848633, 6.259186744689941, 0.0, 0.0, -0.0, -0.0, -0.0, -0.6468130946159363, -2.315122604370117, -0.0, 0.6700657606124878, -0.25996267795562744, -0.0, -0.0, -0.0, -4.886897087097168, -4.422885894775391, -3.6886162757873535, -3.1246941089630127, -3.6595699787139893, -3.5484209060668945, -2.8837625980377197, -2.7595841884613037, -1.7936502695083618, -2.871432304382324, -2.6253769397735596, -1.3496642112731934, -2.5349133014678955, -0.9863477945327759, -1.7855706214904785, -1.319009780883789, -0.7380715012550354, -0.13438689708709717, -1.131361722946167, 0.08763016760349274, -0.6880309581756592, 0.8857421278953552, -0.11570408940315247, -1.12148118019104, -0.7803378701210022, -0.10370155423879623, 0.6804617643356323, 0.501209557056427, 0.29732710123062134, 0.8195777535438538, 0.06447778642177582, 0.05426948517560959, 0.4844230115413666, 0.5606786012649536, 0.03379731997847557, 0.9697974324226379, 0.5070528984069824, 0.8145350217819214, 0.5742673873901367, 0.6908460855484009, 0.559725284576416, 0.4302332401275635, 0.18972478806972504, -0.42130494117736816, 0.5863518714904785, 0.35289135575294495, 0.39236703515052795, 0.49469923973083496, 0.35661226511001587, 0.5971346497535706, 0.23271463811397552, 0.5379171371459961, 0.10228250175714493, 0.4909093379974365, 0.29701605439186096, 0.40374645590782166, 1.615827202796936, 1.0827547311782837, 0.0, 0.0, 0.0, 0.7232027649879456, 1.964974045753479, 5.442384719848633, 6.259186744689941, 0.0, 0.0], [0.0, 0.0, -0.43869855999946594, -3.000553846359253, 0.14534160494804382, 0.0, 2.1813642978668213, 0.0, 0.0, 0.0, -1.583038091659546, -4.648124694824219, -4.867483615875244, -3.6430013179779053, -3.792391777038574, -2.97691011428833, -3.1091482639312744, -2.685124397277832, -2.9699079990386963, -2.6414434909820557, -2.4127979278564453, -2.1593596935272217, -2.4356160163879395, -1.8053227663040161, -1.3055311441421509, -0.9286852478981018, -1.830432415008545, -0.25001150369644165, -0.9489110112190247, -0.25854021310806274, -1.5446856021881104, -0.4979340732097626, -0.16576403379440308, 0.28338372707366943, -0.21146276593208313, 0.21624159812927246, -0.06099212169647217, 1.129252314567566, 0.5598953366279602, 0.37095358967781067, 0.5128198862075806, 0.8851056694984436, 0.46311697363853455, -0.0823177695274353, 0.02990422211587429, 0.9646520614624023, 0.6760143041610718, 1.0596765279769897, 0.8262441754341125, 0.9819622039794922, 0.45412591099739075, 0.5294390916824341, 0.9438965916633606, 0.5024797320365906, 0.931572437286377, 0.7084714770317078, 0.9442030787467957, 0.9830192923545837, 0.4651128053665161, 0.2678386867046356, 0.47695136070251465, 1.0681015253067017, 0.06664905697107315, 0.7604703307151794, 0.5564038753509521, 0.8774318695068359, 0.8599445223808289, -0.06246773153543472, 0.8586047291755676, 1.846718430519104, 0.0, 0.0, 0.3320460617542267, 3.753591537475586, 4.927028179168701, 6.272204399108887, 7.578246593475342, 0.0, -0.0, -0.0, -0.43869855999946594, -3.000553846359253, 0.14534160494804382, 0.0, 2.1813642978668213, -0.0, -0.0, -0.0, -1.583038091659546, -4.648124694824219, -4.867483615875244, -3.6430013179779053, -3.792391777038574, -2.97691011428833, -3.1091482639312744, -2.685124397277832, -2.9699079990386963, -2.6414434909820557, -2.4127979278564453, -2.1593596935272217, -2.4356160163879395, -1.8053227663040161, -1.3055311441421509, -0.9286852478981018, -1.830432415008545, -0.25001150369644165, -0.9489110112190247, -0.25854021310806274, -1.5446856021881104, -0.4979340732097626, -0.16576403379440308, 0.28338372707366943, -0.21146276593208313, 0.21624159812927246, -0.06099212169647217, 1.129252314567566, 0.5598953366279602, 0.37095358967781067, 0.5128198862075806, 0.8851056694984436, 0.46311697363853455, -0.0823177695274353, 0.02990422211587429, 0.9646520614624023, 0.6760143041610718, 1.0596765279769897, 0.8262441754341125, 0.9819622039794922, 0.45412591099739075, 0.5294390916824341, 0.9438965916633606, 0.5024797320365906, 0.931572437286377, 0.7084714770317078, 0.9442030787467957, 0.9830192923545837, 0.4651128053665161, 0.2678386867046356, 0.47695136070251465, 1.0681015253067017, 0.06664905697107315, 0.7604703307151794, 0.5564038753509521, 0.8774318695068359, 0.8599445223808289, -0.06246773153543472, 0.8586047291755676, 1.846718430519104, 0.0, 0.0, 0.3320460617542267, 3.753591537475586, 4.927028179168701, 6.272204399108887, 7.578246593475342, 0.0], [0.0, 0.0, -1.3030556440353394, 0.0, 0.0, 1.9334489107131958, 0.2973822355270386, 0.0, 0.0, 0.0, -4.911220550537109, -4.416654586791992, -4.2708330154418945, -3.8612828254699707, -3.6374049186706543, -4.193282604217529, -3.6996185779571533, -2.655142307281494, -2.2977285385131836, -2.8715286254882812, -2.271078109741211, -2.5574893951416016, -2.1698408126831055, -0.9301104545593262, -0.8526036143302917, -3.7841274738311768, -1.3592699766159058, -0.5804021954536438, -0.9667783379554749, -0.9663761258125305, -0.38362830877304077, -0.21709510684013367, -0.5209233164787292, -0.1083824560046196, -0.18506741523742676, 0.014412951655685902, -0.056680310517549515, -0.0593905933201313, -0.49132585525512695, -0.9299192428588867, -0.20114737749099731, -0.004445949569344521, 0.05765309929847717, 0.29349634051322937, 0.5649182796478271, 1.209424376487732, 0.6276134252548218, 0.7896295189857483, 0.40064579248428345, 0.7336816191673279, 0.7567474842071533, 1.7651758193969727, -0.007456662133336067, 0.9240944385528564, 0.8866243958473206, 0.06106743589043617, 0.5846637487411499, 0.5484252572059631, 0.5490361452102661, 0.6767778396606445, 0.47470343112945557, 0.8555859923362732, 0.6394856572151184, 0.26109689474105835, 0.8327536582946777, 0.979780912399292, 1.270443081855774, -0.12499604374170303, 0.761347770690918, 0.9444059729576111, 0.0, 0.0, 0.0, 0.0, 3.4260542392730713, 4.642366886138916, 6.540705680847168, 0.0, -0.0, -0.0, -1.3030556440353394, -0.0, 0.0, 1.9334489107131958, 0.2973822355270386, 0.0, -0.0, -0.0, -4.911220550537109, -4.416654586791992, -4.2708330154418945, -3.8612828254699707, -3.6374049186706543, -4.193282604217529, -3.6996185779571533, -2.655142307281494, -2.2977285385131836, -2.8715286254882812, -2.271078109741211, -2.5574893951416016, -2.1698408126831055, -0.9301104545593262, -0.8526036143302917, -3.7841274738311768, -1.3592699766159058, -0.5804021954536438, -0.9667783379554749, -0.9663761258125305, -0.38362830877304077, -0.21709510684013367, -0.5209233164787292, -0.1083824560046196, -0.18506741523742676, 0.014412951655685902, -0.056680310517549515, -0.0593905933201313, -0.49132585525512695, -0.9299192428588867, -0.20114737749099731, -0.004445949569344521, 0.05765309929847717, 0.29349634051322937, 0.5649182796478271, 1.209424376487732, 0.6276134252548218, 0.7896295189857483, 0.40064579248428345, 0.7336816191673279, 0.7567474842071533, 1.7651758193969727, -0.007456662133336067, 0.9240944385528564, 0.8866243958473206, 0.06106743589043617, 0.5846637487411499, 0.5484252572059631, 0.5490361452102661, 0.6767778396606445, 0.47470343112945557, 0.8555859923362732, 0.6394856572151184, 0.26109689474105835, 0.8327536582946777, 0.979780912399292, 1.270443081855774, -0.12499604374170303, 0.761347770690918, 0.9444059729576111, 0.0, 0.0, 0.0, 0.0, 3.4260542392730713, 4.642366886138916, 6.540705680847168, 0.0], [0.0, -1.2775688171386719, 1.1844614744186401, 0.0, 0.0, -1.1188572645187378, 0.0, 0.0, 0.0, -3.620593309402466, -4.93172550201416, -4.864360809326172, -4.53112268447876, -3.7624895572662354, -4.483798027038574, -2.9579148292541504, -3.245429277420044, -3.034048080444336, -2.4975268840789795, -3.42195200920105, -2.5288755893707275, -1.385770559310913, -1.693143367767334, -0.6285822987556458, -0.6472574472427368, -0.606062650680542, -1.43230402469635, -1.677396535873413, -0.9914467334747314, -0.49853575229644775, -0.14717629551887512, 0.1382434070110321, -0.23588690161705017, -0.4709327220916748, -0.48784127831459045, 0.1141199842095375, 0.833597719669342, 0.10464347898960114, 0.5441616773605347, -0.41192302107810974, -0.009633954614400864, 0.9707162380218506, 0.6146477460861206, 0.6513359546661377, 0.4072602391242981, 0.4087143838405609, -0.0008818631176836789, 0.7848015427589417, 0.2517246901988983, 0.7446614503860474, 0.40053439140319824, 0.344485878944397, 1.071656584739685, 0.889286458492279, 0.5000410079956055, 0.9844594597816467, 1.0849031209945679, 0.3000445067882538, 0.2058604508638382, 0.6042129993438721, 0.626196563243866, 1.4539698362350464, 0.4680287837982178, 0.32192474603652954, 0.9328408241271973, 0.356343537569046, 0.5881258845329285, 0.22755023837089539, 0.20969107747077942, -0.23302344977855682, 1.261539340019226, 0.0, 0.0, 0.0, 2.161428928375244, 2.2066962718963623, 4.452437400817871, 0.0, -0.0, -1.2775688171386719, 1.1844614744186401, 0.0, -0.0, -1.1188572645187378, 0.0, 0.0, -0.0, -3.620593309402466, -4.93172550201416, -4.864360809326172, -4.53112268447876, -3.7624895572662354, -4.483798027038574, -2.9579148292541504, -3.245429277420044, -3.034048080444336, -2.4975268840789795, -3.42195200920105, -2.5288755893707275, -1.385770559310913, -1.693143367767334, -0.6285822987556458, -0.6472574472427368, -0.606062650680542, -1.43230402469635, -1.677396535873413, -0.9914467334747314, -0.49853575229644775, -0.14717629551887512, 0.1382434070110321, -0.23588690161705017, -0.4709327220916748, -0.48784127831459045, 0.1141199842095375, 0.833597719669342, 0.10464347898960114, 0.5441616773605347, -0.41192302107810974, -0.009633954614400864, 0.9707162380218506, 0.6146477460861206, 0.6513359546661377, 0.4072602391242981, 0.4087143838405609, -0.0008818631176836789, 0.7848015427589417, 0.2517246901988983, 0.7446614503860474, 0.40053439140319824, 0.344485878944397, 1.071656584739685, 0.889286458492279, 0.5000410079956055, 0.9844594597816467, 1.0849031209945679, 0.3000445067882538, 0.2058604508638382, 0.6042129993438721, 0.626196563243866, 1.4539698362350464, 0.4680287837982178, 0.32192474603652954, 0.9328408241271973, 0.356343537569046, 0.5881258845329285, 0.22755023837089539, 0.20969107747077942, -0.23302344977855682, 1.261539340019226, 0.0, 0.0, 0.0, 2.161428928375244, 2.2066962718963623, 4.452437400817871, 0.0], [0.0, -2.5044126510620117, -3.858945608139038, 0.0, 0.0, 0.0, 0.0, 0.0, -2.4383599758148193, -4.6451191902160645, -5.169398784637451, -4.632980823516846, -3.0796914100646973, -3.8035781383514404, -3.2478408813476562, -2.945502281188965, -3.2819976806640625, -3.12546706199646, -3.4210143089294434, -5.585323333740234, -1.8678998947143555, -2.403998851776123, -1.1139942407608032, -1.290174961090088, -0.3401951491832733, -0.45339545607566833, -0.5695455074310303, -0.4246748387813568, -0.9204157590866089, -0.3456905484199524, -0.06764904409646988, -0.6827621459960938, -0.4994833767414093, -0.3225146234035492, -1.3204447031021118, -0.9636045098304749, -1.030243992805481, 0.32173964381217957, -0.03815111890435219, 0.485858678817749, -0.26619789004325867, 0.8945571780204773, 0.06467773020267487, 0.2177450954914093, 0.578281819820404, 0.7020799517631531, -0.238368421792984, 0.8473573923110962, 1.4656519889831543, 1.1182538270950317, 1.4344942569732666, 0.04609739035367966, 0.7280333638191223, 0.6444336175918579, 0.863417387008667, 1.3423763513565063, 0.2826334834098816, 0.10140157490968704, 0.21646513044834137, 0.10054843872785568, 0.7075092792510986, 0.9791545867919922, 0.913628339767456, 0.7194646596908569, 0.56962651014328, 1.239325761795044, 0.7153125405311584, 0.07937587797641754, 0.5876209735870361, 0.20264196395874023, 0.8623877167701721, 1.4735878705978394, 0.0, 0.0, 5.182814121246338, 0.0, 1.9200999736785889, 7.360660076141357, -0.0, -2.5044126510620117, -3.858945608139038, -0.0, -0.0, -0.0, -0.0, -0.0, -2.4383599758148193, -4.6451191902160645, -5.169398784637451, -4.632980823516846, -3.0796914100646973, -3.8035781383514404, -3.2478408813476562, -2.945502281188965, -3.2819976806640625, -3.12546706199646, -3.4210143089294434, -5.585323333740234, -1.8678998947143555, -2.403998851776123, -1.1139942407608032, -1.290174961090088, -0.3401951491832733, -0.45339545607566833, -0.5695455074310303, -0.4246748387813568, -0.9204157590866089, -0.3456905484199524, -0.06764904409646988, -0.6827621459960938, -0.4994833767414093, -0.3225146234035492, -1.3204447031021118, -0.9636045098304749, -1.030243992805481, 0.32173964381217957, -0.03815111890435219, 0.485858678817749, -0.26619789004325867, 0.8945571780204773, 0.06467773020267487, 0.2177450954914093, 0.578281819820404, 0.7020799517631531, -0.238368421792984, 0.8473573923110962, 1.4656519889831543, 1.1182538270950317, 1.4344942569732666, 0.04609739035367966, 0.7280333638191223, 0.6444336175918579, 0.863417387008667, 1.3423763513565063, 0.2826334834098816, 0.10140157490968704, 0.21646513044834137, 0.10054843872785568, 0.7075092792510986, 0.9791545867919922, 0.913628339767456, 0.7194646596908569, 0.56962651014328, 1.239325761795044, 0.7153125405311584, 0.07937587797641754, 0.5876209735870361, 0.20264196395874023, 0.8623877167701721, 1.4735878705978394, 0.0, 0.0, 5.182814121246338, 0.0, 1.9200999736785889, 7.360660076141357], [-3.69246244430542, -3.886510133743286, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -4.989857196807861, -4.992905616760254, -5.118048667907715, -4.401079177856445, -3.9667487144470215, -4.031327247619629, -3.843392848968506, -2.6855123043060303, -3.7183070182800293, -3.2563631534576416, -2.769227981567383, -2.7773046493530273, -1.8348109722137451, -1.0580804347991943, -2.1641523838043213, -1.010053038597107, -1.151128888130188, -0.48952457308769226, -1.0963938236236572, -1.8590861558914185, -0.4401393532752991, -0.5130593180656433, -0.4020780324935913, -0.251846045255661, -0.5413036346435547, -0.11747341603040695, -0.21068818867206573, 0.05983073636889458, -0.16930963099002838, 0.08286257088184357, 0.37966370582580566, 0.37923070788383484, 0.7413129210472107, 0.6736778616905212, 0.5364193916320801, -0.8758613467216492, 0.5899731516838074, 1.6443716287612915, 1.3352574110031128, 0.9866863489151001, 0.8495411276817322, 0.24536707997322083, 1.0494821071624756, 1.7152713537216187, 1.4929358959197998, 1.9261232614517212, 0.7810996174812317, 1.5976334810256958, 0.507989764213562, 0.16047808527946472, 0.42583167552948, 1.2742259502410889, 0.9916180372238159, 0.5928187370300293, 1.5200262069702148, 0.28205588459968567, 0.6730350852012634, 0.6525411605834961, 0.240367129445076, 0.5844183564186096, 0.600966215133667, 0.6013816595077515, 0.9843758344650269, 1.5651112794876099, 0.0, 0.0, 3.9291000366210938, 0.0, 0.0, 6.876922130584717, -3.69246244430542, -3.886510133743286, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -4.989857196807861, -4.992905616760254, -5.118048667907715, -4.401079177856445, -3.9667487144470215, -4.031327247619629, -3.843392848968506, -2.6855123043060303, -3.7183070182800293, -3.2563631534576416, -2.769227981567383, -2.7773046493530273, -1.8348109722137451, -1.0580804347991943, -2.1641523838043213, -1.010053038597107, -1.151128888130188, -0.48952457308769226, -1.0963938236236572, -1.8590861558914185, -0.4401393532752991, -0.5130593180656433, -0.4020780324935913, -0.251846045255661, -0.5413036346435547, -0.11747341603040695, -0.21068818867206573, 0.05983073636889458, -0.16930963099002838, 0.08286257088184357, 0.37966370582580566, 0.37923070788383484, 0.7413129210472107, 0.6736778616905212, 0.5364193916320801, -0.8758613467216492, 0.5899731516838074, 1.6443716287612915, 1.3352574110031128, 0.9866863489151001, 0.8495411276817322, 0.24536707997322083, 1.0494821071624756, 1.7152713537216187, 1.4929358959197998, 1.9261232614517212, 0.7810996174812317, 1.5976334810256958, 0.507989764213562, 0.16047808527946472, 0.42583167552948, 1.2742259502410889, 0.9916180372238159, 0.5928187370300293, 1.5200262069702148, 0.28205588459968567, 0.6730350852012634, 0.6525411605834961, 0.240367129445076, 0.5844183564186096, 0.600966215133667, 0.6013816595077515, 0.9843758344650269, 1.5651112794876099, 0.0, 0.0, 3.9291000366210938, 0.0, 0.0, 6.876922130584717], [-1.191554307937622, -4.1579389572143555, 0.0, 0.0, 0.0, 0.0, 0.0, -3.2347936630249023, -4.714243412017822, -4.804210662841797, -4.896679878234863, -3.988215446472168, -3.0022151470184326, -1.8033102750778198, -3.229663133621216, -3.264540433883667, -2.677318572998047, -1.6333249807357788, -2.070812940597534, -2.699204444885254, -2.799934148788452, -1.833457589149475, -1.6937830448150635, -3.5386874675750732, -1.5365540981292725, -1.1053805351257324, -0.2911681830883026, -1.1170998811721802, -0.7536306977272034, -0.6015072464942932, -1.0506255626678467, -0.6010441184043884, -0.3722732663154602, -0.0956476628780365, 0.07080111652612686, -0.5591939091682434, 0.15275385975837708, 0.8310678005218506, 0.13847552239894867, 0.77342689037323, 1.0547748804092407, 0.6052960753440857, 0.4795070290565491, 0.4329463243484497, -0.35262054204940796, 1.0619471073150635, 0.9890716671943665, 1.0157209634780884, 1.5370646715164185, 1.3400466442108154, 0.5401934385299683, 1.0196423530578613, 0.6033825278282166, 0.6875441670417786, 0.5514365434646606, 0.4384302794933319, 0.8247233629226685, 0.3629224896430969, 1.384759545326233, 1.801605463027954, 1.4493951797485352, 0.4668620228767395, 0.23234803974628448, 0.02277614176273346, -0.09298719465732574, 1.473013997077942, 0.8986172676086426, 0.5958133935928345, 0.8503475189208984, 0.9501870274543762, 1.783783197402954, 1.117250680923462, 0.0, 0.0, 1.8099145889282227, 0.0, 0.0, 9.058931350708008, -1.191554307937622, -4.1579389572143555, -0.0, -0.0, -0.0, -0.0, -0.0, -3.2347936630249023, -4.714243412017822, -4.804210662841797, -4.896679878234863, -3.988215446472168, -3.0022151470184326, -1.8033102750778198, -3.229663133621216, -3.264540433883667, -2.677318572998047, -1.6333249807357788, -2.070812940597534, -2.699204444885254, -2.799934148788452, -1.833457589149475, -1.6937830448150635, -3.5386874675750732, -1.5365540981292725, -1.1053805351257324, -0.2911681830883026, -1.1170998811721802, -0.7536306977272034, -0.6015072464942932, -1.0506255626678467, -0.6010441184043884, -0.3722732663154602, -0.0956476628780365, 0.07080111652612686, -0.5591939091682434, 0.15275385975837708, 0.8310678005218506, 0.13847552239894867, 0.77342689037323, 1.0547748804092407, 0.6052960753440857, 0.4795070290565491, 0.4329463243484497, -0.35262054204940796, 1.0619471073150635, 0.9890716671943665, 1.0157209634780884, 1.5370646715164185, 1.3400466442108154, 0.5401934385299683, 1.0196423530578613, 0.6033825278282166, 0.6875441670417786, 0.5514365434646606, 0.4384302794933319, 0.8247233629226685, 0.3629224896430969, 1.384759545326233, 1.801605463027954, 1.4493951797485352, 0.4668620228767395, 0.23234803974628448, 0.02277614176273346, -0.09298719465732574, 1.473013997077942, 0.8986172676086426, 0.5958133935928345, 0.8503475189208984, 0.9501870274543762, 1.783783197402954, 1.117250680923462, 0.0, 0.0, 1.8099145889282227, 0.0, 0.0, 9.058931350708008], [-1.7274752855300903, -4.939949035644531, 0.0, 0.0, 0.0, 0.0, 0.0, -4.955554962158203, -5.228682518005371, -5.091588497161865, -4.708210468292236, -5.026210308074951, -4.155599594116211, -3.777057409286499, -3.4750075340270996, -2.9846560955047607, -1.5989958047866821, -3.705691337585449, -3.26987361907959, -0.9497373700141907, -2.4569907188415527, -1.720279574394226, -1.1630691289901733, -1.7310917377471924, -0.790890097618103, -1.255170226097107, -0.267012357711792, -0.6761832237243652, 0.16707032918930054, -0.8054163455963135, -0.205351322889328, -0.9459342956542969, -0.5267693400382996, 0.21592427790164948, -0.7951799035072327, -0.17697982490062714, 0.14168047904968262, 1.7769227027893066, 0.9657860994338989, 0.8661245107650757, 0.05449299514293671, 0.18253053724765778, 1.1642080545425415, 1.484076976776123, 1.080230712890625, 0.9056772589683533, 0.9621466398239136, 0.8474170565605164, 0.4953935146331787, 3.5517263412475586, 1.4722917079925537, 1.004805564880371, 1.1296327114105225, 1.171673059463501, 0.8681304454803467, 1.0410963296890259, 0.9301794171333313, 0.2031237930059433, 1.4440717697143555, 0.7502301335334778, 0.4034402668476105, 1.231419563293457, 0.7248380780220032, 0.34686094522476196, 0.6930227875709534, 0.46707409620285034, 1.8441275358200073, 0.7397701144218445, 1.3803772926330566, 0.7275632619857788, 0.591702938079834, 1.0284188985824585, 0.8500984907150269, 0.0, 0.0, 1.4762459993362427, 0.0, 5.976888656616211, -1.7274752855300903, -4.939949035644531, -0.0, -0.0, -0.0, -0.0, -0.0, -4.955554962158203, -5.228682518005371, -5.091588497161865, -4.708210468292236, -5.026210308074951, -4.155599594116211, -3.777057409286499, -3.4750075340270996, -2.9846560955047607, -1.5989958047866821, -3.705691337585449, -3.26987361907959, -0.9497373700141907, -2.4569907188415527, -1.720279574394226, -1.1630691289901733, -1.7310917377471924, -0.790890097618103, -1.255170226097107, -0.267012357711792, -0.6761832237243652, 0.16707032918930054, -0.8054163455963135, -0.205351322889328, -0.9459342956542969, -0.5267693400382996, 0.21592427790164948, -0.7951799035072327, -0.17697982490062714, 0.14168047904968262, 1.7769227027893066, 0.9657860994338989, 0.8661245107650757, 0.05449299514293671, 0.18253053724765778, 1.1642080545425415, 1.484076976776123, 1.080230712890625, 0.9056772589683533, 0.9621466398239136, 0.8474170565605164, 0.4953935146331787, 3.5517263412475586, 1.4722917079925537, 1.004805564880371, 1.1296327114105225, 1.171673059463501, 0.8681304454803467, 1.0410963296890259, 0.9301794171333313, 0.2031237930059433, 1.4440717697143555, 0.7502301335334778, 0.4034402668476105, 1.231419563293457, 0.7248380780220032, 0.34686094522476196, 0.6930227875709534, 0.46707409620285034, 1.8441275358200073, 0.7397701144218445, 1.3803772926330566, 0.7275632619857788, 0.591702938079834, 1.0284188985824585, 0.8500984907150269, 0.0, 0.0, 1.4762459993362427, 0.0, 5.976888656616211], [-3.1878163814544678, -5.268862247467041, 0.0, 0.0, 0.0, 0.0, -6.410630226135254, -5.263724327087402, -5.328965663909912, -4.876725673675537, -4.752374172210693, -4.31626558303833, -4.142093181610107, -3.692471504211426, -4.584841728210449, -2.9419007301330566, -3.1057465076446533, -2.1470444202423096, -2.434965133666992, -3.362945795059204, -3.0147042274475098, -1.6149977445602417, -1.386090636253357, -0.8409294486045837, -1.2940878868103027, -0.8056789636611938, 0.11009532958269119, -0.2321663200855255, -1.9099270105361938, -0.38132160902023315, 0.004294252954423428, -0.22020214796066284, -0.24708586931228638, -0.39584803581237793, 0.07807715237140656, 0.13232645392417908, 0.49152708053588867, -0.8801009654998779, 2.186819553375244, 0.8259994983673096, 1.5150388479232788, 0.6360651254653931, 0.5971431732177734, 0.3745003044605255, 1.7278462648391724, 0.9750179648399353, 0.9364817142486572, 1.928063154220581, 2.0982213020324707, 0.4722210168838501, 1.173799991607666, 2.4710066318511963, 2.1456243991851807, 0.5471575856208801, 1.1360933780670166, 1.1782881021499634, 0.6764336228370667, 1.2464549541473389, 2.5973587036132812, 2.2797694206237793, 1.8687583208084106, 1.066429853439331, 0.5784363150596619, 0.7555528283119202, 1.0234347581863403, 0.5617473125457764, 1.2108769416809082, 1.2805769443511963, 0.742108166217804, 0.4213298559188843, 0.6428214907646179, 1.951318383216858, 1.1624634265899658, 0.0, 0.0, 0.0, 0.0, 0.0, -3.1878163814544678, -5.268862247467041, -0.0, -0.0, -0.0, -0.0, -6.410630226135254, -5.263724327087402, -5.328965663909912, -4.876725673675537, -4.752374172210693, -4.31626558303833, -4.142093181610107, -3.692471504211426, -4.584841728210449, -2.9419007301330566, -3.1057465076446533, -2.1470444202423096, -2.434965133666992, -3.362945795059204, -3.0147042274475098, -1.6149977445602417, -1.386090636253357, -0.8409294486045837, -1.2940878868103027, -0.8056789636611938, 0.11009532958269119, -0.2321663200855255, -1.9099270105361938, -0.38132160902023315, 0.004294252954423428, -0.22020214796066284, -0.24708586931228638, -0.39584803581237793, 0.07807715237140656, 0.13232645392417908, 0.49152708053588867, -0.8801009654998779, 2.186819553375244, 0.8259994983673096, 1.5150388479232788, 0.6360651254653931, 0.5971431732177734, 0.3745003044605255, 1.7278462648391724, 0.9750179648399353, 0.9364817142486572, 1.928063154220581, 2.0982213020324707, 0.4722210168838501, 1.173799991607666, 2.4710066318511963, 2.1456243991851807, 0.5471575856208801, 1.1360933780670166, 1.1782881021499634, 0.6764336228370667, 1.2464549541473389, 2.5973587036132812, 2.2797694206237793, 1.8687583208084106, 1.066429853439331, 0.5784363150596619, 0.7555528283119202, 1.0234347581863403, 0.5617473125457764, 1.2108769416809082, 1.2805769443511963, 0.742108166217804, 0.4213298559188843, 0.6428214907646179, 1.951318383216858, 1.1624634265899658, 0.0, 0.0, 0.0, 0.0, 0.0], [-2.0934195518493652, 0.0, 0.0, 0.0, 0.0, -3.752373456954956, -6.165592193603516, -5.119028091430664, -6.039347171783447, -5.0182366371154785, -4.551897048950195, -4.425530910491943, -4.119929790496826, -3.7863657474517822, -3.707230567932129, -2.830090045928955, -2.611823797225952, -2.9024956226348877, -2.4252123832702637, -2.7356910705566406, -1.6750949621200562, -2.271611213684082, -0.9811098575592041, -2.4574882984161377, -1.7736278772354126, -0.729041337966919, -0.6172858476638794, -1.1802376508712769, -0.42772147059440613, -0.49229925870895386, -0.08904493600130081, -0.5344696044921875, 0.4807548522949219, 0.7715593576431274, 1.1834453344345093, -0.21580219268798828, 1.291097640991211, 2.3470120429992676, 0.4220433831214905, 1.720159649848938, 1.3280677795410156, 0.9180978536605835, 0.45840802788734436, 1.1261699199676514, 1.0422862768173218, 0.5459187030792236, 0.8995904326438904, 0.410863995552063, 1.8382436037063599, 1.317317247390747, 1.5174260139465332, 1.5246341228485107, 1.1674671173095703, 1.7551558017730713, 1.7010411024093628, 1.520403265953064, 0.7479444742202759, 1.0891320705413818, 1.0985183715820312, 2.6734626293182373, 0.8003318905830383, 0.09593354165554047, 1.3249202966690063, 3.266437530517578, 1.3897579908370972, 1.123826026916504, 1.6185784339904785, -0.04415889084339142, 1.1388565301895142, 1.3773812055587769, 1.351135015487671, 1.4646694660186768, 2.347926378250122, 0.41911548376083374, 0.0, 0.0, 0.590228796005249, 0.0, -2.0934195518493652, -0.0, -0.0, -0.0, -0.0, -3.752373456954956, -6.165592193603516, -5.119028091430664, -6.039347171783447, -5.0182366371154785, -4.551897048950195, -4.425530910491943, -4.119929790496826, -3.7863657474517822, -3.707230567932129, -2.830090045928955, -2.611823797225952, -2.9024956226348877, -2.4252123832702637, -2.7356910705566406, -1.6750949621200562, -2.271611213684082, -0.9811098575592041, -2.4574882984161377, -1.7736278772354126, -0.729041337966919, -0.6172858476638794, -1.1802376508712769, -0.42772147059440613, -0.49229925870895386, -0.08904493600130081, -0.5344696044921875, 0.4807548522949219, 0.7715593576431274, 1.1834453344345093, -0.21580219268798828, 1.291097640991211, 2.3470120429992676, 0.4220433831214905, 1.720159649848938, 1.3280677795410156, 0.9180978536605835, 0.45840802788734436, 1.1261699199676514, 1.0422862768173218, 0.5459187030792236, 0.8995904326438904, 0.410863995552063, 1.8382436037063599, 1.317317247390747, 1.5174260139465332, 1.5246341228485107, 1.1674671173095703, 1.7551558017730713, 1.7010411024093628, 1.520403265953064, 0.7479444742202759, 1.0891320705413818, 1.0985183715820312, 2.6734626293182373, 0.8003318905830383, 0.09593354165554047, 1.3249202966690063, 3.266437530517578, 1.3897579908370972, 1.123826026916504, 1.6185784339904785, -0.04415889084339142, 1.1388565301895142, 1.3773812055587769, 1.351135015487671, 1.4646694660186768, 2.347926378250122, 0.41911548376083374, 0.0, 0.0, 0.590228796005249, 0.0], [-5.171684265136719, 0.0, 0.0, 0.0, 0.0, -6.98160457611084, -6.121744632720947, -5.697960376739502, -5.046394348144531, -5.343328952789307, -5.470530986785889, -4.905135154724121, -4.415491580963135, -4.342676639556885, -3.949352741241455, -3.2828500270843506, -3.121001720428467, -2.9452385902404785, -2.5987603664398193, -2.6958253383636475, -1.8357418775558472, -1.1817362308502197, -1.110774278640747, -0.7903234362602234, -0.20456500351428986, -0.4859178066253662, -0.977749228477478, -0.9003912210464478, -1.2447824478149414, 0.42769771814346313, -0.9655821323394775, 0.10836944729089737, 0.290151983499527, 0.7739084362983704, 1.0268850326538086, 1.2229043245315552, 0.7980781197547913, -0.30265647172927856, -0.3168305456638336, 1.5129858255386353, 1.1680190563201904, 1.1775670051574707, 1.352128267288208, 0.625817060470581, 1.2810072898864746, 1.7620371580123901, 1.167841911315918, 1.7166707515716553, 1.1150915622711182, 1.779129147529602, 1.1417317390441895, 1.1443578004837036, 1.0356374979019165, 0.9307051301002502, 1.6557426452636719, 0.9477772116661072, 2.0078301429748535, 0.6601808071136475, -1.3377056121826172, 1.498201608657837, 1.3783893585205078, 1.0349420309066772, 0.557481586933136, 0.9615047574043274, -0.03457116708159447, 1.5297837257385254, 1.0952785015106201, 0.8161213994026184, 0.9626652002334595, 0.8182713389396667, 1.0236279964447021, 1.6244326829910278, 0.9920455813407898, 2.3303258419036865, 0.0, 0.0, 1.554159164428711, 0.0, -5.171684265136719, -0.0, -0.0, -0.0, -0.0, -6.98160457611084, -6.121744632720947, -5.697960376739502, -5.046394348144531, -5.343328952789307, -5.470530986785889, -4.905135154724121, -4.415491580963135, -4.342676639556885, -3.949352741241455, -3.2828500270843506, -3.121001720428467, -2.9452385902404785, -2.5987603664398193, -2.6958253383636475, -1.8357418775558472, -1.1817362308502197, -1.110774278640747, -0.7903234362602234, -0.20456500351428986, -0.4859178066253662, -0.977749228477478, -0.9003912210464478, -1.2447824478149414, 0.42769771814346313, -0.9655821323394775, 0.10836944729089737, 0.290151983499527, 0.7739084362983704, 1.0268850326538086, 1.2229043245315552, 0.7980781197547913, -0.30265647172927856, -0.3168305456638336, 1.5129858255386353, 1.1680190563201904, 1.1775670051574707, 1.352128267288208, 0.625817060470581, 1.2810072898864746, 1.7620371580123901, 1.167841911315918, 1.7166707515716553, 1.1150915622711182, 1.779129147529602, 1.1417317390441895, 1.1443578004837036, 1.0356374979019165, 0.9307051301002502, 1.6557426452636719, 0.9477772116661072, 2.0078301429748535, 0.6601808071136475, -1.3377056121826172, 1.498201608657837, 1.3783893585205078, 1.0349420309066772, 0.557481586933136, 0.9615047574043274, -0.03457116708159447, 1.5297837257385254, 1.0952785015106201, 0.8161213994026184, 0.9626652002334595, 0.8182713389396667, 1.0236279964447021, 1.6244326829910278, 0.9920455813407898, 2.3303258419036865, 0.0, 0.0, 1.554159164428711, 0.0], [-7.407524585723877, 0.0, 0.0, 0.0, -5.03617525100708, -6.149632930755615, -6.169125556945801, -5.711864471435547, -7.22509765625, -4.993510723114014, -4.6775736808776855, -4.039263725280762, -4.693717002868652, -3.87809681892395, -2.90647029876709, -3.3369641304016113, -3.440690279006958, -1.927537441253662, -2.312260150909424, -1.9343554973602295, -1.0720934867858887, -1.5817437171936035, -1.8427081108093262, -1.1940969228744507, -0.7862468957901001, -1.1945246458053589, -0.7363548874855042, -0.12058357894420624, -1.1952910423278809, -1.13414466381073, -0.3176991939544678, 0.3692655563354492, 0.8346469402313232, 0.7756150364875793, -0.2152474969625473, 0.42165184020996094, 1.1648800373077393, -0.21845704317092896, 2.8786706924438477, 1.0285228490829468, 1.0542579889297485, 1.219305396080017, 1.6859362125396729, 1.7201486825942993, 1.256571650505066, 1.6619653701782227, 1.0911452770233154, 3.114384889602661, 2.5077435970306396, 2.4105613231658936, 1.4209458827972412, 1.3539977073669434, 1.6652021408081055, 1.630770206451416, 1.3612009286880493, 1.2153868675231934, 1.3968698978424072, 1.4028620719909668, 1.3968912363052368, 0.5459392070770264, 0.6384232044219971, 1.1359325647354126, 1.3899809122085571, 1.2326146364212036, 1.21553635597229, 0.8351844549179077, 1.9253740310668945, 2.0930895805358887, 0.5277211666107178, 2.137320041656494, 1.1280303001403809, 1.056099772453308, 2.145589828491211, 1.2265433073043823, 0.0, 0.0, 0.0, 0.0, -7.407524585723877, -0.0, -0.0, -0.0, -5.03617525100708, -6.149632930755615, -6.169125556945801, -5.711864471435547, -7.22509765625, -4.993510723114014, -4.6775736808776855, -4.039263725280762, -4.693717002868652, -3.87809681892395, -2.90647029876709, -3.3369641304016113, -3.440690279006958, -1.927537441253662, -2.312260150909424, -1.9343554973602295, -1.0720934867858887, -1.5817437171936035, -1.8427081108093262, -1.1940969228744507, -0.7862468957901001, -1.1945246458053589, -0.7363548874855042, -0.12058357894420624, -1.1952910423278809, -1.13414466381073, -0.3176991939544678, 0.3692655563354492, 0.8346469402313232, 0.7756150364875793, -0.2152474969625473, 0.42165184020996094, 1.1648800373077393, -0.21845704317092896, 2.8786706924438477, 1.0285228490829468, 1.0542579889297485, 1.219305396080017, 1.6859362125396729, 1.7201486825942993, 1.256571650505066, 1.6619653701782227, 1.0911452770233154, 3.114384889602661, 2.5077435970306396, 2.4105613231658936, 1.4209458827972412, 1.3539977073669434, 1.6652021408081055, 1.630770206451416, 1.3612009286880493, 1.2153868675231934, 1.3968698978424072, 1.4028620719909668, 1.3968912363052368, 0.5459392070770264, 0.6384232044219971, 1.1359325647354126, 1.3899809122085571, 1.2326146364212036, 1.21553635597229, 0.8351844549179077, 1.9253740310668945, 2.0930895805358887, 0.5277211666107178, 2.137320041656494, 1.1280303001403809, 1.056099772453308, 2.145589828491211, 1.2265433073043823, 0.0, 0.0, 0.0, 0.0], [-5.159219741821289, 0.0, 0.0, 0.0, -6.475175380706787, -6.902494430541992, -5.794859886169434, -6.085167407989502, -5.289550304412842, -5.354968547821045, -5.530993461608887, -3.836960554122925, -4.824516773223877, -3.488933563232422, -3.5150365829467773, -2.9416656494140625, -3.151106834411621, -3.1044485569000244, -2.6609201431274414, -1.4273185729980469, -2.101407051086426, -2.4083259105682373, -0.9883488416671753, -0.9260618686676025, -1.3568968772888184, -3.3711740970611572, -0.34867456555366516, -0.5982344150543213, -0.7031721472740173, -1.3129630088806152, -0.1565612405538559, 0.6939513087272644, 0.16149947047233582, 0.4879777133464813, 0.3991522789001465, 1.5199031829833984, 1.5392450094223022, 0.4026435315608978, 0.7788644433021545, 1.0483474731445312, 1.0017015933990479, 0.27427053451538086, 1.8277983665466309, 1.569796085357666, 1.2296218872070312, 1.3156404495239258, 2.099371910095215, 0.8696991205215454, 1.0089232921600342, 1.7281004190444946, 1.1999911069869995, 1.2236905097961426, 1.098980188369751, 1.513843297958374, 1.4075030088424683, 1.389893651008606, 0.1785944253206253, 1.1345112323760986, 1.1822926998138428, 1.8731105327606201, 0.4908693730831146, 1.4404493570327759, 2.3144474029541016, 1.0301662683486938, -1.5280561447143555, 2.125338077545166, 0.9291384816169739, 0.7226533889770508, 1.2223445177078247, 0.9373800754547119, 1.4879472255706787, 1.5349040031433105, 0.9292824864387512, 1.4975227117538452, 2.2051563262939453, 0.0, 1.800582766532898, 3.012537956237793, -5.159219741821289, -0.0, -0.0, -0.0, -6.475175380706787, -6.902494430541992, -5.794859886169434, -6.085167407989502, -5.289550304412842, -5.354968547821045, -5.530993461608887, -3.836960554122925, -4.824516773223877, -3.488933563232422, -3.5150365829467773, -2.9416656494140625, -3.151106834411621, -3.1044485569000244, -2.6609201431274414, -1.4273185729980469, -2.101407051086426, -2.4083259105682373, -0.9883488416671753, -0.9260618686676025, -1.3568968772888184, -3.3711740970611572, -0.34867456555366516, -0.5982344150543213, -0.7031721472740173, -1.3129630088806152, -0.1565612405538559, 0.6939513087272644, 0.16149947047233582, 0.4879777133464813, 0.3991522789001465, 1.5199031829833984, 1.5392450094223022, 0.4026435315608978, 0.7788644433021545, 1.0483474731445312, 1.0017015933990479, 0.27427053451538086, 1.8277983665466309, 1.569796085357666, 1.2296218872070312, 1.3156404495239258, 2.099371910095215, 0.8696991205215454, 1.0089232921600342, 1.7281004190444946, 1.1999911069869995, 1.2236905097961426, 1.098980188369751, 1.513843297958374, 1.4075030088424683, 1.389893651008606, 0.1785944253206253, 1.1345112323760986, 1.1822926998138428, 1.8731105327606201, 0.4908693730831146, 1.4404493570327759, 2.3144474029541016, 1.0301662683486938, -1.5280561447143555, 2.125338077545166, 0.9291384816169739, 0.7226533889770508, 1.2223445177078247, 0.9373800754547119, 1.4879472255706787, 1.5349040031433105, 0.9292824864387512, 1.4975227117538452, 2.2051563262939453, 0.0, 1.800582766532898, 3.012537956237793], [-5.007004737854004, -3.7351596355438232, 0.0, 0.0, -5.5682597160339355, -5.840818405151367, -6.198496341705322, -5.9344048500061035, -5.487933158874512, -5.107961654663086, -4.60340690612793, -4.480861663818359, -3.496448278427124, -4.552288055419922, -3.9122819900512695, -4.118533134460449, -2.7692806720733643, -2.613996982574463, -2.45595645904541, -2.01147198677063, -2.458434581756592, -1.2316228151321411, -1.092489242553711, -1.6746734380722046, -1.8434137105941772, -1.5784932374954224, -0.28784632682800293, 0.635206937789917, -0.9655733704566956, -0.1232837364077568, 0.5866348147392273, 0.0361747071146965, 0.09417832642793655, 0.07759624719619751, 0.8456141352653503, -0.25217849016189575, 1.4402767419815063, 0.8133053183555603, 1.6062766313552856, 1.5028817653656006, 1.172857642173767, 0.8083173036575317, 1.4373691082000732, 1.2339973449707031, 2.1181142330169678, 2.3893017768859863, 2.3269739151000977, 2.57826828956604, 1.6665737628936768, 1.4046542644500732, 1.6334210634231567, 1.6709133386611938, 1.7289724349975586, 1.5984728336334229, 1.721454381942749, 1.073463797569275, 0.40791529417037964, 1.2060770988464355, 1.9395767450332642, 0.7658412456512451, 1.114759922027588, 0.734408438205719, 0.24577313661575317, 0.9649571776390076, 2.6355695724487305, 0.620481550693512, 1.4875657558441162, 1.0850672721862793, 0.7333270907402039, 1.7101918458938599, 1.660104751586914, 1.6627388000488281, 1.4267374277114868, 1.247567057609558, -0.35211509466171265, 0.0, 2.4032294750213623, 1.9956763982772827, -5.007004737854004, -3.7351596355438232, -0.0, -0.0, -5.5682597160339355, -5.840818405151367, -6.198496341705322, -5.9344048500061035, -5.487933158874512, -5.107961654663086, -4.60340690612793, -4.480861663818359, -3.496448278427124, -4.552288055419922, -3.9122819900512695, -4.118533134460449, -2.7692806720733643, -2.613996982574463, -2.45595645904541, -2.01147198677063, -2.458434581756592, -1.2316228151321411, -1.092489242553711, -1.6746734380722046, -1.8434137105941772, -1.5784932374954224, -0.28784632682800293, 0.635206937789917, -0.9655733704566956, -0.1232837364077568, 0.5866348147392273, 0.0361747071146965, 0.09417832642793655, 0.07759624719619751, 0.8456141352653503, -0.25217849016189575, 1.4402767419815063, 0.8133053183555603, 1.6062766313552856, 1.5028817653656006, 1.172857642173767, 0.8083173036575317, 1.4373691082000732, 1.2339973449707031, 2.1181142330169678, 2.3893017768859863, 2.3269739151000977, 2.57826828956604, 1.6665737628936768, 1.4046542644500732, 1.6334210634231567, 1.6709133386611938, 1.7289724349975586, 1.5984728336334229, 1.721454381942749, 1.073463797569275, 0.40791529417037964, 1.2060770988464355, 1.9395767450332642, 0.7658412456512451, 1.114759922027588, 0.734408438205719, 0.24577313661575317, 0.9649571776390076, 2.6355695724487305, 0.620481550693512, 1.4875657558441162, 1.0850672721862793, 0.7333270907402039, 1.7101918458938599, 1.660104751586914, 1.6627388000488281, 1.4267374277114868, 1.247567057609558, -0.35211509466171265, 0.0, 2.4032294750213623, 1.9956763982772827], [-3.904229164123535, -5.661882400512695, 0.0, -5.764159202575684, -5.884304046630859, -6.599907398223877, -6.183707237243652, -5.640872955322266, -5.105146408081055, -5.66510009765625, -4.702258586883545, -4.821094989776611, -5.048656463623047, -4.561554431915283, -3.806478500366211, -3.0114428997039795, -3.118656635284424, -2.430716037750244, -2.569220542907715, -2.425344705581665, -2.248594045639038, -1.282056450843811, -1.5220736265182495, -1.302341341972351, -1.2914533615112305, -0.9808131456375122, -0.31595438718795776, -0.5195510387420654, 0.675818920135498, -0.9336346983909607, -0.0791146382689476, 0.6501449942588806, -0.20185311138629913, 0.5314781665802002, 0.5473406314849854, 0.8458890318870544, 1.3843064308166504, 2.1094613075256348, 2.7903695106506348, 1.7383253574371338, 1.0821186304092407, 2.0679690837860107, 1.3090709447860718, 2.284675121307373, 0.4885076582431793, 1.5415034294128418, 1.2448582649230957, 1.3508563041687012, 1.2823631763458252, 1.6338022947311401, 1.2835803031921387, 0.8054203987121582, 1.733198642730713, 1.3641968965530396, 0.8596788644790649, 1.2903279066085815, 1.4897394180297852, 1.0596224069595337, 3.4765090942382812, 0.8981252312660217, 0.7991945147514343, 0.4149502217769623, 0.011831051670014858, 1.8273593187332153, 0.7563230395317078, 1.6257236003875732, 1.7110034227371216, 0.4073687195777893, 1.7206095457077026, 1.3391203880310059, 0.9139136672019958, 1.1291784048080444, 1.3103052377700806, 1.892530083656311, -1.9797649383544922, 0.0, 0.0, 1.8775910139083862, -3.904229164123535, -5.661882400512695, -0.0, -5.764159202575684, -5.884304046630859, -6.599907398223877, -6.183707237243652, -5.640872955322266, -5.105146408081055, -5.66510009765625, -4.702258586883545, -4.821094989776611, -5.048656463623047, -4.561554431915283, -3.806478500366211, -3.0114428997039795, -3.118656635284424, -2.430716037750244, -2.569220542907715, -2.425344705581665, -2.248594045639038, -1.282056450843811, -1.5220736265182495, -1.302341341972351, -1.2914533615112305, -0.9808131456375122, -0.31595438718795776, -0.5195510387420654, 0.675818920135498, -0.9336346983909607, -0.0791146382689476, 0.6501449942588806, -0.20185311138629913, 0.5314781665802002, 0.5473406314849854, 0.8458890318870544, 1.3843064308166504, 2.1094613075256348, 2.7903695106506348, 1.7383253574371338, 1.0821186304092407, 2.0679690837860107, 1.3090709447860718, 2.284675121307373, 0.4885076582431793, 1.5415034294128418, 1.2448582649230957, 1.3508563041687012, 1.2823631763458252, 1.6338022947311401, 1.2835803031921387, 0.8054203987121582, 1.733198642730713, 1.3641968965530396, 0.8596788644790649, 1.2903279066085815, 1.4897394180297852, 1.0596224069595337, 3.4765090942382812, 0.8981252312660217, 0.7991945147514343, 0.4149502217769623, 0.011831051670014858, 1.8273593187332153, 0.7563230395317078, 1.6257236003875732, 1.7110034227371216, 0.4073687195777893, 1.7206095457077026, 1.3391203880310059, 0.9139136672019958, 1.1291784048080444, 1.3103052377700806, 1.892530083656311, -1.9797649383544922, -0.0, 0.0, 1.8775910139083862], [-4.604016304016113, 0.0, 0.0, -8.025147438049316, -6.006487846374512, -6.669500350952148, -5.913399696350098, -6.428510665893555, -4.717716693878174, -5.61927604675293, -5.7421464920043945, -4.433838367462158, -2.4656405448913574, -4.112468719482422, -3.5093767642974854, -4.293895721435547, -1.300992488861084, -2.1913020610809326, -2.015713691711426, -2.2038025856018066, -2.0700135231018066, -1.6459585428237915, -2.1542482376098633, -1.6187984943389893, -0.9922345280647278, -1.0685206651687622, -0.5366272926330566, -1.6028062105178833, -0.027889994904398918, -0.04057075083255768, 0.07016406208276749, -0.1639108955860138, -0.7758978605270386, 0.971197783946991, 0.5403401851654053, 1.0979292392730713, 1.1061317920684814, 2.039795160293579, 1.1537257432937622, 1.3700066804885864, 1.1350067853927612, 1.8909580707550049, 0.9797864556312561, 1.2924169301986694, 0.20767778158187866, 1.6016253232955933, 1.5911964178085327, 1.605540156364441, 1.2582272291183472, 1.1068789958953857, 0.6825460195541382, 1.1623295545578003, 1.2986115217208862, 1.2511078119277954, 1.2277110815048218, 1.3743822574615479, 1.3865922689437866, 2.1912384033203125, 1.4872655868530273, 0.8329033255577087, 1.0882673263549805, 1.8445942401885986, 1.7961739301681519, 1.2587571144104004, 1.3007731437683105, 0.8545095324516296, 1.8053375482559204, 0.8998919129371643, 0.8074381947517395, 1.655882477760315, 1.725640892982483, 1.0599441528320312, 1.7004642486572266, 1.3075275421142578, -0.05696398764848709, 0.0, 0.0, 1.4392828941345215, -4.604016304016113, -0.0, -0.0, -8.025147438049316, -6.006487846374512, -6.669500350952148, -5.913399696350098, -6.428510665893555, -4.717716693878174, -5.61927604675293, -5.7421464920043945, -4.433838367462158, -2.4656405448913574, -4.112468719482422, -3.5093767642974854, -4.293895721435547, -1.300992488861084, -2.1913020610809326, -2.015713691711426, -2.2038025856018066, -2.0700135231018066, -1.6459585428237915, -2.1542482376098633, -1.6187984943389893, -0.9922345280647278, -1.0685206651687622, -0.5366272926330566, -1.6028062105178833, -0.027889994904398918, -0.04057075083255768, 0.07016406208276749, -0.1639108955860138, -0.7758978605270386, 0.971197783946991, 0.5403401851654053, 1.0979292392730713, 1.1061317920684814, 2.039795160293579, 1.1537257432937622, 1.3700066804885864, 1.1350067853927612, 1.8909580707550049, 0.9797864556312561, 1.2924169301986694, 0.20767778158187866, 1.6016253232955933, 1.5911964178085327, 1.605540156364441, 1.2582272291183472, 1.1068789958953857, 0.6825460195541382, 1.1623295545578003, 1.2986115217208862, 1.2511078119277954, 1.2277110815048218, 1.3743822574615479, 1.3865922689437866, 2.1912384033203125, 1.4872655868530273, 0.8329033255577087, 1.0882673263549805, 1.8445942401885986, 1.7961739301681519, 1.2587571144104004, 1.3007731437683105, 0.8545095324516296, 1.8053375482559204, 0.8998919129371643, 0.8074381947517395, 1.655882477760315, 1.725640892982483, 1.0599441528320312, 1.7004642486572266, 1.3075275421142578, -0.05696398764848709, -0.0, 0.0, 1.4392828941345215], [-5.751767158508301, 0.0, 0.0, -6.90234899520874, -5.690297603607178, -6.3664703369140625, -6.175779342651367, -5.672102451324463, -5.569790363311768, -4.827429294586182, -4.918804168701172, -4.8449296951293945, -4.823600769042969, -3.8272979259490967, -4.610479354858398, -3.749131441116333, -3.327613353729248, -2.948115825653076, -1.8074392080307007, -2.559422254562378, -1.6969761848449707, -1.7130752801895142, -1.4924830198287964, -1.8604809045791626, -1.2607656717300415, -1.0226882696151733, -0.7156479358673096, -0.041654445230960846, 0.2719048261642456, 0.31459590792655945, -0.4464598000049591, -0.5967973470687866, -0.055007658898830414, 0.34428903460502625, 1.5543944835662842, 1.7788894176483154, 1.057537317276001, 1.5348145961761475, 0.0, -0.2909727394580841, 1.457419514656067, 3.230088710784912, 0.6312167644500732, 2.143026113510132, 1.3960886001586914, 3.569108486175537, 0.6756450533866882, 1.314072608947754, 1.6326736211776733, 1.613899827003479, 1.7145109176635742, 1.4818449020385742, 1.6383774280548096, 1.249900221824646, 1.5339839458465576, 1.039914846420288, 1.2994012832641602, 1.103200078010559, 1.841567873954773, 1.0113496780395508, 1.395727515220642, 0.8500761389732361, 1.2277189493179321, 0.811615526676178, 1.1050231456756592, 0.8716462850570679, 0.8077865242958069, -0.06178829446434975, 1.6529080867767334, 1.3850326538085938, 0.997608482837677, 1.543710470199585, 1.7815771102905273, 1.3729335069656372, 1.2763266563415527, 0.0, 0.0, 3.4481990337371826, -5.751767158508301, -0.0, -0.0, -6.90234899520874, -5.690297603607178, -6.3664703369140625, -6.175779342651367, -5.672102451324463, -5.569790363311768, -4.827429294586182, -4.918804168701172, -4.8449296951293945, -4.823600769042969, -3.8272979259490967, -4.610479354858398, -3.749131441116333, -3.327613353729248, -2.948115825653076, -1.8074392080307007, -2.559422254562378, -1.6969761848449707, -1.7130752801895142, -1.4924830198287964, -1.8604809045791626, -1.2607656717300415, -1.0226882696151733, -0.7156479358673096, -0.041654445230960846, 0.2719048261642456, 0.31459590792655945, -0.4464598000049591, -0.5967973470687866, -0.055007658898830414, 0.34428903460502625, 1.5543944835662842, 1.7788894176483154, 1.057537317276001, 1.5348145961761475, 0.0, -0.2909727394580841, 1.457419514656067, 3.230088710784912, 0.6312167644500732, 2.143026113510132, 1.3960886001586914, 3.569108486175537, 0.6756450533866882, 1.314072608947754, 1.6326736211776733, 1.613899827003479, 1.7145109176635742, 1.4818449020385742, 1.6383774280548096, 1.249900221824646, 1.5339839458465576, 1.039914846420288, 1.2994012832641602, 1.103200078010559, 1.841567873954773, 1.0113496780395508, 1.395727515220642, 0.8500761389732361, 1.2277189493179321, 0.811615526676178, 1.1050231456756592, 0.8716462850570679, 0.8077865242958069, -0.06178829446434975, 1.6529080867767334, 1.3850326538085938, 0.997608482837677, 1.543710470199585, 1.7815771102905273, 1.3729335069656372, 1.2763266563415527, 0.0, 0.0, 3.4481990337371826], [-7.248859405517578, 0.0, 0.0, -6.665284156799316, -6.720060348510742, -6.607240200042725, -6.8169450759887695, -5.701597213745117, -5.654458045959473, -5.5207600593566895, -3.9454424381256104, -5.109592914581299, -4.653640270233154, -3.8668038845062256, -3.041256904602051, -4.006214618682861, -2.2620301246643066, -2.9175162315368652, -1.5431554317474365, -2.433161735534668, -2.1679320335388184, -1.5810871124267578, -1.4829615354537964, -1.2033812999725342, -0.9774110913276672, -0.6010631918907166, -0.3285990357398987, -1.4404391050338745, 0.8998298645019531, -1.0274945497512817, 0.5457066297531128, -0.38649192452430725, 0.3770979046821594, 1.918958067893982, 1.0265722274780273, 0.45661211013793945, 0.42200857400894165, 0.8734312057495117, 0.2740120589733124, -0.48642098903656006, 0.8563110828399658, 4.418430805206299, -0.5125944018363953, 2.205456495285034, 2.2138266563415527, 0.28524893522262573, 1.370859980583191, 1.6760684251785278, 1.2275505065917969, 1.69925057888031, 1.6074120998382568, 0.9239771962165833, 1.5659945011138916, 1.3813726902008057, 1.025321125984192, 1.2599315643310547, 1.9131929874420166, 1.4376955032348633, 1.7333600521087646, 0.9933872818946838, 1.370110034942627, 1.0963021516799927, 2.049539566040039, 1.2544233798980713, 0.12494263797998428, 1.3441157341003418, 1.4852696657180786, 1.2125577926635742, 1.9587634801864624, 1.8333451747894287, 2.2677342891693115, 1.837908148765564, 1.428815484046936, 0.5595486760139465, 1.1413853168487549, 0.0, 0.0, 0.0, -7.248859405517578, -0.0, -0.0, -6.665284156799316, -6.720060348510742, -6.607240200042725, -6.8169450759887695, -5.701597213745117, -5.654458045959473, -5.5207600593566895, -3.9454424381256104, -5.109592914581299, -4.653640270233154, -3.8668038845062256, -3.041256904602051, -4.006214618682861, -2.2620301246643066, -2.9175162315368652, -1.5431554317474365, -2.433161735534668, -2.1679320335388184, -1.5810871124267578, -1.4829615354537964, -1.2033812999725342, -0.9774110913276672, -0.6010631918907166, -0.3285990357398987, -1.4404391050338745, 0.8998298645019531, -1.0274945497512817, 0.5457066297531128, -0.38649192452430725, 0.3770979046821594, 1.918958067893982, 1.0265722274780273, 0.45661211013793945, 0.42200857400894165, 0.8734312057495117, 0.2740120589733124, -0.48642098903656006, 0.8563110828399658, 4.418430805206299, -0.5125944018363953, 2.205456495285034, 2.2138266563415527, 0.28524893522262573, 1.370859980583191, 1.6760684251785278, 1.2275505065917969, 1.69925057888031, 1.6074120998382568, 0.9239771962165833, 1.5659945011138916, 1.3813726902008057, 1.025321125984192, 1.2599315643310547, 1.9131929874420166, 1.4376955032348633, 1.7333600521087646, 0.9933872818946838, 1.370110034942627, 1.0963021516799927, 2.049539566040039, 1.2544233798980713, 0.12494263797998428, 1.3441157341003418, 1.4852696657180786, 1.2125577926635742, 1.9587634801864624, 1.8333451747894287, 2.2677342891693115, 1.837908148765564, 1.428815484046936, 0.5595486760139465, 1.1413853168487549, 0.0, 0.0, 0.0], [-7.258625030517578, 0.0, -7.607411861419678, -6.233674049377441, -6.131711959838867, -6.7473015785217285, -7.303575038909912, -6.595972537994385, -6.742152690887451, -5.138702392578125, -4.810108184814453, -4.489940643310547, -4.443068504333496, -4.467508316040039, -3.507127523422241, -3.3960328102111816, -3.009963274002075, -3.0065784454345703, -2.5904483795166016, -1.9303841590881348, -1.628052830696106, -1.5330032110214233, -2.1486446857452393, -1.045999526977539, -1.0581064224243164, -0.5867969989776611, -0.7581791877746582, -0.10355371236801147, -0.4078291654586792, 0.7717652320861816, 0.7254189848899841, -0.02616805024445057, 0.6762089729309082, -0.16142098605632782, 1.2891261577606201, 0.14951446652412415, -0.3597564995288849, -0.4177621006965637, -0.9348112344741821, 0.8701241612434387, 0.30419057607650757, 1.521828293800354, 2.3156018257141113, 0.15209759771823883, 1.0340452194213867, 1.1465394496917725, 1.8986445665359497, 1.5930745601654053, 1.8159313201904297, 1.7668941020965576, 1.5546679496765137, 1.3499633073806763, 1.3666797876358032, 1.7366162538528442, 0.35081160068511963, 0.950419008731842, 1.137003779411316, 1.4110008478164673, 1.2899411916732788, 1.0974595546722412, 1.214198112487793, 0.5857993960380554, 0.7929499745368958, 1.957196831703186, 1.4362263679504395, 0.8398646712303162, 1.394031047821045, 1.3561577796936035, 0.6651723384857178, 1.6743282079696655, 0.8376522660255432, 1.6578820943832397, 1.7194163799285889, 1.591792106628418, 1.3512842655181885, 0.0, 0.0, 0.0, -7.258625030517578, -0.0, -7.607411861419678, -6.233674049377441, -6.131711959838867, -6.7473015785217285, -7.303575038909912, -6.595972537994385, -6.742152690887451, -5.138702392578125, -4.810108184814453, -4.489940643310547, -4.443068504333496, -4.467508316040039, -3.507127523422241, -3.3960328102111816, -3.009963274002075, -3.0065784454345703, -2.5904483795166016, -1.9303841590881348, -1.628052830696106, -1.5330032110214233, -2.1486446857452393, -1.045999526977539, -1.0581064224243164, -0.5867969989776611, -0.7581791877746582, -0.10355371236801147, -0.4078291654586792, 0.7717652320861816, 0.7254189848899841, -0.02616805024445057, 0.6762089729309082, -0.16142098605632782, 1.2891261577606201, 0.14951446652412415, -0.3597564995288849, -0.4177621006965637, -0.9348112344741821, 0.8701241612434387, 0.30419057607650757, 1.521828293800354, 2.3156018257141113, 0.15209759771823883, 1.0340452194213867, 1.1465394496917725, 1.8986445665359497, 1.5930745601654053, 1.8159313201904297, 1.7668941020965576, 1.5546679496765137, 1.3499633073806763, 1.3666797876358032, 1.7366162538528442, 0.35081160068511963, 0.950419008731842, 1.137003779411316, 1.4110008478164673, 1.2899411916732788, 1.0974595546722412, 1.214198112487793, 0.5857993960380554, 0.7929499745368958, 1.957196831703186, 1.4362263679504395, 0.8398646712303162, 1.394031047821045, 1.3561577796936035, 0.6651723384857178, 1.6743282079696655, 0.8376522660255432, 1.6578820943832397, 1.7194163799285889, 1.591792106628418, 1.3512842655181885, 0.0, 0.0, 0.0], [-8.456138610839844, 0.0, -6.047725200653076, -7.2851481437683105, -6.93659782409668, -6.2509894371032715, -6.092170715332031, -6.363291263580322, -6.1817779541015625, -5.753868103027344, -5.19675350189209, -5.181385517120361, -4.890463352203369, -4.208353519439697, -4.287566184997559, -3.4040277004241943, -3.75870943069458, -2.951869487762451, -2.7611422538757324, -1.9843264818191528, -2.316909074783325, -1.7822372913360596, -1.2124919891357422, -1.2269365787506104, -0.6296219825744629, -0.8354384899139404, -0.795162558555603, -0.7154969573020935, -0.6626341938972473, -0.47691595554351807, -0.6957069635391235, -0.08630938082933426, 0.5330771207809448, 0.6243325471878052, -0.4512275457382202, 0.23470847308635712, 1.0516552925109863, -0.03287478908896446, -0.03493092954158783, 0.11948440223932266, 0.45065242052078247, 1.726483941078186, 1.057587742805481, 0.39982908964157104, 1.3320941925048828, 1.3299880027770996, 1.183506965637207, 1.5434198379516602, 1.648195743560791, 1.606551170349121, 1.208702564239502, 1.5064884424209595, 1.7230501174926758, 1.16400945186615, 1.3044054508209229, 1.15171217918396, 0.982183039188385, 1.6916916370391846, 1.4975297451019287, 0.34496331214904785, 2.0530805587768555, 1.4926930665969849, 0.9224530458450317, 0.5799885392189026, 1.1502137184143066, 1.7772579193115234, 1.4705076217651367, 0.5035022497177124, 1.100395917892456, 1.4207087755203247, 1.9002033472061157, 1.2470543384552002, 1.8607258796691895, 1.9659104347229004, 1.6305218935012817, 2.6000959873199463, 0.0, 0.0, -8.456138610839844, -0.0, -6.047725200653076, -7.2851481437683105, -6.93659782409668, -6.2509894371032715, -6.092170715332031, -6.363291263580322, -6.1817779541015625, -5.753868103027344, -5.19675350189209, -5.181385517120361, -4.890463352203369, -4.208353519439697, -4.287566184997559, -3.4040277004241943, -3.75870943069458, -2.951869487762451, -2.7611422538757324, -1.9843264818191528, -2.316909074783325, -1.7822372913360596, -1.2124919891357422, -1.2269365787506104, -0.6296219825744629, -0.8354384899139404, -0.795162558555603, -0.7154969573020935, -0.6626341938972473, -0.47691595554351807, -0.6957069635391235, -0.08630938082933426, 0.5330771207809448, 0.6243325471878052, -0.4512275457382202, 0.23470847308635712, 1.0516552925109863, -0.03287478908896446, -0.03493092954158783, 0.11948440223932266, 0.45065242052078247, 1.726483941078186, 1.057587742805481, 0.39982908964157104, 1.3320941925048828, 1.3299880027770996, 1.183506965637207, 1.5434198379516602, 1.648195743560791, 1.606551170349121, 1.208702564239502, 1.5064884424209595, 1.7230501174926758, 1.16400945186615, 1.3044054508209229, 1.15171217918396, 0.982183039188385, 1.6916916370391846, 1.4975297451019287, 0.34496331214904785, 2.0530805587768555, 1.4926930665969849, 0.9224530458450317, 0.5799885392189026, 1.1502137184143066, 1.7772579193115234, 1.4705076217651367, 0.5035022497177124, 1.100395917892456, 1.4207087755203247, 1.9002033472061157, 1.2470543384552002, 1.8607258796691895, 1.9659104347229004, 1.6305218935012817, 2.6000959873199463, 0.0, 0.0], [0.0, 0.0, -8.857550621032715, -6.94807243347168, -6.852635860443115, -7.5954203605651855, -6.486407279968262, -6.442908763885498, -6.135959625244141, -5.880346775054932, -5.205810070037842, -4.100823402404785, -5.009555339813232, -4.088504314422607, -4.744524955749512, -4.571748733520508, -3.5396974086761475, -3.2087695598602295, -1.7151950597763062, 0.523570716381073, -2.7084736824035645, -1.8145623207092285, -0.72903972864151, -1.3703101873397827, -0.883350133895874, -0.7976224422454834, -0.8401868939399719, -0.28835487365722656, -0.21092554926872253, 0.09786300361156464, 0.10000110417604446, 0.04168923571705818, 0.7800788283348083, 0.2692694067955017, 0.5504990220069885, 0.21910202503204346, -0.03459235280752182, -0.2133737951517105, 0.06777236610651016, -0.059022556990385056, 1.322052240371704, 0.293173611164093, 1.925937533378601, 1.1165039539337158, 1.0271351337432861, 1.0810648202896118, 2.2102301120758057, 1.680092453956604, 1.3639365434646606, 1.3714771270751953, 1.3666608333587646, 0.7004626989364624, 1.2142858505249023, 2.4968104362487793, 1.5350143909454346, 1.308330774307251, 1.4591484069824219, 1.87188720703125, 0.841639518737793, 1.2847304344177246, 0.7172566652297974, 0.6545102596282959, 1.1413993835449219, 1.3674547672271729, 0.9598102569580078, 1.2741669416427612, 1.545668601989746, 0.9662503600120544, 0.910333514213562, 0.48348212242126465, 2.401360511779785, 2.8709096908569336, 1.2825493812561035, 1.5516629219055176, 2.1931679248809814, 3.098942995071411, 0.0, 0.0, -0.0, -0.0, -8.857550621032715, -6.94807243347168, -6.852635860443115, -7.5954203605651855, -6.486407279968262, -6.442908763885498, -6.135959625244141, -5.880346775054932, -5.205810070037842, -4.100823402404785, -5.009555339813232, -4.088504314422607, -4.744524955749512, -4.571748733520508, -3.5396974086761475, -3.2087695598602295, -1.7151950597763062, 0.523570716381073, -2.7084736824035645, -1.8145623207092285, -0.72903972864151, -1.3703101873397827, -0.883350133895874, -0.7976224422454834, -0.8401868939399719, -0.28835487365722656, -0.21092554926872253, 0.09786300361156464, 0.10000110417604446, 0.04168923571705818, 0.7800788283348083, 0.2692694067955017, 0.5504990220069885, 0.21910202503204346, -0.03459235280752182, -0.2133737951517105, 0.06777236610651016, -0.059022556990385056, 1.322052240371704, 0.293173611164093, 1.925937533378601, 1.1165039539337158, 1.0271351337432861, 1.0810648202896118, 2.2102301120758057, 1.680092453956604, 1.3639365434646606, 1.3714771270751953, 1.3666608333587646, 0.7004626989364624, 1.2142858505249023, 2.4968104362487793, 1.5350143909454346, 1.308330774307251, 1.4591484069824219, 1.87188720703125, 0.841639518737793, 1.2847304344177246, 0.7172566652297974, 0.6545102596282959, 1.1413993835449219, 1.3674547672271729, 0.9598102569580078, 1.2741669416427612, 1.545668601989746, 0.9662503600120544, 0.910333514213562, 0.48348212242126465, 2.401360511779785, 2.8709096908569336, 1.2825493812561035, 1.5516629219055176, 2.1931679248809814, 3.098942995071411, 0.0, 0.0], [0.0, 0.0, -6.808562755584717, -6.893864154815674, -7.730475425720215, -7.046578884124756, -6.960555076599121, -5.757151126861572, -5.78245735168457, -5.921056270599365, -5.531279563903809, -5.225711822509766, -4.559502124786377, -3.938044309616089, -3.927077293395996, -3.6067328453063965, -3.8538594245910645, -2.8850502967834473, -2.8787755966186523, -3.007490634918213, -2.338022470474243, -2.1852190494537354, -1.6753917932510376, -1.1830962896347046, -1.2084451913833618, -0.6176577210426331, -0.3871571123600006, -1.3612470626831055, -0.2035415917634964, -0.3948458433151245, 0.3553670644760132, -0.2048284113407135, 0.36978060007095337, -0.44948676228523254, -1.2002009153366089, 0.00019048756803385913, -0.26860249042510986, -0.2897722125053406, 0.12952923774719238, 1.52923583984375, 0.9856085181236267, 0.6929225921630859, 1.3566454648971558, 1.9917446374893188, 1.2201210260391235, 2.0555777549743652, 1.2018699645996094, 1.3093721866607666, 1.2735388278961182, 0.7925506234169006, 0.9563559889793396, 1.438729166984558, 1.2196176052093506, 0.7295874357223511, 0.2653574049472809, -0.15389855206012726, 1.5251635313034058, 1.57606041431427, 0.7036736607551575, 1.0309730768203735, 1.857491374015808, 1.7579022645950317, 1.6400693655014038, 1.2070133686065674, 2.8680434226989746, 1.3413227796554565, 1.0465526580810547, 1.0401445627212524, 1.9961570501327515, 1.1283081769943237, 0.9719623923301697, 1.6171900033950806, 1.0525555610656738, 1.4131454229354858, 2.0653648376464844, 2.8717899322509766, 0.0, 0.0, -0.0, -0.0, -6.808562755584717, -6.893864154815674, -7.730475425720215, -7.046578884124756, -6.960555076599121, -5.757151126861572, -5.78245735168457, -5.921056270599365, -5.531279563903809, -5.225711822509766, -4.559502124786377, -3.938044309616089, -3.927077293395996, -3.6067328453063965, -3.8538594245910645, -2.8850502967834473, -2.8787755966186523, -3.007490634918213, -2.338022470474243, -2.1852190494537354, -1.6753917932510376, -1.1830962896347046, -1.2084451913833618, -0.6176577210426331, -0.3871571123600006, -1.3612470626831055, -0.2035415917634964, -0.3948458433151245, 0.3553670644760132, -0.2048284113407135, 0.36978060007095337, -0.44948676228523254, -1.2002009153366089, 0.00019048756803385913, -0.26860249042510986, -0.2897722125053406, 0.12952923774719238, 1.52923583984375, 0.9856085181236267, 0.6929225921630859, 1.3566454648971558, 1.9917446374893188, 1.2201210260391235, 2.0555777549743652, 1.2018699645996094, 1.3093721866607666, 1.2735388278961182, 0.7925506234169006, 0.9563559889793396, 1.438729166984558, 1.2196176052093506, 0.7295874357223511, 0.2653574049472809, -0.15389855206012726, 1.5251635313034058, 1.57606041431427, 0.7036736607551575, 1.0309730768203735, 1.857491374015808, 1.7579022645950317, 1.6400693655014038, 1.2070133686065674, 2.8680434226989746, 1.3413227796554565, 1.0465526580810547, 1.0401445627212524, 1.9961570501327515, 1.1283081769943237, 0.9719623923301697, 1.6171900033950806, 1.0525555610656738, 1.4131454229354858, 2.0653648376464844, 2.8717899322509766, 0.0, 0.0], [0.0, 0.0, -6.860267639160156, -6.946104049682617, -6.793206214904785, -7.364431858062744, -6.433139324188232, -6.893340587615967, -6.194952487945557, -5.9872941970825195, -5.089310646057129, -5.388537406921387, -5.356418132781982, -4.290045261383057, -4.847879886627197, -4.123031139373779, -3.3777523040771484, -3.614014148712158, -3.5615952014923096, -2.733185291290283, -2.0892930030822754, -1.4012839794158936, -1.0294376611709595, -1.6016732454299927, -0.862586259841919, -1.176942229270935, -0.8869167566299438, -0.5639950633049011, -0.6028801798820496, 0.030897751450538635, -0.7706296443939209, 0.6510836482048035, -0.31631582975387573, 0.07711076736450195, 0.044056255370378494, -0.14862528443336487, 0.5854284763336182, 0.7892310619354248, 1.0429062843322754, 0.3825342357158661, 0.7821931838989258, 0.9664300084114075, 1.4025102853775024, 1.4839129447937012, 1.385536789894104, 2.462491035461426, 1.4462753534317017, 0.648555338382721, 0.9427934288978577, 1.6738731861114502, 1.1805880069732666, 0.8753407001495361, 0.46905410289764404, 2.3999874591827393, 3.05936598777771, 1.5428870916366577, 0.3147094249725342, 1.2783821821212769, 1.0084726810455322, 0.9473931193351746, 0.975497841835022, 1.0872381925582886, 0.772171139717102, 0.5476502180099487, 1.0429940223693848, 1.244425892829895, 1.0806074142456055, 0.16872867941856384, 1.6293683052062988, 1.0322188138961792, 1.0443307161331177, 1.1599245071411133, 2.689706325531006, 1.8920856714248657, 2.0581536293029785, 1.7247389554977417, 0.0, 0.0, -0.0, -0.0, -6.860267639160156, -6.946104049682617, -6.793206214904785, -7.364431858062744, -6.433139324188232, -6.893340587615967, -6.194952487945557, -5.9872941970825195, -5.089310646057129, -5.388537406921387, -5.356418132781982, -4.290045261383057, -4.847879886627197, -4.123031139373779, -3.3777523040771484, -3.614014148712158, -3.5615952014923096, -2.733185291290283, -2.0892930030822754, -1.4012839794158936, -1.0294376611709595, -1.6016732454299927, -0.862586259841919, -1.176942229270935, -0.8869167566299438, -0.5639950633049011, -0.6028801798820496, 0.030897751450538635, -0.7706296443939209, 0.6510836482048035, -0.31631582975387573, 0.07711076736450195, 0.044056255370378494, -0.14862528443336487, 0.5854284763336182, 0.7892310619354248, 1.0429062843322754, 0.3825342357158661, 0.7821931838989258, 0.9664300084114075, 1.4025102853775024, 1.4839129447937012, 1.385536789894104, 2.462491035461426, 1.4462753534317017, 0.648555338382721, 0.9427934288978577, 1.6738731861114502, 1.1805880069732666, 0.8753407001495361, 0.46905410289764404, 2.3999874591827393, 3.05936598777771, 1.5428870916366577, 0.3147094249725342, 1.2783821821212769, 1.0084726810455322, 0.9473931193351746, 0.975497841835022, 1.0872381925582886, 0.772171139717102, 0.5476502180099487, 1.0429940223693848, 1.244425892829895, 1.0806074142456055, 0.16872867941856384, 1.6293683052062988, 1.0322188138961792, 1.0443307161331177, 1.1599245071411133, 2.689706325531006, 1.8920856714248657, 2.0581536293029785, 1.7247389554977417, 0.0, 0.0], [0.0, -6.742569923400879, -7.793022632598877, -7.64204216003418, -7.031299114227295, -6.9635162353515625, -7.058359622955322, -7.168916702270508, -6.149658203125, -5.601688861846924, -5.7762274742126465, -5.409757137298584, -4.6338210105896, -5.457515239715576, -4.007063865661621, -4.6708292961120605, -4.032543659210205, -4.275306701660156, -2.6009395122528076, -1.8421138525009155, -2.8801681995391846, -1.8198237419128418, -0.9761425852775574, -1.4726428985595703, -1.0454435348510742, -0.9387151598930359, -0.6000051498413086, -0.5563983917236328, -0.5265407562255859, -0.5074765086174011, 0.19586993753910065, -0.4473012685775757, 1.07246994972229, -0.4477481245994568, 0.4406571388244629, 0.34115070104599, 0.46289578080177307, -0.3318515717983246, 0.8217183351516724, 1.0841686725616455, 1.5266414880752563, 0.46863654255867004, 0.8728238940238953, 0.9807668328285217, 1.7293345928192139, 1.2972660064697266, 2.715496063232422, 1.573313593864441, 0.8669604063034058, 1.1336196660995483, 0.6716318130493164, 1.9270129203796387, 0.9094887375831604, 0.9736060500144958, 1.4344810247421265, 2.0059847831726074, 2.04455304145813, 1.1716420650482178, 0.9341264963150024, 0.9906036257743835, 1.165189504623413, 0.03569091483950615, 1.1719614267349243, 1.112713098526001, 0.7678945660591125, -0.08236199617385864, 0.39565014839172363, 0.9296226501464844, -0.09283269941806793, 0.7478646039962769, 0.7434309124946594, 0.9973424077033997, 1.1007349491119385, 2.031118154525757, 2.4692025184631348, 2.130614757537842, 0.0, 0.0, -0.0, -6.742569923400879, -7.793022632598877, -7.64204216003418, -7.031299114227295, -6.9635162353515625, -7.058359622955322, -7.168916702270508, -6.149658203125, -5.601688861846924, -5.7762274742126465, -5.409757137298584, -4.6338210105896, -5.457515239715576, -4.007063865661621, -4.6708292961120605, -4.032543659210205, -4.275306701660156, -2.6009395122528076, -1.8421138525009155, -2.8801681995391846, -1.8198237419128418, -0.9761425852775574, -1.4726428985595703, -1.0454435348510742, -0.9387151598930359, -0.6000051498413086, -0.5563983917236328, -0.5265407562255859, -0.5074765086174011, 0.19586993753910065, -0.4473012685775757, 1.07246994972229, -0.4477481245994568, 0.4406571388244629, 0.34115070104599, 0.46289578080177307, -0.3318515717983246, 0.8217183351516724, 1.0841686725616455, 1.5266414880752563, 0.46863654255867004, 0.8728238940238953, 0.9807668328285217, 1.7293345928192139, 1.2972660064697266, 2.715496063232422, 1.573313593864441, 0.8669604063034058, 1.1336196660995483, 0.6716318130493164, 1.9270129203796387, 0.9094887375831604, 0.9736060500144958, 1.4344810247421265, 2.0059847831726074, 2.04455304145813, 1.1716420650482178, 0.9341264963150024, 0.9906036257743835, 1.165189504623413, 0.03569091483950615, 1.1719614267349243, 1.112713098526001, 0.7678945660591125, -0.08236199617385864, 0.39565014839172363, 0.9296226501464844, -0.09283269941806793, 0.7478646039962769, 0.7434309124946594, 0.9973424077033997, 1.1007349491119385, 2.031118154525757, 2.4692025184631348, 2.130614757537842, 0.0, 0.0], [0.0, -9.527453422546387, -7.4874796867370605, -7.833531856536865, -7.537869453430176, -6.644869804382324, -6.664849281311035, -7.909717082977295, -6.4819817543029785, -6.936351299285889, -5.746159076690674, -5.1938796043396, -5.320819854736328, -4.7817535400390625, -4.676722049713135, -5.021345138549805, -3.513918876647949, -2.9497463703155518, -2.326094627380371, -2.9641854763031006, -3.0870492458343506, -2.380357503890991, -1.346818447113037, -1.2272562980651855, -1.8730796575546265, -1.1698133945465088, -1.2016308307647705, -0.9467960000038147, -0.33470091223716736, -0.4335750937461853, -0.7293487191200256, -0.0637701004743576, -0.13467176258563995, 0.12303811311721802, 1.0773197412490845, 1.1155251264572144, -0.9243825674057007, -0.44978129863739014, 3.008185863494873, 2.129230499267578, 1.413611650466919, 1.343360185623169, 0.7302654981613159, 0.031181104481220245, 0.6003841757774353, 0.5544610023498535, 0.6069399118423462, 0.832780122756958, 0.43021541833877563, -0.2767268717288971, 0.808137059211731, 1.796547532081604, 1.2880735397338867, 1.717382550239563, 1.6362627744674683, 0.8496747612953186, 1.484894037246704, 1.0146715641021729, 0.7652164101600647, 0.32806336879730225, 1.1463316679000854, 0.9492201805114746, 0.7942050099372864, 0.37286144495010376, 0.7167269587516785, 0.28943175077438354, 0.9551663994789124, 0.8826101422309875, 0.15568871796131134, 0.551843523979187, 0.9213168025016785, -0.06932761520147324, 0.3684641420841217, 1.7206835746765137, 1.6926859617233276, 2.3823676109313965, 3.476376533508301, 0.0, -0.0, -9.527453422546387, -7.4874796867370605, -7.833531856536865, -7.537869453430176, -6.644869804382324, -6.664849281311035, -7.909717082977295, -6.4819817543029785, -6.936351299285889, -5.746159076690674, -5.1938796043396, -5.320819854736328, -4.7817535400390625, -4.676722049713135, -5.021345138549805, -3.513918876647949, -2.9497463703155518, -2.326094627380371, -2.9641854763031006, -3.0870492458343506, -2.380357503890991, -1.346818447113037, -1.2272562980651855, -1.8730796575546265, -1.1698133945465088, -1.2016308307647705, -0.9467960000038147, -0.33470091223716736, -0.4335750937461853, -0.7293487191200256, -0.0637701004743576, -0.13467176258563995, 0.12303811311721802, 1.0773197412490845, 1.1155251264572144, -0.9243825674057007, -0.44978129863739014, 3.008185863494873, 2.129230499267578, 1.413611650466919, 1.343360185623169, 0.7302654981613159, 0.031181104481220245, 0.6003841757774353, 0.5544610023498535, 0.6069399118423462, 0.832780122756958, 0.43021541833877563, -0.2767268717288971, 0.808137059211731, 1.796547532081604, 1.2880735397338867, 1.717382550239563, 1.6362627744674683, 0.8496747612953186, 1.484894037246704, 1.0146715641021729, 0.7652164101600647, 0.32806336879730225, 1.1463316679000854, 0.9492201805114746, 0.7942050099372864, 0.37286144495010376, 0.7167269587516785, 0.28943175077438354, 0.9551663994789124, 0.8826101422309875, 0.15568871796131134, 0.551843523979187, 0.9213168025016785, -0.06932761520147324, 0.3684641420841217, 1.7206835746765137, 1.6926859617233276, 2.3823676109313965, 3.476376533508301, 0.0], [0.0, -9.092761039733887, -8.06416130065918, -8.686280250549316, -7.938993453979492, -7.761132717132568, -7.677353858947754, -7.427772045135498, -6.435096263885498, -6.269577503204346, -6.540979385375977, -6.290673732757568, -6.994283199310303, -5.177280902862549, -4.354546070098877, -4.335548400878906, -4.106415271759033, -4.3730621337890625, -2.797820806503296, -2.9913651943206787, -2.7749266624450684, -2.994285821914673, -1.6835098266601562, -1.971848964691162, -1.1646935939788818, -1.3108150959014893, -1.1394445896148682, -1.2949339151382446, -1.218572974205017, -0.7095525860786438, -1.6957123279571533, -1.349360704421997, -0.8258923888206482, -0.0757400393486023, 0.42979055643081665, -0.5198590755462646, -0.1983221173286438, 1.5939083099365234, 3.6844918727874756, 1.734761118888855, 0.22248706221580505, 1.5648068189620972, 1.7994811534881592, 1.1109840869903564, 0.7001439332962036, 1.3806711435317993, 0.671054482460022, 1.2790443897247314, 0.6735753417015076, 1.3986616134643555, 1.7121343612670898, 0.75099778175354, 2.035776138305664, 1.1491625308990479, 0.9406440258026123, 1.0978355407714844, 0.8227568864822388, 0.6499354243278503, 0.7429671287536621, -0.10771217942237854, 0.12038399279117584, 0.7444717884063721, 1.2166459560394287, 0.6463543772697449, -1.6809284687042236, 0.6108937859535217, 0.08791856467723846, 0.2900621294975281, 0.2422948181629181, 0.945644199848175, 1.012696623802185, 1.0173906087875366, 0.4863732159137726, 1.0253214836120605, 1.3650002479553223, 2.3202972412109375, 2.908841133117676, 0.0, -0.0, -9.092761039733887, -8.06416130065918, -8.686280250549316, -7.938993453979492, -7.761132717132568, -7.677353858947754, -7.427772045135498, -6.435096263885498, -6.269577503204346, -6.540979385375977, -6.290673732757568, -6.994283199310303, -5.177280902862549, -4.354546070098877, -4.335548400878906, -4.106415271759033, -4.3730621337890625, -2.797820806503296, -2.9913651943206787, -2.7749266624450684, -2.994285821914673, -1.6835098266601562, -1.971848964691162, -1.1646935939788818, -1.3108150959014893, -1.1394445896148682, -1.2949339151382446, -1.218572974205017, -0.7095525860786438, -1.6957123279571533, -1.349360704421997, -0.8258923888206482, -0.0757400393486023, 0.42979055643081665, -0.5198590755462646, -0.1983221173286438, 1.5939083099365234, 3.6844918727874756, 1.734761118888855, 0.22248706221580505, 1.5648068189620972, 1.7994811534881592, 1.1109840869903564, 0.7001439332962036, 1.3806711435317993, 0.671054482460022, 1.2790443897247314, 0.6735753417015076, 1.3986616134643555, 1.7121343612670898, 0.75099778175354, 2.035776138305664, 1.1491625308990479, 0.9406440258026123, 1.0978355407714844, 0.8227568864822388, 0.6499354243278503, 0.7429671287536621, -0.10771217942237854, 0.12038399279117584, 0.7444717884063721, 1.2166459560394287, 0.6463543772697449, -1.6809284687042236, 0.6108937859535217, 0.08791856467723846, 0.2900621294975281, 0.2422948181629181, 0.945644199848175, 1.012696623802185, 1.0173906087875366, 0.4863732159137726, 1.0253214836120605, 1.3650002479553223, 2.3202972412109375, 2.908841133117676, 0.0], [0.0, -8.15164566040039, -8.637832641601562, -8.907668113708496, -8.549837112426758, -8.190889358520508, -8.325028419494629, -6.962663650512695, -7.096019268035889, -7.513209342956543, -7.156052112579346, -6.599902629852295, -6.157031059265137, -5.161666393280029, -5.423435688018799, -4.5763020515441895, -4.189828872680664, -3.863361358642578, -4.375309944152832, -3.44071364402771, -2.434246301651001, -2.644554853439331, -2.1863906383514404, -1.511040210723877, -0.534080445766449, -1.6222232580184937, -0.5995595455169678, -2.0445733070373535, -1.0262476205825806, -1.1178494691848755, -1.2696993350982666, -0.8686234354972839, -0.39433029294013977, 0.4205332398414612, 1.1464465856552124, 0.41864848136901855, 1.5423167943954468, 1.3766227960586548, 1.5480302572250366, 2.4365711212158203, 1.0567781925201416, 0.8782855272293091, 0.6591161489486694, 0.3196299374103546, 0.12090104818344116, -0.5992282629013062, 0.3472541868686676, 1.2169909477233887, 0.5778948068618774, 0.03401909023523331, 0.402116060256958, 1.081945776939392, 0.7945054769515991, 0.7733216881752014, 2.329451084136963, 1.357193946838379, 1.4050266742706299, 0.9171483516693115, 0.7378314137458801, 0.7976804971694946, 0.19725953042507172, 0.3054521977901459, -0.20409716665744781, 0.3219093084335327, -0.31996989250183105, 1.1391534805297852, 0.6209853291511536, -0.22187280654907227, 1.6094380617141724, 0.030953828245401382, -0.09735716134309769, 0.636224627494812, 0.9669249057769775, 0.8623508810997009, 1.7095338106155396, 2.4133009910583496, 2.931105136871338, 0.0, -0.0, -8.15164566040039, -8.637832641601562, -8.907668113708496, -8.549837112426758, -8.190889358520508, -8.325028419494629, -6.962663650512695, -7.096019268035889, -7.513209342956543, -7.156052112579346, -6.599902629852295, -6.157031059265137, -5.161666393280029, -5.423435688018799, -4.5763020515441895, -4.189828872680664, -3.863361358642578, -4.375309944152832, -3.44071364402771, -2.434246301651001, -2.644554853439331, -2.1863906383514404, -1.511040210723877, -0.534080445766449, -1.6222232580184937, -0.5995595455169678, -2.0445733070373535, -1.0262476205825806, -1.1178494691848755, -1.2696993350982666, -0.8686234354972839, -0.39433029294013977, 0.4205332398414612, 1.1464465856552124, 0.41864848136901855, 1.5423167943954468, 1.3766227960586548, 1.5480302572250366, 2.4365711212158203, 1.0567781925201416, 0.8782855272293091, 0.6591161489486694, 0.3196299374103546, 0.12090104818344116, -0.5992282629013062, 0.3472541868686676, 1.2169909477233887, 0.5778948068618774, 0.03401909023523331, 0.402116060256958, 1.081945776939392, 0.7945054769515991, 0.7733216881752014, 2.329451084136963, 1.357193946838379, 1.4050266742706299, 0.9171483516693115, 0.7378314137458801, 0.7976804971694946, 0.19725953042507172, 0.3054521977901459, -0.20409716665744781, 0.3219093084335327, -0.31996989250183105, 1.1391534805297852, 0.6209853291511536, -0.22187280654907227, 1.6094380617141724, 0.030953828245401382, -0.09735716134309769, 0.636224627494812, 0.9669249057769775, 0.8623508810997009, 1.7095338106155396, 2.4133009910583496, 2.931105136871338, 0.0], [0.0, -8.85192584991455, -9.36266803741455, -9.158300399780273, -8.726000785827637, -8.342381477355957, -7.8773651123046875, -7.184325695037842, -7.151172161102295, -7.055535316467285, -6.973689079284668, -7.177690505981445, -5.9623026847839355, -6.039422035217285, -6.0066819190979, -5.15574312210083, -4.060000896453857, -2.7217140197753906, -4.434759616851807, -2.969074010848999, -2.753218412399292, -2.7664122581481934, -1.3397730588912964, -2.8003175258636475, 1.17948317527771, -0.5807116627693176, -2.325059413909912, -2.0086889266967773, -1.8638473749160767, -1.0024222135543823, -1.0593501329421997, -0.5834606289863586, -1.5520827770233154, 0.16267000138759613, 1.3814536333084106, -0.7543308138847351, 0.21480503678321838, 0.7269152402877808, 1.4566925764083862, 0.7519598007202148, 4.0970025062561035, 1.3294278383255005, 0.021707436069846153, -0.12469231337308884, 0.8784214854240417, 1.2276878356933594, 0.28639769554138184, 1.9080326557159424, -0.031439803540706635, 1.1831655502319336, 0.748216450214386, 0.1979319304227829, 2.1492180824279785, 1.646605372428894, 1.896628975868225, 1.4792509078979492, 0.5241756439208984, -0.3991057872772217, 1.115059733390808, 0.5768927931785583, 1.0044424533843994, 0.8396430015563965, 0.7143917679786682, 0.05027339980006218, 1.2660863399505615, 0.21898233890533447, 0.5692440271377563, 0.08787427842617035, -0.14809726178646088, 0.28583958745002747, 0.030981063842773438, 0.7556617856025696, 0.6559783220291138, 1.3065924644470215, 1.340604543685913, 1.6936061382293701, 2.6314048767089844, 0.0, -0.0, -8.85192584991455, -9.36266803741455, -9.158300399780273, -8.726000785827637, -8.342381477355957, -7.8773651123046875, -7.184325695037842, -7.151172161102295, -7.055535316467285, -6.973689079284668, -7.177690505981445, -5.9623026847839355, -6.039422035217285, -6.0066819190979, -5.15574312210083, -4.060000896453857, -2.7217140197753906, -4.434759616851807, -2.969074010848999, -2.753218412399292, -2.7664122581481934, -1.3397730588912964, -2.8003175258636475, 1.17948317527771, -0.5807116627693176, -2.325059413909912, -2.0086889266967773, -1.8638473749160767, -1.0024222135543823, -1.0593501329421997, -0.5834606289863586, -1.5520827770233154, 0.16267000138759613, 1.3814536333084106, -0.7543308138847351, 0.21480503678321838, 0.7269152402877808, 1.4566925764083862, 0.7519598007202148, 4.0970025062561035, 1.3294278383255005, 0.021707436069846153, -0.12469231337308884, 0.8784214854240417, 1.2276878356933594, 0.28639769554138184, 1.9080326557159424, -0.031439803540706635, 1.1831655502319336, 0.748216450214386, 0.1979319304227829, 2.1492180824279785, 1.646605372428894, 1.896628975868225, 1.4792509078979492, 0.5241756439208984, -0.3991057872772217, 1.115059733390808, 0.5768927931785583, 1.0044424533843994, 0.8396430015563965, 0.7143917679786682, 0.05027339980006218, 1.2660863399505615, 0.21898233890533447, 0.5692440271377563, 0.08787427842617035, -0.14809726178646088, 0.28583958745002747, 0.030981063842773438, 0.7556617856025696, 0.6559783220291138, 1.3065924644470215, 1.340604543685913, 1.6936061382293701, 2.6314048767089844, 0.0], [0.0, -10.087808609008789, -9.455826759338379, -9.210365295410156, -9.2747220993042, -8.295215606689453, -8.53965950012207, -7.430624008178711, -7.41361141204834, -7.336390018463135, -6.780010223388672, -6.580111026763916, -5.853216171264648, -5.644402980804443, -5.65022087097168, -5.79258394241333, -4.973701000213623, -4.798658847808838, -3.504750967025757, -3.0127317905426025, -2.573174476623535, -2.527184009552002, -1.9552381038665771, -2.946505308151245, -2.2570412158966064, -0.6509816646575928, -1.3618589639663696, -3.1483943462371826, -1.2999207973480225, -1.3542799949645996, -0.3449128270149231, 0.5334462523460388, 0.07522159069776535, -2.482957124710083, -0.8833752274513245, 0.26238518953323364, -1.0514029264450073, 0.8306319117546082, -0.9630399942398071, 0.7777348160743713, 0.3448348641395569, 0.8384830355644226, 0.9918760657310486, 0.7077608704566956, -0.3989279270172119, 1.1049052476882935, -0.16929127275943756, 0.33952367305755615, 1.351701021194458, 0.3786812424659729, 1.7851626873016357, 1.6881924867630005, 1.0542759895324707, 1.904849886894226, 1.40149986743927, 0.7903987169265747, 1.6059836149215698, 0.6982683539390564, 0.994875431060791, 0.6782450079917908, 0.5701966285705566, 0.2521703839302063, -0.05956810712814331, 1.2103849649429321, 1.5649676322937012, -1.0932389497756958, 0.0031061163172125816, -0.24919605255126953, -0.30069759488105774, 0.799221932888031, 0.6307064294815063, -0.29638487100601196, 0.44886183738708496, 1.3056018352508545, 1.1492047309875488, 2.0250022411346436, 1.955570101737976, 0.0, -0.0, -10.087808609008789, -9.455826759338379, -9.210365295410156, -9.2747220993042, -8.295215606689453, -8.53965950012207, -7.430624008178711, -7.41361141204834, -7.336390018463135, -6.780010223388672, -6.580111026763916, -5.853216171264648, -5.644402980804443, -5.65022087097168, -5.79258394241333, -4.973701000213623, -4.798658847808838, -3.504750967025757, -3.0127317905426025, -2.573174476623535, -2.527184009552002, -1.9552381038665771, -2.946505308151245, -2.2570412158966064, -0.6509816646575928, -1.3618589639663696, -3.1483943462371826, -1.2999207973480225, -1.3542799949645996, -0.3449128270149231, 0.5334462523460388, 0.07522159069776535, -2.482957124710083, -0.8833752274513245, 0.26238518953323364, -1.0514029264450073, 0.8306319117546082, -0.9630399942398071, 0.7777348160743713, 0.3448348641395569, 0.8384830355644226, 0.9918760657310486, 0.7077608704566956, -0.3989279270172119, 1.1049052476882935, -0.16929127275943756, 0.33952367305755615, 1.351701021194458, 0.3786812424659729, 1.7851626873016357, 1.6881924867630005, 1.0542759895324707, 1.904849886894226, 1.40149986743927, 0.7903987169265747, 1.6059836149215698, 0.6982683539390564, 0.994875431060791, 0.6782450079917908, 0.5701966285705566, 0.2521703839302063, -0.05956810712814331, 1.2103849649429321, 1.5649676322937012, -1.0932389497756958, 0.0031061163172125816, -0.24919605255126953, -0.30069759488105774, 0.799221932888031, 0.6307064294815063, -0.29638487100601196, 0.44886183738708496, 1.3056018352508545, 1.1492047309875488, 2.0250022411346436, 1.955570101737976, 0.0], [0.0, -9.81728744506836, -9.396358489990234, -9.39024829864502, -9.317059516906738, -9.1249361038208, -8.075284957885742, -7.617496013641357, -7.830001354217529, -8.19706916809082, -6.689882755279541, -7.379063606262207, -6.285731315612793, -5.330010414123535, -5.742119312286377, -4.663869380950928, -4.673051357269287, -4.010329246520996, -4.475925445556641, -3.886509895324707, -1.8357073068618774, -2.103816509246826, -3.0388920307159424, -2.9246060848236084, -1.9489160776138306, -2.2503907680511475, -1.1544239521026611, -0.7073673009872437, -1.5817278623580933, -0.7935296893119812, -1.457233190536499, -0.5379282236099243, -0.32265520095825195, 0.4573318660259247, -0.07093516737222672, 0.17584627866744995, 0.6213129758834839, 0.6148539185523987, 0.5199548602104187, 0.4064081013202667, 1.6124128103256226, 2.5684337615966797, 0.2918053865432739, 0.0410008504986763, -0.2920815050601959, -0.02542462944984436, 0.8550859093666077, 1.1603121757507324, -0.35939687490463257, 0.39813414216041565, 0.10879045724868774, 0.8124962449073792, 0.4353870749473572, 0.5901435613632202, 1.5152974128723145, 1.26115083694458, 0.8119354844093323, 1.1280765533447266, 0.08492842316627502, 0.7576631903648376, -0.26562491059303284, 0.56563401222229, 0.9227126836776733, -0.23997357487678528, 0.2031465321779251, 0.4263652563095093, 0.06682552397251129, -0.3490181565284729, 0.18540510535240173, -0.8316048979759216, -0.45363757014274597, -2.0010385513305664, 0.5470074415206909, -0.6800646781921387, 0.7979996204376221, 1.9389393329620361, 1.9654772281646729, 0.0, -0.0, -9.81728744506836, -9.396358489990234, -9.39024829864502, -9.317059516906738, -9.1249361038208, -8.075284957885742, -7.617496013641357, -7.830001354217529, -8.19706916809082, -6.689882755279541, -7.379063606262207, -6.285731315612793, -5.330010414123535, -5.742119312286377, -4.663869380950928, -4.673051357269287, -4.010329246520996, -4.475925445556641, -3.886509895324707, -1.8357073068618774, -2.103816509246826, -3.0388920307159424, -2.9246060848236084, -1.9489160776138306, -2.2503907680511475, -1.1544239521026611, -0.7073673009872437, -1.5817278623580933, -0.7935296893119812, -1.457233190536499, -0.5379282236099243, -0.32265520095825195, 0.4573318660259247, -0.07093516737222672, 0.17584627866744995, 0.6213129758834839, 0.6148539185523987, 0.5199548602104187, 0.4064081013202667, 1.6124128103256226, 2.5684337615966797, 0.2918053865432739, 0.0410008504986763, -0.2920815050601959, -0.02542462944984436, 0.8550859093666077, 1.1603121757507324, -0.35939687490463257, 0.39813414216041565, 0.10879045724868774, 0.8124962449073792, 0.4353870749473572, 0.5901435613632202, 1.5152974128723145, 1.26115083694458, 0.8119354844093323, 1.1280765533447266, 0.08492842316627502, 0.7576631903648376, -0.26562491059303284, 0.56563401222229, 0.9227126836776733, -0.23997357487678528, 0.2031465321779251, 0.4263652563095093, 0.06682552397251129, -0.3490181565284729, 0.18540510535240173, -0.8316048979759216, -0.45363757014274597, -2.0010385513305664, 0.5470074415206909, -0.6800646781921387, 0.7979996204376221, 1.9389393329620361, 1.9654772281646729, 0.0], [0.0, -11.092719078063965, -10.907432556152344, -10.413970947265625, -10.056706428527832, -9.021836280822754, -8.852572441101074, -7.838492393493652, -8.161701202392578, -8.272104263305664, -6.878348350524902, -6.67207145690918, -5.010696887969971, -7.039270401000977, -7.039326190948486, -5.0942511558532715, -4.5601911544799805, -4.4743475914001465, -4.32695198059082, -3.4418771266937256, -3.150956630706787, -5.11815881729126, -2.815234422683716, -0.5410300493240356, -0.7375217080116272, -1.2560926675796509, -1.4206637144088745, -1.754468560218811, -1.8152589797973633, -1.7321444749832153, -0.3431060314178467, -0.7744229435920715, 0.3068855404853821, -0.8355922102928162, -0.06737089157104492, -0.931382954120636, -0.028462981805205345, -0.39950117468833923, 0.8699904084205627, -0.21912787854671478, 0.9183208346366882, -0.38219350576400757, 0.39696940779685974, 0.07529712468385696, 0.30006739497184753, 0.1719338446855545, 0.7923250198364258, 1.455751895904541, -0.00856209360063076, 1.6633225679397583, 1.1321706771850586, 1.211181879043579, 0.5161268711090088, 2.3751800060272217, 0.45562681555747986, -0.47781163454055786, 0.3712504804134369, 1.4879595041275024, 1.056089997291565, 0.9336710572242737, 0.1638648808002472, 0.06919492036104202, 0.3562738001346588, 0.15680189430713654, -0.42994603514671326, -0.651486873626709, 0.04938719794154167, 0.4102432429790497, 0.09382615983486176, -0.08266931027173996, -0.04900842905044556, -0.38936829566955566, -0.03278645873069763, -0.5776762962341309, -0.3036499619483948, 0.004486763849854469, 1.8227323293685913, 0.0, -0.0, -11.092719078063965, -10.907432556152344, -10.413970947265625, -10.056706428527832, -9.021836280822754, -8.852572441101074, -7.838492393493652, -8.161701202392578, -8.272104263305664, -6.878348350524902, -6.67207145690918, -5.010696887969971, -7.039270401000977, -7.039326190948486, -5.0942511558532715, -4.5601911544799805, -4.4743475914001465, -4.32695198059082, -3.4418771266937256, -3.150956630706787, -5.11815881729126, -2.815234422683716, -0.5410300493240356, -0.7375217080116272, -1.2560926675796509, -1.4206637144088745, -1.754468560218811, -1.8152589797973633, -1.7321444749832153, -0.3431060314178467, -0.7744229435920715, 0.3068855404853821, -0.8355922102928162, -0.06737089157104492, -0.931382954120636, -0.028462981805205345, -0.39950117468833923, 0.8699904084205627, -0.21912787854671478, 0.9183208346366882, -0.38219350576400757, 0.39696940779685974, 0.07529712468385696, 0.30006739497184753, 0.1719338446855545, 0.7923250198364258, 1.455751895904541, -0.00856209360063076, 1.6633225679397583, 1.1321706771850586, 1.211181879043579, 0.5161268711090088, 2.3751800060272217, 0.45562681555747986, -0.47781163454055786, 0.3712504804134369, 1.4879595041275024, 1.056089997291565, 0.9336710572242737, 0.1638648808002472, 0.06919492036104202, 0.3562738001346588, 0.15680189430713654, -0.42994603514671326, -0.651486873626709, 0.04938719794154167, 0.4102432429790497, 0.09382615983486176, -0.08266931027173996, -0.04900842905044556, -0.38936829566955566, -0.03278645873069763, -0.5776762962341309, -0.3036499619483948, 0.004486763849854469, 1.8227323293685913, 0.0], [0.0, -11.036368370056152, -11.04184341430664, -10.62883472442627, -9.559263229370117, -9.944746017456055, -8.554251670837402, -9.036067962646484, -8.21670150756836, -7.876026630401611, -7.191624641418457, -6.368829250335693, -5.985040664672852, -6.517453670501709, -6.543694496154785, -5.595973491668701, -4.704383373260498, -4.625665187835693, -4.366408824920654, -4.435694694519043, -3.6929800510406494, -3.012216567993164, -3.3313121795654297, -3.182818651199341, -2.496677875518799, -2.153188705444336, -2.3524930477142334, -1.8487426042556763, -1.3770771026611328, -0.7193262577056885, -1.187403678894043, -1.3530287742614746, -0.9963754415512085, 0.33022060990333557, -0.4976921081542969, -0.6575477123260498, 0.24625590443611145, 1.011139988899231, 0.36203259229660034, -0.2624087333679199, -0.04716481268405914, -0.5246884822845459, -0.7908700108528137, -0.7065622210502625, 0.2540023624897003, -0.4935236871242523, -1.8602283000946045, -2.051532030105591, 0.16410188376903534, -0.5520586967468262, 1.487700343132019, 0.6857492327690125, 0.7556279301643372, 0.49027615785598755, 1.8146227598190308, 0.7701507806777954, 0.6744757294654846, 0.5761439800262451, 0.1926688849925995, 0.2534603774547577, 0.5300766229629517, 0.15153270959854126, 0.7353668808937073, -0.04227273911237717, -0.29098349809646606, -0.6499239802360535, -1.1283745765686035, 1.044166088104248, -0.29574888944625854, -0.5213661193847656, -0.9355127811431885, 0.36810800433158875, -0.7751948833465576, -1.4666963815689087, 0.051304642111063004, -0.11405713111162186, -0.4839632511138916, 0.0, -0.0, -11.036368370056152, -11.04184341430664, -10.62883472442627, -9.559263229370117, -9.944746017456055, -8.554251670837402, -9.036067962646484, -8.21670150756836, -7.876026630401611, -7.191624641418457, -6.368829250335693, -5.985040664672852, -6.517453670501709, -6.543694496154785, -5.595973491668701, -4.704383373260498, -4.625665187835693, -4.366408824920654, -4.435694694519043, -3.6929800510406494, -3.012216567993164, -3.3313121795654297, -3.182818651199341, -2.496677875518799, -2.153188705444336, -2.3524930477142334, -1.8487426042556763, -1.3770771026611328, -0.7193262577056885, -1.187403678894043, -1.3530287742614746, -0.9963754415512085, 0.33022060990333557, -0.4976921081542969, -0.6575477123260498, 0.24625590443611145, 1.011139988899231, 0.36203259229660034, -0.2624087333679199, -0.04716481268405914, -0.5246884822845459, -0.7908700108528137, -0.7065622210502625, 0.2540023624897003, -0.4935236871242523, -1.8602283000946045, -2.051532030105591, 0.16410188376903534, -0.5520586967468262, 1.487700343132019, 0.6857492327690125, 0.7556279301643372, 0.49027615785598755, 1.8146227598190308, 0.7701507806777954, 0.6744757294654846, 0.5761439800262451, 0.1926688849925995, 0.2534603774547577, 0.5300766229629517, 0.15153270959854126, 0.7353668808937073, -0.04227273911237717, -0.29098349809646606, -0.6499239802360535, -1.1283745765686035, 1.044166088104248, -0.29574888944625854, -0.5213661193847656, -0.9355127811431885, 0.36810800433158875, -0.7751948833465576, -1.4666963815689087, 0.051304642111063004, -0.11405713111162186, -0.4839632511138916, -0.0], [0.0, -11.419838905334473, -10.921940803527832, -12.198107719421387, -10.43950366973877, -10.178945541381836, -9.311436653137207, -9.874078750610352, -8.759501457214355, -8.603006362915039, -6.605900764465332, -7.429897785186768, -8.855199813842773, -6.865499973297119, -6.411515712738037, -5.2593674659729, -5.732748031616211, -4.466496467590332, -3.986647367477417, -3.450899600982666, -3.0011141300201416, -3.0685901641845703, -3.0129871368408203, -2.9641854763031006, -2.650723695755005, -1.6777944564819336, -0.75583815574646, -2.3637542724609375, -1.3124967813491821, -1.072070598602295, -0.5067838430404663, -1.021730899810791, -1.2256801128387451, -1.5586568117141724, -1.5411720275878906, -0.612438976764679, -1.7796118259429932, -0.40551015734672546, -0.3399694859981537, -0.22283606231212616, 0.3778306841850281, -0.5706733465194702, -0.12054860591888428, 0.29114478826522827, -0.204645037651062, 0.3196867108345032, -0.11157850921154022, 0.21833425760269165, 0.6300597190856934, -0.6978945732116699, 1.300754189491272, 1.5341037511825562, 0.318753182888031, 1.5698500871658325, 0.3910786807537079, -2.6498301029205322, 0.8232529163360596, -0.343502014875412, 0.18686002492904663, -0.07398541271686554, 0.23781436681747437, -0.3002925217151642, -0.6084766387939453, 0.19752007722854614, -0.10352379083633423, -0.3843139111995697, -0.12160946428775787, -0.8984044790267944, -0.5266863107681274, -0.8759758472442627, -0.22625620663166046, -0.6821726560592651, -0.9123201370239258, -0.4968918263912201, -0.7678931355476379, -0.42040884494781494, -0.7310265302658081, 0.0, -0.0, -11.419838905334473, -10.921940803527832, -12.198107719421387, -10.43950366973877, -10.178945541381836, -9.311436653137207, -9.874078750610352, -8.759501457214355, -8.603006362915039, -6.605900764465332, -7.429897785186768, -8.855199813842773, -6.865499973297119, -6.411515712738037, -5.2593674659729, -5.732748031616211, -4.466496467590332, -3.986647367477417, -3.450899600982666, -3.0011141300201416, -3.0685901641845703, -3.0129871368408203, -2.9641854763031006, -2.650723695755005, -1.6777944564819336, -0.75583815574646, -2.3637542724609375, -1.3124967813491821, -1.072070598602295, -0.5067838430404663, -1.021730899810791, -1.2256801128387451, -1.5586568117141724, -1.5411720275878906, -0.612438976764679, -1.7796118259429932, -0.40551015734672546, -0.3399694859981537, -0.22283606231212616, 0.3778306841850281, -0.5706733465194702, -0.12054860591888428, 0.29114478826522827, -0.204645037651062, 0.3196867108345032, -0.11157850921154022, 0.21833425760269165, 0.6300597190856934, -0.6978945732116699, 1.300754189491272, 1.5341037511825562, 0.318753182888031, 1.5698500871658325, 0.3910786807537079, -2.6498301029205322, 0.8232529163360596, -0.343502014875412, 0.18686002492904663, -0.07398541271686554, 0.23781436681747437, -0.3002925217151642, -0.6084766387939453, 0.19752007722854614, -0.10352379083633423, -0.3843139111995697, -0.12160946428775787, -0.8984044790267944, -0.5266863107681274, -0.8759758472442627, -0.22625620663166046, -0.6821726560592651, -0.9123201370239258, -0.4968918263912201, -0.7678931355476379, -0.42040884494781494, -0.7310265302658081, -0.0], [0.0, -11.878829956054688, -9.618354797363281, -11.560578346252441, -11.422736167907715, -10.388797760009766, -10.205912590026855, -9.010519027709961, -8.16510009765625, -8.318750381469727, -9.20937442779541, -8.142136573791504, -7.115575790405273, -5.326221942901611, -5.60867977142334, -6.305180072784424, -6.626367568969727, -4.889618396759033, -4.552386283874512, -4.258281230926514, -4.28065824508667, -3.906229019165039, -2.712752342224121, -1.0163661241531372, -2.489010810852051, -2.3262569904327393, -2.338752269744873, -0.8949645757675171, -1.6435234546661377, -1.1584625244140625, -2.357814073562622, -0.6755957007408142, -1.699044108390808, -3.8343539237976074, -1.0138704776763916, -0.675708532333374, -1.0863919258117676, -0.013906918466091156, -0.7102881669998169, -0.30703920125961304, -0.5172557830810547, 0.33133822679519653, -1.0219378471374512, -0.2761182487010956, -0.025423170998692513, 0.003556441981345415, -0.24314501881599426, -0.03572547435760498, 0.23455816507339478, -0.15480993688106537, -1.429185390472412, 0.29557573795318604, 0.28308025002479553, 1.9395051002502441, -0.3500831425189972, -0.41320398449897766, 0.5676506161689758, -0.4952327609062195, 0.7882586717605591, 0.9218870997428894, 0.5446489453315735, -0.3113725781440735, -0.4271785020828247, 0.1604464054107666, 2.49749493598938, 0.20637603104114532, -0.8051619529724121, -0.14774982631206512, -0.5828282237052917, 0.29930832982063293, -1.2881836891174316, -0.4854413866996765, -0.7036014199256897, -0.7125664353370667, -1.233727216720581, -0.6975354552268982, -0.6812723278999329, 0.0, -0.0, -11.878829956054688, -9.618354797363281, -11.560578346252441, -11.422736167907715, -10.388797760009766, -10.205912590026855, -9.010519027709961, -8.16510009765625, -8.318750381469727, -9.20937442779541, -8.142136573791504, -7.115575790405273, -5.326221942901611, -5.60867977142334, -6.305180072784424, -6.626367568969727, -4.889618396759033, -4.552386283874512, -4.258281230926514, -4.28065824508667, -3.906229019165039, -2.712752342224121, -1.0163661241531372, -2.489010810852051, -2.3262569904327393, -2.338752269744873, -0.8949645757675171, -1.6435234546661377, -1.1584625244140625, -2.357814073562622, -0.6755957007408142, -1.699044108390808, -3.8343539237976074, -1.0138704776763916, -0.675708532333374, -1.0863919258117676, -0.013906918466091156, -0.7102881669998169, -0.30703920125961304, -0.5172557830810547, 0.33133822679519653, -1.0219378471374512, -0.2761182487010956, -0.025423170998692513, 0.003556441981345415, -0.24314501881599426, -0.03572547435760498, 0.23455816507339478, -0.15480993688106537, -1.429185390472412, 0.29557573795318604, 0.28308025002479553, 1.9395051002502441, -0.3500831425189972, -0.41320398449897766, 0.5676506161689758, -0.4952327609062195, 0.7882586717605591, 0.9218870997428894, 0.5446489453315735, -0.3113725781440735, -0.4271785020828247, 0.1604464054107666, 2.49749493598938, 0.20637603104114532, -0.8051619529724121, -0.14774982631206512, -0.5828282237052917, 0.29930832982063293, -1.2881836891174316, -0.4854413866996765, -0.7036014199256897, -0.7125664353370667, -1.233727216720581, -0.6975354552268982, -0.6812723278999329, -0.0], [0.0, -9.98176383972168, -12.166943550109863, -11.600159645080566, -11.82975959777832, -11.027383804321289, -9.629093170166016, -9.483464241027832, -9.812984466552734, -8.189470291137695, -8.600689888000488, -8.17084789276123, -6.45510721206665, -7.854788303375244, -5.9977521896362305, -6.052858352661133, -5.295901775360107, -4.6127238273620605, -4.480625152587891, -2.900575876235962, -3.973639488220215, -2.720486879348755, -3.564152479171753, -3.562889337539673, -1.258232593536377, -2.550950288772583, -1.6294372081756592, -2.816828727722168, -4.916662216186523, -1.2783162593841553, -2.1273415088653564, -1.9157718420028687, -1.4959076642990112, -0.9641017317771912, -1.5256885290145874, -1.3498172760009766, -1.971571922302246, -1.0283608436584473, 0.6149335503578186, -1.0363719463348389, -0.31188663840293884, -1.3747642040252686, -1.1427717208862305, -1.3394181728363037, -0.08349868655204773, -0.23552627861499786, 0.35013264417648315, -1.2509939670562744, 0.1280680000782013, 1.0535521507263184, 0.5672033429145813, 0.5664905905723572, 0.5851930379867554, 1.3267536163330078, -0.45768406987190247, -0.3759484887123108, -0.29684436321258545, -0.5614739656448364, 0.39560559391975403, 0.6597353219985962, 0.22697225213050842, 0.059039246290922165, -0.5494830012321472, -0.1330614686012268, 1.7029558420181274, -1.210877537727356, -1.6951589584350586, -1.4103224277496338, 0.18329183757305145, -0.4745175540447235, -0.6685680747032166, -0.29608380794525146, -0.17752018570899963, -1.253780484199524, -0.8238716721534729, -1.616315484046936, -4.511128902435303, 0.0, -0.0, -9.98176383972168, -12.166943550109863, -11.600159645080566, -11.82975959777832, -11.027383804321289, -9.629093170166016, -9.483464241027832, -9.812984466552734, -8.189470291137695, -8.600689888000488, -8.17084789276123, -6.45510721206665, -7.854788303375244, -5.9977521896362305, -6.052858352661133, -5.295901775360107, -4.6127238273620605, -4.480625152587891, -2.900575876235962, -3.973639488220215, -2.720486879348755, -3.564152479171753, -3.562889337539673, -1.258232593536377, -2.550950288772583, -1.6294372081756592, -2.816828727722168, -4.916662216186523, -1.2783162593841553, -2.1273415088653564, -1.9157718420028687, -1.4959076642990112, -0.9641017317771912, -1.5256885290145874, -1.3498172760009766, -1.971571922302246, -1.0283608436584473, 0.6149335503578186, -1.0363719463348389, -0.31188663840293884, -1.3747642040252686, -1.1427717208862305, -1.3394181728363037, -0.08349868655204773, -0.23552627861499786, 0.35013264417648315, -1.2509939670562744, 0.1280680000782013, 1.0535521507263184, 0.5672033429145813, 0.5664905905723572, 0.5851930379867554, 1.3267536163330078, -0.45768406987190247, -0.3759484887123108, -0.29684436321258545, -0.5614739656448364, 0.39560559391975403, 0.6597353219985962, 0.22697225213050842, 0.059039246290922165, -0.5494830012321472, -0.1330614686012268, 1.7029558420181274, -1.210877537727356, -1.6951589584350586, -1.4103224277496338, 0.18329183757305145, -0.4745175540447235, -0.6685680747032166, -0.29608380794525146, -0.17752018570899963, -1.253780484199524, -0.8238716721534729, -1.616315484046936, -4.511128902435303, -0.0], [0.0, -14.037335395812988, -13.314347267150879, -12.496086120605469, -11.543635368347168, -10.722356796264648, -10.503313064575195, -9.913580894470215, -10.340400695800781, -9.656804084777832, -8.457208633422852, -7.633550643920898, -6.294824600219727, -7.144454002380371, -6.8583903312683105, -6.269002437591553, -5.513513088226318, -4.921817302703857, -4.799918174743652, -4.454990863800049, -4.1785969734191895, -3.384136915206909, -2.0339345932006836, -4.457095623016357, -2.666710376739502, -3.983633279800415, -2.3718583583831787, -1.094344139099121, -2.282701015472412, -2.9051167964935303, -2.551255226135254, -3.806471824645996, -2.209110736846924, -1.369083285331726, -2.7883803844451904, -0.6608604192733765, -1.3616383075714111, -1.5089647769927979, -0.747448205947876, -1.3153642416000366, -1.2066922187805176, -0.09686405211687088, -2.028536319732666, -1.5230741500854492, -1.0143109560012817, -2.1211888790130615, -0.4389398396015167, -1.3177380561828613, -0.7643051147460938, -0.5603510141372681, -0.01880715787410736, -0.16074852645397186, -0.06312541663646698, -0.5616297721862793, -0.26429659128189087, 0.6735867857933044, -0.10400644689798355, 0.07137633115053177, 0.37519389390945435, 1.0791261196136475, -0.002179189817979932, 0.09025391936302185, -0.8549888134002686, -0.4832010865211487, 0.28276345133781433, -0.6501047611236572, -0.1369633674621582, -0.9043063521385193, -0.5218196511268616, -0.7491718530654907, -0.4596574604511261, -0.7178775668144226, -1.0196281671524048, -1.1662075519561768, -0.25135913491249084, -1.9279013872146606, -0.9432522654533386, 0.0, -0.0, -14.037335395812988, -13.314347267150879, -12.496086120605469, -11.543635368347168, -10.722356796264648, -10.503313064575195, -9.913580894470215, -10.340400695800781, -9.656804084777832, -8.457208633422852, -7.633550643920898, -6.294824600219727, -7.144454002380371, -6.8583903312683105, -6.269002437591553, -5.513513088226318, -4.921817302703857, -4.799918174743652, -4.454990863800049, -4.1785969734191895, -3.384136915206909, -2.0339345932006836, -4.457095623016357, -2.666710376739502, -3.983633279800415, -2.3718583583831787, -1.094344139099121, -2.282701015472412, -2.9051167964935303, -2.551255226135254, -3.806471824645996, -2.209110736846924, -1.369083285331726, -2.7883803844451904, -0.6608604192733765, -1.3616383075714111, -1.5089647769927979, -0.747448205947876, -1.3153642416000366, -1.2066922187805176, -0.09686405211687088, -2.028536319732666, -1.5230741500854492, -1.0143109560012817, -2.1211888790130615, -0.4389398396015167, -1.3177380561828613, -0.7643051147460938, -0.5603510141372681, -0.01880715787410736, -0.16074852645397186, -0.06312541663646698, -0.5616297721862793, -0.26429659128189087, 0.6735867857933044, -0.10400644689798355, 0.07137633115053177, 0.37519389390945435, 1.0791261196136475, -0.002179189817979932, 0.09025391936302185, -0.8549888134002686, -0.4832010865211487, 0.28276345133781433, -0.6501047611236572, -0.1369633674621582, -0.9043063521385193, -0.5218196511268616, -0.7491718530654907, -0.4596574604511261, -0.7178775668144226, -1.0196281671524048, -1.1662075519561768, -0.25135913491249084, -1.9279013872146606, -0.9432522654533386, -0.0], [0.0, 0.0, -13.099044799804688, -12.964553833007812, -11.806941986083984, -11.238527297973633, -11.058295249938965, -11.103599548339844, -8.769347190856934, -8.405696868896484, -7.182610034942627, -7.810627460479736, -7.910531520843506, -7.374270439147949, -7.368113994598389, -5.722246170043945, -5.860579490661621, -5.18553352355957, -4.8738322257995605, -4.936511993408203, -5.794434070587158, -2.673612117767334, -4.490451812744141, -3.196424961090088, -3.7242040634155273, -0.9537546038627625, -1.5048469305038452, -1.906197190284729, -1.6831976175308228, -1.2227650880813599, -1.4502294063568115, -1.8153785467147827, -3.3029236793518066, -1.9707472324371338, -1.4975520372390747, -2.11887264251709, -1.3372244834899902, -1.1590831279754639, -1.518191933631897, -1.5221153497695923, -1.242074728012085, -1.334120273590088, -0.7798572182655334, -1.4249534606933594, -0.8895378112792969, -1.9757471084594727, -1.2745145559310913, -1.2619231939315796, -0.8492504954338074, 0.3331986963748932, 0.37922218441963196, 0.8795064091682434, -0.5839055180549622, -0.23782548308372498, -0.2532828152179718, -1.4525933265686035, -0.5623897910118103, -0.8649351596832275, 1.315185308456421, -0.5652521848678589, -0.883612871170044, -0.1241224929690361, -0.26904618740081787, -0.018238190561532974, -0.2599918842315674, -0.5690706372261047, -0.3556503355503082, -0.9564675688743591, -0.39027610421180725, 1.6214063167572021, -0.27195537090301514, 0.011526631191372871, -1.9585365056991577, -1.1113272905349731, -1.56473970413208, -4.043002128601074, 0.0, 0.0, -0.0, -0.0, -13.099044799804688, -12.964553833007812, -11.806941986083984, -11.238527297973633, -11.058295249938965, -11.103599548339844, -8.769347190856934, -8.405696868896484, -7.182610034942627, -7.810627460479736, -7.910531520843506, -7.374270439147949, -7.368113994598389, -5.722246170043945, -5.860579490661621, -5.18553352355957, -4.8738322257995605, -4.936511993408203, -5.794434070587158, -2.673612117767334, -4.490451812744141, -3.196424961090088, -3.7242040634155273, -0.9537546038627625, -1.5048469305038452, -1.906197190284729, -1.6831976175308228, -1.2227650880813599, -1.4502294063568115, -1.8153785467147827, -3.3029236793518066, -1.9707472324371338, -1.4975520372390747, -2.11887264251709, -1.3372244834899902, -1.1590831279754639, -1.518191933631897, -1.5221153497695923, -1.242074728012085, -1.334120273590088, -0.7798572182655334, -1.4249534606933594, -0.8895378112792969, -1.9757471084594727, -1.2745145559310913, -1.2619231939315796, -0.8492504954338074, 0.3331986963748932, 0.37922218441963196, 0.8795064091682434, -0.5839055180549622, -0.23782548308372498, -0.2532828152179718, -1.4525933265686035, -0.5623897910118103, -0.8649351596832275, 1.315185308456421, -0.5652521848678589, -0.883612871170044, -0.1241224929690361, -0.26904618740081787, -0.018238190561532974, -0.2599918842315674, -0.5690706372261047, -0.3556503355503082, -0.9564675688743591, -0.39027610421180725, 1.6214063167572021, -0.27195537090301514, 0.011526631191372871, -1.9585365056991577, -1.1113272905349731, -1.56473970413208, -4.043002128601074, -0.0, -0.0], [0.0, 0.0, -15.109341621398926, -12.08176326751709, -12.742130279541016, -10.953554153442383, -10.32730484008789, -9.605050086975098, -8.552167892456055, -9.124464988708496, -8.892462730407715, -7.996737480163574, -8.001117706298828, -6.448375701904297, -6.685873031616211, -6.159874439239502, -5.443845272064209, -5.633884906768799, -4.564029693603516, -4.846655368804932, -4.7766547203063965, -3.0014123916625977, -2.410602569580078, -3.835401773452759, -2.887866497039795, -1.8952836990356445, 0.07192791998386383, -1.930696964263916, -1.4556912183761597, -2.918942451477051, -3.5966475009918213, -3.155172824859619, -1.4697561264038086, -2.388578176498413, -1.667578101158142, -3.7274961471557617, -2.2197256088256836, -1.9242942333221436, -1.2766577005386353, -1.4283084869384766, -1.2053260803222656, -1.6727776527404785, -1.564560890197754, -1.6252291202545166, -0.721928060054779, -2.1165130138397217, -0.6744012832641602, -0.18586407601833344, -1.1740922927856445, -0.10428126901388168, -0.7308008074760437, -0.665323793888092, 0.384250283241272, 0.9273911118507385, -1.4842807054519653, -1.53913152217865, 0.08288457989692688, 0.6170565485954285, -0.6590657830238342, 2.0983004570007324, -0.12777908146381378, 0.7259363532066345, -0.1285334676504135, -0.22321400046348572, -0.360562801361084, -1.20058274269104, -0.8750629425048828, -1.0136250257492065, 0.03481203690171242, -1.0862644910812378, -2.3491251468658447, -1.3831061124801636, -1.7031981945037842, -1.5108236074447632, -1.8497685194015503, -1.4740599393844604, 0.0, 0.0, -0.0, -0.0, -15.109341621398926, -12.08176326751709, -12.742130279541016, -10.953554153442383, -10.32730484008789, -9.605050086975098, -8.552167892456055, -9.124464988708496, -8.892462730407715, -7.996737480163574, -8.001117706298828, -6.448375701904297, -6.685873031616211, -6.159874439239502, -5.443845272064209, -5.633884906768799, -4.564029693603516, -4.846655368804932, -4.7766547203063965, -3.0014123916625977, -2.410602569580078, -3.835401773452759, -2.887866497039795, -1.8952836990356445, 0.07192791998386383, -1.930696964263916, -1.4556912183761597, -2.918942451477051, -3.5966475009918213, -3.155172824859619, -1.4697561264038086, -2.388578176498413, -1.667578101158142, -3.7274961471557617, -2.2197256088256836, -1.9242942333221436, -1.2766577005386353, -1.4283084869384766, -1.2053260803222656, -1.6727776527404785, -1.564560890197754, -1.6252291202545166, -0.721928060054779, -2.1165130138397217, -0.6744012832641602, -0.18586407601833344, -1.1740922927856445, -0.10428126901388168, -0.7308008074760437, -0.665323793888092, 0.384250283241272, 0.9273911118507385, -1.4842807054519653, -1.53913152217865, 0.08288457989692688, 0.6170565485954285, -0.6590657830238342, 2.0983004570007324, -0.12777908146381378, 0.7259363532066345, -0.1285334676504135, -0.22321400046348572, -0.360562801361084, -1.20058274269104, -0.8750629425048828, -1.0136250257492065, 0.03481203690171242, -1.0862644910812378, -2.3491251468658447, -1.3831061124801636, -1.7031981945037842, -1.5108236074447632, -1.8497685194015503, -1.4740599393844604, -0.0, -0.0], [0.0, 0.0, -17.13910484313965, -14.090863227844238, -12.792787551879883, -11.645392417907715, -11.291694641113281, -10.541577339172363, -9.35718059539795, -9.584139823913574, -8.32131576538086, -8.080997467041016, -7.686566352844238, -6.832091808319092, -6.774085998535156, -6.185229778289795, -5.588740825653076, -5.132737159729004, -5.273025035858154, -5.232296466827393, -4.695992469787598, -3.882802724838257, -4.659888744354248, -4.767660140991211, -5.251021862030029, -3.9361958503723145, 0.0264072734862566, -2.3991174697875977, -1.7660146951675415, -2.4743592739105225, -2.7106876373291016, -3.366583824157715, -3.9332239627838135, -2.664569854736328, -2.3702809810638428, -1.9573193788528442, -2.9449923038482666, -2.166306495666504, -2.63266658782959, -2.1571738719940186, -2.544296979904175, -2.130174160003662, -1.4789001941680908, -2.2397665977478027, -2.0390028953552246, -1.4114242792129517, -1.1583020687103271, 0.689256489276886, 0.21884992718696594, 0.36397072672843933, 0.18110808730125427, -0.6370899677276611, -0.020553454756736755, 2.667240619659424, -0.1676579713821411, -0.6151553392410278, -0.02400813065469265, 0.9842281341552734, -0.367787629365921, 0.1135120540857315, -1.4350149631500244, 0.03024519607424736, 0.0013148305006325245, 0.01816360466182232, -0.6290996670722961, -0.6055077314376831, -1.3151978254318237, -0.8905296325683594, -0.46375998854637146, -1.2759133577346802, -0.5077823996543884, -1.3989776372909546, -1.520242691040039, -1.9325159788131714, -2.5024237632751465, -2.0665383338928223, 0.0, 0.0, -0.0, -0.0, -17.13910484313965, -14.090863227844238, -12.792787551879883, -11.645392417907715, -11.291694641113281, -10.541577339172363, -9.35718059539795, -9.584139823913574, -8.32131576538086, -8.080997467041016, -7.686566352844238, -6.832091808319092, -6.774085998535156, -6.185229778289795, -5.588740825653076, -5.132737159729004, -5.273025035858154, -5.232296466827393, -4.695992469787598, -3.882802724838257, -4.659888744354248, -4.767660140991211, -5.251021862030029, -3.9361958503723145, 0.0264072734862566, -2.3991174697875977, -1.7660146951675415, -2.4743592739105225, -2.7106876373291016, -3.366583824157715, -3.9332239627838135, -2.664569854736328, -2.3702809810638428, -1.9573193788528442, -2.9449923038482666, -2.166306495666504, -2.63266658782959, -2.1571738719940186, -2.544296979904175, -2.130174160003662, -1.4789001941680908, -2.2397665977478027, -2.0390028953552246, -1.4114242792129517, -1.1583020687103271, 0.689256489276886, 0.21884992718696594, 0.36397072672843933, 0.18110808730125427, -0.6370899677276611, -0.020553454756736755, 2.667240619659424, -0.1676579713821411, -0.6151553392410278, -0.02400813065469265, 0.9842281341552734, -0.367787629365921, 0.1135120540857315, -1.4350149631500244, 0.03024519607424736, 0.0013148305006325245, 0.01816360466182232, -0.6290996670722961, -0.6055077314376831, -1.3151978254318237, -0.8905296325683594, -0.46375998854637146, -1.2759133577346802, -0.5077823996543884, -1.3989776372909546, -1.520242691040039, -1.9325159788131714, -2.5024237632751465, -2.0665383338928223, -0.0, -0.0], [0.0, 0.0, -15.731877326965332, -15.028488159179688, -13.310194969177246, -12.419629096984863, -11.470744132995605, -10.525480270385742, -9.978682518005371, -8.844167709350586, -8.38054370880127, -8.96837043762207, -8.43443489074707, -7.533356189727783, -6.986178398132324, -5.786129474639893, -5.811175346374512, -5.220156192779541, -5.27883243560791, -5.984260559082031, -5.222527027130127, -3.071362018585205, -3.9925310611724854, -4.308703422546387, -4.277290344238281, -3.0881123542785645, -2.496751308441162, -5.657270908355713, -2.9974632263183594, -3.736722230911255, -2.4275546073913574, -2.4554460048675537, -2.6976935863494873, -1.4156560897827148, -2.7645413875579834, -2.3863558769226074, -2.00943922996521, -3.17354416847229, -3.0553982257843018, -2.368342399597168, -2.1663458347320557, -2.43332576751709, -2.127495288848877, -2.7208800315856934, -1.3961609601974487, -2.3797121047973633, -3.9207773208618164, -1.0716197490692139, -0.9016011953353882, -2.307231903076172, -1.0444061756134033, 0.33580800890922546, 0.18407827615737915, -0.716320812702179, 0.0417306162416935, -1.0048731565475464, -0.5990983247756958, 0.3002127707004547, -0.1654868721961975, -0.05808033421635628, -0.49270325899124146, -0.6698024272918701, -0.28399890661239624, -0.43691161274909973, -0.6914868354797363, -0.6942481994628906, -1.4865100383758545, -0.8447705507278442, -0.9859601855278015, -1.7036080360412598, -2.1215975284576416, -0.8450514674186707, -1.8701162338256836, -1.297135591506958, -2.3762974739074707, -4.463562488555908, 0.0, 0.0, -0.0, -0.0, -15.731877326965332, -15.028488159179688, -13.310194969177246, -12.419629096984863, -11.470744132995605, -10.525480270385742, -9.978682518005371, -8.844167709350586, -8.38054370880127, -8.96837043762207, -8.43443489074707, -7.533356189727783, -6.986178398132324, -5.786129474639893, -5.811175346374512, -5.220156192779541, -5.27883243560791, -5.984260559082031, -5.222527027130127, -3.071362018585205, -3.9925310611724854, -4.308703422546387, -4.277290344238281, -3.0881123542785645, -2.496751308441162, -5.657270908355713, -2.9974632263183594, -3.736722230911255, -2.4275546073913574, -2.4554460048675537, -2.6976935863494873, -1.4156560897827148, -2.7645413875579834, -2.3863558769226074, -2.00943922996521, -3.17354416847229, -3.0553982257843018, -2.368342399597168, -2.1663458347320557, -2.43332576751709, -2.127495288848877, -2.7208800315856934, -1.3961609601974487, -2.3797121047973633, -3.9207773208618164, -1.0716197490692139, -0.9016011953353882, -2.307231903076172, -1.0444061756134033, 0.33580800890922546, 0.18407827615737915, -0.716320812702179, 0.0417306162416935, -1.0048731565475464, -0.5990983247756958, 0.3002127707004547, -0.1654868721961975, -0.05808033421635628, -0.49270325899124146, -0.6698024272918701, -0.28399890661239624, -0.43691161274909973, -0.6914868354797363, -0.6942481994628906, -1.4865100383758545, -0.8447705507278442, -0.9859601855278015, -1.7036080360412598, -2.1215975284576416, -0.8450514674186707, -1.8701162338256836, -1.297135591506958, -2.3762974739074707, -4.463562488555908, -0.0, -0.0], [0.0, 0.0, -17.051597595214844, -14.236146926879883, -14.078020095825195, -12.698407173156738, -11.900010108947754, -10.704838752746582, -10.896714210510254, -8.43294620513916, -8.382308959960938, -8.748961448669434, -7.198349475860596, -9.603419303894043, -6.607817649841309, -6.504502296447754, -6.557648181915283, -5.37001371383667, -4.891079425811768, -4.154190540313721, -5.258959770202637, -4.739161491394043, -5.825238227844238, -3.9287078380584717, -4.069225788116455, -5.749992370605469, -2.590259552001953, -3.408504009246826, -5.043926239013672, -3.1937572956085205, -2.385115146636963, -2.975466012954712, -3.4625906944274902, -3.2712485790252686, -2.758200168609619, -3.891468048095703, -3.4265568256378174, -3.2319209575653076, -3.175813913345337, -3.3102831840515137, -2.6253740787506104, -2.169121265411377, -3.0049233436584473, -2.6353390216827393, -3.7793939113616943, -2.3386173248291016, -1.956173300743103, -1.2746233940124512, -1.5382672548294067, -0.9494126439094543, -1.229535460472107, -1.2299469709396362, -0.6168711185455322, -1.3786754608154297, 0.4074086844921112, -1.4088183641433716, -1.1581655740737915, -0.36298099160194397, -0.12436775863170624, 0.43453624844551086, -0.6528062224388123, -1.1521568298339844, -0.1317622810602188, -0.6753815412521362, -0.4632047116756439, -0.31217557191848755, -0.908507227897644, -1.9461870193481445, -0.9393414258956909, -1.167119026184082, -0.6821874976158142, -1.7532598972320557, -0.9275306463241577, -2.8230278491973877, -3.2796995639801025, -4.0404791831970215, 0.0, 0.0, -0.0, -0.0, -17.051597595214844, -14.236146926879883, -14.078020095825195, -12.698407173156738, -11.900010108947754, -10.704838752746582, -10.896714210510254, -8.43294620513916, -8.382308959960938, -8.748961448669434, -7.198349475860596, -9.603419303894043, -6.607817649841309, -6.504502296447754, -6.557648181915283, -5.37001371383667, -4.891079425811768, -4.154190540313721, -5.258959770202637, -4.739161491394043, -5.825238227844238, -3.9287078380584717, -4.069225788116455, -5.749992370605469, -2.590259552001953, -3.408504009246826, -5.043926239013672, -3.1937572956085205, -2.385115146636963, -2.975466012954712, -3.4625906944274902, -3.2712485790252686, -2.758200168609619, -3.891468048095703, -3.4265568256378174, -3.2319209575653076, -3.175813913345337, -3.3102831840515137, -2.6253740787506104, -2.169121265411377, -3.0049233436584473, -2.6353390216827393, -3.7793939113616943, -2.3386173248291016, -1.956173300743103, -1.2746233940124512, -1.5382672548294067, -0.9494126439094543, -1.229535460472107, -1.2299469709396362, -0.6168711185455322, -1.3786754608154297, 0.4074086844921112, -1.4088183641433716, -1.1581655740737915, -0.36298099160194397, -0.12436775863170624, 0.43453624844551086, -0.6528062224388123, -1.1521568298339844, -0.1317622810602188, -0.6753815412521362, -0.4632047116756439, -0.31217557191848755, -0.908507227897644, -1.9461870193481445, -0.9393414258956909, -1.167119026184082, -0.6821874976158142, -1.7532598972320557, -0.9275306463241577, -2.8230278491973877, -3.2796995639801025, -4.0404791831970215, -0.0, -0.0], [0.0, 0.0, -16.53470802307129, -14.568333625793457, -13.967232704162598, -12.792681694030762, -12.127967834472656, -11.604704856872559, -10.307855606079102, -10.77495288848877, -9.098702430725098, -8.704859733581543, -7.321869373321533, -7.2244954109191895, -7.231163501739502, -6.689990997314453, -6.595035552978516, -6.252768039703369, -5.6653151512146, -5.299314498901367, -4.630547523498535, -4.3965044021606445, -4.426375389099121, -5.133184432983398, -3.395332098007202, -3.8789961338043213, -3.535137414932251, -3.98956561088562, -3.4256861209869385, -4.190441131591797, -3.0175812244415283, -2.7767932415008545, -3.770967483520508, -3.0433478355407715, -3.1888606548309326, -3.474388837814331, -4.783437728881836, -3.7661194801330566, -3.3867809772491455, -3.4588611125946045, -4.376535892486572, -3.4406468868255615, -2.3634257316589355, -3.5106077194213867, -2.3064231872558594, -3.7900636196136475, -2.8916962146759033, -3.247915029525757, 0.14838241040706635, -2.7357540130615234, -1.8000625371932983, -2.973341226577759, -1.713114857673645, -2.3353183269500732, -1.6793856620788574, -0.7371962666511536, 0.48585107922554016, -1.1975791454315186, -1.2266896963119507, -0.014780359342694283, -1.3437659740447998, -1.466401219367981, -0.9917467832565308, -0.9293088912963867, -0.7358261942863464, -0.2488463670015335, -0.8199061751365662, -0.22489400207996368, -1.771647572517395, -1.8039460182189941, -2.0568695068359375, -3.160839557647705, -2.61191463470459, -2.4682438373565674, -3.0697405338287354, -3.899991750717163, -1.5843178033828735, 0.0, -0.0, -0.0, -16.53470802307129, -14.568333625793457, -13.967232704162598, -12.792681694030762, -12.127967834472656, -11.604704856872559, -10.307855606079102, -10.77495288848877, -9.098702430725098, -8.704859733581543, -7.321869373321533, -7.2244954109191895, -7.231163501739502, -6.689990997314453, -6.595035552978516, -6.252768039703369, -5.6653151512146, -5.299314498901367, -4.630547523498535, -4.3965044021606445, -4.426375389099121, -5.133184432983398, -3.395332098007202, -3.8789961338043213, -3.535137414932251, -3.98956561088562, -3.4256861209869385, -4.190441131591797, -3.0175812244415283, -2.7767932415008545, -3.770967483520508, -3.0433478355407715, -3.1888606548309326, -3.474388837814331, -4.783437728881836, -3.7661194801330566, -3.3867809772491455, -3.4588611125946045, -4.376535892486572, -3.4406468868255615, -2.3634257316589355, -3.5106077194213867, -2.3064231872558594, -3.7900636196136475, -2.8916962146759033, -3.247915029525757, 0.14838241040706635, -2.7357540130615234, -1.8000625371932983, -2.973341226577759, -1.713114857673645, -2.3353183269500732, -1.6793856620788574, -0.7371962666511536, 0.48585107922554016, -1.1975791454315186, -1.2266896963119507, -0.014780359342694283, -1.3437659740447998, -1.466401219367981, -0.9917467832565308, -0.9293088912963867, -0.7358261942863464, -0.2488463670015335, -0.8199061751365662, -0.22489400207996368, -1.771647572517395, -1.8039460182189941, -2.0568695068359375, -3.160839557647705, -2.61191463470459, -2.4682438373565674, -3.0697405338287354, -3.899991750717163, -1.5843178033828735, -0.0], [0.0, 0.0, -17.351810455322266, -15.634599685668945, -14.23122787475586, -12.95416259765625, -11.677638053894043, -11.916882514953613, -11.24325942993164, -9.852481842041016, -8.815910339355469, -9.219493865966797, -8.021135330200195, -7.088612079620361, -6.464522838592529, -6.934835910797119, -6.623124122619629, -6.0625481605529785, -5.8581719398498535, -5.28810977935791, -5.3608856201171875, -4.166672706604004, -5.220632553100586, -3.624054431915283, -3.7269532680511475, -4.427913665771484, -4.385904312133789, -3.7517662048339844, -4.275331974029541, -4.919147491455078, -4.115517616271973, -2.664219856262207, -4.34380578994751, -1.4098951816558838, -3.10479998588562, -5.172854423522949, -5.257521152496338, -3.960634708404541, -4.714200496673584, -6.196104526519775, -5.330193519592285, -4.593898773193359, -4.168176174163818, -4.334742546081543, -5.539579391479492, -2.056617259979248, -2.62827205657959, -2.20125150680542, -3.6965510845184326, -2.590801477432251, -2.8647027015686035, -2.023303508758545, -2.3655447959899902, -4.366797924041748, -1.038948893547058, -1.123600959777832, -0.2985174357891083, -1.1462781429290771, -3.6654458045959473, -0.6745209693908691, -1.438233494758606, -1.2349194288253784, -0.31961748003959656, -0.8102527856826782, -0.9990880489349365, -1.0850144624710083, -1.247625708580017, -1.5226973295211792, -1.27939772605896, -1.1355762481689453, -1.6560255289077759, -1.6206766366958618, -2.961643695831299, -2.7433855533599854, -3.26965069770813, -4.22251033782959, 0.0, 0.0, -0.0, -0.0, -17.351810455322266, -15.634599685668945, -14.23122787475586, -12.95416259765625, -11.677638053894043, -11.916882514953613, -11.24325942993164, -9.852481842041016, -8.815910339355469, -9.219493865966797, -8.021135330200195, -7.088612079620361, -6.464522838592529, -6.934835910797119, -6.623124122619629, -6.0625481605529785, -5.8581719398498535, -5.28810977935791, -5.3608856201171875, -4.166672706604004, -5.220632553100586, -3.624054431915283, -3.7269532680511475, -4.427913665771484, -4.385904312133789, -3.7517662048339844, -4.275331974029541, -4.919147491455078, -4.115517616271973, -2.664219856262207, -4.34380578994751, -1.4098951816558838, -3.10479998588562, -5.172854423522949, -5.257521152496338, -3.960634708404541, -4.714200496673584, -6.196104526519775, -5.330193519592285, -4.593898773193359, -4.168176174163818, -4.334742546081543, -5.539579391479492, -2.056617259979248, -2.62827205657959, -2.20125150680542, -3.6965510845184326, -2.590801477432251, -2.8647027015686035, -2.023303508758545, -2.3655447959899902, -4.366797924041748, -1.038948893547058, -1.123600959777832, -0.2985174357891083, -1.1462781429290771, -3.6654458045959473, -0.6745209693908691, -1.438233494758606, -1.2349194288253784, -0.31961748003959656, -0.8102527856826782, -0.9990880489349365, -1.0850144624710083, -1.247625708580017, -1.5226973295211792, -1.27939772605896, -1.1355762481689453, -1.6560255289077759, -1.6206766366958618, -2.961643695831299, -2.7433855533599854, -3.26965069770813, -4.22251033782959, -0.0, -0.0], [0.0, 0.0, -19.055030822753906, -16.72759437561035, -14.741142272949219, -13.341129302978516, -11.849361419677734, -11.255879402160645, -10.589068412780762, -10.513629913330078, -10.018257141113281, -8.590782165527344, -8.300934791564941, -7.328887462615967, -7.292636394500732, -6.519876003265381, -6.5687103271484375, -5.6071929931640625, -6.6172285079956055, -5.100412845611572, -5.430456161499023, -5.423879146575928, -5.717526435852051, -4.891975402832031, -4.730464458465576, -3.418820858001709, -3.3186163902282715, -2.447605609893799, -3.244255781173706, -6.127006530761719, -5.067788600921631, -3.183130979537964, -4.487186908721924, -4.662689208984375, -4.211001873016357, -5.083243370056152, -5.52766752243042, -6.182107448577881, -5.330398082733154, -6.994541645050049, -5.569544315338135, -4.753986835479736, -5.34063720703125, -4.687648773193359, -4.6509552001953125, -3.7178938388824463, -5.234759330749512, -4.045060634613037, -1.8068574666976929, -4.5631256103515625, -3.3360369205474854, -0.7798546552658081, -1.442041277885437, -2.5919246673583984, -2.5928850173950195, -0.4974537789821625, -0.019421624019742012, -1.1785567998886108, -0.5628300905227661, -2.011223316192627, -0.47770705819129944, -0.5996260643005371, -0.5817584991455078, -4.036238193511963, -1.2899152040481567, -1.2446037530899048, -1.3632559776306152, -1.4966425895690918, -1.399251103401184, -1.5700629949569702, -1.0631122589111328, -2.2645914554595947, -3.066988945007324, -3.541921615600586, -3.3438942432403564, -4.461889743804932, 0.0, 0.0, -0.0, -0.0, -19.055030822753906, -16.72759437561035, -14.741142272949219, -13.341129302978516, -11.849361419677734, -11.255879402160645, -10.589068412780762, -10.513629913330078, -10.018257141113281, -8.590782165527344, -8.300934791564941, -7.328887462615967, -7.292636394500732, -6.519876003265381, -6.5687103271484375, -5.6071929931640625, -6.6172285079956055, -5.100412845611572, -5.430456161499023, -5.423879146575928, -5.717526435852051, -4.891975402832031, -4.730464458465576, -3.418820858001709, -3.3186163902282715, -2.447605609893799, -3.244255781173706, -6.127006530761719, -5.067788600921631, -3.183130979537964, -4.487186908721924, -4.662689208984375, -4.211001873016357, -5.083243370056152, -5.52766752243042, -6.182107448577881, -5.330398082733154, -6.994541645050049, -5.569544315338135, -4.753986835479736, -5.34063720703125, -4.687648773193359, -4.6509552001953125, -3.7178938388824463, -5.234759330749512, -4.045060634613037, -1.8068574666976929, -4.5631256103515625, -3.3360369205474854, -0.7798546552658081, -1.442041277885437, -2.5919246673583984, -2.5928850173950195, -0.4974537789821625, -0.019421624019742012, -1.1785567998886108, -0.5628300905227661, -2.011223316192627, -0.47770705819129944, -0.5996260643005371, -0.5817584991455078, -4.036238193511963, -1.2899152040481567, -1.2446037530899048, -1.3632559776306152, -1.4966425895690918, -1.399251103401184, -1.5700629949569702, -1.0631122589111328, -2.2645914554595947, -3.066988945007324, -3.541921615600586, -3.3438942432403564, -4.461889743804932, -0.0, -0.0], [0.0, 0.0, -18.95854377746582, -17.210866928100586, -14.33137321472168, -13.48937702178955, -11.70623779296875, -11.353805541992188, -10.547776222229004, -9.645708084106445, -9.965309143066406, -9.534408569335938, -8.857076644897461, -7.884466648101807, -7.282973766326904, -6.664698600769043, -6.483866214752197, -6.580356121063232, -6.445018291473389, -6.392096996307373, -5.419618129730225, -6.5106401443481445, -5.283138275146484, -6.285443305969238, -5.620907306671143, -4.523458957672119, -4.407323837280273, -4.866410732269287, -3.8985507488250732, -5.563981533050537, -5.900004863739014, -4.234118461608887, -5.680586814880371, -4.831897258758545, -5.105372428894043, -5.2229437828063965, -6.171754837036133, -5.9685869216918945, -6.80876350402832, -6.746356010437012, -6.064109802246094, -4.495056629180908, -6.858245372772217, -5.397707462310791, -4.943798065185547, -6.017118453979492, -4.173101902008057, -4.9922404289245605, -4.292741775512695, -4.783289909362793, -5.872346878051758, -2.505072832107544, -2.1254079341888428, -0.7354652285575867, -1.9357435703277588, -2.354217052459717, -3.3089699745178223, -1.6156448125839233, -1.3015491962432861, -2.0172948837280273, -1.3963993787765503, -0.6556512713432312, -1.357147455215454, -0.8866100907325745, -1.1807177066802979, -1.7835243940353394, 0.2229345738887787, -1.626613974571228, -1.677780270576477, -1.7225996255874634, -1.839701533317566, -3.011451005935669, -2.4408161640167236, -3.866384744644165, -4.255558967590332, -4.499063014984131, 0.0, 0.0, -0.0, -0.0, -18.95854377746582, -17.210866928100586, -14.33137321472168, -13.48937702178955, -11.70623779296875, -11.353805541992188, -10.547776222229004, -9.645708084106445, -9.965309143066406, -9.534408569335938, -8.857076644897461, -7.884466648101807, -7.282973766326904, -6.664698600769043, -6.483866214752197, -6.580356121063232, -6.445018291473389, -6.392096996307373, -5.419618129730225, -6.5106401443481445, -5.283138275146484, -6.285443305969238, -5.620907306671143, -4.523458957672119, -4.407323837280273, -4.866410732269287, -3.8985507488250732, -5.563981533050537, -5.900004863739014, -4.234118461608887, -5.680586814880371, -4.831897258758545, -5.105372428894043, -5.2229437828063965, -6.171754837036133, -5.9685869216918945, -6.80876350402832, -6.746356010437012, -6.064109802246094, -4.495056629180908, -6.858245372772217, -5.397707462310791, -4.943798065185547, -6.017118453979492, -4.173101902008057, -4.9922404289245605, -4.292741775512695, -4.783289909362793, -5.872346878051758, -2.505072832107544, -2.1254079341888428, -0.7354652285575867, -1.9357435703277588, -2.354217052459717, -3.3089699745178223, -1.6156448125839233, -1.3015491962432861, -2.0172948837280273, -1.3963993787765503, -0.6556512713432312, -1.357147455215454, -0.8866100907325745, -1.1807177066802979, -1.7835243940353394, 0.2229345738887787, -1.626613974571228, -1.677780270576477, -1.7225996255874634, -1.839701533317566, -3.011451005935669, -2.4408161640167236, -3.866384744644165, -4.255558967590332, -4.499063014984131, -0.0, -0.0], [0.0, 0.0, -19.429479598999023, -17.097196578979492, -14.712921142578125, -13.741549491882324, -11.9817533493042, -11.052931785583496, -11.312803268432617, -10.515308380126953, -9.660840034484863, -9.29638957977295, -8.533859252929688, -7.913569927215576, -6.621894359588623, -7.279883861541748, -6.081099033355713, -6.713338375091553, -6.168025970458984, -6.223103046417236, -6.1573028564453125, -5.998167037963867, -5.029626369476318, -5.839400291442871, -4.381414890289307, -5.205500602722168, -5.153538703918457, -5.2847819328308105, -6.095335006713867, -5.4575700759887695, -4.671477794647217, -4.334827423095703, -4.694613456726074, -7.491777420043945, -7.267817497253418, -6.180753707885742, -6.779480457305908, -7.612926483154297, -7.091492176055908, -6.800536155700684, -6.6679158210754395, -6.815084457397461, -8.299260139465332, -5.682463645935059, -8.39011287689209, -6.524544715881348, -3.645897150039673, -6.22625732421875, -7.360262870788574, -3.1904327869415283, -4.282557487487793, -3.4506630897521973, -3.7428393363952637, -3.5807719230651855, -0.985042154788971, -1.919907569885254, -3.6111128330230713, -2.2620038986206055, 1.0439503192901611, -2.080793857574463, -1.785144567489624, -1.6658670902252197, -1.433120846748352, -1.4670735597610474, -0.9747999906539917, -1.1756062507629395, -0.9404146075248718, -1.3425092697143555, -1.8073314428329468, -1.9450856447219849, -2.450410842895508, -2.5456395149230957, -2.7559826374053955, -3.63630747795105, -4.938009262084961, -6.063808441162109, 0.0, 0.0, -0.0, -0.0, -19.429479598999023, -17.097196578979492, -14.712921142578125, -13.741549491882324, -11.9817533493042, -11.052931785583496, -11.312803268432617, -10.515308380126953, -9.660840034484863, -9.29638957977295, -8.533859252929688, -7.913569927215576, -6.621894359588623, -7.279883861541748, -6.081099033355713, -6.713338375091553, -6.168025970458984, -6.223103046417236, -6.1573028564453125, -5.998167037963867, -5.029626369476318, -5.839400291442871, -4.381414890289307, -5.205500602722168, -5.153538703918457, -5.2847819328308105, -6.095335006713867, -5.4575700759887695, -4.671477794647217, -4.334827423095703, -4.694613456726074, -7.491777420043945, -7.267817497253418, -6.180753707885742, -6.779480457305908, -7.612926483154297, -7.091492176055908, -6.800536155700684, -6.6679158210754395, -6.815084457397461, -8.299260139465332, -5.682463645935059, -8.39011287689209, -6.524544715881348, -3.645897150039673, -6.22625732421875, -7.360262870788574, -3.1904327869415283, -4.282557487487793, -3.4506630897521973, -3.7428393363952637, -3.5807719230651855, -0.985042154788971, -1.919907569885254, -3.6111128330230713, -2.2620038986206055, 1.0439503192901611, -2.080793857574463, -1.785144567489624, -1.6658670902252197, -1.433120846748352, -1.4670735597610474, -0.9747999906539917, -1.1756062507629395, -0.9404146075248718, -1.3425092697143555, -1.8073314428329468, -1.9450856447219849, -2.450410842895508, -2.5456395149230957, -2.7559826374053955, -3.63630747795105, -4.938009262084961, -6.063808441162109, -0.0, -0.0], [0.0, 0.0, -16.068683624267578, -16.54665756225586, -15.498337745666504, -13.818387031555176, -12.16295051574707, -12.146472930908203, -10.951546669006348, -10.229155540466309, -9.643775939941406, -8.728353500366211, -9.102993965148926, -7.7064738273620605, -7.395175457000732, -7.292192459106445, -7.094841003417969, -7.264132499694824, -6.934441566467285, -5.240577697753906, -8.049881935119629, -5.172780990600586, -5.400518894195557, -3.6576249599456787, -5.975482940673828, -4.417168617248535, -5.942159652709961, -4.082320213317871, -4.703627109527588, -5.315069675445557, -6.034498691558838, -6.138256072998047, -6.908773422241211, -7.871159553527832, -5.802364826202393, -6.294469356536865, -7.713035583496094, -9.49563980102539, -7.3264241218566895, -7.366279602050781, -7.185164451599121, -10.1201810836792, -6.788452625274658, -9.258146286010742, -6.8881988525390625, -7.9001312255859375, -8.11491584777832, -7.374523639678955, -5.783011436462402, -4.657434940338135, -3.2020821571350098, -3.374716281890869, -3.9800705909729004, -4.5566229820251465, -3.357675790786743, -2.4819748401641846, -2.4880404472351074, -2.323854684829712, -0.9533201456069946, 0.6600798964500427, -1.1164594888687134, -1.3813986778259277, -0.833168625831604, -1.353449821472168, -0.9150266647338867, -1.1674015522003174, -0.8916923999786377, -1.7807186841964722, -2.3103280067443848, -1.5105146169662476, -1.4152843952178955, -2.9354138374328613, -3.748300790786743, -4.480410575866699, -5.184251308441162, 0.0, 0.0, 1.6097148656845093, -0.0, -0.0, -16.068683624267578, -16.54665756225586, -15.498337745666504, -13.818387031555176, -12.16295051574707, -12.146472930908203, -10.951546669006348, -10.229155540466309, -9.643775939941406, -8.728353500366211, -9.102993965148926, -7.7064738273620605, -7.395175457000732, -7.292192459106445, -7.094841003417969, -7.264132499694824, -6.934441566467285, -5.240577697753906, -8.049881935119629, -5.172780990600586, -5.400518894195557, -3.6576249599456787, -5.975482940673828, -4.417168617248535, -5.942159652709961, -4.082320213317871, -4.703627109527588, -5.315069675445557, -6.034498691558838, -6.138256072998047, -6.908773422241211, -7.871159553527832, -5.802364826202393, -6.294469356536865, -7.713035583496094, -9.49563980102539, -7.3264241218566895, -7.366279602050781, -7.185164451599121, -10.1201810836792, -6.788452625274658, -9.258146286010742, -6.8881988525390625, -7.9001312255859375, -8.11491584777832, -7.374523639678955, -5.783011436462402, -4.657434940338135, -3.2020821571350098, -3.374716281890869, -3.9800705909729004, -4.5566229820251465, -3.357675790786743, -2.4819748401641846, -2.4880404472351074, -2.323854684829712, -0.9533201456069946, 0.6600798964500427, -1.1164594888687134, -1.3813986778259277, -0.833168625831604, -1.353449821472168, -0.9150266647338867, -1.1674015522003174, -0.8916923999786377, -1.7807186841964722, -2.3103280067443848, -1.5105146169662476, -1.4152843952178955, -2.9354138374328613, -3.748300790786743, -4.480410575866699, -5.184251308441162, -0.0, -0.0, 1.6097148656845093], [0.0, 0.0, 0.0, -13.760363578796387, -14.967589378356934, -13.851579666137695, -12.436848640441895, -10.884931564331055, -11.612401962280273, -10.592789649963379, -9.698416709899902, -9.178608894348145, -9.033557891845703, -7.645934104919434, -7.5017828941345215, -7.725761890411377, -6.813844203948975, -7.190068244934082, -7.090436935424805, -6.463574409484863, -5.76708459854126, -6.273411273956299, -5.80742883682251, -6.921713829040527, -6.393091201782227, -5.607100486755371, -6.267303466796875, -6.8237104415893555, -7.4142327308654785, -6.780306816101074, -7.043023109436035, -7.249721527099609, -9.179484367370605, -7.255763530731201, -7.060691833496094, -11.332006454467773, -7.984241962432861, -9.063122749328613, -8.14227294921875, -9.831747055053711, -8.946794509887695, -9.18043327331543, -8.786453247070312, -8.887588500976562, -9.383428573608398, -7.945434093475342, -7.536351203918457, -6.32661247253418, -7.046360492706299, -5.816501617431641, -4.953949928283691, -7.9058146476745605, -2.7133283615112305, -4.064014911651611, -3.496925115585327, -5.941303730010986, -3.0900497436523438, -3.163437604904175, -1.3489543199539185, -2.023534059524536, -2.26798939704895, -2.3303751945495605, -1.0165735483169556, -1.5308130979537964, -2.422985553741455, -1.46479070186615, -2.2103524208068848, -2.7078795433044434, -2.6925559043884277, -2.5213632583618164, -2.6383631229400635, -3.2621335983276367, -3.6094202995300293, -4.5928168296813965, -5.381904125213623, 0.0, 0.0, 1.8617912530899048, -0.0, -0.0, -0.0, -13.760363578796387, -14.967589378356934, -13.851579666137695, -12.436848640441895, -10.884931564331055, -11.612401962280273, -10.592789649963379, -9.698416709899902, -9.178608894348145, -9.033557891845703, -7.645934104919434, -7.5017828941345215, -7.725761890411377, -6.813844203948975, -7.190068244934082, -7.090436935424805, -6.463574409484863, -5.76708459854126, -6.273411273956299, -5.80742883682251, -6.921713829040527, -6.393091201782227, -5.607100486755371, -6.267303466796875, -6.8237104415893555, -7.4142327308654785, -6.780306816101074, -7.043023109436035, -7.249721527099609, -9.179484367370605, -7.255763530731201, -7.060691833496094, -11.332006454467773, -7.984241962432861, -9.063122749328613, -8.14227294921875, -9.831747055053711, -8.946794509887695, -9.18043327331543, -8.786453247070312, -8.887588500976562, -9.383428573608398, -7.945434093475342, -7.536351203918457, -6.32661247253418, -7.046360492706299, -5.816501617431641, -4.953949928283691, -7.9058146476745605, -2.7133283615112305, -4.064014911651611, -3.496925115585327, -5.941303730010986, -3.0900497436523438, -3.163437604904175, -1.3489543199539185, -2.023534059524536, -2.26798939704895, -2.3303751945495605, -1.0165735483169556, -1.5308130979537964, -2.422985553741455, -1.46479070186615, -2.2103524208068848, -2.7078795433044434, -2.6925559043884277, -2.5213632583618164, -2.6383631229400635, -3.2621335983276367, -3.6094202995300293, -4.5928168296813965, -5.381904125213623, -0.0, -0.0, 1.8617912530899048], [0.0, 0.0, 0.0, -17.808027267456055, -14.912222862243652, -13.779051780700684, -12.745108604431152, -12.351113319396973, -11.014603614807129, -10.65048599243164, -8.101531982421875, -9.365607261657715, -8.90754222869873, -8.667683601379395, -7.4059529304504395, -7.501034259796143, -7.249484539031982, -7.304072856903076, -7.278771877288818, -6.728494167327881, -7.547268867492676, -5.491103649139404, -5.942626476287842, -6.372332572937012, -6.473258972167969, -6.445408821105957, -6.7624664306640625, -7.6569132804870605, -7.2606000900268555, -6.997093677520752, -8.827279090881348, -8.578064918518066, -9.163272857666016, -6.072207927703857, -7.377730369567871, -9.198260307312012, -9.350796699523926, -9.781993865966797, -9.602095603942871, -10.108637809753418, -10.735629081726074, -11.007902145385742, -8.921293258666992, -9.605324745178223, -8.069286346435547, -9.328547477722168, -7.773110866546631, -6.910704612731934, -6.501276969909668, -5.0984978675842285, -3.803709030151367, -5.133192539215088, -4.296538352966309, -3.7976009845733643, -4.010801792144775, -3.1223819255828857, -3.514254093170166, -3.452378749847412, -1.9621762037277222, -2.5967211723327637, -1.6380212306976318, -2.449026584625244, -2.422342300415039, -1.9163438081741333, -1.6083959341049194, -1.4929709434509277, -2.00645112991333, -1.5412514209747314, -2.4768381118774414, -2.6696102619171143, -2.9156086444854736, -3.242666482925415, -4.477386474609375, -4.412933826446533, -6.039844036102295, 0.0, 0.0, -0.8051614165306091, -0.0, -0.0, -0.0, -17.808027267456055, -14.912222862243652, -13.779051780700684, -12.745108604431152, -12.351113319396973, -11.014603614807129, -10.65048599243164, -8.101531982421875, -9.365607261657715, -8.90754222869873, -8.667683601379395, -7.4059529304504395, -7.501034259796143, -7.249484539031982, -7.304072856903076, -7.278771877288818, -6.728494167327881, -7.547268867492676, -5.491103649139404, -5.942626476287842, -6.372332572937012, -6.473258972167969, -6.445408821105957, -6.7624664306640625, -7.6569132804870605, -7.2606000900268555, -6.997093677520752, -8.827279090881348, -8.578064918518066, -9.163272857666016, -6.072207927703857, -7.377730369567871, -9.198260307312012, -9.350796699523926, -9.781993865966797, -9.602095603942871, -10.108637809753418, -10.735629081726074, -11.007902145385742, -8.921293258666992, -9.605324745178223, -8.069286346435547, -9.328547477722168, -7.773110866546631, -6.910704612731934, -6.501276969909668, -5.0984978675842285, -3.803709030151367, -5.133192539215088, -4.296538352966309, -3.7976009845733643, -4.010801792144775, -3.1223819255828857, -3.514254093170166, -3.452378749847412, -1.9621762037277222, -2.5967211723327637, -1.6380212306976318, -2.449026584625244, -2.422342300415039, -1.9163438081741333, -1.6083959341049194, -1.4929709434509277, -2.00645112991333, -1.5412514209747314, -2.4768381118774414, -2.6696102619171143, -2.9156086444854736, -3.242666482925415, -4.477386474609375, -4.412933826446533, -6.039844036102295, -0.0, -0.0, -0.8051614165306091], [-13.183781623840332, 0.0, 0.0, -16.96268081665039, -15.254498481750488, -14.219377517700195, -13.295711517333984, -12.016202926635742, -11.40587043762207, -10.669782638549805, -9.83620548248291, -8.944243431091309, -8.891648292541504, -8.444677352905273, -7.693551540374756, -6.959963798522949, -7.6903486251831055, -7.249989986419678, -7.399423599243164, -7.393752574920654, -7.13762903213501, -7.450318813323975, -6.868102073669434, -7.312954425811768, -6.218183994293213, -7.786904811859131, -7.899866104125977, -6.944366931915283, -9.111873626708984, -8.094847679138184, -8.515491485595703, -9.258399963378906, -10.205573081970215, -9.75760269165039, -9.982441902160645, -11.516234397888184, -11.178425788879395, -10.57332992553711, -9.7524995803833, -11.352727890014648, -12.248796463012695, -11.323087692260742, -12.767258644104004, -9.399124145507812, -10.371267318725586, -9.951531410217285, -7.822470664978027, -9.615886688232422, -9.38339614868164, -7.627202033996582, -6.2027201652526855, -6.676506519317627, -5.589127540588379, -5.120754718780518, -5.456853866577148, -4.91401481628418, -4.502553939819336, -3.1020870208740234, -1.9163286685943604, -2.890902519226074, -3.0656821727752686, -1.6383112668991089, -2.6631078720092773, -1.6209931373596191, -1.6047251224517822, -1.5005371570587158, -2.4286012649536133, -2.3907837867736816, -2.367379665374756, -2.3400096893310547, -3.2491910457611084, -4.2392120361328125, -3.8892595767974854, -5.249542713165283, 0.0, 0.0, 0.0, 0.4820096790790558, -13.183781623840332, -0.0, -0.0, -16.96268081665039, -15.254498481750488, -14.219377517700195, -13.295711517333984, -12.016202926635742, -11.40587043762207, -10.669782638549805, -9.83620548248291, -8.944243431091309, -8.891648292541504, -8.444677352905273, -7.693551540374756, -6.959963798522949, -7.6903486251831055, -7.249989986419678, -7.399423599243164, -7.393752574920654, -7.13762903213501, -7.450318813323975, -6.868102073669434, -7.312954425811768, -6.218183994293213, -7.786904811859131, -7.899866104125977, -6.944366931915283, -9.111873626708984, -8.094847679138184, -8.515491485595703, -9.258399963378906, -10.205573081970215, -9.75760269165039, -9.982441902160645, -11.516234397888184, -11.178425788879395, -10.57332992553711, -9.7524995803833, -11.352727890014648, -12.248796463012695, -11.323087692260742, -12.767258644104004, -9.399124145507812, -10.371267318725586, -9.951531410217285, -7.822470664978027, -9.615886688232422, -9.38339614868164, -7.627202033996582, -6.2027201652526855, -6.676506519317627, -5.589127540588379, -5.120754718780518, -5.456853866577148, -4.91401481628418, -4.502553939819336, -3.1020870208740234, -1.9163286685943604, -2.890902519226074, -3.0656821727752686, -1.6383112668991089, -2.6631078720092773, -1.6209931373596191, -1.6047251224517822, -1.5005371570587158, -2.4286012649536133, -2.3907837867736816, -2.367379665374756, -2.3400096893310547, -3.2491910457611084, -4.2392120361328125, -3.8892595767974854, -5.249542713165283, -0.0, -0.0, -0.0, 0.4820096790790558], [-17.045387268066406, 0.0, 0.0, -18.886167526245117, -16.217939376831055, -14.535754203796387, -13.317411422729492, -11.939062118530273, -11.658581733703613, -11.160638809204102, -9.809203147888184, -10.547492027282715, -8.365652084350586, -8.932867050170898, -8.012495040893555, -7.867056846618652, -7.456941604614258, -7.392279624938965, -7.358154296875, -7.007258415222168, -7.4386491775512695, -7.7690935134887695, -7.531174659729004, -7.3117499351501465, -7.36100435256958, -7.838467121124268, -8.440637588500977, -8.797386169433594, -8.053339958190918, -8.294472694396973, -8.74483585357666, -9.795417785644531, -10.677762031555176, -10.852012634277344, -12.565475463867188, -9.881417274475098, -11.221001625061035, -11.72191047668457, -12.787200927734375, -12.606414794921875, -12.565645217895508, -12.627126693725586, -12.631545066833496, -13.100217819213867, -12.122824668884277, -11.311456680297852, -10.587339401245117, -8.154499053955078, -10.528849601745605, -9.002293586730957, -7.587732315063477, -7.190868377685547, -6.6941118240356445, -6.109109878540039, -5.3031697273254395, -5.231612205505371, -4.5473151206970215, -5.5266642570495605, -6.36054801940918, -3.2386622428894043, -2.4598660469055176, -2.1839537620544434, -2.152090072631836, -2.465238332748413, -2.185201644897461, -1.6716852188110352, -2.096156597137451, -1.5590054988861084, -2.975127696990967, -2.434197187423706, -3.757415771484375, -3.7800283432006836, -4.439253330230713, -5.564390182495117, 0.0, 0.0, 0.0, 2.0138893127441406, -17.045387268066406, -0.0, -0.0, -18.886167526245117, -16.217939376831055, -14.535754203796387, -13.317411422729492, -11.939062118530273, -11.658581733703613, -11.160638809204102, -9.809203147888184, -10.547492027282715, -8.365652084350586, -8.932867050170898, -8.012495040893555, -7.867056846618652, -7.456941604614258, -7.392279624938965, -7.358154296875, -7.007258415222168, -7.4386491775512695, -7.7690935134887695, -7.531174659729004, -7.3117499351501465, -7.36100435256958, -7.838467121124268, -8.440637588500977, -8.797386169433594, -8.053339958190918, -8.294472694396973, -8.74483585357666, -9.795417785644531, -10.677762031555176, -10.852012634277344, -12.565475463867188, -9.881417274475098, -11.221001625061035, -11.72191047668457, -12.787200927734375, -12.606414794921875, -12.565645217895508, -12.627126693725586, -12.631545066833496, -13.100217819213867, -12.122824668884277, -11.311456680297852, -10.587339401245117, -8.154499053955078, -10.528849601745605, -9.002293586730957, -7.587732315063477, -7.190868377685547, -6.6941118240356445, -6.109109878540039, -5.3031697273254395, -5.231612205505371, -4.5473151206970215, -5.5266642570495605, -6.36054801940918, -3.2386622428894043, -2.4598660469055176, -2.1839537620544434, -2.152090072631836, -2.465238332748413, -2.185201644897461, -1.6716852188110352, -2.096156597137451, -1.5590054988861084, -2.975127696990967, -2.434197187423706, -3.757415771484375, -3.7800283432006836, -4.439253330230713, -5.564390182495117, -0.0, -0.0, -0.0, 2.0138893127441406], [-15.672313690185547, 0.0, 0.0, 0.0, -16.348722457885742, -14.83055591583252, -13.997118949890137, -12.160237312316895, -11.85023307800293, -11.026396751403809, -9.838310241699219, -9.277048110961914, -9.2286376953125, -8.011487007141113, -8.421964645385742, -7.950764179229736, -7.332418441772461, -7.554417610168457, -7.847750186920166, -7.249174118041992, -7.8259711265563965, -7.00423526763916, -6.894411087036133, -7.761570930480957, -7.636333465576172, -8.535945892333984, -8.758018493652344, -9.334604263305664, -8.719127655029297, -8.410063743591309, -11.53653621673584, -11.514799118041992, -12.178836822509766, -11.38772964477539, -12.99739933013916, -13.92978572845459, -13.583963394165039, -13.760931015014648, -14.771138191223145, -14.36949634552002, -13.67965030670166, -14.963330268859863, -15.554383277893066, -13.907562255859375, -12.15665054321289, -12.66466999053955, -10.888028144836426, -12.776636123657227, -10.567425727844238, -10.024958610534668, -8.921899795532227, -8.42700481414795, -7.807457447052002, -7.057578086853027, -6.6619696617126465, -4.540262222290039, -4.702388763427734, -3.683518886566162, -3.936035394668579, -3.9045121669769287, -3.6548449993133545, -3.718860387802124, -2.8738491535186768, -2.146775245666504, -2.642817974090576, -2.133725166320801, -1.8507366180419922, -2.4613757133483887, -3.215852737426758, -2.926246404647827, -3.4735066890716553, -4.412999629974365, -5.222916603088379, -4.897767543792725, 0.0, 0.0, -0.48661503195762634, 0.5046184659004211, -15.672313690185547, -0.0, -0.0, -0.0, -16.348722457885742, -14.83055591583252, -13.997118949890137, -12.160237312316895, -11.85023307800293, -11.026396751403809, -9.838310241699219, -9.277048110961914, -9.2286376953125, -8.011487007141113, -8.421964645385742, -7.950764179229736, -7.332418441772461, -7.554417610168457, -7.847750186920166, -7.249174118041992, -7.8259711265563965, -7.00423526763916, -6.894411087036133, -7.761570930480957, -7.636333465576172, -8.535945892333984, -8.758018493652344, -9.334604263305664, -8.719127655029297, -8.410063743591309, -11.53653621673584, -11.514799118041992, -12.178836822509766, -11.38772964477539, -12.99739933013916, -13.92978572845459, -13.583963394165039, -13.760931015014648, -14.771138191223145, -14.36949634552002, -13.67965030670166, -14.963330268859863, -15.554383277893066, -13.907562255859375, -12.15665054321289, -12.66466999053955, -10.888028144836426, -12.776636123657227, -10.567425727844238, -10.024958610534668, -8.921899795532227, -8.42700481414795, -7.807457447052002, -7.057578086853027, -6.6619696617126465, -4.540262222290039, -4.702388763427734, -3.683518886566162, -3.936035394668579, -3.9045121669769287, -3.6548449993133545, -3.718860387802124, -2.8738491535186768, -2.146775245666504, -2.642817974090576, -2.133725166320801, -1.8507366180419922, -2.4613757133483887, -3.215852737426758, -2.926246404647827, -3.4735066890716553, -4.412999629974365, -5.222916603088379, -4.897767543792725, -0.0, -0.0, -0.48661503195762634, 0.5046184659004211], [-19.195636749267578, -18.136268615722656, 0.0, 0.0, -16.85453987121582, -15.571237564086914, -14.795283317565918, -12.97016716003418, -11.9345703125, -10.986929893493652, -9.354667663574219, -10.00948429107666, -9.268373489379883, -8.840127944946289, -8.850961685180664, -8.57274341583252, -6.321786880493164, -7.788023948669434, -7.8890156745910645, -7.223971843719482, -7.553475379943848, -8.405823707580566, -7.59215784072876, -8.175091743469238, -7.964846134185791, -8.44670581817627, -9.26648998260498, -9.72107982635498, -9.41020679473877, -10.289320945739746, -11.793121337890625, -10.372148513793945, -15.675775527954102, -13.629215240478516, -14.258916854858398, -14.559651374816895, -15.746312141418457, -15.842035293579102, -15.211090087890625, -16.144697189331055, -15.773096084594727, -16.395166397094727, -14.520918846130371, -14.347875595092773, -16.353954315185547, -14.612756729125977, -14.45773696899414, -12.484691619873047, -12.31204605102539, -10.947543144226074, -8.281590461730957, -8.138606071472168, -9.082306861877441, -6.253446578979492, -6.3087382316589355, -5.626716613769531, -5.064768314361572, -5.130210876464844, -4.538787841796875, -3.907249927520752, -2.951707363128662, -3.2043070793151855, -2.733478307723999, -2.4842071533203125, -2.242448091506958, -2.489501953125, -2.1458399295806885, -1.9474986791610718, -3.31097674369812, -3.6079440116882324, -4.144399642944336, -4.843740463256836, -5.775550365447998, -4.776791572570801, 0.0, 0.0, -0.9123564958572388, 0.9999619126319885, -19.195636749267578, -18.136268615722656, -0.0, -0.0, -16.85453987121582, -15.571237564086914, -14.795283317565918, -12.97016716003418, -11.9345703125, -10.986929893493652, -9.354667663574219, -10.00948429107666, -9.268373489379883, -8.840127944946289, -8.850961685180664, -8.57274341583252, -6.321786880493164, -7.788023948669434, -7.8890156745910645, -7.223971843719482, -7.553475379943848, -8.405823707580566, -7.59215784072876, -8.175091743469238, -7.964846134185791, -8.44670581817627, -9.26648998260498, -9.72107982635498, -9.41020679473877, -10.289320945739746, -11.793121337890625, -10.372148513793945, -15.675775527954102, -13.629215240478516, -14.258916854858398, -14.559651374816895, -15.746312141418457, -15.842035293579102, -15.211090087890625, -16.144697189331055, -15.773096084594727, -16.395166397094727, -14.520918846130371, -14.347875595092773, -16.353954315185547, -14.612756729125977, -14.45773696899414, -12.484691619873047, -12.31204605102539, -10.947543144226074, -8.281590461730957, -8.138606071472168, -9.082306861877441, -6.253446578979492, -6.3087382316589355, -5.626716613769531, -5.064768314361572, -5.130210876464844, -4.538787841796875, -3.907249927520752, -2.951707363128662, -3.2043070793151855, -2.733478307723999, -2.4842071533203125, -2.242448091506958, -2.489501953125, -2.1458399295806885, -1.9474986791610718, -3.31097674369812, -3.6079440116882324, -4.144399642944336, -4.843740463256836, -5.775550365447998, -4.776791572570801, -0.0, -0.0, -0.9123564958572388, 0.9999619126319885], [-18.874101638793945, -20.183269500732422, 0.0, 0.0, -15.586380004882812, -15.426982879638672, -13.699387550354004, -13.493934631347656, -12.4771728515625, -10.352842330932617, -10.363255500793457, -10.038912773132324, -9.431893348693848, -10.066869735717773, -8.54466724395752, -8.172379493713379, -9.528220176696777, -7.147521495819092, -8.800777435302734, -9.047562599182129, -7.745821475982666, -8.22529125213623, -7.295440196990967, -7.953186988830566, -9.315897941589355, -8.471146583557129, -7.954799175262451, -10.658563613891602, -10.957159042358398, -12.437957763671875, -13.021757125854492, -12.874975204467773, -14.034463882446289, -14.947460174560547, -15.820425033569336, -14.673527717590332, -16.118173599243164, -16.884374618530273, -17.568161010742188, -16.768741607666016, -16.91141128540039, -16.792253494262695, -14.42061710357666, -16.034650802612305, -16.119285583496094, -15.00748062133789, -14.141641616821289, -14.324366569519043, -11.120369911193848, -11.680642127990723, -10.468246459960938, -9.799836158752441, -8.979921340942383, -8.184432983398438, -7.083977222442627, -6.40936803817749, -4.989071369171143, -4.906228542327881, -5.07742977142334, -4.400975704193115, -4.184709548950195, -3.769850730895996, -2.7367851734161377, -2.6027400493621826, -1.8504475355148315, -2.4300665855407715, -2.3162002563476562, -1.570143699645996, -4.418068885803223, -4.615634441375732, -4.355218887329102, -5.383278846740723, -5.849715709686279, 0.0, 0.0, 0.0, -0.015954798087477684, 1.8434592485427856, -18.874101638793945, -20.183269500732422, -0.0, -0.0, -15.586380004882812, -15.426982879638672, -13.699387550354004, -13.493934631347656, -12.4771728515625, -10.352842330932617, -10.363255500793457, -10.038912773132324, -9.431893348693848, -10.066869735717773, -8.54466724395752, -8.172379493713379, -9.528220176696777, -7.147521495819092, -8.800777435302734, -9.047562599182129, -7.745821475982666, -8.22529125213623, -7.295440196990967, -7.953186988830566, -9.315897941589355, -8.471146583557129, -7.954799175262451, -10.658563613891602, -10.957159042358398, -12.437957763671875, -13.021757125854492, -12.874975204467773, -14.034463882446289, -14.947460174560547, -15.820425033569336, -14.673527717590332, -16.118173599243164, -16.884374618530273, -17.568161010742188, -16.768741607666016, -16.91141128540039, -16.792253494262695, -14.42061710357666, -16.034650802612305, -16.119285583496094, -15.00748062133789, -14.141641616821289, -14.324366569519043, -11.120369911193848, -11.680642127990723, -10.468246459960938, -9.799836158752441, -8.979921340942383, -8.184432983398438, -7.083977222442627, -6.40936803817749, -4.989071369171143, -4.906228542327881, -5.07742977142334, -4.400975704193115, -4.184709548950195, -3.769850730895996, -2.7367851734161377, -2.6027400493621826, -1.8504475355148315, -2.4300665855407715, -2.3162002563476562, -1.570143699645996, -4.418068885803223, -4.615634441375732, -4.355218887329102, -5.383278846740723, -5.849715709686279, -0.0, -0.0, -0.0, -0.015954798087477684, 1.8434592485427856], [-20.630414962768555, -19.213886260986328, 0.0, 0.0, -16.98851776123047, -15.152132987976074, -14.718520164489746, -13.171826362609863, -11.658462524414062, -11.575737953186035, -9.721479415893555, -10.233657836914062, -9.90867805480957, -8.513794898986816, -9.03225326538086, -8.416369438171387, -8.7168550491333, -8.7510986328125, -8.743520736694336, -7.996514797210693, -8.85651969909668, -8.843470573425293, -9.223515510559082, -6.660045623779297, -9.370269775390625, -10.357102394104004, -10.734529495239258, -10.933775901794434, -11.423261642456055, -13.69532299041748, -13.32081413269043, -15.647336959838867, -13.413653373718262, -15.8203706741333, -16.78492546081543, -16.770048141479492, -16.147485733032227, -16.529197692871094, -18.948978424072266, -18.438491821289062, -18.837509155273438, -17.720136642456055, -17.100048065185547, -19.533199310302734, -19.39632797241211, -16.233627319335938, -16.12206268310547, -15.177191734313965, -13.408129692077637, -13.141651153564453, -12.948004722595215, -12.546287536621094, -9.242338180541992, -9.295343399047852, -7.2116875648498535, -7.799088954925537, -6.05031156539917, -6.560696125030518, -4.086802005767822, -4.123813152313232, -4.442834377288818, -3.670067310333252, -3.4565670490264893, -3.113689661026001, -2.795400381088257, -2.397412061691284, -2.976717233657837, -3.7952165603637695, -3.812302350997925, -3.022913932800293, -4.642084121704102, -6.041708946228027, -3.125915765762329, 0.0, 0.0, 0.0, -0.43295663595199585, 1.6441481113433838, -20.630414962768555, -19.213886260986328, -0.0, -0.0, -16.98851776123047, -15.152132987976074, -14.718520164489746, -13.171826362609863, -11.658462524414062, -11.575737953186035, -9.721479415893555, -10.233657836914062, -9.90867805480957, -8.513794898986816, -9.03225326538086, -8.416369438171387, -8.7168550491333, -8.7510986328125, -8.743520736694336, -7.996514797210693, -8.85651969909668, -8.843470573425293, -9.223515510559082, -6.660045623779297, -9.370269775390625, -10.357102394104004, -10.734529495239258, -10.933775901794434, -11.423261642456055, -13.69532299041748, -13.32081413269043, -15.647336959838867, -13.413653373718262, -15.8203706741333, -16.78492546081543, -16.770048141479492, -16.147485733032227, -16.529197692871094, -18.948978424072266, -18.438491821289062, -18.837509155273438, -17.720136642456055, -17.100048065185547, -19.533199310302734, -19.39632797241211, -16.233627319335938, -16.12206268310547, -15.177191734313965, -13.408129692077637, -13.141651153564453, -12.948004722595215, -12.546287536621094, -9.242338180541992, -9.295343399047852, -7.2116875648498535, -7.799088954925537, -6.05031156539917, -6.560696125030518, -4.086802005767822, -4.123813152313232, -4.442834377288818, -3.670067310333252, -3.4565670490264893, -3.113689661026001, -2.795400381088257, -2.397412061691284, -2.976717233657837, -3.7952165603637695, -3.812302350997925, -3.022913932800293, -4.642084121704102, -6.041708946228027, -3.125915765762329, -0.0, 0.0, -0.0, -0.43295663595199585, 1.6441481113433838], [-20.64767837524414, -19.220840454101562, -18.32193946838379, 0.0, 0.0, -16.955915451049805, -14.327107429504395, -13.591102600097656, -12.552934646606445, -11.24996566772461, -10.623364448547363, -10.485183715820312, -10.199687957763672, -9.942283630371094, -9.1604642868042, -8.786173820495605, -8.462635040283203, -8.323714256286621, -8.767038345336914, -8.478132247924805, -8.863436698913574, -9.306550025939941, -8.171831130981445, -9.37602710723877, -10.008837699890137, -10.190149307250977, -10.857421875, -13.272405624389648, -12.724358558654785, -13.789325714111328, -14.781506538391113, -15.201775550842285, -16.226238250732422, -18.486513137817383, -20.018884658813477, -18.883970260620117, -18.808996200561523, -19.370691299438477, -21.612041473388672, -19.3925838470459, -19.91119384765625, -19.134031295776367, -19.659072875976562, -19.022171020507812, -17.985876083374023, -14.629108428955078, -16.45596694946289, -15.248126029968262, -13.05795955657959, -13.792407989501953, -12.414176940917969, -10.677482604980469, -10.546368598937988, -8.872275352478027, -9.577449798583984, -7.5945305824279785, -6.580461502075195, -6.466247081756592, -4.629920959472656, -4.907076358795166, -4.204428195953369, -4.95863676071167, -4.21942138671875, -3.5097570419311523, -3.7743771076202393, -3.263496160507202, -2.5322678089141846, -3.0647435188293457, -3.560093402862549, -4.706027984619141, -5.781282424926758, -6.0534186363220215, 0.0, 0.0, 0.0, 2.142947196960449, 2.2502975463867188, 2.255338191986084, -20.64767837524414, -19.220840454101562, -18.32193946838379, -0.0, -0.0, -16.955915451049805, -14.327107429504395, -13.591102600097656, -12.552934646606445, -11.24996566772461, -10.623364448547363, -10.485183715820312, -10.199687957763672, -9.942283630371094, -9.1604642868042, -8.786173820495605, -8.462635040283203, -8.323714256286621, -8.767038345336914, -8.478132247924805, -8.863436698913574, -9.306550025939941, -8.171831130981445, -9.37602710723877, -10.008837699890137, -10.190149307250977, -10.857421875, -13.272405624389648, -12.724358558654785, -13.789325714111328, -14.781506538391113, -15.201775550842285, -16.226238250732422, -18.486513137817383, -20.018884658813477, -18.883970260620117, -18.808996200561523, -19.370691299438477, -21.612041473388672, -19.3925838470459, -19.91119384765625, -19.134031295776367, -19.659072875976562, -19.022171020507812, -17.985876083374023, -14.629108428955078, -16.45596694946289, -15.248126029968262, -13.05795955657959, -13.792407989501953, -12.414176940917969, -10.677482604980469, -10.546368598937988, -8.872275352478027, -9.577449798583984, -7.5945305824279785, -6.580461502075195, -6.466247081756592, -4.629920959472656, -4.907076358795166, -4.204428195953369, -4.95863676071167, -4.21942138671875, -3.5097570419311523, -3.7743771076202393, -3.263496160507202, -2.5322678089141846, -3.0647435188293457, -3.560093402862549, -4.706027984619141, -5.781282424926758, -6.0534186363220215, -0.0, -0.0, 0.0, 2.142947196960449, 2.2502975463867188, 2.255338191986084], [-19.130916595458984, -19.46172523498535, -18.374589920043945, 0.0, 0.0, -16.374662399291992, -15.16242790222168, -13.3146333694458, -12.448156356811523, -12.017735481262207, -11.7637939453125, -10.538349151611328, -10.542160034179688, -10.171243667602539, -9.900422096252441, -10.217451095581055, -8.827873229980469, -9.409019470214844, -9.006216049194336, -9.33853816986084, -9.712240219116211, -9.260222434997559, -10.107754707336426, -9.431425094604492, -10.110090255737305, -8.760744094848633, -11.616765975952148, -12.216931343078613, -13.159706115722656, -14.05710506439209, -14.941229820251465, -16.2856388092041, -17.00051498413086, -18.8792667388916, -19.191200256347656, -19.891202926635742, -22.298019409179688, -21.273841857910156, 0.0, -21.303117752075195, -20.798023223876953, -22.12895965576172, -21.571128845214844, -21.13656234741211, -22.774595260620117, -20.273298263549805, -17.573665618896484, -17.62128448486328, -15.700562477111816, -14.91878604888916, -12.361083984375, -12.357845306396484, -11.018708229064941, -8.43041706085205, -9.275044441223145, -7.6034440994262695, -7.806173801422119, -7.4993085861206055, -6.043772220611572, -6.42119026184082, -4.9897780418396, -4.755512714385986, -4.500559329986572, -4.2676520347595215, -3.8282511234283447, -4.359424591064453, -4.589861869812012, -5.0293731689453125, -4.787412166595459, -4.808979034423828, -5.623135089874268, -6.733784198760986, 0.0, 0.0, 3.6959214210510254, 2.677398681640625, -0.5993115901947021, 0.8635666370391846, -19.130916595458984, -19.46172523498535, -18.374589920043945, -0.0, -0.0, -16.374662399291992, -15.16242790222168, -13.3146333694458, -12.448156356811523, -12.017735481262207, -11.7637939453125, -10.538349151611328, -10.542160034179688, -10.171243667602539, -9.900422096252441, -10.217451095581055, -8.827873229980469, -9.409019470214844, -9.006216049194336, -9.33853816986084, -9.712240219116211, -9.260222434997559, -10.107754707336426, -9.431425094604492, -10.110090255737305, -8.760744094848633, -11.616765975952148, -12.216931343078613, -13.159706115722656, -14.05710506439209, -14.941229820251465, -16.2856388092041, -17.00051498413086, -18.8792667388916, -19.191200256347656, -19.891202926635742, -22.298019409179688, -21.273841857910156, -0.0, -21.303117752075195, -20.798023223876953, -22.12895965576172, -21.571128845214844, -21.13656234741211, -22.774595260620117, -20.273298263549805, -17.573665618896484, -17.62128448486328, -15.700562477111816, -14.91878604888916, -12.361083984375, -12.357845306396484, -11.018708229064941, -8.43041706085205, -9.275044441223145, -7.6034440994262695, -7.806173801422119, -7.4993085861206055, -6.043772220611572, -6.42119026184082, -4.9897780418396, -4.755512714385986, -4.500559329986572, -4.2676520347595215, -3.8282511234283447, -4.359424591064453, -4.589861869812012, -5.0293731689453125, -4.787412166595459, -4.808979034423828, -5.623135089874268, -6.733784198760986, -0.0, 0.0, 3.6959214210510254, 2.677398681640625, -0.5993115901947021, 0.8635666370391846], [-20.09156608581543, -20.15874481201172, -18.693828582763672, 0.0, 0.0, 0.0, -15.068870544433594, -13.066312789916992, -12.74712085723877, -11.8349609375, -10.837148666381836, -10.278931617736816, -10.592517852783203, -9.957189559936523, -9.60007095336914, -9.473372459411621, -9.80283260345459, -9.66887092590332, -9.204543113708496, -9.275045394897461, -10.955260276794434, -9.767265319824219, -9.545164108276367, -11.487997055053711, -11.048673629760742, -12.921808242797852, -12.242603302001953, -14.120932579040527, -14.278697967529297, -16.085636138916016, -15.637133598327637, -17.779130935668945, -18.577884674072266, -20.463266372680664, -21.987211227416992, -21.040822982788086, -20.87618637084961, -22.408233642578125, 0.0, -23.3695011138916, -23.112449645996094, -22.69782066345215, -22.596858978271484, -22.87457275390625, -21.123668670654297, -21.488006591796875, -19.06587791442871, -20.428020477294922, -16.881689071655273, -14.047357559204102, -14.540678024291992, -13.845625877380371, -11.884610176086426, -11.146190643310547, -9.454564094543457, -7.136070251464844, -7.354160308837891, -7.7947211265563965, -6.819536209106445, -5.458791255950928, -5.9803338050842285, -5.673859596252441, -5.070374011993408, -4.815781593322754, -4.769844055175781, -5.436611175537109, -4.978993892669678, -5.679266929626465, -5.500259876251221, -1.3659976720809937, -2.063143491744995, 0.0, 0.0, 0.0, 0.28554263710975647, 2.29133677482605, 2.7048842906951904, 1.9812899827957153, -20.09156608581543, -20.15874481201172, -18.693828582763672, -0.0, -0.0, -0.0, -15.068870544433594, -13.066312789916992, -12.74712085723877, -11.8349609375, -10.837148666381836, -10.278931617736816, -10.592517852783203, -9.957189559936523, -9.60007095336914, -9.473372459411621, -9.80283260345459, -9.66887092590332, -9.204543113708496, -9.275045394897461, -10.955260276794434, -9.767265319824219, -9.545164108276367, -11.487997055053711, -11.048673629760742, -12.921808242797852, -12.242603302001953, -14.120932579040527, -14.278697967529297, -16.085636138916016, -15.637133598327637, -17.779130935668945, -18.577884674072266, -20.463266372680664, -21.987211227416992, -21.040822982788086, -20.87618637084961, -22.408233642578125, -0.0, -23.3695011138916, -23.112449645996094, -22.69782066345215, -22.596858978271484, -22.87457275390625, -21.123668670654297, -21.488006591796875, -19.06587791442871, -20.428020477294922, -16.881689071655273, -14.047357559204102, -14.540678024291992, -13.845625877380371, -11.884610176086426, -11.146190643310547, -9.454564094543457, -7.136070251464844, -7.354160308837891, -7.7947211265563965, -6.819536209106445, -5.458791255950928, -5.9803338050842285, -5.673859596252441, -5.070374011993408, -4.815781593322754, -4.769844055175781, -5.436611175537109, -4.978993892669678, -5.679266929626465, -5.500259876251221, -1.3659976720809937, -2.063143491744995, -0.0, -0.0, 0.0, 0.28554263710975647, 2.29133677482605, 2.7048842906951904, 1.9812899827957153], [-20.126007080078125, -19.246946334838867, -18.140945434570312, -17.70380210876465, 0.0, 0.0, -13.935033798217773, -12.540665626525879, -12.614480972290039, -11.792074203491211, -10.760346412658691, -10.683788299560547, -10.511676788330078, -10.176609992980957, -10.439398765563965, -10.526918411254883, -9.11013126373291, -9.139717102050781, -10.118803977966309, -10.55072021484375, -10.628535270690918, -10.95000171661377, -10.875531196594238, -11.767573356628418, -12.323507308959961, -12.091836929321289, -12.64981460571289, -14.120287895202637, -16.353097915649414, -16.445274353027344, -18.148944854736328, -19.012107849121094, -20.126358032226562, -20.84711265563965, -21.532697677612305, -22.6347599029541, -23.36390495300293, -25.007976531982422, -24.46795654296875, -24.9547119140625, -25.353939056396484, -23.87380027770996, -24.0693359375, -22.14201545715332, -23.50153350830078, -21.15949249267578, -19.403053283691406, -20.48345375061035, -17.21552848815918, -16.42626190185547, -16.116703033447266, -14.380574226379395, -12.351282119750977, -10.299005508422852, -12.534347534179688, -10.210017204284668, -8.691518783569336, -8.831804275512695, -7.890290260314941, -5.803595066070557, -5.9735188484191895, -5.294347763061523, -4.438618183135986, -3.017939567565918, -4.913300037384033, -5.694509983062744, -5.499223709106445, 0.0, -5.561966419219971, -2.998629331588745, 0.0, 0.0, 0.0, 3.689924478530884, 3.726698398590088, 3.051328659057617, 2.071915626525879, 2.1504695415496826, -20.126007080078125, -19.246946334838867, -18.140945434570312, -17.70380210876465, -0.0, -0.0, -13.935033798217773, -12.540665626525879, -12.614480972290039, -11.792074203491211, -10.760346412658691, -10.683788299560547, -10.511676788330078, -10.176609992980957, -10.439398765563965, -10.526918411254883, -9.11013126373291, -9.139717102050781, -10.118803977966309, -10.55072021484375, -10.628535270690918, -10.95000171661377, -10.875531196594238, -11.767573356628418, -12.323507308959961, -12.091836929321289, -12.64981460571289, -14.120287895202637, -16.353097915649414, -16.445274353027344, -18.148944854736328, -19.012107849121094, -20.126358032226562, -20.84711265563965, -21.532697677612305, -22.6347599029541, -23.36390495300293, -25.007976531982422, -24.46795654296875, -24.9547119140625, -25.353939056396484, -23.87380027770996, -24.0693359375, -22.14201545715332, -23.50153350830078, -21.15949249267578, -19.403053283691406, -20.48345375061035, -17.21552848815918, -16.42626190185547, -16.116703033447266, -14.380574226379395, -12.351282119750977, -10.299005508422852, -12.534347534179688, -10.210017204284668, -8.691518783569336, -8.831804275512695, -7.890290260314941, -5.803595066070557, -5.9735188484191895, -5.294347763061523, -4.438618183135986, -3.017939567565918, -4.913300037384033, -5.694509983062744, -5.499223709106445, -0.0, -5.561966419219971, -2.998629331588745, -0.0, -0.0, 0.0, 3.689924478530884, 3.726698398590088, 3.051328659057617, 2.071915626525879, 2.1504695415496826], [-19.969890594482422, -18.580522537231445, -17.563392639160156, -16.51424789428711, -14.0726900100708, 0.0, 0.0, -12.352482795715332, -12.050978660583496, -12.147188186645508, -11.433995246887207, -10.584416389465332, -10.022295951843262, -10.340702056884766, -10.482088088989258, -10.12973403930664, -10.416537284851074, -9.668233871459961, -10.906449317932129, -10.075285911560059, -10.620537757873535, -10.683445930480957, -11.028584480285645, -11.455333709716797, -12.747472763061523, -11.782827377319336, -13.805415153503418, -15.069748878479004, -15.492793083190918, -17.394081115722656, -19.346460342407227, -20.232175827026367, -21.448680877685547, -23.095518112182617, -23.27954864501953, -24.18304443359375, -28.273319244384766, -28.382408142089844, -26.539724349975586, -26.848230361938477, -27.045602798461914, -26.91769027709961, -25.31903076171875, -24.214906692504883, -24.609622955322266, -22.968793869018555, -22.77297019958496, -20.54672622680664, -20.813247680664062, -17.840761184692383, -17.151460647583008, -15.779853820800781, -12.652016639709473, -12.923347473144531, -10.106072425842285, -10.06661319732666, -8.775760650634766, -8.375709533691406, -8.09618091583252, -7.723829746246338, -6.960941314697266, -6.494787216186523, -5.679599285125732, -4.578564643859863, -5.259281635284424, -5.427709102630615, -6.3390045166015625, -1.3077175617218018, 0.0, 0.11076395958662033, 0.0, 0.0, 4.16164493560791, 4.242539405822754, 2.7103958129882812, 2.938642978668213, 2.0385584831237793, 2.6785943508148193, -19.969890594482422, -18.580522537231445, -17.563392639160156, -16.51424789428711, -14.0726900100708, -0.0, -0.0, -12.352482795715332, -12.050978660583496, -12.147188186645508, -11.433995246887207, -10.584416389465332, -10.022295951843262, -10.340702056884766, -10.482088088989258, -10.12973403930664, -10.416537284851074, -9.668233871459961, -10.906449317932129, -10.075285911560059, -10.620537757873535, -10.683445930480957, -11.028584480285645, -11.455333709716797, -12.747472763061523, -11.782827377319336, -13.805415153503418, -15.069748878479004, -15.492793083190918, -17.394081115722656, -19.346460342407227, -20.232175827026367, -21.448680877685547, -23.095518112182617, -23.27954864501953, -24.18304443359375, -28.273319244384766, -28.382408142089844, -26.539724349975586, -26.848230361938477, -27.045602798461914, -26.91769027709961, -25.31903076171875, -24.214906692504883, -24.609622955322266, -22.968793869018555, -22.77297019958496, -20.54672622680664, -20.813247680664062, -17.840761184692383, -17.151460647583008, -15.779853820800781, -12.652016639709473, -12.923347473144531, -10.106072425842285, -10.06661319732666, -8.775760650634766, -8.375709533691406, -8.09618091583252, -7.723829746246338, -6.960941314697266, -6.494787216186523, -5.679599285125732, -4.578564643859863, -5.259281635284424, -5.427709102630615, -6.3390045166015625, -1.3077175617218018, -0.0, 0.11076395958662033, 0.0, 0.0, 4.16164493560791, 4.242539405822754, 2.7103958129882812, 2.938642978668213, 2.0385584831237793, 2.6785943508148193], [-19.07192611694336, -19.121923446655273, -17.609710693359375, -16.447452545166016, -14.30757999420166, -12.896997451782227, 0.0, 0.0, -11.899380683898926, -12.11600112915039, -11.995525360107422, -11.377030372619629, -10.109107971191406, -9.6641206741333, -10.147605895996094, -10.62083625793457, -10.326446533203125, -10.531197547912598, -12.468338966369629, -11.702072143554688, -10.772825241088867, -12.05704116821289, -12.19096851348877, -12.635759353637695, -12.068887710571289, -13.367353439331055, -15.625748634338379, -14.988738059997559, -16.920421600341797, -16.856353759765625, -19.069143295288086, -21.816465377807617, -21.39410400390625, -23.941850662231445, -25.61860466003418, -25.947357177734375, -29.53412628173828, -25.449825286865234, -25.906591415405273, -27.573678970336914, -28.538677215576172, -27.865495681762695, -28.023954391479492, -26.493467330932617, -27.0506591796875, -25.205322265625, -24.003402709960938, -21.501949310302734, -21.113819122314453, -19.00403594970703, -16.31667137145996, -17.248952865600586, -16.800861358642578, -13.595113754272461, -12.60782527923584, -8.711055755615234, -8.423069953918457, -9.617012977600098, -8.008101463317871, -7.685545921325684, -8.056392669677734, -7.445653438568115, -6.283649444580078, -3.426457166671753, -5.305081367492676, -2.8254568576812744, -1.6245583295822144, -2.268813133239746, 0.0, 0.0, 0.0, 0.0, 4.608530044555664, 4.652547359466553, 3.8344459533691406, 3.4817700386047363, 2.8229384422302246, 2.1501364707946777, -19.07192611694336, -19.121923446655273, -17.609710693359375, -16.447452545166016, -14.30757999420166, -12.896997451782227, -0.0, -0.0, -11.899380683898926, -12.11600112915039, -11.995525360107422, -11.377030372619629, -10.109107971191406, -9.6641206741333, -10.147605895996094, -10.62083625793457, -10.326446533203125, -10.531197547912598, -12.468338966369629, -11.702072143554688, -10.772825241088867, -12.05704116821289, -12.19096851348877, -12.635759353637695, -12.068887710571289, -13.367353439331055, -15.625748634338379, -14.988738059997559, -16.920421600341797, -16.856353759765625, -19.069143295288086, -21.816465377807617, -21.39410400390625, -23.941850662231445, -25.61860466003418, -25.947357177734375, -29.53412628173828, -25.449825286865234, -25.906591415405273, -27.573678970336914, -28.538677215576172, -27.865495681762695, -28.023954391479492, -26.493467330932617, -27.0506591796875, -25.205322265625, -24.003402709960938, -21.501949310302734, -21.113819122314453, -19.00403594970703, -16.31667137145996, -17.248952865600586, -16.800861358642578, -13.595113754272461, -12.60782527923584, -8.711055755615234, -8.423069953918457, -9.617012977600098, -8.008101463317871, -7.685545921325684, -8.056392669677734, -7.445653438568115, -6.283649444580078, -3.426457166671753, -5.305081367492676, -2.8254568576812744, -1.6245583295822144, -2.268813133239746, -0.0, 0.0, 0.0, 0.0, 4.608530044555664, 4.652547359466553, 3.8344459533691406, 3.4817700386047363, 2.8229384422302246, 2.1501364707946777], [-20.46401596069336, -16.9102783203125, -17.957073211669922, -16.828886032104492, -15.641685485839844, -14.607196807861328, -13.150918006896973, 0.0, 0.0, -11.527396202087402, -12.104399681091309, -12.037413597106934, -10.402920722961426, -9.644638061523438, -10.59211254119873, -10.829070091247559, -10.446979522705078, -11.320605278015137, -12.674490928649902, -12.049118995666504, -11.787760734558105, -12.997638702392578, -13.309069633483887, -12.943496704101562, -14.019978523254395, -14.77230453491211, -15.244467735290527, -15.521271705627441, -16.821016311645508, -21.22266387939453, -21.380210876464844, -22.76152992248535, -24.10907745361328, -25.68429946899414, -26.242366790771484, -27.774944305419922, -28.90888023376465, -29.036418914794922, -29.838621139526367, -30.656761169433594, -30.28390884399414, -28.790014266967773, -28.631816864013672, -29.065162658691406, -25.218116760253906, -27.25306510925293, -24.373268127441406, -23.563650131225586, -23.01581573486328, -20.506574630737305, -18.256423950195312, -17.4404354095459, -15.955055236816406, -14.654694557189941, -12.240013122558594, -10.928253173828125, -9.111523628234863, -10.833144187927246, -9.015453338623047, -8.553122520446777, -7.664981842041016, -6.096667766571045, -6.0488996505737305, -4.319110870361328, -2.346621513366699, -2.774045467376709, -2.5424108505249023, -2.0471200942993164, -4.00614070892334, 0.0, 0.0, 6.008662700653076, 4.458658695220947, 3.2588117122650146, 2.2837181091308594, 3.4137141704559326, 1.7964032888412476, 0.0, -20.46401596069336, -16.9102783203125, -17.957073211669922, -16.828886032104492, -15.641685485839844, -14.607196807861328, -13.150918006896973, -0.0, -0.0, -11.527396202087402, -12.104399681091309, -12.037413597106934, -10.402920722961426, -9.644638061523438, -10.59211254119873, -10.829070091247559, -10.446979522705078, -11.320605278015137, -12.674490928649902, -12.049118995666504, -11.787760734558105, -12.997638702392578, -13.309069633483887, -12.943496704101562, -14.019978523254395, -14.77230453491211, -15.244467735290527, -15.521271705627441, -17.328458786010742, -20.280118942260742, -21.190982818603516, -22.693065643310547, -24.024295806884766, -25.524478912353516, -26.32109832763672, -27.6958065032959, -28.736270904541016, -29.108097076416016, -29.809200286865234, -30.369678497314453, -30.071983337402344, -28.989482879638672, -28.57894515991211, -28.607446670532227, -25.772666931152344, -26.755136489868164, -24.49509620666504, -23.560728073120117, -22.641887664794922, -20.51312828063965, -18.517423629760742, -17.393266677856445, -15.871247291564941, -14.46922779083252, -12.240013122558594, -10.928253173828125, -9.111523628234863, -10.833144187927246, -9.015453338623047, -8.553122520446777, -7.664981842041016, -6.096667766571045, -6.0488996505737305, -4.319110870361328, -2.346621513366699, -2.774045467376709, -2.5424108505249023, -2.0471200942993164, -4.00614070892334, -0.0, 0.0, 6.008662700653076, 4.458658695220947, 3.2588117122650146, 2.2837181091308594, 3.4137141704559326, 1.7964032888412476, 0.0], [-16.92046356201172, -17.99977684020996, -17.632484436035156, -16.294023513793945, -15.156189918518066, -14.12911319732666, -10.819622993469238, -9.883655548095703, 0.0, 0.0, -12.867430686950684, -11.363168716430664, -8.306769371032715, -9.183165550231934, -10.866118431091309, -10.867912292480469, -11.615252494812012, -11.42359447479248, -12.093415260314941, -12.570770263671875, -14.887392044067383, -13.666009902954102, -13.873924255371094, -12.63149356842041, -15.29265308380127, -15.551346778869629, -15.991144180297852, -17.205509185791016, -17.776277542114258, -20.239709854125977, -21.776208877563477, -23.443519592285156, -25.2620849609375, -26.58340835571289, -26.757431030273438, -29.943016052246094, -30.411422729492188, -30.906217575073242, -32.20459747314453, -33.10834884643555, -31.586713790893555, -31.645896911621094, -30.030858993530273, -29.542634963989258, -28.034751892089844, -26.9593563079834, -26.223485946655273, -24.628870010375977, -25.136533737182617, -21.516307830810547, -20.728740692138672, -18.624773025512695, -15.777284622192383, -14.976913452148438, -13.40107536315918, -14.598494529724121, -11.107973098754883, -10.939504623413086, -9.734392166137695, -9.063948631286621, -8.859457969665527, -6.97113037109375, -4.740915775299072, -5.562834739685059, -4.562201023101807, -4.352599143981934, -2.3118643760681152, -4.237547397613525, -5.1704511642456055, -5.599835395812988, 0.0, 5.171699523925781, 3.6242265701293945, 3.5705249309539795, 2.7342729568481445, 2.6121861934661865, 0.2429952621459961, 0.0, -16.92046356201172, -17.99977684020996, -17.632484436035156, -16.294023513793945, -15.156189918518066, -14.12911319732666, -10.819622993469238, -9.883655548095703, -0.0, -0.0, -12.867430686950684, -11.363168716430664, -8.306769371032715, -9.183165550231934, -10.866118431091309, -10.867912292480469, -11.615252494812012, -11.42359447479248, -12.093415260314941, -12.570770263671875, -14.887392044067383, -13.666009902954102, -13.873924255371094, -12.63149356842041, -15.29265308380127, -15.551346778869629, -15.991144180297852, -17.205509185791016, -18.14208221435547, -20.177276611328125, -21.7811222076416, -23.37522315979004, -24.93852996826172, -26.413917541503906, -27.674047470092773, -28.929229736328125, -29.980831146240234, -30.68975257873535, -31.228410720825195, -31.47698974609375, -31.24746322631836, -30.642000198364258, -30.028133392333984, -29.296594619750977, -28.021135330200195, -27.28202247619629, -25.976634979248047, -24.694320678710938, -23.331172943115234, -21.620241165161133, -19.900100708007812, -18.31157112121582, -16.67374610900879, -15.039891242980957, -13.40107536315918, -14.598494529724121, -11.107973098754883, -10.939504623413086, -9.734392166137695, -9.063948631286621, -8.859457969665527, -6.97113037109375, -4.740915775299072, -5.562834739685059, -4.562201023101807, -4.352599143981934, -2.3118643760681152, -4.237547397613525, -5.1704511642456055, -5.599835395812988, 0.0, 5.171699523925781, 3.6242265701293945, 3.5705249309539795, 2.7342729568481445, 2.6121861934661865, 0.2429952621459961, 0.0], [0.0, -19.63932228088379, -17.867420196533203, -16.168195724487305, -15.156978607177734, -14.386435508728027, -12.836663246154785, -12.940117835998535, -12.175005912780762, 0.0, 0.0, -8.609049797058105, -9.170092582702637, -10.4298095703125, -11.306934356689453, -10.950078010559082, -11.632330894470215, -14.804252624511719, -14.220340728759766, -15.004514694213867, -14.349935531616211, -13.94611930847168, -15.035529136657715, -18.300626754760742, -15.202656745910645, -18.748794555664062, -16.722126007080078, -18.14691734313965, -19.078706741333008, -20.280799865722656, -21.727094650268555, -23.199106216430664, -25.831941604614258, -27.07774543762207, -29.43102264404297, -31.386295318603516, -31.571998596191406, -32.64358901977539, -34.282711029052734, -33.687095642089844, -29.53630828857422, -31.99331283569336, -29.31975555419922, -30.88355255126953, -28.047298431396484, -25.3131103515625, -27.998210906982422, -28.398365020751953, -23.40467071533203, -22.383419036865234, -21.4670467376709, -21.05155372619629, -17.403072357177734, -15.392782211303711, -14.93397331237793, -14.875460624694824, -11.633893013000488, -11.897181510925293, -10.304889678955078, -9.563359260559082, -8.002696990966797, -9.916101455688477, -7.229946613311768, -4.909293174743652, -3.8915674686431885, -4.873810291290283, -5.591121673583984, -5.126520156860352, -6.100582122802734, 0.0, 0.0, 3.8383443355560303, 2.0379908084869385, 3.1767125129699707, 4.196358680725098, 1.791029453277588, 0.0, 0.0, -0.0, -19.63932228088379, -17.867420196533203, -16.168195724487305, -15.156978607177734, -14.386435508728027, -12.836663246154785, -12.940117835998535, -12.175005912780762, -0.0, -0.0, -8.609049797058105, -9.170092582702637, -10.4298095703125, -11.306934356689453, -10.950078010559082, -11.632330894470215, -14.804252624511719, -14.220340728759766, -15.004514694213867, -14.349935531616211, -13.94611930847168, -15.035529136657715, -18.300626754760742, -15.202656745910645, -18.748794555664062, -16.722126007080078, -18.14691734313965, -19.10283088684082, -20.588008880615234, -22.233219146728516, -23.96030616760254, -25.673044204711914, -27.269439697265625, -28.731943130493164, -30.035404205322266, -31.139223098754883, -31.96297836303711, -32.45283126831055, -32.597328186035156, -32.4130973815918, -31.95088005065918, -31.260425567626953, -30.400054931640625, -29.43619728088379, -28.340499877929688, -27.1319637298584, -25.747203826904297, -24.235567092895508, -22.633750915527344, -20.977304458618164, -19.235231399536133, -17.457639694213867, -15.529012680053711, -14.93397331237793, -14.875460624694824, -11.633893013000488, -11.897181510925293, -10.304889678955078, -9.563359260559082, -8.002696990966797, -9.916101455688477, -7.229946613311768, -4.909293174743652, -3.8915674686431885, -4.873810291290283, -5.591121673583984, -5.126520156860352, -6.100582122802734, -0.0, 0.0, 3.8383443355560303, 2.0379908084869385, 3.1767125129699707, 4.196358680725098, 1.791029453277588, 0.0, 0.0], [0.0, -21.738300323486328, -17.823944091796875, -16.57179832458496, -14.93117904663086, -14.667072296142578, -14.137846946716309, -13.28184700012207, -12.989086151123047, -15.679218292236328, 0.0, 0.0, -9.932045936584473, -9.210126876831055, -10.95727252960205, -10.83796501159668, -10.140914916992188, -9.357222557067871, -14.298944473266602, -15.535473823547363, -15.988356590270996, -15.296799659729004, -15.264090538024902, -17.55801773071289, -16.01247215270996, -16.944883346557617, -18.704458236694336, -18.24769401550293, -19.726449966430664, -21.34836196899414, -21.35116958618164, -25.180313110351562, -27.431795120239258, -29.07210350036621, -31.06631088256836, -30.227985382080078, -28.403684616088867, -28.31549835205078, -33.896881103515625, -31.50271224975586, -34.3819694519043, -33.64522933959961, -33.84912109375, -33.23025894165039, -31.12917137145996, -30.413551330566406, -28.989601135253906, -27.91006088256836, -26.928699493408203, -23.766590118408203, -22.262195587158203, -19.374393463134766, -19.540142059326172, -16.887451171875, -15.32638168334961, -14.464539527893066, -14.220067024230957, -12.917287826538086, -11.07432746887207, -9.88499641418457, -8.456687927246094, -10.467236518859863, -8.651910781860352, -7.094825744628906, -6.695592880249023, -7.001639366149902, -8.406586647033691, -5.002559185028076, 0.0, 0.0, 3.75866436958313, 3.4929087162017822, 3.327587127685547, 3.5716748237609863, 1.801626205444336, 0.30029699206352234, 0.0, 5.684253215789795, -0.0, -21.738300323486328, -17.823944091796875, -16.57179832458496, -14.93117904663086, -14.667072296142578, -14.137846946716309, -13.28184700012207, -12.989086151123047, -15.679218292236328, -0.0, -0.0, -9.932045936584473, -9.210126876831055, -10.95727252960205, -10.83796501159668, -10.140914916992188, -9.357222557067871, -14.298944473266602, -15.535473823547363, -15.988356590270996, -15.296799659729004, -15.264090538024902, -17.55801773071289, -16.01247215270996, -16.944883346557617, -18.704458236694336, -18.24769401550293, -19.745485305786133, -21.17448616027832, -22.787002563476562, -24.556438446044922, -26.367246627807617, -28.073041915893555, -29.634164810180664, -31.010761260986328, -32.16262435913086, -33.02294158935547, -33.52284240722656, -33.67021942138672, -33.495941162109375, -33.05573272705078, -32.38932418823242, -31.55357551574707, -30.599023818969727, -29.48041534423828, -28.206417083740234, -26.76869773864746, -25.231103897094727, -23.60375213623047, -21.903060913085938, -20.136737823486328, -18.403356552124023, -16.788164138793945, -15.32638168334961, -14.464539527893066, -14.220067024230957, -12.917287826538086, -11.07432746887207, -9.88499641418457, -8.456687927246094, -10.467236518859863, -8.651910781860352, -7.094825744628906, -6.695592880249023, -7.001639366149902, -8.406586647033691, -5.002559185028076, -0.0, 0.0, 3.75866436958313, 3.4929087162017822, 3.327587127685547, 3.5716748237609863, 1.801626205444336, 0.30029699206352234, 0.0, 5.684253215789795], [0.0, 0.0, -14.773884773254395, -16.313791275024414, -14.773695945739746, -13.735649108886719, -12.267647743225098, -14.1798734664917, -13.389811515808105, -12.068519592285156, -11.881509780883789, 0.0, 0.0, -6.823887348175049, 0.0, 0.0, 0.0, 0.0, 0.0, -16.460533142089844, -17.284408569335938, -17.013442993164062, -18.47938346862793, -17.408611297607422, -17.783370971679688, -17.82823371887207, -18.240705490112305, -20.57080078125, -20.837005615234375, -21.707590103149414, -24.019411087036133, -24.89317512512207, -27.81365966796875, -29.28465461730957, -25.736072540283203, -27.638288497924805, -28.342239379882812, -29.82871437072754, -28.645769119262695, -30.645732879638672, -34.96399688720703, -31.02420425415039, -33.377891540527344, -34.315704345703125, -32.378013610839844, -31.833139419555664, -30.014720916748047, -29.056846618652344, -23.6309757232666, -24.912879943847656, -22.321163177490234, -22.0218505859375, -18.528112411499023, -17.481000900268555, -15.683380126953125, -12.01750373840332, -11.635581016540527, -13.368270874023438, -8.659167289733887, 0.0, -8.101696968078613, -8.405266761779785, -6.901888847351074, -7.870657920837402, -8.08091926574707, -8.753918647766113, -4.966770648956299, 0.0, 0.0, 0.0, 2.4021084308624268, 3.397296905517578, 3.273578643798828, 0.12284846603870392, 0.5757129192352295, 0.0, 0.0, 0.0, -0.0, -0.0, -14.773884773254395, -16.313791275024414, -14.773695945739746, -13.735649108886719, -12.267647743225098, -14.1798734664917, -13.389811515808105, -12.068519592285156, -11.881509780883789, -0.0, -0.0, -6.823887348175049, -0.0, -0.0, -0.0, -0.0, -0.0, -16.460533142089844, -17.284408569335938, -17.013442993164062, -18.47938346862793, -17.408611297607422, -17.783370971679688, -17.82823371887207, -18.240705490112305, -20.57080078125, -20.663549423217773, -21.82933235168457, -23.374116897583008, -25.132497787475586, -27.001686096191406, -28.81409454345703, -30.44989585876465, -31.87131118774414, -33.04820251464844, -33.90526580810547, -34.41035842895508, -34.57357406616211, -34.41712188720703, -33.997074127197266, -33.38235855102539, -32.59854507446289, -31.65970230102539, -30.5606632232666, -29.246559143066406, -27.76024055480957, -26.18193244934082, -24.532493591308594, -22.816579818725586, -21.07682991027832, -19.2899112701416, -17.474885940551758, -15.683380126953125, -12.01750373840332, -11.635581016540527, -13.368270874023438, -8.659167289733887, -0.0, -8.101696968078613, -8.405266761779785, -6.901888847351074, -7.870657920837402, -8.08091926574707, -8.753918647766113, -4.966770648956299, -0.0, -0.0, 0.0, 2.4021084308624268, 3.397296905517578, 3.273578643798828, 0.12284846603870392, 0.5757129192352295, 0.0, 0.0, 0.0], [-20.591270446777344, -21.36842918395996, 0.0, -17.107202529907227, -16.32952308654785, -15.168458938598633, -13.926712989807129, -13.296428680419922, -11.405455589294434, -12.248101234436035, -11.850397109985352, -11.754738807678223, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.883081436157227, 0.0, -17.590913772583008, -17.16835594177246, -16.74102020263672, -18.468223571777344, -18.594017028808594, -18.73216438293457, -21.15369415283203, -20.637033462524414, -21.18863868713379, -22.900972366333008, -24.517675399780273, -26.97368812561035, -28.297012329101562, -30.810670852661133, -26.829343795776367, -28.64642906188965, -29.140342712402344, -28.749101638793945, -30.57581901550293, -30.23697853088379, -30.60694694519043, -30.92831039428711, -34.24298858642578, -30.44358253479004, -27.855091094970703, -27.699981689453125, -30.656938552856445, -31.35373878479004, -26.62039566040039, -25.624950408935547, -25.400300979614258, -22.044904708862305, -19.883255004882812, -18.599262237548828, -14.860739707946777, -13.263311386108398, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.20296049118042, -7.746506690979004, -11.080282211303711, -7.431976318359375, 0.0, 0.0, 0.0, 2.602050542831421, 1.581741213798523, 1.4450279474258423, 2.7762415409088135, 0.6190668940544128, 0.5696724653244019, 0.0, 0.0, 0.0, -20.591270446777344, -21.36842918395996, -0.0, -17.107202529907227, -16.32952308654785, -15.168458938598633, -13.926712989807129, -13.296428680419922, -11.405455589294434, -12.248101234436035, -11.850397109985352, -11.754738807678223, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.883081436157227, -0.0, -17.590913772583008, -17.16835594177246, -16.74102020263672, -18.468223571777344, -18.594017028808594, -18.73216438293457, -21.15369415283203, -20.637033462524414, -21.139123916625977, -22.36130714416504, -23.905990600585938, -25.685428619384766, -27.60198402404785, -29.474363327026367, -31.155824661254883, -32.594627380371094, -33.75049591064453, -34.56380844116211, -35.04237747192383, -35.20871353149414, -35.09492111206055, -34.73180389404297, -34.173126220703125, -33.44925308227539, -32.56505584716797, -31.50433921813965, -30.186784744262695, -28.666818618774414, -27.048362731933594, -25.377164840698242, -23.6738224029541, -21.924110412597656, -20.197214126586914, -18.503629684448242, -14.860739707946777, -13.263311386108398, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.20296049118042, -7.746506690979004, -11.080282211303711, -7.431976318359375, -0.0, -0.0, 0.0, 2.602050542831421, 1.581741213798523, 1.4450279474258423, 2.7762415409088135, 0.6190668940544128, 0.5696724653244019, 0.0, 0.0, 0.0], [-19.99032211303711, -24.026885986328125, 0.0, 0.0, -17.425418853759766, -16.282487869262695, -13.226511001586914, -10.485050201416016, -11.659530639648438, -13.222638130187988, -11.636492729187012, -11.429473876953125, -11.16550350189209, 0.0, 0.0, -18.3101806640625, 0.0, -15.98110294342041, -16.860515594482422, 0.0, 0.0, -20.355344772338867, -18.688961029052734, -18.929729461669922, -19.526960372924805, -21.279172897338867, -21.182220458984375, -20.859121322631836, -21.05295753479004, -22.939924240112305, -24.387483596801758, -27.353580474853516, -24.2865047454834, -26.51220703125, -26.98305320739746, -29.79865264892578, -30.102785110473633, -32.57906723022461, -30.365375518798828, -30.270605087280273, -29.60770606994629, -32.7823371887207, -35.10686111450195, -33.72373580932617, -30.820783615112305, -29.293447494506836, -27.02428436279297, -25.59054183959961, -23.961135864257812, -28.26959228515625, -24.159669876098633, -23.270090103149414, -22.642908096313477, -19.80996322631836, -14.5509614944458, -15.46852970123291, -15.184164047241211, -14.54316520690918, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.383593559265137, -7.038001537322998, -8.880348205566406, 0.0, 0.0, 0.737568199634552, 1.9743733406066895, 1.485196828842163, 1.9654853343963623, 0.9034570455551147, 0.0, 0.0, 0.0, 0.0, -19.99032211303711, -24.026885986328125, -0.0, -0.0, -17.425418853759766, -16.282487869262695, -13.226511001586914, -10.485050201416016, -11.659530639648438, -13.222638130187988, -11.636492729187012, -11.429473876953125, -11.16550350189209, -0.0, -0.0, -18.3101806640625, -0.0, -15.98110294342041, -16.860515594482422, -0.0, -0.0, -20.355344772338867, -18.688961029052734, -18.929729461669922, -19.526960372924805, -21.279172897338867, -21.182220458984375, -20.859121322631836, -21.17088508605957, -22.689538955688477, -24.297779083251953, -26.15352439880371, -28.132158279418945, -30.030776977539062, -31.720901489257812, -33.159278869628906, -34.28788375854492, -35.03953170776367, -35.457759857177734, -35.61247253417969, -35.52740478515625, -35.222721099853516, -34.7326545715332, -34.0945930480957, -33.30458068847656, -32.317420959472656, -31.02362632751465, -29.471656799316406, -27.81435775756836, -26.10144805908203, -24.384035110473633, -22.703369140625, -21.062822341918945, -19.527793884277344, -14.5509614944458, -15.46852970123291, -15.184164047241211, -14.54316520690918, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.383593559265137, -7.038001537322998, -8.880348205566406, -0.0, 0.0, 0.737568199634552, 1.9743733406066895, 1.485196828842163, 1.9654853343963623, 0.9034570455551147, 0.0, 0.0, -0.0, -0.0], [-20.437801361083984, 0.0, -17.782825469970703, 0.0, -18.0516414642334, -16.1960506439209, -13.565570831298828, -14.93228530883789, -14.051154136657715, -13.246207237243652, -13.399450302124023, -11.72553539276123, -12.527541160583496, 0.0, 0.0, -15.557272911071777, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.49823570251465, 0.0, -21.74215316772461, -23.84393310546875, -23.23126792907715, -23.136110305786133, -22.929426193237305, -22.6276912689209, -24.22163200378418, -24.889944076538086, -24.711437225341797, -26.5086669921875, -29.49730110168457, -29.703990936279297, -30.0843448638916, -32.558021545410156, -35.262229919433594, -33.35317611694336, -30.698171615600586, -31.391714096069336, -30.89950180053711, -30.873638153076172, -28.654510498046875, -28.2003231048584, -28.294246673583984, -28.6782283782959, -25.722166061401367, -29.543231964111328, -26.536020278930664, -25.752286911010742, -23.50769805908203, -20.525667190551758, -17.862415313720703, -16.31279182434082, -14.981399536132812, 0.0, 0.0, -15.80422306060791, 0.0, -11.448135375976562, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.8828831911087036, 1.4279934167861938, 1.2774300575256348, 0.0933670699596405, -1.2750427722930908, 0.0, 0.0, 0.0, 0.0, -20.437801361083984, -0.0, -17.782825469970703, -0.0, -18.0516414642334, -16.1960506439209, -13.565570831298828, -14.93228530883789, -14.051154136657715, -13.246207237243652, -13.399450302124023, -11.72553539276123, -12.527541160583496, -0.0, -0.0, -15.557272911071777, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.49823570251465, -0.0, -21.74215316772461, -23.84393310546875, -23.23126792907715, -23.136110305786133, -22.40073013305664, -23.013465881347656, -24.558578491210938, -26.577251434326172, -28.61933135986328, -30.502532958984375, -32.175270080566406, -33.600372314453125, -34.6798210144043, -35.37178039550781, -35.7282600402832, -35.84413528442383, -35.754268646240234, -35.486976623535156, -35.08266067504883, -34.578025817871094, -33.942813873291016, -33.07871627807617, -31.81243896484375, -30.196712493896484, -28.466875076293945, -26.707548141479492, -24.99330711364746, -23.341943740844727, -21.753488540649414, -20.262371063232422, -17.862415313720703, -16.31279182434082, -14.981399536132812, -0.0, -0.0, -15.80422306060791, -0.0, -11.448135375976562, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.8828831911087036, 1.4279934167861938, 1.2774300575256348, 0.0933670699596405, -1.2750427722930908, -0.0, -0.0, -0.0, -0.0], [-23.036306381225586, 0.0, -16.20831298828125, 0.0, 0.0, -14.38443660736084, -16.212499618530273, -15.14743709564209, -15.37829303741455, -14.140338897705078, -12.327704429626465, -9.400601387023926, -11.8298978805542, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.932392120361328, 0.0, 0.0, 0.0, -22.36848258972168, 0.0, -20.798690795898438, -21.447952270507812, -23.748064041137695, -28.394102096557617, -26.11235809326172, -25.714832305908203, -28.784095764160156, 0.0, -30.145288467407227, -31.102279663085938, -36.30279541015625, -34.527427673339844, -31.15224838256836, -32.04877471923828, -30.542720794677734, -28.454002380371094, -30.08564567565918, -29.51006507873535, -30.279220581054688, -26.983375549316406, -26.079071044921875, -30.057720184326172, -27.436357498168945, -25.43049430847168, -21.964033126831055, -20.71844482421875, -19.71381950378418, -20.69483757019043, 0.0, 0.0, -11.631229400634766, -12.593056678771973, 0.0, -12.68163776397705, -12.791296005249023, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.19339875876903534, -0.16153739392757416, 0.005733601748943329, 0.40358781814575195, 0.14951655268669128, 0.0, 0.0, -1.0318957567214966, 0.0, -23.036306381225586, -0.0, -16.20831298828125, -0.0, -0.0, -14.38443660736084, -16.212499618530273, -15.14743709564209, -15.37829303741455, -14.140338897705078, -12.327704429626465, -9.400601387023926, -11.8298978805542, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.932392120361328, -0.0, -0.0, -0.0, -22.36848258972168, -0.0, -21.095720291137695, -22.984580993652344, -25.027128219604492, -27.128883361816406, -29.123205184936523, -30.918569564819336, -32.512718200683594, -0.0, -34.934814453125, -35.572845458984375, -35.85945510864258, -35.903194427490234, -35.7645263671875, -35.51944351196289, -35.1997184753418, -34.83680725097656, -34.41624069213867, -33.747257232666016, -32.53474807739258, -30.836891174316406, -28.990083694458008, -27.172327041625977, -25.45018768310547, -23.880632400512695, -22.343690872192383, -20.683364868164062, -19.71381950378418, -20.69483757019043, -0.0, -0.0, -11.631229400634766, -12.593056678771973, -0.0, -12.68163776397705, -12.791296005249023, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.19339875876903534, -0.16153739392757416, 0.005733601748943329, 0.40358781814575195, 0.14951655268669128, 0.0, -0.0, -1.0318957567214966, -0.0], [-25.13617515563965, -21.00349998474121, -18.833263397216797, 0.0, 0.0, -12.562265396118164, -15.971193313598633, -16.40921974182129, -14.011100769042969, -12.765849113464355, -12.893635749816895, -12.402725219726562, -13.010551452636719, -14.334259986877441, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -21.752666473388672, -22.418073654174805, -22.59340476989746, 0.0, -20.123674392700195, -23.091259002685547, -26.433086395263672, -29.026948928833008, -25.74927520751953, -26.71440315246582, -31.203205108642578, -31.842735290527344, 0.0, -32.2882080078125, -35.38001251220703, -32.10392761230469, -30.847644805908203, -31.683574676513672, -31.212759017944336, -30.424741744995117, -31.654653549194336, -34.565120697021484, -30.48748016357422, -28.541173934936523, -27.797117233276367, -30.23097038269043, -30.085886001586914, -29.376766204833984, -24.287044525146484, -22.12555694580078, -23.61188316345215, -19.819965362548828, 0.0, 0.0, -14.274199485778809, -13.411698341369629, -15.52532958984375, -14.914875984191895, -14.968213081359863, -14.20837116241455, 0.0, 0.0, 0.0, 0.0, 0.0, -0.7956147789955139, -0.5903875231742859, -0.2212735414505005, -0.9695568680763245, -0.9814705848693848, 0.0, 0.0, 0.429225355386734, 0.0, -25.13617515563965, -21.00349998474121, -18.833263397216797, -0.0, -0.0, -12.562265396118164, -15.971193313598633, -16.40921974182129, -14.011100769042969, -12.765849113464355, -12.893635749816895, -12.402725219726562, -13.010551452636719, -14.334259986877441, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -21.752666473388672, -22.418073654174805, -22.59340476989746, -0.0, -21.027494430541992, -23.369672775268555, -25.66942596435547, -27.732479095458984, -29.577056884765625, -31.207019805908203, -32.689456939697266, -34.02115249633789, -0.0, -35.60415267944336, -35.80978012084961, -35.756103515625, -35.55175018310547, -35.282615661621094, -34.998477935791016, -34.7508430480957, -34.557106018066406, -34.180702209472656, -33.10028839111328, -31.335420608520508, -29.38127899169922, -27.496768951416016, -25.740476608276367, -24.215007781982422, -22.9998779296875, -22.085071563720703, -23.61188316345215, -19.819965362548828, -0.0, -0.0, -14.274199485778809, -13.411698341369629, -15.52532958984375, -14.914875984191895, -14.968213081359863, -14.20837116241455, -0.0, -0.0, -0.0, -0.0, -0.0, -0.7956147789955139, -0.5903875231742859, -0.2212735414505005, -0.9695568680763245, -0.9814705848693848, -0.0, -0.0, 0.429225355386734, -0.0], [-25.117050170898438, -22.468751907348633, 0.0, 0.0, 0.0, 0.0, -17.651046752929688, -16.058460235595703, -15.6281099319458, -15.15466022491455, -14.114035606384277, -12.489741325378418, -14.841620445251465, -14.798868179321289, 0.0, 0.0, 0.0, 0.0, -8.644996643066406, -9.653278350830078, 0.0, 0.0, -22.93352699279785, 0.0, -22.77744483947754, -23.740921020507812, -25.04150390625, 0.0, 0.0, -26.525001525878906, -27.99764633178711, -30.010723114013672, -32.301963806152344, -28.667743682861328, -31.389802932739258, 0.0, -31.806779861450195, -33.64673614501953, -33.0894889831543, -31.03145980834961, -30.993165969848633, -30.488445281982422, -29.927202224731445, -32.289859771728516, -31.125581741333008, -31.896949768066406, -31.853891372680664, -30.89228630065918, -28.347795486450195, -26.9010009765625, -30.556764602661133, -27.206295013427734, -26.73442268371582, -23.743263244628906, -23.291820526123047, 0.0, -19.11561393737793, -16.033395767211914, -16.105892181396484, -15.002330780029297, -16.199186325073242, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.9966535568237305, -1.1371310949325562, -0.5305744409561157, -0.8514620661735535, -3.9133284091949463, 0.0, 0.0, 0.9710450172424316, 0.0, -25.117050170898438, -22.468751907348633, -0.0, -0.0, -0.0, -0.0, -17.651046752929688, -16.058460235595703, -15.6281099319458, -15.15466022491455, -14.114035606384277, -12.489741325378418, -14.841620445251465, -14.798868179321289, -0.0, -0.0, -0.0, -0.0, -8.644996643066406, -9.653278350830078, -0.0, -0.0, -22.93352699279785, -0.0, -22.77744483947754, -23.740921020507812, -25.04150390625, -0.0, -0.0, -24.61713981628418, -26.547277450561523, -28.2519588470459, -29.859603881835938, -31.355615615844727, -32.783321380615234, -0.0, -34.99821472167969, -35.369258880615234, -35.378211975097656, -35.24687957763672, -35.029964447021484, -34.694435119628906, -34.359439849853516, -34.25346374511719, -34.34047317504883, -34.291038513183594, -33.3609504699707, -31.57933235168457, -29.57917022705078, -27.694774627685547, -25.931032180786133, -24.356369018554688, -23.22227668762207, -23.71581268310547, -23.291820526123047, -0.0, -19.11561393737793, -16.033395767211914, -16.105892181396484, -15.002330780029297, -16.199186325073242, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -2.9966535568237305, -1.1371310949325562, -0.5305744409561157, -0.8514620661735535, -3.9133284091949463, -0.0, -0.0, 0.9710450172424316, -0.0], [0.0, -18.51231575012207, 0.0, 0.0, 0.0, 0.0, 0.0, -15.496417999267578, -15.667028427124023, -17.193300247192383, -14.417675018310547, -14.040581703186035, -13.3574857711792, 0.0, 0.0, 0.0, 0.0, 0.0, -9.42065143585205, 0.0, 0.0, 0.0, 0.0, -20.44778060913086, -22.28733253479004, -22.73409652709961, -25.85213851928711, -28.083816528320312, 0.0, -31.111019134521484, -30.18198013305664, -32.98955154418945, -32.79275131225586, -33.56009292602539, -31.179834365844727, -30.431243896484375, -31.32294273376465, -30.3150634765625, -33.47043228149414, -31.152814865112305, -30.888450622558594, -30.855342864990234, -30.07691192626953, -31.370555877685547, -33.351104736328125, -33.59549331665039, -29.8316593170166, -32.587318420410156, -28.500518798828125, -29.010135650634766, -26.473176956176758, -27.564790725708008, -22.510360717773438, 0.0, -23.93409538269043, -18.678314208984375, -16.678667068481445, -17.188358306884766, -16.964988708496094, -15.847623825073242, -15.27699089050293, -13.625419616699219, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.6625783443450928, -2.915078639984131, -1.2711281776428223, 0.0, 0.0, -1.7154959440231323, -2.5792531967163086, -1.8177921772003174, 0.0, -0.0, -18.51231575012207, -0.0, -0.0, -0.0, -0.0, -0.0, -15.496417999267578, -15.667028427124023, -17.193300247192383, -14.417675018310547, -14.040581703186035, -13.3574857711792, -0.0, -0.0, -0.0, -0.0, -0.0, -9.42065143585205, -0.0, -0.0, -0.0, -0.0, -20.44778060913086, -22.28733253479004, -22.73409652709961, -25.85213851928711, -28.083816528320312, -0.0, -27.293685913085938, -27.630958557128906, -28.764625549316406, -30.12179946899414, -31.51331329345703, -32.87704086303711, -33.99211120605469, -34.5595588684082, -34.54566192626953, -34.35586929321289, -34.254966735839844, -34.123313903808594, -33.82789993286133, -33.51047897338867, -33.49244689941406, -33.65922546386719, -33.95777893066406, -33.33319854736328, -31.621150970458984, -29.74250030517578, -27.94417381286621, -26.20938491821289, -24.560548782348633, -23.25058364868164, -0.0, -23.93409538269043, -18.678314208984375, -16.678667068481445, -17.188358306884766, -16.964988708496094, -15.847623825073242, -15.27699089050293, -13.625419616699219, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -2.6625783443450928, -2.915078639984131, -1.2711281776428223, -0.0, -0.0, -1.7154959440231323, -2.5792531967163086, -1.8177921772003174, -0.0], [0.0, 0.0, 0.0, 0.0, -19.439128875732422, 0.0, 0.0, 0.0, -15.864274024963379, -14.331168174743652, -14.379081726074219, -13.708985328674316, -14.410185813903809, 0.0, -13.085009574890137, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.54616355895996, -23.937885284423828, -22.874059677124023, -26.443437576293945, -27.317386627197266, -27.353408813476562, -29.884994506835938, -31.406585693359375, -31.894380569458008, -33.195594787597656, -29.029033660888672, -29.9598445892334, -31.43657684326172, -30.207765579223633, -31.81946563720703, -34.276466369628906, -29.58918571472168, -29.329822540283203, -30.22989845275879, -30.400524139404297, -32.817840576171875, -31.623489379882812, 0.0, -33.041481018066406, -28.535476684570312, -27.438753128051758, -27.5589599609375, -26.944501876831055, -26.407323837280273, -22.16525650024414, 0.0, 0.0, -18.78897476196289, -17.583965301513672, -17.596519470214844, -15.874259948730469, -15.271834373474121, -16.558656692504883, -12.768021583557129, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.9490392208099365, -1.8663305044174194, -2.676677703857422, 0.0, 0.0, -5.7791242599487305, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -19.439128875732422, -0.0, -0.0, -0.0, -15.864274024963379, -14.331168174743652, -14.379081726074219, -13.708985328674316, -14.410185813903809, -0.0, -13.085009574890137, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.54616355895996, -23.937885284423828, -22.874059677124023, -26.443437576293945, -27.317386627197266, -26.81633758544922, -27.882286071777344, -28.376522064208984, -29.230680465698242, -30.364582061767578, -31.65033721923828, -32.72838592529297, -33.34687042236328, -33.51126480102539, -33.28166580200195, -33.04865646362305, -33.020267486572266, -33.04933166503906, -32.85606002807617, -32.594398498535156, -32.50263214111328, -32.674072265625, -0.0, -32.95287322998047, -31.536548614501953, -29.90215301513672, -28.291608810424805, -26.577442169189453, -24.92525291442871, -23.350223541259766, -0.0, -0.0, -18.78897476196289, -17.583965301513672, -17.596519470214844, -15.874259948730469, -15.271834373474121, -16.558656692504883, -12.768021583557129, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -3.9490392208099365, -1.8663305044174194, -2.676677703857422, -0.0, -0.0, -5.7791242599487305, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -23.76698875427246, -19.653242111206055, 0.0, 0.0, -17.344419479370117, -15.289862632751465, -14.321887016296387, -13.678586959838867, -12.899724006652832, -10.043532371520996, -10.672971725463867, -11.653077125549316, 0.0, 0.0, -13.407569885253906, -16.526487350463867, -18.651071548461914, -18.528242111206055, -19.57747459411621, -24.18228530883789, -23.680498123168945, -24.672510147094727, -25.001527786254883, -25.742948532104492, -26.907958984375, -30.915895462036133, -32.87507629394531, -33.491355895996094, -28.513957977294922, -30.516651153564453, -31.3857421875, -34.108985900878906, -32.74013137817383, -30.378469467163086, -30.64238166809082, -34.9599723815918, -34.28046417236328, -33.92427444458008, -34.67094802856445, -36.70663833618164, -35.25828170776367, 0.0, -28.24916648864746, -27.18653678894043, -28.75435447692871, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.42249870300293, -20.34519386291504, -16.74297332763672, -15.123003005981445, -14.894905090332031, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.868870735168457, -6.687090873718262, 0.0, -4.200286388397217, -2.3558509349823, 0.0, 0.0, -6.409848690032959, -6.048528671264648, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -23.76698875427246, -19.653242111206055, -0.0, -0.0, -17.344419479370117, -15.289862632751465, -14.321887016296387, -13.678586959838867, -12.899724006652832, -10.043532371520996, -10.672971725463867, -11.653077125549316, -0.0, -0.0, -13.407569885253906, -16.526487350463867, -18.651071548461914, -18.528242111206055, -19.57747459411621, -24.18228530883789, -23.680498123168945, -24.672510147094727, -25.001527786254883, -25.742948532104492, -27.28791046142578, -28.13555145263672, -28.65522003173828, -29.406240463256836, -30.40203285217285, -31.450109481811523, -32.170494079589844, -32.45368576049805, -32.36371612548828, -31.91888427734375, -31.65231704711914, -31.609193801879883, -31.66680908203125, -31.637798309326172, -31.451616287231445, -31.284255981445312, -31.314529418945312, -0.0, -31.844100952148438, -31.134815216064453, -29.68126678466797, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.42249870300293, -20.34519386291504, -16.74297332763672, -15.123003005981445, -14.894905090332031, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -8.868870735168457, -6.687090873718262, -0.0, -4.200286388397217, -2.3558509349823, -0.0, -0.0, -6.409848690032959, -6.048528671264648, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -23.227828979492188, -22.5355167388916, 0.0, 0.0, -15.000709533691406, -14.995075225830078, -15.223923683166504, -15.164709091186523, 0.0, -11.436660766601562, -11.418904304504395, -12.723053932189941, 0.0, -14.41362190246582, -14.721186637878418, -17.492050170898438, -17.75316047668457, -18.785587310791016, -19.49395751953125, -20.93021583557129, -20.397022247314453, 0.0, -23.971994400024414, 0.0, -27.997753143310547, 0.0, 0.0, -29.111909866333008, -29.47233772277832, -31.919334411621094, -33.252017974853516, -33.408775329589844, -32.219444274902344, -30.3258056640625, -29.357091903686523, -33.89128875732422, -31.866243362426758, -31.820556640625, -32.472225189208984, -35.78632354736328, -33.699398040771484, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.770671844482422, -16.485197067260742, -17.206083297729492, -16.823915481567383, -16.29107093811035, 0.0, 0.0, 0.0, -14.043424606323242, -9.996236801147461, -10.035219192504883, 0.0, 0.0, -4.46811056137085, -3.4268970489501953, 0.0, 0.0, -7.0814313888549805, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -23.227828979492188, -22.5355167388916, -0.0, -0.0, -15.000709533691406, -14.995075225830078, -15.223923683166504, -15.164709091186523, -0.0, -11.436660766601562, -11.418904304504395, -12.723053932189941, -0.0, -14.41362190246582, -14.721186637878418, -17.492050170898438, -17.75316047668457, -18.785587310791016, -19.49395751953125, -20.93021583557129, -20.397022247314453, -0.0, -23.971994400024414, -0.0, -27.815061569213867, -0.0, -0.0, -29.340078353881836, -30.175872802734375, -30.99689483642578, -31.454185485839844, -31.644676208496094, -31.334749221801758, -30.639677047729492, -30.232357025146484, -30.219158172607422, -30.253705978393555, -30.173160552978516, -30.006885528564453, -29.833049774169922, -29.859769821166992, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.770671844482422, -16.485197067260742, -17.206083297729492, -16.823915481567383, -16.29107093811035, -0.0, -0.0, -0.0, -14.043424606323242, -9.996236801147461, -10.035219192504883, -0.0, -0.0, -4.46811056137085, -3.4268970489501953, -0.0, -0.0, -7.0814313888549805, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -25.29450225830078, -21.59798240661621, -19.84927749633789, 0.0, 0.0, -17.99138832092285, -15.884675025939941, 0.0, -13.724546432495117, -12.027969360351562, -13.78508472442627, -15.032670021057129, -14.713237762451172, -16.564956665039062, -16.48503875732422, -17.570377349853516, -18.355852127075195, -18.40382194519043, -19.85007667541504, -20.687776565551758, -21.227447509765625, -22.5227108001709, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -31.73211669921875, -30.849979400634766, 0.0, -31.546342849731445, -31.106435775756836, -31.06305694580078, -29.27574920654297, -32.22397994995117, -29.66117286682129, -29.73888397216797, -31.563278198242188, -34.756736755371094, 0.0, -22.989648818969727, 0.0, -22.16483497619629, -22.63094139099121, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.464431762695312, -18.0930118560791, -17.73196029663086, -17.35874366760254, -15.946765899658203, -16.068340301513672, -16.521520614624023, -15.112656593322754, -15.230802536010742, -13.819230079650879, 0.0, -11.493369102478027, 0.0, 0.0, 0.0, 0.0, -7.068972110748291, -9.443116188049316, -8.451743125915527, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -25.29450225830078, -21.59798240661621, -19.84927749633789, -0.0, -0.0, -17.99138832092285, -15.884675025939941, -0.0, -13.724546432495117, -12.027969360351562, -13.78508472442627, -15.032670021057129, -14.713237762451172, -16.564956665039062, -16.48503875732422, -17.570377349853516, -18.355852127075195, -18.40382194519043, -19.85007667541504, -20.687776565551758, -21.227447509765625, -22.5227108001709, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -29.963167190551758, -30.532676696777344, -0.0, -30.857851028442383, -30.230186462402344, -29.485069274902344, -28.997438430786133, -28.980897903442383, -28.908864974975586, -28.684520721435547, -28.477609634399414, -28.195899963378906, -0.0, -28.099254608154297, -0.0, -27.600683212280273, -26.90407371520996, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.464431762695312, -18.0930118560791, -17.73196029663086, -17.35874366760254, -15.946765899658203, -16.068340301513672, -16.521520614624023, -15.112656593322754, -15.230802536010742, -13.819230079650879, -0.0, -11.493369102478027, -0.0, -0.0, -0.0, -0.0, -7.068972110748291, -9.443116188049316, -8.451743125915527, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -22.554073333740234, -21.458816528320312, 0.0, 0.0, -19.1286678314209, 0.0, 0.0, -12.424886703491211, -13.49635124206543, -13.928932189941406, -14.738417625427246, -15.319682121276855, -16.135711669921875, -16.78094482421875, -17.686298370361328, -18.9246883392334, -19.99783706665039, -20.25358009338379, -21.085487365722656, -22.126184463500977, -22.945592880249023, -25.12763786315918, 0.0, 0.0, 0.0, -24.94927406311035, -27.55925941467285, -28.790790557861328, -32.59641647338867, -33.81646728515625, 0.0, -28.50900650024414, -30.683897018432617, -28.638120651245117, -27.090009689331055, -26.987478256225586, -27.6549015045166, -28.02170753479004, -30.019306182861328, 0.0, 0.0, -25.55083656311035, 0.0, 0.0, -26.035451889038086, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.340139389038086, -19.762798309326172, -18.464399337768555, -19.278247833251953, -17.04859161376953, -18.01103973388672, -17.52238655090332, -16.799009323120117, -14.165826797485352, -14.276091575622559, -14.105978965759277, 0.0, -9.932547569274902, 0.0, 0.0, 0.0, 0.0, -6.669094562530518, -4.355833530426025, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.554073333740234, -21.458816528320312, -0.0, -0.0, -19.1286678314209, -0.0, -0.0, -12.424886703491211, -13.49635124206543, -13.928932189941406, -14.738417625427246, -15.319682121276855, -16.135711669921875, -16.78094482421875, -17.686298370361328, -18.9246883392334, -19.99783706665039, -20.25358009338379, -21.085487365722656, -22.126184463500977, -22.945592880249023, -25.12763786315918, -0.0, -0.0, -0.0, -28.670351028442383, -29.519407272338867, -29.90090560913086, -30.142667770385742, -30.274280548095703, -0.0, -29.131357192993164, -28.580333709716797, -28.03441047668457, -27.834959030151367, -27.721477508544922, -27.434938430786133, -27.043222427368164, -26.58901596069336, -0.0, -0.0, -26.71932601928711, -0.0, -0.0, -25.00832748413086, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.340139389038086, -19.762798309326172, -18.464399337768555, -19.278247833251953, -17.04859161376953, -18.01103973388672, -17.52238655090332, -16.799009323120117, -14.165826797485352, -14.276091575622559, -14.105978965759277, -0.0, -9.932547569274902, -0.0, -0.0, -0.0, -0.0, -6.669094562530518, -4.355833530426025, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -23.295324325561523, -24.139507293701172, -25.06242561340332, -22.723052978515625, 0.0, 0.0, 0.0, -14.672740936279297, -13.493485450744629, -14.354808807373047, -14.7324857711792, -15.6764497756958, -16.329933166503906, -17.377986907958984, -18.34217071533203, -18.958148956298828, -20.433391571044922, -20.773656845092773, -22.114669799804688, -22.919918060302734, -24.093202590942383, -24.376680374145508, -24.9755916595459, 0.0, 0.0, 0.0, -28.13874053955078, -29.013019561767578, -34.41067123413086, 0.0, 0.0, 0.0, -31.891626358032227, 0.0, 0.0, -24.78757095336914, -26.05425262451172, -28.806716918945312, -30.47757339477539, 0.0, 0.0, -25.940710067749023, -26.791366577148438, -27.951313018798828, -27.10980796813965, 0.0, 0.0, 0.0, 0.0, 0.0, -20.566646575927734, -21.029460906982422, -20.317169189453125, -20.081268310546875, -20.586204528808594, -19.407615661621094, -19.176124572753906, -18.79791831970215, -17.52121353149414, -16.602724075317383, -15.846242904663086, -14.303064346313477, -14.467310905456543, -9.592452049255371, 0.0, 0.0, 0.0, 0.0, -4.44734525680542, -4.668454170227051, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.295324325561523, -24.139507293701172, -25.06242561340332, -22.723052978515625, -0.0, -0.0, -0.0, -14.672740936279297, -13.493485450744629, -14.354808807373047, -14.7324857711792, -15.6764497756958, -16.329933166503906, -17.377986907958984, -18.34217071533203, -18.958148956298828, -20.433391571044922, -20.773656845092773, -22.114669799804688, -22.919918060302734, -24.093202590942383, -24.376680374145508, -24.9755916595459, -0.0, -0.0, -0.0, -29.50819206237793, -29.712932586669922, -29.716670989990234, -0.0, -0.0, -0.0, -28.02931785583496, -0.0, -0.0, -26.52608299255371, -26.543781280517578, -26.225940704345703, -25.54381561279297, -0.0, -0.0, -25.778703689575195, -25.747098922729492, -25.300865173339844, -24.567716598510742, -0.0, -0.0, -0.0, -0.0, -0.0, -20.566646575927734, -21.029460906982422, -20.317169189453125, -20.081268310546875, -20.586204528808594, -19.407615661621094, -19.176124572753906, -18.79791831970215, -17.52121353149414, -16.602724075317383, -15.846242904663086, -14.303064346313477, -14.467310905456543, -9.592452049255371, -0.0, -0.0, -0.0, -0.0, -4.44734525680542, -4.668454170227051, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -20.220745086669922, -24.648649215698242, -22.24352264404297, 0.0, 0.0, 0.0, 0.0, -13.694777488708496, -13.117518424987793, -14.456024169921875, -15.709220886230469, -15.758769989013672, -16.15900993347168, -17.045637130737305, -18.272092819213867, -19.07289695739746, -20.501317977905273, -21.098114013671875, -22.151166915893555, -23.14826774597168, -24.125070571899414, -24.40066909790039, -25.54433822631836, 0.0, 0.0, -29.726709365844727, -28.72984504699707, 0.0, -35.991943359375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.852113723754883, 0.0, 0.0, -26.586990356445312, 0.0, 0.0, -25.156824111938477, 0.0, 0.0, 0.0, 0.0, 0.0, -20.540538787841797, -23.447813034057617, -21.304479598999023, -22.078054428100586, -21.502010345458984, -21.831159591674805, -21.1634521484375, -21.69572639465332, -19.591054916381836, -19.064958572387695, -18.046735763549805, -15.434906959533691, -13.239538192749023, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.7320556640625, -5.8014020919799805, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.220745086669922, -24.648649215698242, -22.24352264404297, -0.0, -0.0, -0.0, -0.0, -13.694777488708496, -13.117518424987793, -14.456024169921875, -15.709220886230469, -15.758769989013672, -16.15900993347168, -17.045637130737305, -18.272092819213867, -19.07289695739746, -20.501317977905273, -21.098114013671875, -22.151166915893555, -23.14826774597168, -24.125070571899414, -24.40066909790039, -25.54433822631836, -0.0, -0.0, -28.731639862060547, -29.329788208007812, -0.0, -29.7536678314209, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.801816940307617, -0.0, -0.0, -25.229530334472656, -0.0, -0.0, -25.06047821044922, -0.0, -0.0, -0.0, -0.0, -0.0, -20.540538787841797, -23.447813034057617, -21.304479598999023, -22.078054428100586, -21.502010345458984, -21.831159591674805, -21.1634521484375, -21.69572639465332, -19.591054916381836, -19.064958572387695, -18.046735763549805, -15.434906959533691, -13.239538192749023, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.7320556640625, -5.8014020919799805, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.081018447875977, -24.611425399780273, 0.0, 0.0, 0.0, 0.0, -13.662369728088379, 0.0, -14.379652976989746, -15.074538230895996, -15.205110549926758, -15.744017601013184, -16.546226501464844, -17.406919479370117, -18.73967933654785, -20.12397575378418, -21.646913528442383, -22.458040237426758, -23.572254180908203, -24.37221908569336, -24.984506607055664, -26.02907943725586, -26.764163970947266, 0.0, 0.0, -30.658185958862305, 0.0, -37.49932861328125, -38.61973190307617, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.468847274780273, -23.01686668395996, -24.548553466796875, 0.0, 0.0, 0.0, 0.0, -20.573938369750977, -17.651247024536133, -21.47587013244629, -22.08413314819336, -22.301965713500977, -21.882827758789062, -21.8890438079834, -22.164369583129883, -20.68242073059082, -20.269533157348633, -18.393192291259766, -17.12183380126953, -15.166646957397461, -13.670161247253418, 0.0, 0.0, 0.0, 0.0, 0.0, -5.6252641677856445, -6.467493534088135, -7.667384624481201, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.081018447875977, -24.611425399780273, -0.0, -0.0, -0.0, -0.0, -13.662369728088379, -0.0, -14.379652976989746, -15.074538230895996, -15.205110549926758, -15.744017601013184, -16.546226501464844, -17.406919479370117, -18.73967933654785, -20.12397575378418, -21.646913528442383, -22.458040237426758, -23.572254180908203, -24.37221908569336, -24.984506607055664, -26.02907943725586, -26.792341232299805, -0.0, -0.0, -29.532386779785156, -0.0, -29.847681045532227, -29.688678741455078, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.173526763916016, -25.046066284179688, -24.987146377563477, -0.0, -0.0, -0.0, -0.0, -21.034805297851562, -17.651247024536133, -21.47587013244629, -22.08413314819336, -22.301965713500977, -21.882827758789062, -21.8890438079834, -22.164369583129883, -20.68242073059082, -20.269533157348633, -18.393192291259766, -17.12183380126953, -15.166646957397461, -13.670161247253418, -0.0, -0.0, -0.0, -0.0, -0.0, -5.6252641677856445, -6.467493534088135, -7.667384624481201, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.80502700805664, -22.45796775817871, 0.0, 0.0, 0.0, 0.0, -12.109107971191406, 0.0, -14.110974311828613, -14.865357398986816, -14.541598320007324, -15.284499168395996, -16.199504852294922, -17.083654403686523, -18.541643142700195, -19.99185562133789, -21.965740203857422, -22.641469955444336, -23.84396743774414, -25.01084327697754, -25.659555435180664, -25.849092483520508, -26.183767318725586, 0.0, 0.0, -28.114826202392578, 0.0, -36.80899429321289, -36.12971496582031, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.609790802001953, -25.30555534362793, -25.54887580871582, 0.0, 0.0, 0.0, 0.0, 0.0, -20.517377853393555, -22.615278244018555, -22.791574478149414, -22.902814865112305, -22.371623992919922, -21.58672332763672, -22.38443374633789, -20.874977111816406, -19.87701416015625, -19.242286682128906, -17.267580032348633, -13.212181091308594, -13.336045265197754, 0.0, 0.0, 0.0, 0.0, 0.0, -8.496400833129883, -8.446998596191406, -8.277259826660156, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.80502700805664, -22.45796775817871, -0.0, -0.0, -0.0, -0.0, -12.109107971191406, -0.0, -14.110974311828613, -14.865357398986816, -14.541598320007324, -15.284499168395996, -16.199504852294922, -17.083654403686523, -18.541643142700195, -19.99185562133789, -21.965740203857422, -22.641469955444336, -23.84396743774414, -25.01084327697754, -25.659555435180664, -25.849092483520508, -26.445119857788086, -0.0, -0.0, -29.61273765563965, -0.0, -29.59929847717285, -29.665287017822266, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.847763061523438, -24.68521499633789, -24.623334884643555, -0.0, -0.0, -0.0, -0.0, -0.0, -20.517377853393555, -22.615278244018555, -22.791574478149414, -22.902814865112305, -22.371623992919922, -21.58672332763672, -22.38443374633789, -20.874977111816406, -19.87701416015625, -19.242286682128906, -17.267580032348633, -13.212181091308594, -13.336045265197754, -0.0, -0.0, -0.0, -0.0, -0.0, -8.496400833129883, -8.446998596191406, -8.277259826660156, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.68906593322754, -25.517675399780273, 0.0, 0.0, 0.0, 0.0, -14.59314250946045, 0.0, -16.596588134765625, -15.120478630065918, -14.427701950073242, -14.599794387817383, -15.386282920837402, -16.077072143554688, -17.384323120117188, -17.95775604248047, -20.294530868530273, -21.654579162597656, -23.439990997314453, -24.144380569458008, -25.406818389892578, -26.83754539489746, -26.889488220214844, 0.0, 0.0, 0.0, 0.0, 0.0, -35.291221618652344, -34.95448684692383, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.515066146850586, -25.571142196655273, -26.518293380737305, 0.0, 0.0, 0.0, 0.0, 0.0, -23.20807647705078, -22.26242446899414, -20.973669052124023, -22.437786102294922, -24.10542106628418, -22.3610897064209, 0.0, 0.0, -17.747915267944336, -16.81321144104004, -16.03528594970703, -14.773370742797852, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.743041515350342, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.68906593322754, -25.517675399780273, -0.0, -0.0, -0.0, -0.0, -14.59314250946045, -0.0, -16.596588134765625, -15.120478630065918, -14.427701950073242, -14.599794387817383, -15.386282920837402, -16.077072143554688, -17.384323120117188, -17.95775604248047, -20.294530868530273, -21.654579162597656, -23.439990997314453, -24.144380569458008, -25.406818389892578, -26.83754539489746, -26.846649169921875, -0.0, -0.0, -0.0, -0.0, -0.0, -29.7017822265625, -29.43222427368164, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.459970474243164, -24.056488037109375, -23.817411422729492, -0.0, -0.0, -0.0, -0.0, -0.0, -23.20807647705078, -22.26242446899414, -20.973669052124023, -22.437786102294922, -24.10542106628418, -22.3610897064209, -0.0, -0.0, -17.747915267944336, -16.81321144104004, -16.03528594970703, -14.773370742797852, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.743041515350342, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.413352966308594, -26.364490509033203, 0.0, 0.0, 0.0, 0.0, -16.25411605834961, -14.443109512329102, -15.133002281188965, -15.675643920898438, -14.799583435058594, -14.098566055297852, -14.40776252746582, -14.325108528137207, -14.889732360839844, -15.79414176940918, -18.292654037475586, -19.872331619262695, -21.849666595458984, -23.359575271606445, -24.881038665771484, -26.204294204711914, -26.955432891845703, 0.0, 0.0, 0.0, 0.0, 0.0, -37.312435150146484, -34.164703369140625, -35.546268463134766, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.327089309692383, -23.41192054748535, -22.882888793945312, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.948163986206055, 0.0, -19.468908309936523, 0.0, -16.315685272216797, 0.0, -15.712522506713867, -15.288097381591797, -15.083852767944336, -13.908381462097168, -15.228350639343262, 0.0, -9.772141456604004, 0.0, 0.0, -16.3521671295166, 0.0, -3.6680850982666016, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.413352966308594, -26.364490509033203, -0.0, -0.0, -0.0, -0.0, -16.25411605834961, -14.443109512329102, -15.133002281188965, -15.675643920898438, -14.799583435058594, -14.098566055297852, -14.40776252746582, -14.325108528137207, -14.889732360839844, -15.79414176940918, -18.292654037475586, -19.872331619262695, -21.849666595458984, -23.359575271606445, -24.881038665771484, -26.204294204711914, -26.702573776245117, -0.0, -0.0, -0.0, -0.0, -0.0, -29.60411834716797, -29.16632843017578, -28.250526428222656, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.4580020904541, -22.804000854492188, -22.679214477539062, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.948163986206055, -0.0, -19.468908309936523, -0.0, -16.315685272216797, -0.0, -15.712522506713867, -15.288097381591797, -15.083852767944336, -13.908381462097168, -15.228350639343262, -0.0, -9.772141456604004, -0.0, -0.0, -16.3521671295166, -0.0, -3.6680850982666016, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.880502700805664, -25.432636260986328, 0.0, 0.0, 0.0, -16.519899368286133, -16.856660842895508, -16.568679809570312, -14.887565612792969, -14.031564712524414, -14.638540267944336, -14.500714302062988, -13.331513404846191, -13.198973655700684, 0.0, -17.963470458984375, 0.0, -20.338956832885742, -22.13763427734375, -23.21902847290039, -24.7211856842041, -24.901531219482422, 0.0, 0.0, 0.0, 0.0, 0.0, -35.71799087524414, -36.80670928955078, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.229875564575195, 0.0, -20.101015090942383, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.436919212341309, -16.907732009887695, -13.769466400146484, -14.36618423461914, 0.0, -12.85679817199707, 0.0, -14.027674674987793, 0.0, 0.0, 0.0, 0.0, -14.490303039550781, -11.638054847717285, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.880502700805664, -25.432636260986328, -0.0, -0.0, -0.0, -16.519899368286133, -16.856660842895508, -16.568679809570312, -14.887565612792969, -14.031564712524414, -14.638540267944336, -14.500714302062988, -13.331513404846191, -13.198973655700684, -0.0, -17.963470458984375, -0.0, -20.338956832885742, -22.13763427734375, -23.21902847290039, -24.7211856842041, -24.909833908081055, -0.0, -0.0, -0.0, -0.0, -0.0, -29.18135643005371, -29.13798713684082, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.421003341674805, -0.0, -21.861495971679688, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.436919212341309, -16.907732009887695, -13.769466400146484, -14.36618423461914, -0.0, -12.85679817199707, -0.0, -14.027674674987793, -0.0, -0.0, -0.0, -0.0, -14.490303039550781, -11.638054847717285, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.629878997802734, -22.03270721435547, -24.51549530029297, 0.0, -13.240143775939941, -14.727453231811523, -18.78281021118164, -14.486595153808594, -13.518906593322754, -15.064927101135254, -14.306588172912598, -14.378280639648438, -13.029620170593262, -11.735054016113281, -12.321172714233398, -17.990583419799805, -18.100826263427734, 0.0, -21.20277214050293, -22.702489852905273, -24.135372161865234, 0.0, 0.0, 0.0, 0.0, 0.0, -35.25716018676758, -34.6231803894043, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.281902313232422, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.11197853088379, -15.556841850280762, -15.643643379211426, -10.424522399902344, -11.96034049987793, -12.148065567016602, -11.576215744018555, -11.732983589172363, -12.819340705871582, 0.0, 0.0, 0.0, 0.0, 0.0, -11.337343215942383, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.629878997802734, -22.03270721435547, -24.51549530029297, -0.0, -13.240143775939941, -14.727453231811523, -18.78281021118164, -14.486595153808594, -13.518906593322754, -15.064927101135254, -14.306588172912598, -14.378280639648438, -13.029620170593262, -11.735054016113281, -12.321172714233398, -17.990583419799805, -18.100826263427734, -0.0, -21.20277214050293, -22.702489852905273, -23.96540641784668, -0.0, -0.0, -0.0, -0.0, -0.0, -28.671205520629883, -28.844890594482422, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.851057052612305, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.11197853088379, -15.556841850280762, -15.643643379211426, -10.424522399902344, -11.96034049987793, -12.148065567016602, -11.576215744018555, -11.732983589172363, -12.819340705871582, -0.0, -0.0, -0.0, -0.0, -0.0, -11.337343215942383, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -21.466594696044922, -26.005495071411133, 0.0, 0.0, -15.61429214477539, -17.19902801513672, 0.0, 0.0, -14.624160766601562, -14.643569946289062, -15.944562911987305, -15.485108375549316, -14.674553871154785, -14.392818450927734, 0.0, 0.0, 0.0, -17.811092376708984, -19.8817138671875, -18.278860092163086, -21.480789184570312, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.75077247619629, -15.15359878540039, -12.892578125, -9.813673973083496, -13.585509300231934, -13.881868362426758, -14.74461841583252, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -21.466594696044922, -26.005495071411133, -0.0, -0.0, -15.61429214477539, -17.19902801513672, -0.0, -0.0, -14.624160766601562, -14.643569946289062, -15.944562911987305, -15.485108375549316, -14.674553871154785, -14.392818450927734, -0.0, -0.0, -0.0, -17.811092376708984, -19.8817138671875, -19.670230865478516, -22.351486206054688, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.75077247619629, -15.15359878540039, -12.892578125, -9.813673973083496, -13.585509300231934, -13.881868362426758, -14.74461841583252, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.336150169372559, -15.70482063293457, 0.0, 0.0, 0.0, -14.742128372192383, -11.893860816955566, -11.11931324005127, 0.0, -15.806488037109375, 0.0, 0.0, 0.0, -20.4700984954834, -16.99953269958496, -19.36041831970215, -22.947738647460938, -21.842039108276367, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.59752082824707, -14.58701229095459, 0.0, 0.0, 0.0, -18.09295654296875, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.336150169372559, -15.70482063293457, -0.0, -0.0, -0.0, -14.742128372192383, -11.893860816955566, -11.11931324005127, -0.0, -15.806488037109375, -0.0, -0.0, -0.0, -20.4700984954834, -16.99953269958496, -19.321033477783203, -20.77830696105957, -22.51606559753418, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.59752082824707, -14.58701229095459, -0.0, -0.0, -0.0, -18.09295654296875, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.16300106048584, 0.0, 0.0, 0.0, 0.0, 0.0, -20.238929748535156, -18.203397750854492, -20.479215621948242, -21.589122772216797, -20.735698699951172, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.16300106048584, -0.0, -0.0, -0.0, -0.0, -0.0, -20.238929748535156, -18.203397750854492, -20.479215621948242, -20.44648551940918, -20.50918197631836, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.778553009033203, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.778553009033203, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.066320419311523, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.319944381713867, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -29.066320419311523, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.319944381713867, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.236526489257812, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.236526489257812, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.482280731201172, -17.347204208374023, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.482280731201172, -17.347204208374023, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0]]}, {\"colorbar\": {\"title\": {\"text\": \"B<sub>0</sub> (Hz)\"}}, \"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.3333333333333333, \"rgb(230,0,0)\"], [0.6666666666666666, \"rgb(255,210,0)\"], [1.0, \"rgb(255,255,255)\"]], \"name\": \"comparison heatmap\", \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 20.60269546508789, 20.096513748168945, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 20.60269546508789, 20.096513748168945, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 17.257959365844727, 15.366580963134766, 13.403276443481445, 12.5564546585083, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 17.257959365844727, 15.366580963134766, 13.403276443481445, 12.5564546585083, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.178827285766602, 13.052009582519531, 0.0, 0.0, 13.735548973083496, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.178827285766602, 13.052009582519531, 0.0, 0.0, 13.735548973083496, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 12.915556907653809, 0.0, 11.419498443603516, 13.314544677734375, 13.995889663696289, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 12.915556907653809, 0.0, 11.419498443603516, 13.314544677734375, 13.995889663696289, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 11.802616119384766, 10.861406326293945, 12.634267807006836, 10.473306655883789, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 11.802616119384766, 10.861406326293945, 12.634267807006836, 10.473306655883789, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 13.421565055847168, 10.463440895080566, 7.703912734985352, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 13.421565055847168, 10.463440895080566, 7.703912734985352, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.15789875388145447, -1.7228895425796509, -1.1659741401672363, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.375777244567871, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.15789875388145447, -1.7228895425796509, -1.1659741401672363, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.375777244567871, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.8371009826660156, 0.0, 0.0, 4.787996768951416, 4.805371284484863, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.779716491699219, 0.0, 8.027575492858887, 6.704516887664795, 0.0, 9.585551261901855, 10.75214958190918, 8.000532150268555, 8.570629119873047, 8.994266510009766, 7.035375595092773, 8.186456680297852, 8.30589485168457, 0.0, 6.330631256103516, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.8371009826660156, 0.0, -0.0, 4.787996768951416, 4.805371284484863, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.779716491699219, 0.0, 8.027575492858887, 6.704516887664795, 0.0, 9.585551261901855, 10.75214958190918, 8.000532150268555, 8.570629119873047, 8.994266510009766, 7.035375595092773, 8.186456680297852, 8.30589485168457, 0.0, 6.330631256103516, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.432724952697754, 3.1058201789855957, 6.214292049407959, 5.060319423675537, 5.72247838973999, 4.715215682983398, 5.882051944732666, 6.269768238067627, 6.514837265014648, 6.2345733642578125, 7.046799659729004, 6.925510883331299, 6.848918437957764, 5.994685173034668, 6.508269309997559, 6.558152675628662, 7.187248229980469, 9.860218048095703, 9.088105201721191, 10.50307846069336, 8.166377067565918, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.432724952697754, 3.1058201789855957, 6.214292049407959, 5.060319423675537, 5.72247838973999, 4.715215682983398, 5.882051944732666, 6.269768238067627, 6.514837265014648, 6.2345733642578125, 7.046799659729004, 6.925510883331299, 6.848918437957764, 5.994685173034668, 6.508269309997559, 6.558152675628662, 7.187248229980469, 9.860218048095703, 9.088105201721191, 10.50307846069336, 8.166377067565918, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.7313506603240967, 5.631591796875, 5.640514373779297, 5.506892204284668, 3.452181339263916, 4.661414623260498, 5.1621785163879395, 4.2296223640441895, 4.8318047523498535, 3.8387889862060547, 4.767641067504883, 6.422875881195068, 2.553358554840088, 5.4781174659729, 4.125391006469727, 8.252860069274902, 10.957768440246582, 8.28256893157959, 0.0, 5.6365227699279785, 7.132369518280029, 5.149358749389648, 5.2981696128845215, 5.667604923248291, 6.046984672546387, 6.7878828048706055, 6.229406356811523, 8.55897331237793, 8.014036178588867, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.7313506603240967, 5.631591796875, 5.640514373779297, 5.506892204284668, 3.452181339263916, 4.661414623260498, 5.1621785163879395, 4.2296223640441895, 4.8318047523498535, 3.8387889862060547, 4.767641067504883, 6.422875881195068, 2.553358554840088, 5.4781174659729, 4.125391006469727, 8.252860069274902, 10.957768440246582, 8.28256893157959, 0.0, 5.6365227699279785, 7.132369518280029, 5.149358749389648, 5.2981696128845215, 5.667604923248291, 6.046984672546387, 6.7878828048706055, 6.229406356811523, 8.55897331237793, 8.014036178588867, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.0678486824035645, 4.905378818511963, 6.272444248199463, 4.906250476837158, 4.764636516571045, 3.87322998046875, 3.031934976577759, 2.3468337059020996, 5.480582237243652, 0.0, 0.0, 0.0, 0.0, 6.3943705558776855, 3.9898903369903564, 7.363158702850342, 8.244482040405273, 6.7314934730529785, 9.218093872070312, 7.611474990844727, 0.0, 0.0, 8.319150924682617, 7.786047458648682, 3.654679775238037, 0.0, 4.144467830657959, 5.341405868530273, 2.088074207305908, 3.9679677486419678, 7.763431072235107, 5.700874328613281, 7.750019073486328, 3.718254327774048, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.0678486824035645, 4.905378818511963, 6.272444248199463, 4.906250476837158, 4.764636516571045, 3.87322998046875, 3.031934976577759, 2.3468337059020996, 5.480582237243652, 0.0, 0.0, 0.0, 0.0, 6.3943705558776855, 3.9898903369903564, 7.363158702850342, 8.244482040405273, 6.7314934730529785, 9.218093872070312, 7.611474990844727, 0.0, 0.0, 8.319150924682617, 7.786047458648682, 3.654679775238037, 0.0, 4.144467830657959, 5.341405868530273, 2.088074207305908, 3.9679677486419678, 7.763431072235107, 5.700874328613281, 7.750019073486328, 3.718254327774048, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.462989330291748, 7.047060489654541, 4.801944255828857, 5.902650356292725, 3.8366734981536865, 4.408438682556152, 1.7583379745483398, 2.615212917327881, 0.0, 3.4909451007843018, 0.0, 5.106356143951416, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.031559944152832, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.165992259979248, 3.3759028911590576, 4.141564846038818, 5.0499396324157715, 6.795630931854248, 7.018962383270264, 8.679471969604492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.462989330291748, 7.047060489654541, 4.801944255828857, 5.902650356292725, 3.8366734981536865, 4.408438682556152, 1.7583379745483398, 2.615212917327881, 0.0, 3.4909451007843018, 0.0, 5.106356143951416, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.031559944152832, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.165992259979248, 3.3759028911590576, 4.141564846038818, 5.0499396324157715, 6.795630931854248, 7.018962383270264, 8.679471969604492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.339318752288818, 5.726258754730225, 4.141923427581787, 5.492209434509277, 2.0025434494018555, 1.6933907270431519, 0.14066490530967712, 1.9802342653274536, 4.683938026428223, 0.0, 4.0182623863220215, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.077150821685791, 5.7081732749938965, 5.685253143310547, 0.0, 0.0, 0.0, 5.808711528778076, 6.064574241638184, 5.959862232208252, 8.389079093933105, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.339318752288818, 5.726258754730225, 4.141923427581787, 5.492209434509277, 2.0025434494018555, 1.6933907270431519, 0.14066490530967712, 1.9802342653274536, 4.683938026428223, 0.0, 4.0182623863220215, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.077150821685791, 5.7081732749938965, 5.685253143310547, 0.0, 0.0, 0.0, 5.808711528778076, 6.064574241638184, 5.959862232208252, 8.389079093933105, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.207789897918701, 4.345494270324707, 4.445897579193115, 3.4728057384490967, 3.5247628688812256, 1.2363848686218262, -0.3435775935649872, 0.0, 0.0, 0.0, 3.8850209712982178, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.5422921180725098, 2.84663724899292, 3.382230520248413, 3.225191354751587, 5.743992328643799, 6.303398609161377, 7.129524230957031, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 5.207789897918701, 4.345494270324707, 4.445897579193115, 3.4728057384490967, 3.5247628688812256, 1.2363848686218262, -0.3435775935649872, 0.0, 0.0, 0.0, 3.8850209712982178, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.5422921180725098, 2.84663724899292, 3.382230520248413, 3.225191354751587, 5.743992328643799, 6.303398609161377, 7.129524230957031, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.2016539573669434, 4.193009376525879, 1.4762578010559082, 2.728529214859009, 2.559004306793213, 1.856960654258728, 1.1102142333984375, -1.137222409248352, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.37442144751548767, -0.8107284307479858, 1.4646281003952026, 2.2223246097564697, -0.04650497809052467, 2.592313289642334, 0.0, 0.6557197570800781, 0.43062227964401245, -0.4218379259109497, -2.2747182846069336, 1.6134074926376343, 1.6218717098236084, 0.8686734437942505, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.6236796379089355, 0.747798502445221, 0.0, 2.2994582653045654, 2.806121587753296, 4.998651027679443, 7.342369556427002, 3.6356618404388428, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 2.2016539573669434, 4.193009376525879, 1.4762578010559082, 2.728529214859009, 2.559004306793213, 1.856960654258728, 1.1102142333984375, -1.137222409248352, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.37442144751548767, -0.8107284307479858, 1.4646281003952026, 2.2223246097564697, -0.04650497809052467, 2.592313289642334, 0.0, 0.6557197570800781, 0.43062227964401245, -0.4218379259109497, -2.2747182846069336, 1.6134074926376343, 1.6218717098236084, 0.8686734437942505, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, -1.6236796379089355, 0.747798502445221, 0.0, 2.2994582653045654, 2.806121587753296, 4.998651027679443, 7.342369556427002, 3.6356618404388428, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.7888904809951782, 3.1548209190368652, 3.7380030155181885, 1.0940866470336914, -1.1941688060760498, -1.3420631885528564, 0.27756327390670776, -0.4099487066268921, 0.2661891579627991, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.019729789346456528, 0.8149011731147766, -0.23565241694450378, -1.318489909172058, 0.17204110324382782, -0.10096682608127594, -0.470082551240921, -0.9446950554847717, -0.09696654975414276, -0.15096378326416016, -0.18342870473861694, -0.4345727264881134, 0.13956394791603088, -0.3980393409729004, -0.28937867283821106, 0.24772542715072632, 0.045347198843955994, -0.2557825446128845, 0.45293962955474854, -0.8143489360809326, -0.8790744543075562, 0.0, 0.0, 0.0, 0.0, 0.0, 3.9808456897735596, 2.0826663970947266, 5.961106777191162, 0.0, 0.0, 5.364595413208008, 4.046279430389404, 7.5973005294799805, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.7888904809951782, 3.1548209190368652, 3.7380030155181885, 1.0940866470336914, -1.1941688060760498, -1.3420631885528564, 0.27756327390670776, -0.4099487066268921, 0.2661891579627991, -0.0, -0.0, -0.0, 0.0, -0.0, 0.0, -0.0, -0.0, 0.0, 0.019729789346456528, 0.8149011731147766, -0.23565241694450378, -1.318489909172058, 0.17204110324382782, -0.10096682608127594, -0.470082551240921, -0.9446950554847717, -0.09696654975414276, -0.15096378326416016, -0.18342870473861694, -0.4345727264881134, 0.13956394791603088, -0.3980393409729004, -0.28937867283821106, 0.24772542715072632, 0.045347198843955994, -0.2557825446128845, 0.45293962955474854, -0.8143489360809326, -0.8790744543075562, -0.0, -0.0, -0.0, -0.0, -0.0, 3.9808456897735596, 2.0826663970947266, 5.961106777191162, 0.0, 0.0, 5.364595413208008, 4.046279430389404, 7.5973005294799805, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.485520601272583, 2.2869606018066406, 0.47170087695121765, -0.33465874195098877, 0.0, -1.3903230428695679, 0.0, 0.0, 0.0, 0.0, -0.47058960795402527, 0.0, -0.04557442292571068, 1.0952130556106567, -0.7975869178771973, 0.055945269763469696, -0.6663987040519714, -1.06610906124115, -3.830573558807373, -1.7777128219604492, 1.817873239517212, -0.05935777351260185, -2.346721887588501, -2.370406150817871, -2.1816604137420654, -1.8741395473480225, -0.8853330612182617, -0.31900593638420105, -0.4875068962574005, 0.40339717268943787, 0.29006263613700867, -0.6866274476051331, -0.004741581156849861, 0.4300406575202942, -0.0878656804561615, -0.3246288299560547, -0.5433679223060608, -0.3735313415527344, -0.801455557346344, -0.13517643511295319, -0.3021315932273865, -0.09494467079639435, -0.587300717830658, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.737245559692383, 7.045840263366699, 4.368133068084717, 6.03870964050293, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 2.485520601272583, 2.2869606018066406, 0.47170087695121765, -0.33465874195098877, 0.0, -1.3903230428695679, -0.0, 0.0, -0.0, 0.0, -0.47058960795402527, -0.0, -0.04557442292571068, 1.0952130556106567, -0.7975869178771973, 0.055945269763469696, -0.6663987040519714, -1.06610906124115, -3.830573558807373, -1.7777128219604492, 1.817873239517212, -0.05935777351260185, -2.346721887588501, -2.370406150817871, -2.1816604137420654, -1.8741395473480225, -0.8853330612182617, -0.31900593638420105, -0.4875068962574005, 0.40339717268943787, 0.29006263613700867, -0.6866274476051331, -0.004741581156849861, 0.4300406575202942, -0.0878656804561615, -0.3246288299560547, -0.5433679223060608, -0.3735313415527344, -0.801455557346344, -0.13517643511295319, -0.3021315932273865, -0.09494467079639435, -0.587300717830658, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.737245559692383, 7.045840263366699, 4.368133068084717, 6.03870964050293, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.8076069355010986, 1.4543137550354004, -0.8412666916847229, -2.2068779468536377, -2.525381326675415, -1.3950344324111938, 1.5504573583602905, 0.0, 0.0, 0.0, 0.0, 1.0163662433624268, 1.81133234500885, -1.7364085912704468, -0.6991317868232727, -1.3307013511657715, -2.304636001586914, -1.3497062921524048, -0.6834587454795837, -0.3621799647808075, -1.4349684715270996, -2.711158037185669, -2.8746538162231445, -1.3283979892730713, -1.9800686836242676, -2.327115058898926, -0.1337740272283554, -0.2560577988624573, -0.11557142436504364, 0.008493432775139809, -0.6631624698638916, 0.141466423869133, 0.41312193870544434, -0.2534845471382141, 0.038822174072265625, 0.6701257824897766, -0.1577933430671692, -0.24717766046524048, -0.6331459283828735, -0.5891051292419434, -0.046356432139873505, -0.07045123726129532, -0.02453632839024067, -0.14542581140995026, -0.10425948351621628, 0.427874356508255, -3.2984535694122314, 0.0, 0.0, 0.0, 0.0, 0.0, 6.072262763977051, 6.463554382324219, 4.798412799835205, 5.6350321769714355, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 1.8076069355010986, 1.4543137550354004, -0.8412666916847229, -2.2068779468536377, -2.525381326675415, -1.3950344324111938, 1.5504573583602905, 0.0, 0.0, -0.0, 0.0, 1.0163662433624268, 1.81133234500885, -1.7364085912704468, -0.6991317868232727, -1.3307013511657715, -2.304636001586914, -1.3497062921524048, -0.6834587454795837, -0.3621799647808075, -1.4349684715270996, -2.711158037185669, -2.8746538162231445, -1.3283979892730713, -1.9800686836242676, -2.327115058898926, -0.1337740272283554, -0.2560577988624573, -0.11557142436504364, 0.008493432775139809, -0.6631624698638916, 0.141466423869133, 0.41312193870544434, -0.2534845471382141, 0.038822174072265625, 0.6701257824897766, -0.1577933430671692, -0.24717766046524048, -0.6331459283828735, -0.5891051292419434, -0.046356432139873505, -0.07045123726129532, -0.02453632839024067, -0.14542581140995026, -0.10425948351621628, 0.427874356508255, -3.2984535694122314, -0.0, 0.0, 0.0, 0.0, 0.0, 6.072262763977051, 6.463554382324219, 4.798412799835205, 5.6350321769714355, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.7073779106140137, 0.9648021459579468, 0.12765857577323914, 0.0, 0.12270472943782806, 1.0278420448303223, 0.0, 0.0, 0.0, 0.6860277652740479, 0.0, -4.703965663909912, -2.529522657394409, -1.4477289915084839, -1.4402494430541992, -1.6282212734222412, -1.507546305656433, -0.6458732485771179, -0.8422373533248901, -0.9148892164230347, -0.7453545331954956, -0.3130873143672943, 0.29095423221588135, 0.0, -2.968897819519043, -2.680382013320923, 0.4988071322441101, -0.026056120172142982, -0.0029370798729360104, -0.2948334217071533, -0.07813765108585358, -0.42069727182388306, 0.3701695203781128, -0.27675002813339233, -0.35540255904197693, -0.7063719630241394, -0.8433962464332581, -0.42465728521347046, 0.2047920525074005, 0.3915556073188782, 0.23513302206993103, 0.49229148030281067, 0.3291947841644287, -0.5694523453712463, -0.07981651276350021, -0.6512458324432373, -0.6603886485099792, -0.4283980429172516, 0.0, 0.0, 0.0, 0.0, 0.0, 6.8529486656188965, 0.0, 2.6674206256866455, 4.9217352867126465, 6.994511604309082, 5.510735511779785, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 1.7073779106140137, 0.9648021459579468, 0.12765857577323914, -0.0, 0.12270472943782806, 1.0278420448303223, 0.0, 0.0, 0.0, 0.6860277652740479, -0.0, -4.703965663909912, -2.529522657394409, -1.4477289915084839, -1.4402494430541992, -1.6282212734222412, -1.507546305656433, -0.6458732485771179, -0.8422373533248901, -0.9148892164230347, -0.7453545331954956, -0.3130873143672943, 0.29095423221588135, -0.0, -2.968897819519043, -2.680382013320923, 0.4988071322441101, -0.026056120172142982, -0.0029370798729360104, -0.2948334217071533, -0.07813765108585358, -0.42069727182388306, 0.3701695203781128, -0.27675002813339233, -0.35540255904197693, -0.7063719630241394, -0.8433962464332581, -0.42465728521347046, 0.2047920525074005, 0.3915556073188782, 0.23513302206993103, 0.49229148030281067, 0.3291947841644287, -0.5694523453712463, -0.07981651276350021, -0.6512458324432373, -0.6603886485099792, -0.4283980429172516, -0.0, -0.0, -0.0, 0.0, 0.0, 6.8529486656188965, 0.0, 2.6674206256866455, 4.9217352867126465, 6.994511604309082, 5.510735511779785, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.0587613582611084, -0.08372202515602112, 0.5063244104385376, -3.0440876483917236, 0.0, 0.0, 0.2899893522262573, 0.0, 0.0, 0.0, -1.9684009552001953, -1.6303563117980957, -1.5275366306304932, -2.150308609008789, -1.628085732460022, -1.5717417001724243, -1.7455910444259644, -1.4013214111328125, -1.9497663974761963, -0.5695642828941345, -0.9760052561759949, -1.5901556015014648, -0.9764853715896606, -0.5870422124862671, -0.1943322718143463, -0.21324042975902557, 0.467058926820755, -3.054525375366211, 0.29236507415771484, 0.026873083785176277, -0.16653501987457275, -0.35426732897758484, -0.9052568078041077, 1.3258001804351807, -0.08081835508346558, 0.13122732937335968, 0.26298144459724426, -0.442035436630249, -0.2416618913412094, 0.1654748022556305, 0.5618692636489868, -0.8282734155654907, -0.06082783639431, 0.20734857022762299, 0.29297760128974915, -0.49281778931617737, -0.049123555421829224, 0.20604686439037323, -0.037466034293174744, -0.12371549010276794, -0.414864718914032, -1.1197808980941772, 0.0, 0.0, 0.0, 0.0, 3.4441370964050293, 0.0, 4.853237152099609, 3.8084964752197266, 5.15872859954834, 5.400127410888672, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -2.0587613582611084, -0.08372202515602112, 0.5063244104385376, -3.0440876483917236, 0.0, 0.0, 0.2899893522262573, 0.0, -0.0, -0.0, -1.9684009552001953, -1.6303563117980957, -1.5275366306304932, -2.150308609008789, -1.628085732460022, -1.5717417001724243, -1.7455910444259644, -1.4013214111328125, -1.9497663974761963, -0.5695642828941345, -0.9760052561759949, -1.5901556015014648, -0.9764853715896606, -0.5870422124862671, -0.1943322718143463, -0.21324042975902557, 0.467058926820755, -3.054525375366211, 0.29236507415771484, 0.026873083785176277, -0.16653501987457275, -0.35426732897758484, -0.9052568078041077, 1.3258001804351807, -0.08081835508346558, 0.13122732937335968, 0.26298144459724426, -0.442035436630249, -0.2416618913412094, 0.1654748022556305, 0.5618692636489868, -0.8282734155654907, -0.06082783639431, 0.20734857022762299, 0.29297760128974915, -0.49281778931617737, -0.049123555421829224, 0.20604686439037323, -0.037466034293174744, -0.12371549010276794, -0.414864718914032, -1.1197808980941772, -0.0, 0.0, 0.0, 0.0, 3.4441370964050293, 0.0, 4.853237152099609, 3.8084964752197266, 5.15872859954834, 5.400127410888672, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.4150398075580597, -1.1390103101730347, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.13168203830719, -1.9206962585449219, -1.6064426898956299, -2.0425751209259033, -1.471301555633545, -1.2141177654266357, -1.8372831344604492, -2.0218005180358887, -2.0259711742401123, -1.1559646129608154, -1.2696715593338013, -0.967811644077301, -1.2613787651062012, -0.9374171495437622, -0.7047044038772583, -0.3041675388813019, -0.6839928030967712, 0.003989714663475752, -0.2614687979221344, 0.09358354657888412, -0.03093787096440792, 0.32515209913253784, -0.05933656916022301, 0.14644522964954376, 0.3281043767929077, -0.33940184116363525, -0.6359440684318542, -0.18226347863674164, 0.7889872789382935, 0.3061419725418091, 0.40475913882255554, 0.44136399030685425, 0.7635113000869751, 1.3215346336364746, 0.03137988969683647, 0.6310603618621826, 0.4698144197463989, 0.3081453740596771, 0.013755223713815212, 0.11616258323192596, -0.11111756414175034, -0.19752006232738495, -0.023495836183428764, -0.29981017112731934, 0.201423779129982, 0.0, 0.0, 0.0, 0.0, 4.368965148925781, 0.0, 0.0, 6.398262977600098, 5.328588008880615, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.4150398075580597, -1.1390103101730347, 0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -1.13168203830719, -1.9206962585449219, -1.6064426898956299, -2.0425751209259033, -1.471301555633545, -1.2141177654266357, -1.8372831344604492, -2.0218005180358887, -2.0259711742401123, -1.1559646129608154, -1.2696715593338013, -0.967811644077301, -1.2613787651062012, -0.9374171495437622, -0.7047044038772583, -0.3041675388813019, -0.6839928030967712, 0.003989714663475752, -0.2614687979221344, 0.09358354657888412, -0.03093787096440792, 0.32515209913253784, -0.05933656916022301, 0.14644522964954376, 0.3281043767929077, -0.33940184116363525, -0.6359440684318542, -0.18226347863674164, 0.7889872789382935, 0.3061419725418091, 0.40475913882255554, 0.44136399030685425, 0.7635113000869751, 1.3215346336364746, 0.03137988969683647, 0.6310603618621826, 0.4698144197463989, 0.3081453740596771, 0.013755223713815212, 0.11616258323192596, -0.11111756414175034, -0.19752006232738495, -0.023495836183428764, -0.29981017112731934, 0.201423779129982, 0.0, -0.0, -0.0, 0.0, 4.368965148925781, 0.0, 0.0, 6.398262977600098, 5.328588008880615, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.1663406938314438, -0.17868845164775848, -1.191366195678711, 0.0, -2.485015392303467, 0.0, 0.0, -5.314905643463135, -2.370026111602783, -1.7907676696777344, -1.9878100156784058, -1.994551181793213, -2.1301331520080566, -2.133739948272705, -1.4907150268554688, -1.872402548789978, -1.8388019800186157, -2.046745777130127, -1.511857509613037, -0.5818268060684204, -0.47013306617736816, -1.1651934385299683, -0.4662511348724365, 0.026676541194319725, -0.7882009148597717, 0.09770844131708145, -0.9005270004272461, -0.5786353349685669, -0.04993207007646561, -0.5869676470756531, 0.4957662522792816, -0.3428359031677246, 0.36570268869400024, 0.1694965660572052, 0.41866520047187805, 0.5471735000610352, 0.4064890146255493, -0.12504690885543823, -0.0031652357429265976, 0.5538159608840942, 0.5669710636138916, -0.12721776962280273, 0.22319629788398743, 0.3691047728061676, 0.3870108127593994, 0.31853631138801575, 0.0886080339550972, -0.03128298372030258, -0.03361088037490845, 0.25572699308395386, 0.0459664985537529, -0.030917009338736534, -0.1674003005027771, 0.17018009722232819, 0.41943052411079407, -2.2617440223693848, 0.0, 0.0, 0.0, 0.0, 0.0, 6.050876140594482, 4.088898181915283, 6.019964694976807, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.1663406938314438, -0.17868845164775848, -1.191366195678711, -0.0, -2.485015392303467, -0.0, -0.0, -5.314905643463135, -2.370026111602783, -1.7907676696777344, -1.9878100156784058, -1.994551181793213, -2.1301331520080566, -2.133739948272705, -1.4907150268554688, -1.872402548789978, -1.8388019800186157, -2.046745777130127, -1.511857509613037, -0.5818268060684204, -0.47013306617736816, -1.1651934385299683, -0.4662511348724365, 0.026676541194319725, -0.7882009148597717, 0.09770844131708145, -0.9005270004272461, -0.5786353349685669, -0.04993207007646561, -0.5869676470756531, 0.4957662522792816, -0.3428359031677246, 0.36570268869400024, 0.1694965660572052, 0.41866520047187805, 0.5471735000610352, 0.4064890146255493, -0.12504690885543823, -0.0031652357429265976, 0.5538159608840942, 0.5669710636138916, -0.12721776962280273, 0.22319629788398743, 0.3691047728061676, 0.3870108127593994, 0.31853631138801575, 0.0886080339550972, -0.03128298372030258, -0.03361088037490845, 0.25572699308395386, 0.0459664985537529, -0.030917009338736534, -0.1674003005027771, 0.17018009722232819, 0.41943052411079407, -2.2617440223693848, -0.0, -0.0, 0.0, 0.0, 0.0, 6.050876140594482, 4.088898181915283, 6.019964694976807, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.3137977123260498, -1.3935680389404297, 0.0, 0.0, 1.1168773174285889, 0.0, 0.0, 0.0, -2.0418753623962402, -2.2446253299713135, -2.5675549507141113, -1.9622764587402344, -2.267085552215576, -1.8478434085845947, -1.6689456701278687, -1.9108937978744507, -1.6391608715057373, -1.4107857942581177, -1.0589543581008911, -1.7448080778121948, -0.6166343688964844, -0.8757662773132324, -1.5883357524871826, -0.7581402063369751, 0.023055091500282288, 0.09103978425264359, -0.3563530743122101, 0.14107640087604523, -0.22928863763809204, -0.3996221423149109, -0.536222517490387, -0.09290070086717606, -0.03164676949381828, -0.06695152819156647, 0.23971335589885712, 0.7000359296798706, 0.7411805391311646, 0.8535280227661133, 0.284201055765152, 0.08360201120376587, 0.44590625166893005, 0.6695030331611633, -0.4541005790233612, 1.050676703453064, 0.3663311004638672, 0.40797072649002075, 0.5144257545471191, -0.1801212728023529, 0.08104594051837921, 1.0767043828964233, 0.37390226125717163, 0.3452688157558441, 0.1742021143436432, 0.3967348337173462, 0.031353503465652466, -0.05763200297951698, 0.40242093801498413, -1.6408261060714722, 0.0, 0.0, 0.0, 5.354796409606934, 4.022937774658203, 2.648569345474243, 4.207834720611572, 5.304487705230713, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.3137977123260498, -1.3935680389404297, -0.0, -0.0, 1.1168773174285889, -0.0, -0.0, -0.0, -2.0418753623962402, -2.2446253299713135, -2.5675549507141113, -1.9622764587402344, -2.267085552215576, -1.8478434085845947, -1.6689456701278687, -1.9108937978744507, -1.6391608715057373, -1.4107857942581177, -1.0589543581008911, -1.7448080778121948, -0.6166343688964844, -0.8757662773132324, -1.5883357524871826, -0.7581402063369751, 0.023055091500282288, 0.09103978425264359, -0.3563530743122101, 0.14107640087604523, -0.22928863763809204, -0.3996221423149109, -0.536222517490387, -0.09290070086717606, -0.03164676949381828, -0.06695152819156647, 0.23971335589885712, 0.7000359296798706, 0.7411805391311646, 0.8535280227661133, 0.284201055765152, 0.08360201120376587, 0.44590625166893005, 0.6695030331611633, -0.4541005790233612, 1.050676703453064, 0.3663311004638672, 0.40797072649002075, 0.5144257545471191, -0.1801212728023529, 0.08104594051837921, 1.0767043828964233, 0.37390226125717163, 0.3452688157558441, 0.1742021143436432, 0.3967348337173462, 0.031353503465652466, -0.05763200297951698, 0.40242093801498413, -1.6408261060714722, -0.0, 0.0, 0.0, 5.354796409606934, 4.022937774658203, 2.648569345474243, 4.207834720611572, 5.304487705230713, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.6417862176895142, -1.721023678779602, 0.0, 0.0, 0.6730334758758545, 0.0, 0.0, 0.0, -3.3043718338012695, -2.277703046798706, -2.6071596145629883, -2.9191055297851562, -2.8719143867492676, -2.214938163757324, -2.4374866485595703, -1.9292596578598022, -1.3162301778793335, -1.5577325820922852, -1.3620896339416504, -1.579935073852539, -0.010893510654568672, -0.7540273666381836, -0.6131196022033691, -0.6200246214866638, -0.06163982301950455, -0.7127605080604553, -0.3625606298446655, -0.06920497119426727, -0.42618972063064575, -0.4048149883747101, 0.7813166379928589, 0.5837210416793823, 0.14999137818813324, 0.1912499964237213, -0.11736699938774109, 0.49180206656455994, 0.6948875188827515, -0.14751262962818146, 0.009414320811629295, 0.8528121113777161, 0.7776954770088196, 0.564948320388794, 0.2232835739850998, 0.7402721643447876, 0.7818459272384644, 0.4816792607307434, 0.7919525504112244, 0.5448588132858276, -0.29718640446662903, 0.22999775409698486, 0.7767283916473389, 0.5646184682846069, 0.45846879482269287, 0.41423299908638, 1.01250422000885, -0.3130352199077606, 0.29649874567985535, -0.016850534826517105, 0.42802658677101135, 0.502138614654541, 0.0, 0.0, 0.0, 4.920433044433594, 3.1952242851257324, 0.0, 4.316183090209961, 5.643712997436523, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.6417862176895142, -1.721023678779602, -0.0, -0.0, 0.6730334758758545, -0.0, -0.0, -0.0, -3.3043718338012695, -2.277703046798706, -2.6071596145629883, -2.9191055297851562, -2.8719143867492676, -2.214938163757324, -2.4374866485595703, -1.9292596578598022, -1.3162301778793335, -1.5577325820922852, -1.3620896339416504, -1.579935073852539, -0.010893510654568672, -0.7540273666381836, -0.6131196022033691, -0.6200246214866638, -0.06163982301950455, -0.7127605080604553, -0.3625606298446655, -0.06920497119426727, -0.42618972063064575, -0.4048149883747101, 0.7813166379928589, 0.5837210416793823, 0.14999137818813324, 0.1912499964237213, -0.11736699938774109, 0.49180206656455994, 0.6948875188827515, -0.14751262962818146, 0.009414320811629295, 0.8528121113777161, 0.7776954770088196, 0.564948320388794, 0.2232835739850998, 0.7402721643447876, 0.7818459272384644, 0.4816792607307434, 0.7919525504112244, 0.5448588132858276, -0.29718640446662903, 0.22999775409698486, 0.7767283916473389, 0.5646184682846069, 0.45846879482269287, 0.41423299908638, 1.01250422000885, -0.3130352199077606, 0.29649874567985535, -0.016850534826517105, 0.42802658677101135, 0.502138614654541, 0.0, 0.0, 0.0, 4.920433044433594, 3.1952242851257324, 0.0, 4.316183090209961, 5.643712997436523, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -1.4566853046417236, -1.872035026550293, 0.0, 0.0, -4.309769630432129, 0.0, 0.0, 0.0, -3.2100722789764404, -2.975597858428955, -2.9192984104156494, -3.428563117980957, -2.4966483116149902, -2.6442453861236572, -1.3988020420074463, -2.3046765327453613, -2.3685827255249023, -1.0164554119110107, -1.438869833946228, -1.3135125637054443, -0.8869236707687378, -1.0962648391723633, -1.2385605573654175, -1.0293570756912231, -1.2494235038757324, -0.9542768001556396, -0.862992525100708, -0.392322838306427, -0.5548511147499084, 0.024155719205737114, -0.03032628260552883, 0.48110970854759216, -0.046539951115846634, 0.8069449067115784, 0.3600609004497528, 0.224666565656662, 0.2699827551841736, 0.4511827230453491, 0.02550145424902439, 0.48548293113708496, 0.8148841261863708, 0.14552351832389832, 0.0877641960978508, 0.8908767104148865, 0.5635694861412048, 0.24045951664447784, -0.33024680614471436, 0.6952447891235352, 0.7796753644943237, 0.5631328821182251, 0.7086423635482788, 0.9040622115135193, 0.5551049113273621, -0.0920855849981308, 1.3191313743591309, 0.39811569452285767, 0.056680113077163696, 0.04170076176524162, 0.568757176399231, 0.45344409346580505, 0.7592349648475647, 1.833916187286377, 0.0, 0.0, 0.0, 2.796342611312866, -0.8957425951957703, 3.063955783843994, 5.874622344970703, 4.917026996612549, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.4566853046417236, -1.872035026550293, -0.0, 0.0, -4.309769630432129, -0.0, -0.0, -0.0, -3.2100722789764404, -2.975597858428955, -2.9192984104156494, -3.428563117980957, -2.4966483116149902, -2.6442453861236572, -1.3988020420074463, -2.3046765327453613, -2.3685827255249023, -1.0164554119110107, -1.438869833946228, -1.3135125637054443, -0.8869236707687378, -1.0962648391723633, -1.2385605573654175, -1.0293570756912231, -1.2494235038757324, -0.9542768001556396, -0.862992525100708, -0.392322838306427, -0.5548511147499084, 0.024155719205737114, -0.03032628260552883, 0.48110970854759216, -0.046539951115846634, 0.8069449067115784, 0.3600609004497528, 0.224666565656662, 0.2699827551841736, 0.4511827230453491, 0.02550145424902439, 0.48548293113708496, 0.8148841261863708, 0.14552351832389832, 0.0877641960978508, 0.8908767104148865, 0.5635694861412048, 0.24045951664447784, -0.33024680614471436, 0.6952447891235352, 0.7796753644943237, 0.5631328821182251, 0.7086423635482788, 0.9040622115135193, 0.5551049113273621, -0.0920855849981308, 1.3191313743591309, 0.39811569452285767, 0.056680113077163696, 0.04170076176524162, 0.568757176399231, 0.45344409346580505, 0.7592349648475647, 1.833916187286377, 0.0, 0.0, 0.0, 2.796342611312866, -0.8957425951957703, 3.063955783843994, 5.874622344970703, 4.917026996612549, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -2.629166841506958, -2.6132752895355225, -2.8026986122131348, 0.0, 2.9952821731567383, 0.0, 0.0, 0.0, -3.25850510597229, -3.764652967453003, -3.617532730102539, -3.339773654937744, -2.957181930541992, -2.9183881282806396, -2.8425800800323486, -2.019930362701416, -2.5277955532073975, -1.8015764951705933, -1.3106800317764282, -1.3324337005615234, -1.488681674003601, -1.6089688539505005, -1.2633020877838135, -0.8075238466262817, -0.5972049236297607, 0.025557272136211395, 0.06510359048843384, -0.1376643031835556, -1.431028962135315, -0.47179892659187317, 0.1836947202682495, 0.21121880412101746, 0.285702645778656, 0.0843890905380249, -0.13194356858730316, 0.2833751142024994, 0.7088560461997986, 0.26745912432670593, 0.46390974521636963, 1.1301212310791016, 0.15589921176433563, 0.2803310453891754, 0.32597118616104126, 0.7353342175483704, 0.5552062392234802, 1.026163935661316, 1.1438220739364624, 0.5040080547332764, 0.8903003931045532, 0.3140115737915039, 0.4467269778251648, -0.4416601359844208, 1.8512532711029053, 1.3639968633651733, 0.507543683052063, -0.036928653717041016, 0.5847684144973755, 0.2842860817909241, 0.43838948011398315, -0.021031441166996956, -0.04875222593545914, 0.21312841773033142, 0.696825385093689, -0.6974411606788635, 0.0, 0.0, 0.0, 1.6690117120742798, 2.670114040374756, 1.2592884302139282, 4.50791072845459, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -2.629166841506958, -2.6132752895355225, -2.8026986122131348, 0.0, 2.9952821731567383, 0.0, -0.0, -0.0, -3.25850510597229, -3.764652967453003, -3.617532730102539, -3.339773654937744, -2.957181930541992, -2.9183881282806396, -2.8425800800323486, -2.019930362701416, -2.5277955532073975, -1.8015764951705933, -1.3106800317764282, -1.3324337005615234, -1.488681674003601, -1.6089688539505005, -1.2633020877838135, -0.8075238466262817, -0.5972049236297607, 0.025557272136211395, 0.06510359048843384, -0.1376643031835556, -1.431028962135315, -0.47179892659187317, 0.1836947202682495, 0.21121880412101746, 0.285702645778656, 0.0843890905380249, -0.13194356858730316, 0.2833751142024994, 0.7088560461997986, 0.26745912432670593, 0.46390974521636963, 1.1301212310791016, 0.15589921176433563, 0.2803310453891754, 0.32597118616104126, 0.7353342175483704, 0.5552062392234802, 1.026163935661316, 1.1438220739364624, 0.5040080547332764, 0.8903003931045532, 0.3140115737915039, 0.4467269778251648, -0.4416601359844208, 1.8512532711029053, 1.3639968633651733, 0.507543683052063, -0.036928653717041016, 0.5847684144973755, 0.2842860817909241, 0.43838948011398315, -0.021031441166996956, -0.04875222593545914, 0.21312841773033142, 0.696825385093689, -0.6974411606788635, -0.0, 0.0, 0.0, 1.6690117120742798, 2.670114040374756, 1.2592884302139282, 4.50791072845459, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -1.5588736534118652, 0.0, 1.9936920404434204, -1.135417103767395, 0.7301572561264038, 0.0, 0.0, -2.7510132789611816, -3.6526501178741455, -4.1035943031311035, -2.4640212059020996, -3.239748954772949, -2.7181005477905273, -2.419049024581909, -3.1116368770599365, -2.7126474380493164, -2.473461627960205, -2.0453624725341797, -1.3015137910842896, -1.8218847513198853, -1.1084496974945068, -1.1292293071746826, -0.2709347903728485, -1.0855761766433716, -0.5369985103607178, -1.3107925653457642, 0.686225175857544, -0.9132357835769653, -0.6617765426635742, 0.10290840268135071, 0.26198455691337585, 0.4524933993816376, -1.2222882509231567, 0.15602585673332214, -0.7537473440170288, 0.24856659770011902, 0.31669217348098755, -0.014767851680517197, 0.13694047927856445, -0.05601964145898819, 0.2799793779850006, 1.0939983129501343, 0.41449466347694397, 0.3142157793045044, 1.3457928895950317, 0.8142387270927429, 0.7326564788818359, 0.13676248490810394, 0.8957042694091797, 0.4371384084224701, 0.5530863404273987, 1.265431523323059, 0.4243837296962738, 0.3897126019001007, 1.4512583017349243, 1.0188425779342651, 0.4762561023235321, 0.7956032156944275, 0.5281385183334351, 0.6029562950134277, 0.4100244641304016, 0.16548575460910797, 0.22755247354507446, 0.6339383721351624, 1.7824519872665405, 0.0, 0.0, 4.917967319488525, 0.12672343850135803, 2.924196243286133, 4.707303524017334, 6.219947814941406, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -1.5588736534118652, -0.0, 1.9936920404434204, -1.135417103767395, 0.7301572561264038, 0.0, -0.0, -2.7510132789611816, -3.6526501178741455, -4.1035943031311035, -2.4640212059020996, -3.239748954772949, -2.7181005477905273, -2.419049024581909, -3.1116368770599365, -2.7126474380493164, -2.473461627960205, -2.0453624725341797, -1.3015137910842896, -1.8218847513198853, -1.1084496974945068, -1.1292293071746826, -0.2709347903728485, -1.0855761766433716, -0.5369985103607178, -1.3107925653457642, 0.686225175857544, -0.9132357835769653, -0.6617765426635742, 0.10290840268135071, 0.26198455691337585, 0.4524933993816376, -1.2222882509231567, 0.15602585673332214, -0.7537473440170288, 0.24856659770011902, 0.31669217348098755, -0.014767851680517197, 0.13694047927856445, -0.05601964145898819, 0.2799793779850006, 1.0939983129501343, 0.41449466347694397, 0.3142157793045044, 1.3457928895950317, 0.8142387270927429, 0.7326564788818359, 0.13676248490810394, 0.8957042694091797, 0.4371384084224701, 0.5530863404273987, 1.265431523323059, 0.4243837296962738, 0.3897126019001007, 1.4512583017349243, 1.0188425779342651, 0.4762561023235321, 0.7956032156944275, 0.5281385183334351, 0.6029562950134277, 0.4100244641304016, 0.16548575460910797, 0.22755247354507446, 0.6339383721351624, 1.7824519872665405, 0.0, 0.0, 4.917967319488525, 0.12672343850135803, 2.924196243286133, 4.707303524017334, 6.219947814941406, 0.0, 0.0], [0.0, 0.0, 0.0, -2.0704216957092285, -3.6015589237213135, 0.0, -1.1981327533721924, 0.0, 0.0, 0.0, -3.2893388271331787, -3.5336339473724365, -4.0787811279296875, -3.673678159713745, -3.622558355331421, -3.3021318912506104, -3.559786319732666, -2.7746963500976562, -2.2500839233398438, -2.238870859146118, -1.4884933233261108, -2.030949115753174, -1.5443593263626099, -1.5945502519607544, -0.9195899963378906, -0.3496360778808594, -1.6806960105895996, -1.3610059022903442, -0.7152163982391357, -0.4227416515350342, -0.8819925785064697, -0.2760469615459442, -0.6152509450912476, -0.0777997300028801, -0.08771859109401703, 0.6055422425270081, 0.06018570438027382, 0.22596988081932068, -0.029025323688983917, 0.4142936170101166, 0.1528729796409607, 0.5056611895561218, 0.5692713856697083, -0.4215715825557709, 0.2132490575313568, 0.6146295070648193, 0.836869478225708, 0.6152215003967285, 0.10505091398954391, 0.4897705912590027, 0.7751001119613647, 1.124507188796997, 0.4849502742290497, 0.20757783949375153, 0.7259575724601746, -0.04439414292573929, -0.3057357370853424, 0.621539294719696, 0.19397632777690887, -0.01711047627031803, 0.11503881961107254, 0.4141955077648163, -0.2679195702075958, 1.3255549669265747, 0.399970144033432, 0.8816068172454834, 0.829269528388977, 0.7549967169761658, 0.8615531921386719, 1.1560871601104736, 0.0, 0.0, -2.4038147926330566, 2.1092419624328613, 4.103017330169678, 6.488832473754883, 7.053334712982178, 0.0, 0.0, 0.0, -0.0, -2.0704216957092285, -3.6015589237213135, -0.0, -1.1981327533721924, 0.0, 0.0, -0.0, -3.2893388271331787, -3.5336339473724365, -4.0787811279296875, -3.673678159713745, -3.622558355331421, -3.3021318912506104, -3.559786319732666, -2.7746963500976562, -2.2500839233398438, -2.238870859146118, -1.4884933233261108, -2.030949115753174, -1.5443593263626099, -1.5945502519607544, -0.9195899963378906, -0.3496360778808594, -1.6806960105895996, -1.3610059022903442, -0.7152163982391357, -0.4227416515350342, -0.8819925785064697, -0.2760469615459442, -0.6152509450912476, -0.0777997300028801, -0.08771859109401703, 0.6055422425270081, 0.06018570438027382, 0.22596988081932068, -0.029025323688983917, 0.4142936170101166, 0.1528729796409607, 0.5056611895561218, 0.5692713856697083, -0.4215715825557709, 0.2132490575313568, 0.6146295070648193, 0.836869478225708, 0.6152215003967285, 0.10505091398954391, 0.4897705912590027, 0.7751001119613647, 1.124507188796997, 0.4849502742290497, 0.20757783949375153, 0.7259575724601746, -0.04439414292573929, -0.3057357370853424, 0.621539294719696, 0.19397632777690887, -0.01711047627031803, 0.11503881961107254, 0.4141955077648163, -0.2679195702075958, 1.3255549669265747, 0.399970144033432, 0.8816068172454834, 0.829269528388977, 0.7549967169761658, 0.8615531921386719, 1.1560871601104736, 0.0, 0.0, -2.4038147926330566, 2.1092419624328613, 4.103017330169678, 6.488832473754883, 7.053334712982178, 0.0], [0.0, 0.0, 0.793434202671051, -1.6844509840011597, -0.03644409403204918, -1.3197917938232422, -3.696676015853882, 0.0, 0.0, 0.0, -3.7758543491363525, -5.045042991638184, -4.372939109802246, -4.203299522399902, -3.320007085800171, -3.8022067546844482, -3.0280964374542236, -3.1834657192230225, -2.2219557762145996, -2.895359992980957, -2.2037415504455566, -1.715286135673523, -2.5763750076293945, -1.216689109802246, -1.1843583583831787, -0.35071006417274475, 0.5328584909439087, -1.2555731534957886, -1.7624119520187378, -0.5252464413642883, -0.8379267454147339, -0.46495354175567627, -0.26462966203689575, 0.029165146872401237, 0.8773916363716125, 0.9138503074645996, -0.06946893036365509, 0.4286052882671356, 0.13027489185333252, 0.5608558654785156, 0.5961517691612244, 0.23012198507785797, 0.9493410587310791, 0.024860316887497902, 0.3417024314403534, 1.3625195026397705, 0.6480535864830017, 1.7321361303329468, 0.510942280292511, 1.2878562211990356, 1.3568689823150635, 1.6400110721588135, 0.8458053469657898, 1.200336217880249, 0.8912235498428345, 1.0376224517822266, 0.1871105581521988, 1.3146295547485352, 0.9811132550239563, 0.4831947088241577, 0.4110112190246582, -0.35512417554855347, 0.6163511872291565, -0.23856130242347717, 0.8290783762931824, 0.5626481175422668, 0.09170328080654144, 1.3536502122879028, 0.49708840250968933, 1.562969446182251, 0.0, 0.0, 0.0, 4.881162166595459, 6.038568019866943, 6.162007808685303, 5.9723896980285645, 0.0, -0.0, 0.0, 0.793434202671051, -1.6844509840011597, -0.03644409403204918, -1.3197917938232422, -3.696676015853882, -0.0, -0.0, -0.0, -3.7758543491363525, -5.045042991638184, -4.372939109802246, -4.203299522399902, -3.320007085800171, -3.8022067546844482, -3.0280964374542236, -3.1834657192230225, -2.2219557762145996, -2.895359992980957, -2.2037415504455566, -1.715286135673523, -2.5763750076293945, -1.216689109802246, -1.1843583583831787, -0.35071006417274475, 0.5328584909439087, -1.2555731534957886, -1.7624119520187378, -0.5252464413642883, -0.8379267454147339, -0.46495354175567627, -0.26462966203689575, 0.029165146872401237, 0.8773916363716125, 0.9138503074645996, -0.06946893036365509, 0.4286052882671356, 0.13027489185333252, 0.5608558654785156, 0.5961517691612244, 0.23012198507785797, 0.9493410587310791, 0.024860316887497902, 0.3417024314403534, 1.3625195026397705, 0.6480535864830017, 1.7321361303329468, 0.510942280292511, 1.2878562211990356, 1.3568689823150635, 1.6400110721588135, 0.8458053469657898, 1.200336217880249, 0.8912235498428345, 1.0376224517822266, 0.1871105581521988, 1.3146295547485352, 0.9811132550239563, 0.4831947088241577, 0.4110112190246582, -0.35512417554855347, 0.6163511872291565, -0.23856130242347717, 0.8290783762931824, 0.5626481175422668, 0.09170328080654144, 1.3536502122879028, 0.49708840250968933, 1.562969446182251, 0.0, -0.0, -0.0, 4.881162166595459, 6.038568019866943, 6.162007808685303, 5.9723896980285645, 0.0], [0.0, -4.0052103996276855, 0.4073042571544647, 2.5730700492858887, 0.0, -2.6595332622528076, 0.0, 0.0, 0.0, -4.584079265594482, -4.2804741859436035, -4.774026393890381, -4.141788959503174, -4.291504859924316, -3.875033140182495, -3.8516955375671387, -3.42702317237854, -3.088718891143799, -2.0921030044555664, -2.807060956954956, -1.697245717048645, -1.8267332315444946, -1.1285359859466553, -1.5831304788589478, -0.24973805248737335, -1.1849701404571533, -2.0549659729003906, -0.5374245643615723, -0.30788376927375793, -0.874546229839325, -0.7796605825424194, -0.4460256099700928, -0.15778616070747375, 0.2808351516723633, -0.14882904291152954, -0.6108899116516113, -0.061031997203826904, 0.2213839292526245, -0.050779905170202255, 0.04724191129207611, 1.6270943880081177, -0.024365590885281563, 1.1707277297973633, 0.8275030851364136, 0.3946209251880646, 0.9572815299034119, 0.7058180570602417, 1.189378023147583, 0.4222955107688904, 1.541916012763977, 1.2380136251449585, 1.1161593198776245, 1.1393526792526245, 0.7806283235549927, 0.34829384088516235, 1.043299913406372, 1.0760148763656616, 1.1206395626068115, 0.8204171657562256, 0.8528518080711365, 0.4872935116291046, 0.5119457840919495, 0.8805686235427856, 0.3120483458042145, 0.3542645573616028, 0.5414068698883057, 0.47364872694015503, 0.6329686641693115, 0.7422546148300171, 0.7505574822425842, 0.2749900221824646, 0.0, 0.0, 6.09029483795166, 0.0, 3.391540288925171, 5.8412933349609375, 7.534725189208984, -0.0, -4.0052103996276855, 0.4073042571544647, 2.5730700492858887, -0.0, -2.6595332622528076, -0.0, -0.0, -0.0, -4.584079265594482, -4.2804741859436035, -4.774026393890381, -4.141788959503174, -4.291504859924316, -3.875033140182495, -3.8516955375671387, -3.42702317237854, -3.088718891143799, -2.0921030044555664, -2.807060956954956, -1.697245717048645, -1.8267332315444946, -1.1285359859466553, -1.5831304788589478, -0.24973805248737335, -1.1849701404571533, -2.0549659729003906, -0.5374245643615723, -0.30788376927375793, -0.874546229839325, -0.7796605825424194, -0.4460256099700928, -0.15778616070747375, 0.2808351516723633, -0.14882904291152954, -0.6108899116516113, -0.061031997203826904, 0.2213839292526245, -0.050779905170202255, 0.04724191129207611, 1.6270943880081177, -0.024365590885281563, 1.1707277297973633, 0.8275030851364136, 0.3946209251880646, 0.9572815299034119, 0.7058180570602417, 1.189378023147583, 0.4222955107688904, 1.541916012763977, 1.2380136251449585, 1.1161593198776245, 1.1393526792526245, 0.7806283235549927, 0.34829384088516235, 1.043299913406372, 1.0760148763656616, 1.1206395626068115, 0.8204171657562256, 0.8528518080711365, 0.4872935116291046, 0.5119457840919495, 0.8805686235427856, 0.3120483458042145, 0.3542645573616028, 0.5414068698883057, 0.47364872694015503, 0.6329686641693115, 0.7422546148300171, 0.7505574822425842, 0.2749900221824646, 0.0, 0.0, 6.09029483795166, 0.0, 3.391540288925171, 5.8412933349609375, 7.534725189208984], [0.0, -1.395026683807373, -2.558464765548706, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.18557071685791, -5.085760116577148, -4.538525581359863, -4.601037979125977, -4.189718246459961, -4.079071998596191, -2.9248294830322266, -3.0475354194641113, -3.3912203311920166, -1.743071436882019, -1.9608672857284546, -1.4206386804580688, -2.485189199447632, -1.1337254047393799, -1.2978265285491943, -1.5288740396499634, -0.8926642537117004, -1.5158501863479614, -1.412034273147583, -1.6897889375686646, -0.8948830962181091, -0.5438985228538513, -1.0134512186050415, -0.15425057709217072, -0.6446776390075684, 0.46153101325035095, -0.4961349666118622, 0.4889867901802063, -0.46707338094711304, 0.900151252746582, 0.8021131753921509, 0.4333065450191498, 0.6540824770927429, 0.33807358145713806, 0.7966713905334473, 0.9444330334663391, 0.5627299547195435, 0.6713771820068359, -0.013633391819894314, 1.3018242120742798, 1.885852336883545, 0.638816237449646, 0.6218031644821167, 0.6993230581283569, 1.3932090997695923, 2.5241708755493164, -0.5620279908180237, 1.1160622835159302, 1.268742322921753, 1.4582736492156982, 0.5804305076599121, 0.9313908815383911, 1.368891716003418, 0.4983648359775543, 0.8847342133522034, 1.1299307346343994, 0.6513537168502808, 1.175774335861206, 1.235203504562378, 0.8640123605728149, 1.0319069623947144, 1.382977843284607, -0.011184402741491795, 0.0, 0.0, 0.0, 0.0, 6.352049827575684, 8.61476993560791, -0.0, -1.395026683807373, -2.558464765548706, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.18557071685791, -5.085760116577148, -4.538525581359863, -4.601037979125977, -4.189718246459961, -4.079071998596191, -2.9248294830322266, -3.0475354194641113, -3.3912203311920166, -1.743071436882019, -1.9608672857284546, -1.4206386804580688, -2.485189199447632, -1.1337254047393799, -1.2978265285491943, -1.5288740396499634, -0.8926642537117004, -1.5158501863479614, -1.412034273147583, -1.6897889375686646, -0.8948830962181091, -0.5438985228538513, -1.0134512186050415, -0.15425057709217072, -0.6446776390075684, 0.46153101325035095, -0.4961349666118622, 0.4889867901802063, -0.46707338094711304, 0.900151252746582, 0.8021131753921509, 0.4333065450191498, 0.6540824770927429, 0.33807358145713806, 0.7966713905334473, 0.9444330334663391, 0.5627299547195435, 0.6713771820068359, -0.013633391819894314, 1.3018242120742798, 1.885852336883545, 0.638816237449646, 0.6218031644821167, 0.6993230581283569, 1.3932090997695923, 2.5241708755493164, -0.5620279908180237, 1.1160622835159302, 1.268742322921753, 1.4582736492156982, 0.5804305076599121, 0.9313908815383911, 1.368891716003418, 0.4983648359775543, 0.8847342133522034, 1.1299307346343994, 0.6513537168502808, 1.175774335861206, 1.235203504562378, 0.8640123605728149, 1.0319069623947144, 1.382977843284607, -0.011184402741491795, -0.0, 0.0, 0.0, 0.0, 6.352049827575684, 8.61476993560791], [-6.159733772277832, -3.2031521797180176, -4.715553283691406, 0.0, 0.0, 0.0, 0.0, 0.0, -5.706653594970703, -4.9789509773254395, -4.730910778045654, -4.789371013641357, -4.55961275100708, -3.886519193649292, -3.383741855621338, -3.5815582275390625, -3.3449759483337402, -3.156369209289551, -3.350721836090088, -2.3064441680908203, -1.7422828674316406, -1.5094828605651855, -1.9169574975967407, -0.863889753818512, -0.2782665193080902, -2.5732102394104004, -1.058968424797058, -0.7073736786842346, -0.9905298948287964, -0.457303524017334, -0.7024847865104675, -0.3433127701282501, 0.07662051171064377, 0.5057336688041687, 0.7018408179283142, 0.9920340776443481, 0.8450450301170349, 0.866230309009552, 0.8355172872543335, 0.4882570207118988, 0.115901879966259, 0.40191954374313354, 0.402986615896225, 0.5528126955032349, 1.152305245399475, 0.5655689835548401, 0.9008888006210327, 1.3231271505355835, 2.475966453552246, 1.1891968250274658, 1.0437731742858887, 0.7302817702293396, 0.019894829019904137, 1.564264178276062, 2.018716812133789, 1.1672766208648682, 1.322774887084961, 0.9488712549209595, 0.7786235809326172, 0.4510582685470581, 0.39953842759132385, -0.39942294359207153, 1.3853930234909058, 1.2282769680023193, 0.1099814921617508, 1.4693410396575928, 1.2842028141021729, 0.48798868060112, 0.6103599071502686, 1.230819582939148, 1.1622809171676636, 2.02984619140625, 0.0, 0.0, 0.47082993388175964, 0.0, 0.0, 8.075897216796875, -6.159733772277832, -3.2031521797180176, -4.715553283691406, -0.0, -0.0, -0.0, -0.0, -0.0, -5.706653594970703, -4.9789509773254395, -4.730910778045654, -4.789371013641357, -4.55961275100708, -3.886519193649292, -3.383741855621338, -3.5815582275390625, -3.3449759483337402, -3.156369209289551, -3.350721836090088, -2.3064441680908203, -1.7422828674316406, -1.5094828605651855, -1.9169574975967407, -0.863889753818512, -0.2782665193080902, -2.5732102394104004, -1.058968424797058, -0.7073736786842346, -0.9905298948287964, -0.457303524017334, -0.7024847865104675, -0.3433127701282501, 0.07662051171064377, 0.5057336688041687, 0.7018408179283142, 0.9920340776443481, 0.8450450301170349, 0.866230309009552, 0.8355172872543335, 0.4882570207118988, 0.115901879966259, 0.40191954374313354, 0.402986615896225, 0.5528126955032349, 1.152305245399475, 0.5655689835548401, 0.9008888006210327, 1.3231271505355835, 2.475966453552246, 1.1891968250274658, 1.0437731742858887, 0.7302817702293396, 0.019894829019904137, 1.564264178276062, 2.018716812133789, 1.1672766208648682, 1.322774887084961, 0.9488712549209595, 0.7786235809326172, 0.4510582685470581, 0.39953842759132385, -0.39942294359207153, 1.3853930234909058, 1.2282769680023193, 0.1099814921617508, 1.4693410396575928, 1.2842028141021729, 0.48798868060112, 0.6103599071502686, 1.230819582939148, 1.1622809171676636, 2.02984619140625, 0.0, 0.0, 0.47082993388175964, 0.0, 0.0, 8.075897216796875], [-2.3827009201049805, -3.1248281002044678, -4.696011066436768, 0.0, 0.0, 0.0, 0.0, -5.035196781158447, -5.363424777984619, -5.2118635177612305, -5.146111011505127, -4.978015899658203, -4.510735511779785, -4.332491874694824, -3.037475824356079, -3.4258615970611572, -2.855228900909424, -2.443099021911621, -3.0697569847106934, -1.8172117471694946, -2.17864990234375, -1.5129231214523315, -1.3109102249145508, -0.7747536897659302, -1.4379602670669556, -0.784927248954773, -1.0081865787506104, -0.2070780247449875, -0.5684465169906616, 0.14848825335502625, -0.6470614671707153, -0.07349139451980591, 0.1018698439002037, -0.03396429121494293, -0.06614897400140762, 1.0879919528961182, 0.19196757674217224, -0.2357858419418335, 0.7327722311019897, 0.8185983300209045, 0.49752140045166016, 0.3070944845676422, 0.8249249458312988, 0.8013176918029785, 1.05722975730896, 0.7213088274002075, 0.11849003285169601, 1.5382752418518066, 0.7853075265884399, 1.0949788093566895, 0.8888289928436279, 1.5852923393249512, 1.0211557149887085, 1.8657653331756592, 0.7743908166885376, 0.9308300018310547, 0.37882253527641296, 0.720642626285553, 1.5232664346694946, 1.2080938816070557, 1.490900993347168, 0.37667447328567505, 0.031504180282354355, 0.9072986841201782, 0.7678589224815369, 1.210430383682251, 0.8070265650749207, 0.3888114392757416, 0.9208680987358093, 1.7292970418930054, 1.1843582391738892, 0.9119628667831421, 0.0, 0.0, 0.23740267753601074, 0.0, 0.0, 0.0, -2.3827009201049805, -3.1248281002044678, -4.696011066436768, -0.0, -0.0, -0.0, -0.0, -5.035196781158447, -5.363424777984619, -5.2118635177612305, -5.146111011505127, -4.978015899658203, -4.510735511779785, -4.332491874694824, -3.037475824356079, -3.4258615970611572, -2.855228900909424, -2.443099021911621, -3.0697569847106934, -1.8172117471694946, -2.17864990234375, -1.5129231214523315, -1.3109102249145508, -0.7747536897659302, -1.4379602670669556, -0.784927248954773, -1.0081865787506104, -0.2070780247449875, -0.5684465169906616, 0.14848825335502625, -0.6470614671707153, -0.07349139451980591, 0.1018698439002037, -0.03396429121494293, -0.06614897400140762, 1.0879919528961182, 0.19196757674217224, -0.2357858419418335, 0.7327722311019897, 0.8185983300209045, 0.49752140045166016, 0.3070944845676422, 0.8249249458312988, 0.8013176918029785, 1.05722975730896, 0.7213088274002075, 0.11849003285169601, 1.5382752418518066, 0.7853075265884399, 1.0949788093566895, 0.8888289928436279, 1.5852923393249512, 1.0211557149887085, 1.8657653331756592, 0.7743908166885376, 0.9308300018310547, 0.37882253527641296, 0.720642626285553, 1.5232664346694946, 1.2080938816070557, 1.490900993347168, 0.37667447328567505, 0.031504180282354355, 0.9072986841201782, 0.7678589224815369, 1.210430383682251, 0.8070265650749207, 0.3888114392757416, 0.9208680987358093, 1.7292970418930054, 1.1843582391738892, 0.9119628667831421, 0.0, 0.0, 0.23740267753601074, 0.0, 0.0, 0.0], [-1.5322191715240479, -3.856076717376709, 0.0, 0.0, 0.0, 0.0, 0.0, -6.053097248077393, -5.166969299316406, -4.197805404663086, -4.456407070159912, -4.914431095123291, -5.112851619720459, -4.2334513664245605, -3.937692403793335, -3.565979480743408, -4.128570079803467, -2.563131332397461, -2.9595115184783936, -1.5470203161239624, -2.323336362838745, -1.8171625137329102, -1.375555396080017, -0.4479408264160156, -0.616033673286438, -0.05143464356660843, -0.4372791647911072, -0.7120141386985779, -0.3468717336654663, -1.6338223218917847, -0.29411548376083374, -0.17543014883995056, -0.37265902757644653, 0.38775739073753357, -0.3270135819911957, 0.4226735532283783, 0.5035948157310486, 0.2292613387107849, 0.29883691668510437, 1.6758846044540405, 1.1384066343307495, 0.5315483808517456, 0.41440683603286743, 0.523379921913147, 0.6385024785995483, 1.0511510372161865, 1.1411560773849487, 1.1780802011489868, 1.2649071216583252, 0.9837999939918518, 0.351065993309021, 1.0878981351852417, 1.8851487636566162, 2.049473285675049, 1.0567710399627686, -1.7772064208984375, 1.3103601932525635, 2.104768753051758, 0.7972118258476257, 1.5318772792816162, 0.18017692863941193, 1.36519193649292, -0.26010507345199585, 1.018004059791565, 1.3114906549453735, 1.5061513185501099, 0.2976517975330353, 1.464777946472168, 0.7254932522773743, 1.1483652591705322, 1.7471503019332886, 1.0079904794692993, 0.0, 0.0, 0.0, 0.45263350009918213, 0.0, 0.0, -1.5322191715240479, -3.856076717376709, -0.0, -0.0, -0.0, -0.0, -0.0, -6.053097248077393, -5.166969299316406, -4.197805404663086, -4.456407070159912, -4.914431095123291, -5.112851619720459, -4.2334513664245605, -3.937692403793335, -3.565979480743408, -4.128570079803467, -2.563131332397461, -2.9595115184783936, -1.5470203161239624, -2.323336362838745, -1.8171625137329102, -1.375555396080017, -0.4479408264160156, -0.616033673286438, -0.05143464356660843, -0.4372791647911072, -0.7120141386985779, -0.3468717336654663, -1.6338223218917847, -0.29411548376083374, -0.17543014883995056, -0.37265902757644653, 0.38775739073753357, -0.3270135819911957, 0.4226735532283783, 0.5035948157310486, 0.2292613387107849, 0.29883691668510437, 1.6758846044540405, 1.1384066343307495, 0.5315483808517456, 0.41440683603286743, 0.523379921913147, 0.6385024785995483, 1.0511510372161865, 1.1411560773849487, 1.1780802011489868, 1.2649071216583252, 0.9837999939918518, 0.351065993309021, 1.0878981351852417, 1.8851487636566162, 2.049473285675049, 1.0567710399627686, -1.7772064208984375, 1.3103601932525635, 2.104768753051758, 0.7972118258476257, 1.5318772792816162, 0.18017692863941193, 1.36519193649292, -0.26010507345199585, 1.018004059791565, 1.3114906549453735, 1.5061513185501099, 0.2976517975330353, 1.464777946472168, 0.7254932522773743, 1.1483652591705322, 1.7471503019332886, 1.0079904794692993, 0.0, 0.0, 0.0, 0.45263350009918213, 0.0, 0.0], [0.030708296224474907, 0.0, 0.0, 0.0, 0.0, 0.0, -5.438551425933838, -6.48938512802124, -5.2329630851745605, -2.0315980911254883, -4.1069488525390625, -4.530811786651611, -4.291821002960205, -3.795062780380249, -2.663806200027466, -3.4623446464538574, -3.3449246883392334, -2.7508325576782227, -2.373300790786743, -2.3584518432617188, 0.6397104263305664, -0.9052366614341736, -0.38346102833747864, -0.17100735008716583, -0.8457985520362854, -1.0100369453430176, -0.8612726926803589, -0.7052209377288818, -0.7114588618278503, 0.2514142692089081, -0.5948852896690369, 0.5464169979095459, -0.04000205546617508, 0.4239412546157837, 0.2708888053894043, 0.4598347544670105, 0.45705288648605347, 0.500005841255188, 1.0963975191116333, 1.2007725238800049, 1.0856887102127075, 0.18035629391670227, 0.09633217751979828, 1.0445754528045654, 1.4146156311035156, 0.6214704513549805, 0.755793571472168, 1.892640233039856, 0.9696078300476074, 1.749559998512268, 1.1329541206359863, 0.07546635717153549, 1.307624101638794, 2.1039724349975586, 1.3671903610229492, 0.6883164048194885, 0.6571022272109985, 0.34212782979011536, 0.5014710426330566, 1.1566762924194336, 0.4576789438724518, 0.46484479308128357, -0.18247966468334198, 1.3417292833328247, 0.9217899441719055, 1.495100975036621, 1.9817633628845215, 0.5174144506454468, 1.1103638410568237, 0.8348113298416138, 1.2050992250442505, 1.673134446144104, 1.452236533164978, 0.0, 0.0, 0.09239141643047333, 0.0, 0.0, 0.030708296224474907, -0.0, -0.0, -0.0, -0.0, -0.0, -5.438551425933838, -6.48938512802124, -5.2329630851745605, -2.0315980911254883, -4.1069488525390625, -4.530811786651611, -4.291821002960205, -3.795062780380249, -2.663806200027466, -3.4623446464538574, -3.3449246883392334, -2.7508325576782227, -2.373300790786743, -2.3584518432617188, 0.6397104263305664, -0.9052366614341736, -0.38346102833747864, -0.17100735008716583, -0.8457985520362854, -1.0100369453430176, -0.8612726926803589, -0.7052209377288818, -0.7114588618278503, 0.2514142692089081, -0.5948852896690369, 0.5464169979095459, -0.04000205546617508, 0.4239412546157837, 0.2708888053894043, 0.4598347544670105, 0.45705288648605347, 0.500005841255188, 1.0963975191116333, 1.2007725238800049, 1.0856887102127075, 0.18035629391670227, 0.09633217751979828, 1.0445754528045654, 1.4146156311035156, 0.6214704513549805, 0.755793571472168, 1.892640233039856, 0.9696078300476074, 1.749559998512268, 1.1329541206359863, 0.07546635717153549, 1.307624101638794, 2.1039724349975586, 1.3671903610229492, 0.6883164048194885, 0.6571022272109985, 0.34212782979011536, 0.5014710426330566, 1.1566762924194336, 0.4576789438724518, 0.46484479308128357, -0.18247966468334198, 1.3417292833328247, 0.9217899441719055, 1.495100975036621, 1.9817633628845215, 0.5174144506454468, 1.1103638410568237, 0.8348113298416138, 1.2050992250442505, 1.673134446144104, 1.452236533164978, 0.0, 0.0, 0.09239141643047333, 0.0, 0.0], [-4.082250595092773, 0.0, 0.0, 0.0, 0.0, -5.0305986404418945, -6.524361610412598, -5.955978870391846, -6.088446617126465, -5.224411964416504, -4.461483001708984, -4.730050086975098, -4.2968268394470215, -4.101224899291992, -3.4515182971954346, -3.0190823078155518, -3.46628475189209, -2.4332504272460938, -2.4995508193969727, -2.5187504291534424, -1.773091435432434, -1.3324030637741089, -1.61981999874115, -0.4854489862918854, -1.0987197160720825, -1.354956865310669, -0.9094396829605103, -1.04345703125, 0.023766620084643364, 0.030510902404785156, -0.7094034552574158, 0.29349279403686523, 0.5979800820350647, -1.0010792016983032, 0.6893141269683838, 1.3244402408599854, 0.8722299933433533, 1.4763832092285156, 1.8442074060440063, 1.2160604000091553, 0.898148775100708, 0.864931583404541, 0.8875675201416016, 0.8584926724433899, 1.0637050867080688, 1.8406444787979126, 0.3186623156070709, 1.2597310543060303, -0.19811666011810303, 1.5470647811889648, 1.0766220092773438, 1.10002601146698, 1.747944712638855, 0.6511489152908325, 0.8603731393814087, 0.8098471164703369, 1.7387081384658813, 0.2297455072402954, 1.213913917541504, 1.3643181324005127, 1.1407999992370605, 1.1312297582626343, 1.265775442123413, 1.0910555124282837, 0.924219012260437, 1.2167060375213623, 2.349616765975952, 2.1576011180877686, 0.7190287113189697, 1.3380178213119507, 1.2871240377426147, 1.1398282051086426, 1.8097500801086426, -1.8891273736953735, 0.0, 0.0, 0.0, 0.0, -4.082250595092773, -0.0, -0.0, -0.0, -0.0, -5.0305986404418945, -6.524361610412598, -5.955978870391846, -6.088446617126465, -5.224411964416504, -4.461483001708984, -4.730050086975098, -4.2968268394470215, -4.101224899291992, -3.4515182971954346, -3.0190823078155518, -3.46628475189209, -2.4332504272460938, -2.4995508193969727, -2.5187504291534424, -1.773091435432434, -1.3324030637741089, -1.61981999874115, -0.4854489862918854, -1.0987197160720825, -1.354956865310669, -0.9094396829605103, -1.04345703125, 0.023766620084643364, 0.030510902404785156, -0.7094034552574158, 0.29349279403686523, 0.5979800820350647, -1.0010792016983032, 0.6893141269683838, 1.3244402408599854, 0.8722299933433533, 1.4763832092285156, 1.8442074060440063, 1.2160604000091553, 0.898148775100708, 0.864931583404541, 0.8875675201416016, 0.8584926724433899, 1.0637050867080688, 1.8406444787979126, 0.3186623156070709, 1.2597310543060303, -0.19811666011810303, 1.5470647811889648, 1.0766220092773438, 1.10002601146698, 1.747944712638855, 0.6511489152908325, 0.8603731393814087, 0.8098471164703369, 1.7387081384658813, 0.2297455072402954, 1.213913917541504, 1.3643181324005127, 1.1407999992370605, 1.1312297582626343, 1.265775442123413, 1.0910555124282837, 0.924219012260437, 1.2167060375213623, 2.349616765975952, 2.1576011180877686, 0.7190287113189697, 1.3380178213119507, 1.2871240377426147, 1.1398282051086426, 1.8097500801086426, -1.8891273736953735, -0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -5.684878349304199, -5.860602855682373, -6.218060493469238, -5.115279674530029, -5.091962814331055, -4.925734996795654, -4.855677604675293, -3.9076602458953857, -3.922914743423462, -3.2190074920654297, -3.463176965713501, -1.745967984199524, -2.419703960418701, -1.6349620819091797, -3.001716136932373, -0.9608942866325378, -0.5425916314125061, -0.7926255464553833, -0.07001388072967529, 1.2652796506881714, -1.0405278205871582, -0.43662843108177185, -0.5350385308265686, -0.3440411388874054, -0.6849257946014404, -0.2643144726753235, -0.07068078219890594, -0.11109346896409988, 0.7387210130691528, 0.8356167674064636, 0.5916001200675964, 1.1996753215789795, 0.76651930809021, 0.8502742648124695, 1.0182089805603027, 1.0428802967071533, 1.0211776494979858, 3.552858591079712, 1.2180315256118774, 1.3426764011383057, 1.4640514850616455, 1.8072885274887085, 2.0505213737487793, 2.365806818008423, 1.8160361051559448, 1.591027021408081, 1.1300703287124634, 1.4622327089309692, 1.434272050857544, 0.75262451171875, 1.145613670349121, -1.1551262140274048, 0.6924545764923096, 1.9406890869140625, 1.19404935836792, 0.6582714915275574, 1.193160057067871, 0.6438173651695251, 1.1100177764892578, 1.0990636348724365, 0.7336355447769165, 1.3857319355010986, 1.5005052089691162, 1.5113013982772827, 2.1290831565856934, 1.6887134313583374, 1.3136231899261475, 1.6722687482833862, 1.1187524795532227, 0.0, 0.0, 3.0202300548553467, 6.617249488830566, -0.0, -0.0, -0.0, -0.0, -0.0, -5.684878349304199, -5.860602855682373, -6.218060493469238, -5.115279674530029, -5.091962814331055, -4.925734996795654, -4.855677604675293, -3.9076602458953857, -3.922914743423462, -3.2190074920654297, -3.463176965713501, -1.745967984199524, -2.419703960418701, -1.6349620819091797, -3.001716136932373, -0.9608942866325378, -0.5425916314125061, -0.7926255464553833, -0.07001388072967529, 1.2652796506881714, -1.0405278205871582, -0.43662843108177185, -0.5350385308265686, -0.3440411388874054, -0.6849257946014404, -0.2643144726753235, -0.07068078219890594, -0.11109346896409988, 0.7387210130691528, 0.8356167674064636, 0.5916001200675964, 1.1996753215789795, 0.76651930809021, 0.8502742648124695, 1.0182089805603027, 1.0428802967071533, 1.0211776494979858, 3.552858591079712, 1.2180315256118774, 1.3426764011383057, 1.4640514850616455, 1.8072885274887085, 2.0505213737487793, 2.365806818008423, 1.8160361051559448, 1.591027021408081, 1.1300703287124634, 1.4622327089309692, 1.434272050857544, 0.75262451171875, 1.145613670349121, -1.1551262140274048, 0.6924545764923096, 1.9406890869140625, 1.19404935836792, 0.6582714915275574, 1.193160057067871, 0.6438173651695251, 1.1100177764892578, 1.0990636348724365, 0.7336355447769165, 1.3857319355010986, 1.5005052089691162, 1.5113013982772827, 2.1290831565856934, 1.6887134313583374, 1.3136231899261475, 1.6722687482833862, 1.1187524795532227, 0.0, 0.0, 3.0202300548553467, 6.617249488830566], [0.0, 0.0, 0.0, 0.0, -6.263872146606445, -6.160449504852295, -5.4723687171936035, -6.223207950592041, -4.5563859939575195, -6.628002643585205, -5.1454572677612305, -4.566441535949707, -3.709270715713501, -4.229343891143799, -1.8422106504440308, -3.580822706222534, -3.0328915119171143, -2.777163505554199, -3.3371684551239014, -2.2783563137054443, -1.7154542207717896, -1.558785080909729, -0.8783624172210693, -0.23954880237579346, 0.05982864648103714, -0.6974575519561768, 0.23561763763427734, -0.4654565155506134, -0.29915058612823486, -0.04340560734272003, 0.37137213349342346, 0.10587805509567261, 0.05554574355483055, -0.35113486647605896, 1.0125010013580322, 0.6954661011695862, 0.7847791314125061, 0.37617480754852295, 1.168008804321289, 0.5223407745361328, 0.38738369941711426, 1.3070242404937744, 1.0358744859695435, 0.4726548492908478, 1.5515028238296509, 1.1817607879638672, 1.299456000328064, 1.5685559511184692, 2.023695468902588, 1.373648762702942, 1.7228384017944336, 1.3238047361373901, 1.3396393060684204, 1.1243656873703003, 1.4235708713531494, 0.497014582157135, 1.7437695264816284, 1.1152032613754272, 1.615981101989746, 3.579472541809082, 1.5864360332489014, 2.4788880348205566, 1.0813961029052734, 1.510825514793396, 1.3941859006881714, 3.858532190322876, 1.917210340499878, 0.682062566280365, 1.1861833333969116, 1.4922436475753784, 1.8426554203033447, 1.9992128610610962, 2.0051252841949463, 2.178330421447754, 0.0, 0.0, 1.6100661754608154, 0.0, -0.0, -0.0, -0.0, -0.0, -6.263872146606445, -6.160449504852295, -5.4723687171936035, -6.223207950592041, -4.5563859939575195, -6.628002643585205, -5.1454572677612305, -4.566441535949707, -3.709270715713501, -4.229343891143799, -1.8422106504440308, -3.580822706222534, -3.0328915119171143, -2.777163505554199, -3.3371684551239014, -2.2783563137054443, -1.7154542207717896, -1.558785080909729, -0.8783624172210693, -0.23954880237579346, 0.05982864648103714, -0.6974575519561768, 0.23561763763427734, -0.4654565155506134, -0.29915058612823486, -0.04340560734272003, 0.37137213349342346, 0.10587805509567261, 0.05554574355483055, -0.35113486647605896, 1.0125010013580322, 0.6954661011695862, 0.7847791314125061, 0.37617480754852295, 1.168008804321289, 0.5223407745361328, 0.38738369941711426, 1.3070242404937744, 1.0358744859695435, 0.4726548492908478, 1.5515028238296509, 1.1817607879638672, 1.299456000328064, 1.5685559511184692, 2.023695468902588, 1.373648762702942, 1.7228384017944336, 1.3238047361373901, 1.3396393060684204, 1.1243656873703003, 1.4235708713531494, 0.497014582157135, 1.7437695264816284, 1.1152032613754272, 1.615981101989746, 3.579472541809082, 1.5864360332489014, 2.4788880348205566, 1.0813961029052734, 1.510825514793396, 1.3941859006881714, 3.858532190322876, 1.917210340499878, 0.682062566280365, 1.1861833333969116, 1.4922436475753784, 1.8426554203033447, 1.9992128610610962, 2.0051252841949463, 2.178330421447754, 0.0, 0.0, 1.6100661754608154, 0.0], [0.0, 0.0, 0.0, 0.0, -6.558455944061279, -6.160333156585693, -6.109262466430664, -5.765851020812988, -5.399194240570068, -5.302988052368164, -4.4891743659973145, -4.879154682159424, -4.301263332366943, -4.362665176391602, -4.862746238708496, -4.531777858734131, -2.6850054264068604, -3.2633373737335205, -2.8155078887939453, -1.0166062116622925, -1.8201100826263428, -2.0907914638519287, -1.3638689517974854, -1.1680171489715576, -1.0190932750701904, 0.017255205661058426, -1.105835199356079, 0.1717519611120224, -1.0346741676330566, 2.244826316833496, -1.0296541452407837, -0.42519626021385193, 1.479148507118225, 0.9223315119743347, 0.2850949466228485, 1.2356293201446533, 1.099382996559143, 0.9432106018066406, 0.006436939351260662, 1.239356279373169, 1.2234728336334229, 0.8831418752670288, 0.475588321685791, 1.4108420610427856, 0.10122909396886826, 1.3507823944091797, 2.0819594860076904, 1.2854739427566528, 1.1519676446914673, 1.547763705253601, 1.3679966926574707, 1.4663244485855103, 1.384427785873413, 1.3898159265518188, 0.7683529853820801, 1.2964078187942505, 1.6419278383255005, 1.3489266633987427, 1.9196140766143799, 1.3153669834136963, 1.8850730657577515, 1.7186558246612549, 0.539563775062561, 0.27875787019729614, 0.7426671981811523, 1.9128268957138062, 1.6005152463912964, 3.3839480876922607, 1.3156964778900146, 1.998674988746643, 0.0480315275490284, 0.2796333432197571, 1.7014986276626587, 1.2552183866500854, 2.522634506225586, 0.0, 3.610456943511963, 5.050403118133545, -0.0, -0.0, -0.0, -0.0, -6.558455944061279, -6.160333156585693, -6.109262466430664, -5.765851020812988, -5.399194240570068, -5.302988052368164, -4.4891743659973145, -4.879154682159424, -4.301263332366943, -4.362665176391602, -4.862746238708496, -4.531777858734131, -2.6850054264068604, -3.2633373737335205, -2.8155078887939453, -1.0166062116622925, -1.8201100826263428, -2.0907914638519287, -1.3638689517974854, -1.1680171489715576, -1.0190932750701904, 0.017255205661058426, -1.105835199356079, 0.1717519611120224, -1.0346741676330566, 2.244826316833496, -1.0296541452407837, -0.42519626021385193, 1.479148507118225, 0.9223315119743347, 0.2850949466228485, 1.2356293201446533, 1.099382996559143, 0.9432106018066406, 0.006436939351260662, 1.239356279373169, 1.2234728336334229, 0.8831418752670288, 0.475588321685791, 1.4108420610427856, 0.10122909396886826, 1.3507823944091797, 2.0819594860076904, 1.2854739427566528, 1.1519676446914673, 1.547763705253601, 1.3679966926574707, 1.4663244485855103, 1.384427785873413, 1.3898159265518188, 0.7683529853820801, 1.2964078187942505, 1.6419278383255005, 1.3489266633987427, 1.9196140766143799, 1.3153669834136963, 1.8850730657577515, 1.7186558246612549, 0.539563775062561, 0.27875787019729614, 0.7426671981811523, 1.9128268957138062, 1.6005152463912964, 3.3839480876922607, 1.3156964778900146, 1.998674988746643, 0.0480315275490284, 0.2796333432197571, 1.7014986276626587, 1.2552183866500854, 2.522634506225586, 0.0, 3.610456943511963, 5.050403118133545], [0.0, 0.0, 0.0, -7.945815563201904, -6.190922737121582, -6.808412551879883, -6.675900459289551, -5.104867458343506, -5.075218200683594, -4.951491832733154, -4.643024921417236, -4.245615482330322, -4.661154747009277, -3.835984468460083, -3.7850592136383057, -3.4828708171844482, -3.7264702320098877, -2.8305745124816895, -5.162099838256836, -2.6226346492767334, -0.886759340763092, -1.5703158378601074, -2.2705698013305664, -1.6728928089141846, -0.6754875779151917, -1.0695281028747559, -1.2062326669692993, -0.7472265362739563, 0.05796221271157265, -0.08001752942800522, 1.0729893445968628, 0.15564557909965515, 0.36706769466400146, 1.46450936794281, 0.9408382773399353, 0.11206233501434326, 1.020902156829834, 2.718470335006714, 1.5110552310943604, 1.341658353805542, 0.9316429495811462, 1.8599985837936401, 0.5806930065155029, 0.8467556834220886, 1.5739632844924927, 0.8119721412658691, 0.9988217949867249, 1.0811305046081543, 1.729627013206482, 1.3655681610107422, 1.5071895122528076, 1.292482852935791, 1.3853789567947388, 1.2831053733825684, 0.9601487517356873, 0.9039904475212097, 1.1558033227920532, 0.6882224082946777, 1.9842528104782104, 0.6197094917297363, 1.3178355693817139, 1.8499237298965454, 0.4382554888725281, 1.1714599132537842, 1.1360230445861816, 1.1545157432556152, 0.6828391551971436, 1.2980704307556152, 1.3788045644760132, 2.4164366722106934, 0.9101777076721191, 1.9280723333358765, 1.7223204374313354, 1.6015268564224243, 1.5296790599822998, 0.0, 0.0, 2.7587411403656006, -0.0, -0.0, -0.0, -7.945815563201904, -6.190922737121582, -6.808412551879883, -6.675900459289551, -5.104867458343506, -5.075218200683594, -4.951491832733154, -4.643024921417236, -4.245615482330322, -4.661154747009277, -3.835984468460083, -3.7850592136383057, -3.4828708171844482, -3.7264702320098877, -2.8305745124816895, -5.162099838256836, -2.6226346492767334, -0.886759340763092, -1.5703158378601074, -2.2705698013305664, -1.6728928089141846, -0.6754875779151917, -1.0695281028747559, -1.2062326669692993, -0.7472265362739563, 0.05796221271157265, -0.08001752942800522, 1.0729893445968628, 0.15564557909965515, 0.36706769466400146, 1.46450936794281, 0.9408382773399353, 0.11206233501434326, 1.020902156829834, 2.718470335006714, 1.5110552310943604, 1.341658353805542, 0.9316429495811462, 1.8599985837936401, 0.5806930065155029, 0.8467556834220886, 1.5739632844924927, 0.8119721412658691, 0.9988217949867249, 1.0811305046081543, 1.729627013206482, 1.3655681610107422, 1.5071895122528076, 1.292482852935791, 1.3853789567947388, 1.2831053733825684, 0.9601487517356873, 0.9039904475212097, 1.1558033227920532, 0.6882224082946777, 1.9842528104782104, 0.6197094917297363, 1.3178355693817139, 1.8499237298965454, 0.4382554888725281, 1.1714599132537842, 1.1360230445861816, 1.1545157432556152, 0.6828391551971436, 1.2980704307556152, 1.3788045644760132, 2.4164366722106934, 0.9101777076721191, 1.9280723333358765, 1.7223204374313354, 1.6015268564224243, 1.5296790599822998, 0.0, 0.0, 2.7587411403656006], [0.0, 0.0, 0.0, -6.416391849517822, -6.455662250518799, -5.9231791496276855, -5.968578815460205, -5.903702735900879, -5.381735801696777, -4.981464385986328, -4.515194416046143, -4.78633451461792, -3.867387056350708, -4.436392784118652, -4.09804630279541, -3.411750078201294, -2.7386081218719482, -2.11061429977417, -2.112119674682617, -2.2590749263763428, -2.510342597961426, -2.7138118743896484, -1.7001457214355469, -0.9066342711448669, -0.968083918094635, -0.565346896648407, -0.04580754414200783, -1.1146106719970703, -0.183089941740036, 0.9529253840446472, -0.4711323082447052, 0.5504887104034424, 1.7813819646835327, 2.6005287170410156, 1.1404863595962524, -0.18866278231143951, 0.8926799893379211, 0.36090269684791565, 0.00944790430366993, 0.8033335208892822, 0.5854411125183105, 0.8048699498176575, 0.7772164940834045, 0.45096516609191895, 1.020978569984436, 0.7141388058662415, 1.5636686086654663, 1.6833525896072388, 1.1719623804092407, 1.1832630634307861, 1.500867486000061, 1.3051338195800781, 1.4202083349227905, 1.5519582033157349, 1.694558024406433, 0.6150319576263428, 1.3814120292663574, 1.2398571968078613, 2.667196273803711, 1.215134859085083, 1.1616618633270264, -0.2906498908996582, 1.226252794265747, 1.374343752861023, 0.7078486680984497, 0.47725027799606323, 1.2817453145980835, 1.4538946151733398, 1.251363754272461, 1.379746437072754, 1.307327389717102, 1.2612017393112183, 1.3276281356811523, 1.863444447517395, 2.910062313079834, 0.0, 0.0, 4.290410041809082, -0.0, -0.0, -0.0, -6.416391849517822, -6.455662250518799, -5.9231791496276855, -5.968578815460205, -5.903702735900879, -5.381735801696777, -4.981464385986328, -4.515194416046143, -4.78633451461792, -3.867387056350708, -4.436392784118652, -4.09804630279541, -3.411750078201294, -2.7386081218719482, -2.11061429977417, -2.112119674682617, -2.2590749263763428, -2.510342597961426, -2.7138118743896484, -1.7001457214355469, -0.9066342711448669, -0.968083918094635, -0.565346896648407, -0.04580754414200783, -1.1146106719970703, -0.183089941740036, 0.9529253840446472, -0.4711323082447052, 0.5504887104034424, 1.7813819646835327, 2.6005287170410156, 1.1404863595962524, -0.18866278231143951, 0.8926799893379211, 0.36090269684791565, 0.00944790430366993, 0.8033335208892822, 0.5854411125183105, 0.8048699498176575, 0.7772164940834045, 0.45096516609191895, 1.020978569984436, 0.7141388058662415, 1.5636686086654663, 1.6833525896072388, 1.1719623804092407, 1.1832630634307861, 1.500867486000061, 1.3051338195800781, 1.4202083349227905, 1.5519582033157349, 1.694558024406433, 0.6150319576263428, 1.3814120292663574, 1.2398571968078613, 2.667196273803711, 1.215134859085083, 1.1616618633270264, -0.2906498908996582, 1.226252794265747, 1.374343752861023, 0.7078486680984497, 0.47725027799606323, 1.2817453145980835, 1.4538946151733398, 1.251363754272461, 1.379746437072754, 1.307327389717102, 1.2612017393112183, 1.3276281356811523, 1.863444447517395, 2.910062313079834, 0.0, 0.0, 4.290410041809082], [-2.1057028770446777, 0.0, 0.0, -6.284280776977539, -6.1452531814575195, -6.277077674865723, -6.477550983428955, -6.034964561462402, -4.755447864532471, -4.916503429412842, -4.784030437469482, -4.472971439361572, -4.025003910064697, -3.8983733654022217, -3.9470858573913574, -3.672670602798462, -3.8565657138824463, -2.4025816917419434, -3.7251622676849365, -2.372296094894409, -1.4375959634780884, -1.4190322160720825, -1.963260531425476, -1.0346760749816895, -0.4820154309272766, -0.8948347568511963, -2.0572242736816406, 1.2590831518173218, 2.2366631031036377, 0.23074378073215485, 0.20594824850559235, 0.3966165781021118, 0.04722774401307106, 0.3088667690753937, -0.4456769824028015, 0.05887370556592941, 0.05446804687380791, -1.2733526229858398, 1.1890331506729126, 2.4143571853637695, 2.4604127407073975, 1.263228178024292, 1.2640981674194336, 0.6720696687698364, 1.2717769145965576, 2.1539831161499023, 0.739712655544281, 1.1223065853118896, 1.790971279144287, 1.3510956764221191, 1.463357925415039, 1.4353822469711304, 1.7587567567825317, 1.6025978326797485, 0.8089041113853455, 1.626057744026184, 2.026297092437744, 0.3528479039669037, 1.2076690196990967, 1.290802240371704, 1.7411876916885376, 1.5183509588241577, 0.7296542525291443, 1.4075889587402344, 1.356249213218689, 1.4806947708129883, 0.8562594056129456, 0.8417461514472961, 0.9812370538711548, 1.7422983646392822, 2.504185676574707, 0.5053924322128296, 1.1611850261688232, 1.1931605339050293, 2.274947166442871, 0.0, 0.0, 1.2824183702468872, -2.1057028770446777, -0.0, -0.0, -6.284280776977539, -6.1452531814575195, -6.277077674865723, -6.477550983428955, -6.034964561462402, -4.755447864532471, -4.916503429412842, -4.784030437469482, -4.472971439361572, -4.025003910064697, -3.8983733654022217, -3.9470858573913574, -3.672670602798462, -3.8565657138824463, -2.4025816917419434, -3.7251622676849365, -2.372296094894409, -1.4375959634780884, -1.4190322160720825, -1.963260531425476, -1.0346760749816895, -0.4820154309272766, -0.8948347568511963, -2.0572242736816406, 1.2590831518173218, 2.2366631031036377, 0.23074378073215485, 0.20594824850559235, 0.3966165781021118, 0.04722774401307106, 0.3088667690753937, -0.4456769824028015, 0.05887370556592941, 0.05446804687380791, -1.2733526229858398, 1.1890331506729126, 2.4143571853637695, 2.4604127407073975, 1.263228178024292, 1.2640981674194336, 0.6720696687698364, 1.2717769145965576, 2.1539831161499023, 0.739712655544281, 1.1223065853118896, 1.790971279144287, 1.3510956764221191, 1.463357925415039, 1.4353822469711304, 1.7587567567825317, 1.6025978326797485, 0.8089041113853455, 1.626057744026184, 2.026297092437744, 0.3528479039669037, 1.2076690196990967, 1.290802240371704, 1.7411876916885376, 1.5183509588241577, 0.7296542525291443, 1.4075889587402344, 1.356249213218689, 1.4806947708129883, 0.8562594056129456, 0.8417461514472961, 0.9812370538711548, 1.7422983646392822, 2.504185676574707, 0.5053924322128296, 1.1611850261688232, 1.1931605339050293, 2.274947166442871, 0.0, 0.0, 1.2824183702468872], [-3.7876322269439697, 0.0, 0.0, -6.872500419616699, -6.464304447174072, -6.4137163162231445, -6.4752678871154785, -5.624993324279785, -5.078553199768066, -4.9842634201049805, -5.339661598205566, -4.29805326461792, -4.163215637207031, -4.230497360229492, -3.373265027999878, -2.6985111236572266, -3.8899614810943604, -2.497575521469116, -2.794158458709717, -2.883378744125366, -1.776161551475525, -1.5897246599197388, -0.4964238405227661, -1.284910798072815, -1.221818447113037, -0.5170406103134155, -0.7837878465652466, -1.146610975265503, 0.8979446291923523, -0.22006161510944366, -2.1484227180480957, -0.7621655464172363, 0.8559813499450684, 1.8869184255599976, 0.4487425982952118, 0.29595306515693665, 0.6498124599456787, -1.0143556594848633, 0.24286605417728424, -0.1723126322031021, 0.7957919836044312, 0.7327941656112671, 0.20608755946159363, 1.4125115871429443, 1.6930912733078003, 1.8494969606399536, 1.9168850183486938, 2.033109188079834, 1.1851069927215576, 1.812554955482483, 1.6864211559295654, 1.4241654872894287, 1.6663520336151123, 1.7272471189498901, 1.930226445198059, -0.014120225794613361, 2.1369757652282715, 1.3611335754394531, 1.3240400552749634, 1.7576028108596802, 1.143062710762024, 0.9511297345161438, 1.2947005033493042, 1.6127244234085083, 1.3085927963256836, 1.0287418365478516, 1.2125437259674072, 1.1738284826278687, 1.34075927734375, 1.0765858888626099, 0.9568233489990234, 0.8720490336418152, 1.6225930452346802, 1.4398682117462158, 1.1488685607910156, 0.0, 0.0, 1.7270662784576416, -3.7876322269439697, -0.0, -0.0, -6.872500419616699, -6.464304447174072, -6.4137163162231445, -6.4752678871154785, -5.624993324279785, -5.078553199768066, -4.9842634201049805, -5.339661598205566, -4.29805326461792, -4.163215637207031, -4.230497360229492, -3.373265027999878, -2.6985111236572266, -3.8899614810943604, -2.497575521469116, -2.794158458709717, -2.883378744125366, -1.776161551475525, -1.5897246599197388, -0.4964238405227661, -1.284910798072815, -1.221818447113037, -0.5170406103134155, -0.7837878465652466, -1.146610975265503, 0.8979446291923523, -0.22006161510944366, -2.1484227180480957, -0.7621655464172363, 0.8559813499450684, 1.8869184255599976, 0.4487425982952118, 0.29595306515693665, 0.6498124599456787, -1.0143556594848633, 0.24286605417728424, -0.1723126322031021, 0.7957919836044312, 0.7327941656112671, 0.20608755946159363, 1.4125115871429443, 1.6930912733078003, 1.8494969606399536, 1.9168850183486938, 2.033109188079834, 1.1851069927215576, 1.812554955482483, 1.6864211559295654, 1.4241654872894287, 1.6663520336151123, 1.7272471189498901, 1.930226445198059, -0.014120225794613361, 2.1369757652282715, 1.3611335754394531, 1.3240400552749634, 1.7576028108596802, 1.143062710762024, 0.9511297345161438, 1.2947005033493042, 1.6127244234085083, 1.3085927963256836, 1.0287418365478516, 1.2125437259674072, 1.1738284826278687, 1.34075927734375, 1.0765858888626099, 0.9568233489990234, 0.8720490336418152, 1.6225930452346802, 1.4398682117462158, 1.1488685607910156, 0.0, 0.0, 1.7270662784576416], [-7.431119441986084, 0.0, 0.0, -7.086088180541992, -6.576106548309326, -6.361393928527832, -6.431903839111328, -5.867198467254639, -5.742173671722412, -5.4751410484313965, -5.278406620025635, -4.320960521697998, -4.502490520477295, -4.591793060302734, -3.591952323913574, -2.954204797744751, -3.302907705307007, -2.8810577392578125, -2.500903844833374, -2.235931396484375, -1.7835426330566406, -2.3905906677246094, -1.5166274309158325, -1.252312421798706, -0.4649870991706848, -0.743294894695282, -0.9442054629325867, -0.9414798617362976, 0.37869560718536377, -0.8782800436019897, 0.10460004210472107, -0.45503702759742737, 0.3373802602291107, -0.6004986763000488, 0.28191158175468445, 1.594892978668213, 0.1751682162284851, -0.003120819106698036, -0.5346217155456543, 1.1282683610916138, 3.143599033355713, 5.006292819976807, 1.3433080911636353, 0.7501100897789001, 1.422728419303894, 1.2963811159133911, 1.7654447555541992, 1.7076878547668457, 1.4200873374938965, 1.5821171998977661, 1.6724128723144531, 1.4511466026306152, 1.447622299194336, 1.681247353553772, 2.1469836235046387, 1.6943087577819824, 1.206284523010254, 1.4011101722717285, 1.2960379123687744, 0.8474693298339844, 0.47269368171691895, 2.5630288124084473, 0.8169651627540588, 1.2645370960235596, 1.5282751321792603, 1.1639671325683594, 1.306861162185669, 2.047517776489258, 0.4805402457714081, 1.0961010456085205, 1.45954430103302, 0.5460017323493958, 1.6901521682739258, 1.8653838634490967, 1.834473729133606, 0.0, 0.0, 3.2658567428588867, -7.431119441986084, -0.0, -0.0, -7.086088180541992, -6.576106548309326, -6.361393928527832, -6.431903839111328, -5.867198467254639, -5.742173671722412, -5.4751410484313965, -5.278406620025635, -4.320960521697998, -4.502490520477295, -4.591793060302734, -3.591952323913574, -2.954204797744751, -3.302907705307007, -2.8810577392578125, -2.500903844833374, -2.235931396484375, -1.7835426330566406, -2.3905906677246094, -1.5166274309158325, -1.252312421798706, -0.4649870991706848, -0.743294894695282, -0.9442054629325867, -0.9414798617362976, 0.37869560718536377, -0.8782800436019897, 0.10460004210472107, -0.45503702759742737, 0.3373802602291107, -0.6004986763000488, 0.28191158175468445, 1.594892978668213, 0.1751682162284851, -0.003120819106698036, -0.5346217155456543, 1.1282683610916138, 3.143599033355713, 5.006292819976807, 1.3433080911636353, 0.7501100897789001, 1.422728419303894, 1.2963811159133911, 1.7654447555541992, 1.7076878547668457, 1.4200873374938965, 1.5821171998977661, 1.6724128723144531, 1.4511466026306152, 1.447622299194336, 1.681247353553772, 2.1469836235046387, 1.6943087577819824, 1.206284523010254, 1.4011101722717285, 1.2960379123687744, 0.8474693298339844, 0.47269368171691895, 2.5630288124084473, 0.8169651627540588, 1.2645370960235596, 1.5282751321792603, 1.1639671325683594, 1.306861162185669, 2.047517776489258, 0.4805402457714081, 1.0961010456085205, 1.45954430103302, 0.5460017323493958, 1.6901521682739258, 1.8653838634490967, 1.834473729133606, 0.0, 0.0, 3.2658567428588867], [-5.505417823791504, 0.0, -7.022550582885742, -6.771347999572754, -6.882387161254883, -6.8575615882873535, -6.297714710235596, -6.357539176940918, -5.967771053314209, -6.668745040893555, -5.249642372131348, -4.458937644958496, -4.851238250732422, -4.202524662017822, -3.835191488265991, -3.812502145767212, -3.7763233184814453, -3.040656089782715, -2.6691017150878906, -1.0236775875091553, -1.9139734506607056, -1.75665283203125, -1.5299668312072754, -1.190081000328064, -0.7712826728820801, -1.3998090028762817, -0.7607017159461975, -0.32466238737106323, -0.926740288734436, 0.2605445086956024, 0.8074355125427246, 0.24860607087612152, 1.2037264108657837, 0.07408156991004944, -0.19382046163082123, 1.4382497072219849, 0.23742350935935974, 0.753856897354126, 0.9166302680969238, 0.2022152841091156, 0.771194577217102, 0.6352007389068604, -0.321455717086792, 1.6870920658111572, 1.158252477645874, 1.407409906387329, 1.6259806156158447, 1.374528408050537, 1.6707223653793335, 1.7285410165786743, 1.4447206258773804, 1.3624980449676514, 0.973925769329071, 1.4612020254135132, 0.21505914628505707, 0.3523743748664856, 1.405869483947754, 1.0512356758117676, 2.0968992710113525, 1.515375018119812, 0.9681628942489624, 0.17371565103530884, 1.6078547239303589, 1.069216012954712, 1.346829891204834, 0.9597793221473694, 1.100620985031128, 0.6390789747238159, 1.4385133981704712, 1.5103394985198975, 1.9452149868011475, 1.521321177482605, 0.7317541837692261, 1.7244070768356323, 2.095271110534668, 0.0, 0.0, 0.0, -5.505417823791504, -0.0, -7.022550582885742, -6.771347999572754, -6.882387161254883, -6.8575615882873535, -6.297714710235596, -6.357539176940918, -5.967771053314209, -6.668745040893555, -5.249642372131348, -4.458937644958496, -4.851238250732422, -4.202524662017822, -3.835191488265991, -3.812502145767212, -3.7763233184814453, -3.040656089782715, -2.6691017150878906, -1.0236775875091553, -1.9139734506607056, -1.75665283203125, -1.5299668312072754, -1.190081000328064, -0.7712826728820801, -1.3998090028762817, -0.7607017159461975, -0.32466238737106323, -0.926740288734436, 0.2605445086956024, 0.8074355125427246, 0.24860607087612152, 1.2037264108657837, 0.07408156991004944, -0.19382046163082123, 1.4382497072219849, 0.23742350935935974, 0.753856897354126, 0.9166302680969238, 0.2022152841091156, 0.771194577217102, 0.6352007389068604, -0.321455717086792, 1.6870920658111572, 1.158252477645874, 1.407409906387329, 1.6259806156158447, 1.374528408050537, 1.6707223653793335, 1.7285410165786743, 1.4447206258773804, 1.3624980449676514, 0.973925769329071, 1.4612020254135132, 0.21505914628505707, 0.3523743748664856, 1.405869483947754, 1.0512356758117676, 2.0968992710113525, 1.515375018119812, 0.9681628942489624, 0.17371565103530884, 1.6078547239303589, 1.069216012954712, 1.346829891204834, 0.9597793221473694, 1.100620985031128, 0.6390789747238159, 1.4385133981704712, 1.5103394985198975, 1.9452149868011475, 1.521321177482605, 0.7317541837692261, 1.7244070768356323, 2.095271110534668, 0.0, 0.0, 0.0], [-4.159066677093506, 0.0, -8.986830711364746, -7.617158889770508, -7.986417770385742, -6.0452375411987305, -6.563561916351318, -6.060267925262451, -5.888787269592285, -5.064001083374023, -5.206785202026367, -4.837715148925781, -4.6071858406066895, -4.879439353942871, -3.9943244457244873, -4.145171642303467, -3.788125991821289, -3.7024624347686768, -2.1647255420684814, -2.691131353378296, -2.4169883728027344, -2.2253055572509766, -2.144726276397705, -0.9619622826576233, -1.0468828678131104, -1.2587642669677734, -0.9479476809501648, -0.3772704303264618, 0.08308093994855881, -1.2502540349960327, 0.09474772959947586, 0.43639805912971497, 0.8555873036384583, 0.295676052570343, -0.19771623611450195, -0.13402679562568665, 0.045583076775074005, 0.87501060962677, 0.9550977349281311, 0.3787655532360077, 0.25326305627822876, 0.9021616578102112, 1.1001108884811401, 1.2318100929260254, 1.7343450784683228, 1.0562330484390259, 1.7205263376235962, 1.1122711896896362, 1.0906208753585815, 0.7501544952392578, 1.8505065441131592, 1.5096287727355957, 1.4437416791915894, 1.4352669715881348, 1.2339518070220947, 1.7094074487686157, 0.237488254904747, 0.7646058797836304, 1.3323194980621338, 0.8827915191650391, 1.0798941850662231, 0.7716646790504456, 0.7088726758956909, 1.4298650026321411, 0.8785535097122192, 1.0517637729644775, 0.763153076171875, 1.218756079673767, 0.4331818222999573, 1.7248482704162598, 1.197838306427002, 2.1791810989379883, 1.4154114723205566, 0.9899343848228455, 1.5084903240203857, 2.415152072906494, 0.0, 0.0, -4.159066677093506, -0.0, -8.986830711364746, -7.617158889770508, -7.986417770385742, -6.0452375411987305, -6.563561916351318, -6.060267925262451, -5.888787269592285, -5.064001083374023, -5.206785202026367, -4.837715148925781, -4.6071858406066895, -4.879439353942871, -3.9943244457244873, -4.145171642303467, -3.788125991821289, -3.7024624347686768, -2.1647255420684814, -2.691131353378296, -2.4169883728027344, -2.2253055572509766, -2.144726276397705, -0.9619622826576233, -1.0468828678131104, -1.2587642669677734, -0.9479476809501648, -0.3772704303264618, 0.08308093994855881, -1.2502540349960327, 0.09474772959947586, 0.43639805912971497, 0.8555873036384583, 0.295676052570343, -0.19771623611450195, -0.13402679562568665, 0.045583076775074005, 0.87501060962677, 0.9550977349281311, 0.3787655532360077, 0.25326305627822876, 0.9021616578102112, 1.1001108884811401, 1.2318100929260254, 1.7343450784683228, 1.0562330484390259, 1.7205263376235962, 1.1122711896896362, 1.0906208753585815, 0.7501544952392578, 1.8505065441131592, 1.5096287727355957, 1.4437416791915894, 1.4352669715881348, 1.2339518070220947, 1.7094074487686157, 0.237488254904747, 0.7646058797836304, 1.3323194980621338, 0.8827915191650391, 1.0798941850662231, 0.7716646790504456, 0.7088726758956909, 1.4298650026321411, 0.8785535097122192, 1.0517637729644775, 0.763153076171875, 1.218756079673767, 0.4331818222999573, 1.7248482704162598, 1.197838306427002, 2.1791810989379883, 1.4154114723205566, 0.9899343848228455, 1.5084903240203857, 2.415152072906494, 0.0, 0.0], [-6.283909797668457, 0.0, -5.227476119995117, -7.241640090942383, -7.535679340362549, -6.9964165687561035, -6.842804908752441, -6.829705238342285, -6.112392425537109, -4.888490676879883, -4.834959506988525, -5.128329753875732, -5.127220630645752, -4.874995708465576, -2.3262581825256348, -4.751220703125, -3.533482789993286, -3.761685609817505, -3.9738571643829346, -2.0077567100524902, -2.3366994857788086, -1.6068609952926636, -1.7110356092453003, -1.1404682397842407, -1.305613398551941, -1.3172705173492432, -0.19947996735572815, -0.16951018571853638, 0.10157307982444763, 0.22585782408714294, -0.25854772329330444, -0.0851011574268341, 1.2419672012329102, 3.5883829593658447, 0.6917024254798889, 0.26063141226768494, 1.1374233961105347, 0.908316969871521, 0.9678515195846558, 0.5958642363548279, 0.8017440438270569, 1.0656940937042236, 1.4598616361618042, 1.3758796453475952, 1.4842134714126587, 1.5886842012405396, 1.451357126235962, 1.3918977975845337, 1.2499687671661377, 1.4753363132476807, 1.7676661014556885, 1.0915594100952148, 1.1973956823349, 0.18073198199272156, 1.1640000343322754, 1.2969262599945068, 1.9316033124923706, 0.8037075996398926, 2.9702723026275635, 0.6782510280609131, 0.9792285561561584, 0.41812825202941895, 0.9903644323348999, 0.5197945237159729, 1.0493367910385132, 1.1126316785812378, 1.083635687828064, 1.3683946132659912, 0.9529629349708557, 1.711010217666626, 1.1696722507476807, 1.7179511785507202, 1.0714980363845825, 1.4452701807022095, 2.6531412601470947, 0.0, 0.0, 0.0, -6.283909797668457, -0.0, -5.227476119995117, -7.241640090942383, -7.535679340362549, -6.9964165687561035, -6.842804908752441, -6.829705238342285, -6.112392425537109, -4.888490676879883, -4.834959506988525, -5.128329753875732, -5.127220630645752, -4.874995708465576, -2.3262581825256348, -4.751220703125, -3.533482789993286, -3.761685609817505, -3.9738571643829346, -2.0077567100524902, -2.3366994857788086, -1.6068609952926636, -1.7110356092453003, -1.1404682397842407, -1.305613398551941, -1.3172705173492432, -0.19947996735572815, -0.16951018571853638, 0.10157307982444763, 0.22585782408714294, -0.25854772329330444, -0.0851011574268341, 1.2419672012329102, 3.5883829593658447, 0.6917024254798889, 0.26063141226768494, 1.1374233961105347, 0.908316969871521, 0.9678515195846558, 0.5958642363548279, 0.8017440438270569, 1.0656940937042236, 1.4598616361618042, 1.3758796453475952, 1.4842134714126587, 1.5886842012405396, 1.451357126235962, 1.3918977975845337, 1.2499687671661377, 1.4753363132476807, 1.7676661014556885, 1.0915594100952148, 1.1973956823349, 0.18073198199272156, 1.1640000343322754, 1.2969262599945068, 1.9316033124923706, 0.8037075996398926, 2.9702723026275635, 0.6782510280609131, 0.9792285561561584, 0.41812825202941895, 0.9903644323348999, 0.5197945237159729, 1.0493367910385132, 1.1126316785812378, 1.083635687828064, 1.3683946132659912, 0.9529629349708557, 1.711010217666626, 1.1696722507476807, 1.7179511785507202, 1.0714980363845825, 1.4452701807022095, 2.6531412601470947, 0.0, 0.0, 0.0], [0.0, 0.0, -6.446991443634033, -7.118053913116455, -7.267098426818848, -7.265559196472168, -6.457040786743164, -6.175483226776123, -6.06818962097168, -5.635918617248535, -5.345116138458252, -5.40545654296875, -4.941805839538574, -4.717248916625977, -4.774893760681152, -4.527351379394531, -4.0326313972473145, -1.9846283197402954, -3.437225818634033, -4.9959001541137695, -1.565338373184204, -1.4406801462173462, -1.2067327499389648, -1.620168924331665, -0.9626085758209229, -0.36000362038612366, -0.5289899110794067, -1.144972801208496, -0.1875564306974411, 0.4807749092578888, -0.13552916049957275, 0.31059807538986206, -0.13325229287147522, 0.41215041279792786, 0.29426267743110657, 1.3016963005065918, -0.34292638301849365, 1.0532467365264893, 0.16328777372837067, 0.5564829707145691, 0.4007002115249634, 1.221597671508789, 1.1185065507888794, 1.4518206119537354, 1.3283114433288574, 0.8454189300537109, 1.3469260931015015, 1.3985881805419922, 1.6864169836044312, 1.1450932025909424, 1.6276414394378662, 1.1354458332061768, 1.4204260110855103, 2.404127836227417, 0.471678763628006, 0.8448139429092407, 1.0753604173660278, 0.9770827293395996, 0.7452642321586609, 1.0885697603225708, 0.42497673630714417, 0.8533763885498047, 0.8902947902679443, 1.1250669956207275, 1.5034054517745972, 0.8986594080924988, 1.3778574466705322, 1.4109536409378052, 1.1723142862319946, 1.4003486633300781, 1.0678086280822754, 1.073376178741455, 1.1974183320999146, 1.2959611415863037, 1.764664649963379, 2.837324380874634, 0.0, 0.0, -0.0, -0.0, -6.446991443634033, -7.118053913116455, -7.267098426818848, -7.265559196472168, -6.457040786743164, -6.175483226776123, -6.06818962097168, -5.635918617248535, -5.345116138458252, -5.40545654296875, -4.941805839538574, -4.717248916625977, -4.774893760681152, -4.527351379394531, -4.0326313972473145, -1.9846283197402954, -3.437225818634033, -4.9959001541137695, -1.565338373184204, -1.4406801462173462, -1.2067327499389648, -1.620168924331665, -0.9626085758209229, -0.36000362038612366, -0.5289899110794067, -1.144972801208496, -0.1875564306974411, 0.4807749092578888, -0.13552916049957275, 0.31059807538986206, -0.13325229287147522, 0.41215041279792786, 0.29426267743110657, 1.3016963005065918, -0.34292638301849365, 1.0532467365264893, 0.16328777372837067, 0.5564829707145691, 0.4007002115249634, 1.221597671508789, 1.1185065507888794, 1.4518206119537354, 1.3283114433288574, 0.8454189300537109, 1.3469260931015015, 1.3985881805419922, 1.6864169836044312, 1.1450932025909424, 1.6276414394378662, 1.1354458332061768, 1.4204260110855103, 2.404127836227417, 0.471678763628006, 0.8448139429092407, 1.0753604173660278, 0.9770827293395996, 0.7452642321586609, 1.0885697603225708, 0.42497673630714417, 0.8533763885498047, 0.8902947902679443, 1.1250669956207275, 1.5034054517745972, 0.8986594080924988, 1.3778574466705322, 1.4109536409378052, 1.1723142862319946, 1.4003486633300781, 1.0678086280822754, 1.073376178741455, 1.1974183320999146, 1.2959611415863037, 1.764664649963379, 2.837324380874634, 0.0, 0.0], [0.0, 0.0, -7.804837226867676, -7.639061450958252, -6.956287384033203, -7.10307502746582, -7.500960826873779, -8.420528411865234, -6.706782341003418, -6.0911736488342285, -6.0547895431518555, -5.465221405029297, -5.92136812210083, -4.270870685577393, -3.3297383785247803, -4.114023208618164, -3.835355043411255, -3.041036605834961, -3.082505941390991, -2.300452709197998, -3.0738589763641357, -1.5873502492904663, -1.3195452690124512, -1.5524908304214478, -1.1645293235778809, -0.9935939908027649, -0.8196858763694763, -0.3854767978191376, -0.528130054473877, -0.7452970147132874, -0.5398133993148804, -0.44972214102745056, -0.004989363253116608, 0.41345134377479553, -0.6173686981201172, -0.27440616488456726, 0.22329972684383392, 0.5329603552818298, 0.1270061433315277, 0.8919944167137146, 0.48082032799720764, 0.06275170296430588, 0.8677444458007812, 1.627581238746643, 0.8233046531677246, 0.8655416369438171, 1.2582300901412964, 0.797156810760498, 1.3147351741790771, 1.0141412019729614, 1.758949637413025, 0.6889933347702026, 1.828079342842102, 2.2426209449768066, 1.4556888341903687, 0.5354576706886292, 1.0336329936981201, 1.3403525352478027, 0.9663704633712769, 0.7134601473808289, 0.1710144728422165, 1.5826417207717896, 0.6256282925605774, 1.3914703130722046, 1.308760643005371, 1.4278029203414917, 1.013674259185791, 0.1410108506679535, 1.0356534719467163, 1.892146348953247, 1.0503686666488647, 0.869377851486206, 1.1087664365768433, 1.4843417406082153, 2.1754138469696045, 1.7906984090805054, 0.0, 0.0, -0.0, -0.0, -7.804837226867676, -7.639061450958252, -6.956287384033203, -7.10307502746582, -7.500960826873779, -8.420528411865234, -6.706782341003418, -6.0911736488342285, -6.0547895431518555, -5.465221405029297, -5.92136812210083, -4.270870685577393, -3.3297383785247803, -4.114023208618164, -3.835355043411255, -3.041036605834961, -3.082505941390991, -2.300452709197998, -3.0738589763641357, -1.5873502492904663, -1.3195452690124512, -1.5524908304214478, -1.1645293235778809, -0.9935939908027649, -0.8196858763694763, -0.3854767978191376, -0.528130054473877, -0.7452970147132874, -0.5398133993148804, -0.44972214102745056, -0.004989363253116608, 0.41345134377479553, -0.6173686981201172, -0.27440616488456726, 0.22329972684383392, 0.5329603552818298, 0.1270061433315277, 0.8919944167137146, 0.48082032799720764, 0.06275170296430588, 0.8677444458007812, 1.627581238746643, 0.8233046531677246, 0.8655416369438171, 1.2582300901412964, 0.797156810760498, 1.3147351741790771, 1.0141412019729614, 1.758949637413025, 0.6889933347702026, 1.828079342842102, 2.2426209449768066, 1.4556888341903687, 0.5354576706886292, 1.0336329936981201, 1.3403525352478027, 0.9663704633712769, 0.7134601473808289, 0.1710144728422165, 1.5826417207717896, 0.6256282925605774, 1.3914703130722046, 1.308760643005371, 1.4278029203414917, 1.013674259185791, 0.1410108506679535, 1.0356534719467163, 1.892146348953247, 1.0503686666488647, 0.869377851486206, 1.1087664365768433, 1.4843417406082153, 2.1754138469696045, 1.7906984090805054, 0.0, 0.0], [0.0, -9.405587196350098, -7.4863481521606445, -7.648702144622803, -7.446077823638916, -7.091934680938721, -7.936809539794922, -6.4770660400390625, -6.3507819175720215, -6.145149230957031, -5.935337066650391, -5.402501106262207, -4.481661796569824, -4.957873344421387, -4.6500701904296875, -4.398617267608643, -3.549734115600586, -1.7115119695663452, -3.3614251613616943, -1.998785376548767, -2.0433547496795654, -2.606900453567505, -1.4640849828720093, -1.7659574747085571, -1.3979902267456055, -1.0599617958068848, -0.8072924017906189, -0.19614405930042267, -0.7412706613540649, -0.015867110341787338, -0.20601017773151398, -0.24335555732250214, 0.009814931079745293, -0.06510762870311737, 0.10714004188776016, 0.19561748206615448, 1.6351866722106934, 1.060346007347107, 1.2153120040893555, 1.1850097179412842, 0.8271571397781372, 1.1353340148925781, 1.266091227531433, 1.4882683753967285, 1.939624309539795, 1.4928971529006958, 1.3351242542266846, 1.0906587839126587, 1.3436613082885742, 1.255676031112671, 0.9969770312309265, 1.1849205493927002, 1.1747137308120728, 0.8676400184631348, 0.24348868429660797, 0.7661834359169006, 0.8334674835205078, 0.9684934020042419, 1.37136709690094, 0.736561119556427, 0.8401006460189819, 0.5909209251403809, 0.46166738867759705, 0.4291980564594269, 1.3743096590042114, -0.3853156566619873, 0.7802320122718811, 2.351184844970703, 3.0961880683898926, 1.528676152229309, 0.6532199382781982, 0.8438989520072937, 0.694295346736908, 1.2035000324249268, 2.0730504989624023, 1.7949773073196411, 0.0, 0.0, -0.0, -9.405587196350098, -7.4863481521606445, -7.648702144622803, -7.446077823638916, -7.091934680938721, -7.936809539794922, -6.4770660400390625, -6.3507819175720215, -6.145149230957031, -5.935337066650391, -5.402501106262207, -4.481661796569824, -4.957873344421387, -4.6500701904296875, -4.398617267608643, -3.549734115600586, -1.7115119695663452, -3.3614251613616943, -1.998785376548767, -2.0433547496795654, -2.606900453567505, -1.4640849828720093, -1.7659574747085571, -1.3979902267456055, -1.0599617958068848, -0.8072924017906189, -0.19614405930042267, -0.7412706613540649, -0.015867110341787338, -0.20601017773151398, -0.24335555732250214, 0.009814931079745293, -0.06510762870311737, 0.10714004188776016, 0.19561748206615448, 1.6351866722106934, 1.060346007347107, 1.2153120040893555, 1.1850097179412842, 0.8271571397781372, 1.1353340148925781, 1.266091227531433, 1.4882683753967285, 1.939624309539795, 1.4928971529006958, 1.3351242542266846, 1.0906587839126587, 1.3436613082885742, 1.255676031112671, 0.9969770312309265, 1.1849205493927002, 1.1747137308120728, 0.8676400184631348, 0.24348868429660797, 0.7661834359169006, 0.8334674835205078, 0.9684934020042419, 1.37136709690094, 0.736561119556427, 0.8401006460189819, 0.5909209251403809, 0.46166738867759705, 0.4291980564594269, 1.3743096590042114, -0.3853156566619873, 0.7802320122718811, 2.351184844970703, 3.0961880683898926, 1.528676152229309, 0.6532199382781982, 0.8438989520072937, 0.694295346736908, 1.2035000324249268, 2.0730504989624023, 1.7949773073196411, 0.0, 0.0], [0.0, -8.19393539428711, -7.378815650939941, -8.422561645507812, -8.010563850402832, -7.128716945648193, -7.7011799812316895, -6.989686489105225, -7.417098522186279, -6.065046310424805, -6.361496448516846, -5.5387067794799805, -5.27094030380249, -5.800542831420898, -4.864548683166504, -4.283779144287109, -4.195297718048096, -4.0800580978393555, -4.497982025146484, -3.183044910430908, -2.3833091259002686, -2.4388134479522705, -1.645601749420166, -2.112924098968506, -1.012423038482666, -1.6731536388397217, -0.7833583354949951, -1.418365478515625, 0.20123989880084991, -0.539429783821106, 0.11174223572015762, -0.5322485566139221, 0.23562604188919067, -0.40605875849723816, 0.21225900948047638, 0.4441060423851013, 2.1279664039611816, 1.4003729820251465, 1.2293564081192017, 1.4059133529663086, 0.7598924040794373, 1.293681263923645, 1.3156015872955322, 1.3919377326965332, 1.0919872522354126, 1.4051358699798584, 1.145435094833374, 1.9296672344207764, 1.396622657775879, -0.09336523711681366, 1.4233652353286743, 1.1142852306365967, 1.1715338230133057, 1.6438814401626587, 0.6714931726455688, 1.378801941871643, 0.9352312684059143, 0.733040988445282, 1.0659961700439453, 0.09625406563282013, 0.8918462991714478, 0.19090065360069275, 0.7949714064598083, 0.6781519055366516, 0.3582543730735779, 0.5079166293144226, 0.6929836273193359, 0.5335273146629333, 0.6297755241394043, 1.2127243280410767, 1.033257007598877, 1.251291036605835, 1.1838350296020508, 1.5095268487930298, 1.6342498064041138, 2.8041086196899414, 0.0, 0.0, -0.0, -8.19393539428711, -7.378815650939941, -8.422561645507812, -8.010563850402832, -7.128716945648193, -7.7011799812316895, -6.989686489105225, -7.417098522186279, -6.065046310424805, -6.361496448516846, -5.5387067794799805, -5.27094030380249, -5.800542831420898, -4.864548683166504, -4.283779144287109, -4.195297718048096, -4.0800580978393555, -4.497982025146484, -3.183044910430908, -2.3833091259002686, -2.4388134479522705, -1.645601749420166, -2.112924098968506, -1.012423038482666, -1.6731536388397217, -0.7833583354949951, -1.418365478515625, 0.20123989880084991, -0.539429783821106, 0.11174223572015762, -0.5322485566139221, 0.23562604188919067, -0.40605875849723816, 0.21225900948047638, 0.4441060423851013, 2.1279664039611816, 1.4003729820251465, 1.2293564081192017, 1.4059133529663086, 0.7598924040794373, 1.293681263923645, 1.3156015872955322, 1.3919377326965332, 1.0919872522354126, 1.4051358699798584, 1.145435094833374, 1.9296672344207764, 1.396622657775879, -0.09336523711681366, 1.4233652353286743, 1.1142852306365967, 1.1715338230133057, 1.6438814401626587, 0.6714931726455688, 1.378801941871643, 0.9352312684059143, 0.733040988445282, 1.0659961700439453, 0.09625406563282013, 0.8918462991714478, 0.19090065360069275, 0.7949714064598083, 0.6781519055366516, 0.3582543730735779, 0.5079166293144226, 0.6929836273193359, 0.5335273146629333, 0.6297755241394043, 1.2127243280410767, 1.033257007598877, 1.251291036605835, 1.1838350296020508, 1.5095268487930298, 1.6342498064041138, 2.8041086196899414, 0.0, 0.0], [0.0, -7.054931640625, -7.966360092163086, -8.353240013122559, -7.725297451019287, -8.103740692138672, -7.914627552032471, -6.190616130828857, -6.612945079803467, -6.317337989807129, -5.363339424133301, -5.844491958618164, -6.146913051605225, -5.382662773132324, -4.877218246459961, -4.927092552185059, -3.383194923400879, -6.415813446044922, -2.4986321926116943, -2.59879469871521, -2.881741762161255, -2.947208881378174, -2.608419895172119, -1.7015148401260376, -1.9271626472473145, -1.4524738788604736, -0.8262907266616821, -1.8986690044403076, -1.7076140642166138, -0.9429525136947632, -0.10764278471469879, 0.26672959327697754, -1.091031551361084, -0.11069580167531967, 0.4882548451423645, 0.6297016143798828, 1.7012473344802856, 2.6174159049987793, 2.290022850036621, 1.3861552476882935, 1.3100985288619995, 0.9891225695610046, 0.555436909198761, 0.9149362444877625, 1.4303182363510132, 0.4137079119682312, 0.8313658237457275, 1.1463571786880493, -0.30322930216789246, 0.8354011178016663, 2.8399548530578613, 1.792763352394104, 0.6556194424629211, 0.7519097924232483, 0.5423313975334167, 1.5780789852142334, 0.8392596244812012, 0.5865058898925781, 0.2866925895214081, 0.5419069528579712, 0.5675866007804871, 0.781902015209198, 0.34342554211616516, 0.5446043014526367, 1.0794119834899902, 0.978001058101654, 0.5372107625007629, 0.7728866338729858, 0.8654213547706604, 1.136210322380066, 0.8590719699859619, 1.5984340906143188, 1.6644366979599, 1.514847993850708, 1.0068132877349854, 2.4385623931884766, 0.0, 0.0, -0.0, -7.054931640625, -7.966360092163086, -8.353240013122559, -7.725297451019287, -8.103740692138672, -7.914627552032471, -6.190616130828857, -6.612945079803467, -6.317337989807129, -5.363339424133301, -5.844491958618164, -6.146913051605225, -5.382662773132324, -4.877218246459961, -4.927092552185059, -3.383194923400879, -6.415813446044922, -2.4986321926116943, -2.59879469871521, -2.881741762161255, -2.947208881378174, -2.608419895172119, -1.7015148401260376, -1.9271626472473145, -1.4524738788604736, -0.8262907266616821, -1.8986690044403076, -1.7076140642166138, -0.9429525136947632, -0.10764278471469879, 0.26672959327697754, -1.091031551361084, -0.11069580167531967, 0.4882548451423645, 0.6297016143798828, 1.7012473344802856, 2.6174159049987793, 2.290022850036621, 1.3861552476882935, 1.3100985288619995, 0.9891225695610046, 0.555436909198761, 0.9149362444877625, 1.4303182363510132, 0.4137079119682312, 0.8313658237457275, 1.1463571786880493, -0.30322930216789246, 0.8354011178016663, 2.8399548530578613, 1.792763352394104, 0.6556194424629211, 0.7519097924232483, 0.5423313975334167, 1.5780789852142334, 0.8392596244812012, 0.5865058898925781, 0.2866925895214081, 0.5419069528579712, 0.5675866007804871, 0.781902015209198, 0.34342554211616516, 0.5446043014526367, 1.0794119834899902, 0.978001058101654, 0.5372107625007629, 0.7728866338729858, 0.8654213547706604, 1.136210322380066, 0.8590719699859619, 1.5984340906143188, 1.6644366979599, 1.514847993850708, 1.0068132877349854, 2.4385623931884766, 0.0, 0.0], [0.0, -8.499900817871094, -8.420445442199707, -9.106385231018066, -8.800430297851562, -7.9505743980407715, -7.883469581604004, -7.1576642990112305, -7.316928386688232, -6.421921730041504, -5.237420082092285, -5.88522481918335, -5.483541488647461, -5.149790287017822, -4.628054141998291, -4.573464393615723, -5.391697883605957, -4.5523881912231445, -3.9951248168945312, -3.4327011108398438, -3.2792389392852783, -1.2490171194076538, -1.562932014465332, -2.307455062866211, -2.6215200424194336, -1.6952338218688965, -1.3462600708007812, -1.6456193923950195, -0.36240482330322266, 0.09661098569631577, -0.9498084783554077, -1.479500651359558, 0.590585470199585, -0.21384693682193756, 0.14539068937301636, 0.9272205233573914, 2.063509464263916, 0.10045409947633743, 2.1693291664123535, 2.6167733669281006, 0.8676733374595642, 0.751863956451416, 0.8267828226089478, 0.8422709107398987, 0.4554542899131775, 0.14006710052490234, 0.6816073656082153, 0.12276685982942581, 0.1663532555103302, 1.8032764196395874, 1.0169185400009155, 0.6385407447814941, 0.9234153032302856, 1.6966866254806519, 0.3548000752925873, 1.633539080619812, 0.6883448362350464, 1.142061710357666, 0.5771097540855408, 0.26761335134506226, 0.8327310085296631, 0.5104811787605286, 0.5094267129898071, -0.3049761652946472, 1.0695898532867432, 0.4562971591949463, 0.8512406945228577, -0.23605607450008392, 0.29339879751205444, 0.3920566439628601, -0.37256211042404175, 0.9939690828323364, 1.087404489517212, 0.7927243709564209, 1.5848685503005981, 1.9496333599090576, 0.0, 0.0, -0.0, -8.499900817871094, -8.420445442199707, -9.106385231018066, -8.800430297851562, -7.9505743980407715, -7.883469581604004, -7.1576642990112305, -7.316928386688232, -6.421921730041504, -5.237420082092285, -5.88522481918335, -5.483541488647461, -5.149790287017822, -4.628054141998291, -4.573464393615723, -5.391697883605957, -4.5523881912231445, -3.9951248168945312, -3.4327011108398438, -3.2792389392852783, -1.2490171194076538, -1.562932014465332, -2.307455062866211, -2.6215200424194336, -1.6952338218688965, -1.3462600708007812, -1.6456193923950195, -0.36240482330322266, 0.09661098569631577, -0.9498084783554077, -1.479500651359558, 0.590585470199585, -0.21384693682193756, 0.14539068937301636, 0.9272205233573914, 2.063509464263916, 0.10045409947633743, 2.1693291664123535, 2.6167733669281006, 0.8676733374595642, 0.751863956451416, 0.8267828226089478, 0.8422709107398987, 0.4554542899131775, 0.14006710052490234, 0.6816073656082153, 0.12276685982942581, 0.1663532555103302, 1.8032764196395874, 1.0169185400009155, 0.6385407447814941, 0.9234153032302856, 1.6966866254806519, 0.3548000752925873, 1.633539080619812, 0.6883448362350464, 1.142061710357666, 0.5771097540855408, 0.26761335134506226, 0.8327310085296631, 0.5104811787605286, 0.5094267129898071, -0.3049761652946472, 1.0695898532867432, 0.4562971591949463, 0.8512406945228577, -0.23605607450008392, 0.29339879751205444, 0.3920566439628601, -0.37256211042404175, 0.9939690828323364, 1.087404489517212, 0.7927243709564209, 1.5848685503005981, 1.9496333599090576, 0.0, 0.0], [0.0, -9.73315715789795, -9.558795928955078, -8.137001991271973, -9.01705265045166, -8.090566635131836, -8.063620567321777, -7.535719871520996, -7.451850891113281, -6.625983715057373, -7.071618556976318, -6.088757514953613, -5.591921329498291, -5.808406829833984, -4.332518100738525, -5.075527191162109, -5.1270551681518555, -3.963505506515503, -3.486729860305786, -4.740441799163818, -1.5416467189788818, -1.3520176410675049, -2.9848592281341553, -2.117262601852417, -1.4625957012176514, -2.078876495361328, -1.6361702680587769, -0.8525002598762512, -1.355848789215088, -1.5089898109436035, -1.23309326171875, -0.33774447441101074, -0.3041022717952728, -0.5918857455253601, -0.31371748447418213, 0.20684103667736053, 0.6883106827735901, 0.8286437392234802, -0.1490877866744995, 1.902413010597229, 0.8909291625022888, 1.3154410123825073, 0.07773640751838684, 0.5730637311935425, 3.2456934452056885, 0.905907928943634, 0.8341842889785767, 0.6132391691207886, 1.0671218633651733, 0.42525312304496765, 1.0896238088607788, 1.2452467679977417, 1.3613359928131104, 1.6356244087219238, 0.8993892669677734, 1.7913944721221924, -0.06206652522087097, 1.142383098602295, 0.6129201054573059, 0.17801415920257568, 0.6284996271133423, 0.22157606482505798, 0.9306464791297913, 0.3258381187915802, -0.009124715812504292, 0.2965834140777588, -0.0017199221765622497, 1.3513575792312622, -0.29166895151138306, 0.834690511226654, 1.4176561832427979, 0.9288002848625183, 1.4698749780654907, 1.1454718112945557, 1.2755298614501953, 1.863171100616455, 2.283687114715576, 0.0, -0.0, -9.73315715789795, -9.558795928955078, -8.137001991271973, -9.01705265045166, -8.090566635131836, -8.063620567321777, -7.535719871520996, -7.451850891113281, -6.625983715057373, -7.071618556976318, -6.088757514953613, -5.591921329498291, -5.808406829833984, -4.332518100738525, -5.075527191162109, -5.1270551681518555, -3.963505506515503, -3.486729860305786, -4.740441799163818, -1.5416467189788818, -1.3520176410675049, -2.9848592281341553, -2.117262601852417, -1.4625957012176514, -2.078876495361328, -1.6361702680587769, -0.8525002598762512, -1.355848789215088, -1.5089898109436035, -1.23309326171875, -0.33774447441101074, -0.3041022717952728, -0.5918857455253601, -0.31371748447418213, 0.20684103667736053, 0.6883106827735901, 0.8286437392234802, -0.1490877866744995, 1.902413010597229, 0.8909291625022888, 1.3154410123825073, 0.07773640751838684, 0.5730637311935425, 3.2456934452056885, 0.905907928943634, 0.8341842889785767, 0.6132391691207886, 1.0671218633651733, 0.42525312304496765, 1.0896238088607788, 1.2452467679977417, 1.3613359928131104, 1.6356244087219238, 0.8993892669677734, 1.7913944721221924, -0.06206652522087097, 1.142383098602295, 0.6129201054573059, 0.17801415920257568, 0.6284996271133423, 0.22157606482505798, 0.9306464791297913, 0.3258381187915802, -0.009124715812504292, 0.2965834140777588, -0.0017199221765622497, 1.3513575792312622, -0.29166895151138306, 0.834690511226654, 1.4176561832427979, 0.9288002848625183, 1.4698749780654907, 1.1454718112945557, 1.2755298614501953, 1.863171100616455, 2.283687114715576, 0.0], [0.0, -9.510427474975586, -10.068461418151855, -8.847774505615234, -8.677592277526855, -8.14795970916748, -7.790012359619141, -7.626285552978516, -7.410640716552734, -7.084758281707764, -6.575837135314941, -6.198518753051758, -5.749501705169678, -5.978025913238525, -5.7460503578186035, -4.62960147857666, -4.687788486480713, -4.323444843292236, -5.068197727203369, -3.215970277786255, -3.3813703060150146, -2.3270304203033447, -2.097015380859375, -2.195589065551758, -2.2615864276885986, -1.7944709062576294, -1.8279091119766235, -1.4434540271759033, -0.5011073350906372, -0.8499088883399963, -1.72879958152771, -0.8882162570953369, -0.0123209897428751, -0.3112236559391022, -0.2664400041103363, 0.11307316273450851, 0.36572086811065674, 0.6860858798027039, 2.131577968597412, -0.602383553981781, 0.5097928643226624, 1.5597864389419556, 1.165812373161316, 0.5835264325141907, 1.2007317543029785, 1.4782136678695679, 0.6520431041717529, -0.4760989546775818, 0.3734642267227173, 0.37481579184532166, 0.7580723166465759, 0.4486110508441925, 0.800657331943512, 1.203913927078247, -1.8006055355072021, -0.44527944922447205, 0.622075080871582, 0.6776427626609802, 0.9574332237243652, -0.49337711930274963, 0.7197121381759644, 0.24692441523075104, 0.287078857421875, 0.3200763761997223, 0.11102402210235596, -0.6379902362823486, -0.5252388119697571, 0.19393303990364075, 0.40085068345069885, -0.07888805866241455, 0.26555418968200684, 1.1390047073364258, 1.077610731124878, 0.3076831102371216, 0.2471550852060318, 0.8479176163673401, 0.0, 0.0, -0.0, -9.510427474975586, -10.068461418151855, -8.847774505615234, -8.677592277526855, -8.14795970916748, -7.790012359619141, -7.626285552978516, -7.410640716552734, -7.084758281707764, -6.575837135314941, -6.198518753051758, -5.749501705169678, -5.978025913238525, -5.7460503578186035, -4.62960147857666, -4.687788486480713, -4.323444843292236, -5.068197727203369, -3.215970277786255, -3.3813703060150146, -2.3270304203033447, -2.097015380859375, -2.195589065551758, -2.2615864276885986, -1.7944709062576294, -1.8279091119766235, -1.4434540271759033, -0.5011073350906372, -0.8499088883399963, -1.72879958152771, -0.8882162570953369, -0.0123209897428751, -0.3112236559391022, -0.2664400041103363, 0.11307316273450851, 0.36572086811065674, 0.6860858798027039, 2.131577968597412, -0.602383553981781, 0.5097928643226624, 1.5597864389419556, 1.165812373161316, 0.5835264325141907, 1.2007317543029785, 1.4782136678695679, 0.6520431041717529, -0.4760989546775818, 0.3734642267227173, 0.37481579184532166, 0.7580723166465759, 0.4486110508441925, 0.800657331943512, 1.203913927078247, -1.8006055355072021, -0.44527944922447205, 0.622075080871582, 0.6776427626609802, 0.9574332237243652, -0.49337711930274963, 0.7197121381759644, 0.24692441523075104, 0.287078857421875, 0.3200763761997223, 0.11102402210235596, -0.6379902362823486, -0.5252388119697571, 0.19393303990364075, 0.40085068345069885, -0.07888805866241455, 0.26555418968200684, 1.1390047073364258, 1.077610731124878, 0.3076831102371216, 0.2471550852060318, 0.8479176163673401, 0.0, 0.0], [0.0, -11.143072128295898, -10.161264419555664, -9.690581321716309, -8.99758529663086, -8.77692985534668, -8.663308143615723, -7.583280086517334, -8.408257484436035, -7.68134880065918, -7.2328972816467285, -7.493480205535889, -6.338867664337158, -5.846163272857666, -6.52809476852417, -4.036965847015381, -3.0364890098571777, -4.03186559677124, -3.1921067237854004, -3.416121006011963, -3.383108615875244, -2.9382359981536865, -2.630828619003296, -2.6101157665252686, -2.9667348861694336, -1.4423449039459229, -1.5574995279312134, -0.5302280783653259, -1.7238454818725586, -0.3284820318222046, -1.0377837419509888, -0.0784464180469513, -0.813316822052002, 1.8354676961898804, -0.4880827069282532, -2.1066627502441406, -0.23719023168087006, 0.28400516510009766, 0.5172229409217834, -0.8523693680763245, 1.134813904762268, 0.64735347032547, 1.1545270681381226, 0.6970698237419128, -1.4722508192062378, 1.9955976009368896, 0.1275946944952011, 0.8304693102836609, 1.044960618019104, 0.7503405809402466, 0.8298028111457825, 2.6229591369628906, 1.4825209379196167, 0.986968457698822, 1.6466343402862549, 2.2204883098602295, 0.2158474624156952, -0.12638737261295319, 1.2107148170471191, 0.2153249979019165, 0.6296710968017578, 0.8333602547645569, 0.5909835696220398, 0.40724068880081177, 0.4571892023086548, -0.11408183723688126, 1.14725923538208, 0.20714867115020752, -0.5115687251091003, 0.12455864995718002, 0.2724333107471466, -0.5219183564186096, -0.6058189272880554, -0.03378347307443619, 1.107136607170105, 1.2663393020629883, 2.8834753036499023, 0.0, -0.0, -11.143072128295898, -10.161264419555664, -9.690581321716309, -8.99758529663086, -8.77692985534668, -8.663308143615723, -7.583280086517334, -8.408257484436035, -7.68134880065918, -7.2328972816467285, -7.493480205535889, -6.338867664337158, -5.846163272857666, -6.52809476852417, -4.036965847015381, -3.0364890098571777, -4.03186559677124, -3.1921067237854004, -3.416121006011963, -3.383108615875244, -2.9382359981536865, -2.630828619003296, -2.6101157665252686, -2.9667348861694336, -1.4423449039459229, -1.5574995279312134, -0.5302280783653259, -1.7238454818725586, -0.3284820318222046, -1.0377837419509888, -0.0784464180469513, -0.813316822052002, 1.8354676961898804, -0.4880827069282532, -2.1066627502441406, -0.23719023168087006, 0.28400516510009766, 0.5172229409217834, -0.8523693680763245, 1.134813904762268, 0.64735347032547, 1.1545270681381226, 0.6970698237419128, -1.4722508192062378, 1.9955976009368896, 0.1275946944952011, 0.8304693102836609, 1.044960618019104, 0.7503405809402466, 0.8298028111457825, 2.6229591369628906, 1.4825209379196167, 0.986968457698822, 1.6466343402862549, 2.2204883098602295, 0.2158474624156952, -0.12638737261295319, 1.2107148170471191, 0.2153249979019165, 0.6296710968017578, 0.8333602547645569, 0.5909835696220398, 0.40724068880081177, 0.4571892023086548, -0.11408183723688126, 1.14725923538208, 0.20714867115020752, -0.5115687251091003, 0.12455864995718002, 0.2724333107471466, -0.5219183564186096, -0.6058189272880554, -0.03378347307443619, 1.107136607170105, 1.2663393020629883, 2.8834753036499023, 0.0], [0.0, -11.001632690429688, -9.708892822265625, -9.741327285766602, -9.659147262573242, -9.174899101257324, -8.368742942810059, -8.112702369689941, -8.204140663146973, -7.220523357391357, -7.474825382232666, -6.970088958740234, -6.130753993988037, -6.764431953430176, -7.433661937713623, -5.15421199798584, -4.700042247772217, -4.198253154754639, -3.5942270755767822, -3.737229824066162, -3.8354134559631348, -4.091030120849609, -2.0775012969970703, -3.136235475540161, -1.6831766366958618, -1.1734620332717896, -3.4577219486236572, -2.5368518829345703, -0.9411380290985107, -2.169726848602295, -2.024808883666992, -0.4141266942024231, -0.18319407105445862, -0.9968904852867126, -0.44901809096336365, 0.07247710973024368, -0.0003139222098980099, 0.5434949398040771, 0.5489462018013, -0.2577689588069916, 0.2388230860233307, 0.28979039192199707, 0.04352403059601784, -0.1092696338891983, -0.1538420170545578, 0.9361448287963867, 0.850001335144043, 1.7336583137512207, 0.41176217794418335, -0.047114670276641846, -0.04746113717556, 1.2716330289840698, 1.036017656326294, 1.0097569227218628, 1.7799391746520996, 0.16952835023403168, 0.3077680468559265, 0.7596848607063293, 0.5691264867782593, 0.2883290946483612, 0.2232293039560318, 0.08650308847427368, 0.23429518938064575, 0.13854938745498657, 0.48123347759246826, -0.004785834811627865, 0.3565998077392578, 0.7684255838394165, -0.6869737505912781, 0.03739343583583832, -0.012688899412751198, -0.28140997886657715, -0.020480172708630562, 0.48677271604537964, 0.6085574626922607, 0.9048555493354797, 2.8358492851257324, 0.0, -0.0, -11.001632690429688, -9.708892822265625, -9.741327285766602, -9.659147262573242, -9.174899101257324, -8.368742942810059, -8.112702369689941, -8.204140663146973, -7.220523357391357, -7.474825382232666, -6.970088958740234, -6.130753993988037, -6.764431953430176, -7.433661937713623, -5.15421199798584, -4.700042247772217, -4.198253154754639, -3.5942270755767822, -3.737229824066162, -3.8354134559631348, -4.091030120849609, -2.0775012969970703, -3.136235475540161, -1.6831766366958618, -1.1734620332717896, -3.4577219486236572, -2.5368518829345703, -0.9411380290985107, -2.169726848602295, -2.024808883666992, -0.4141266942024231, -0.18319407105445862, -0.9968904852867126, -0.44901809096336365, 0.07247710973024368, -0.0003139222098980099, 0.5434949398040771, 0.5489462018013, -0.2577689588069916, 0.2388230860233307, 0.28979039192199707, 0.04352403059601784, -0.1092696338891983, -0.1538420170545578, 0.9361448287963867, 0.850001335144043, 1.7336583137512207, 0.41176217794418335, -0.047114670276641846, -0.04746113717556, 1.2716330289840698, 1.036017656326294, 1.0097569227218628, 1.7799391746520996, 0.16952835023403168, 0.3077680468559265, 0.7596848607063293, 0.5691264867782593, 0.2883290946483612, 0.2232293039560318, 0.08650308847427368, 0.23429518938064575, 0.13854938745498657, 0.48123347759246826, -0.004785834811627865, 0.3565998077392578, 0.7684255838394165, -0.6869737505912781, 0.03739343583583832, -0.012688899412751198, -0.28140997886657715, -0.020480172708630562, 0.48677271604537964, 0.6085574626922607, 0.9048555493354797, 2.8358492851257324, 0.0], [0.0, -9.721953392028809, -10.323698043823242, -10.150055885314941, -10.277924537658691, -9.513775825500488, -9.437126159667969, -8.31549072265625, -8.053276062011719, -9.174776077270508, -6.42576789855957, -5.634652614593506, -6.208438396453857, -6.580273628234863, -6.0323872566223145, -5.439165115356445, -4.265763759613037, -5.097933769226074, -4.340780258178711, -3.6551973819732666, -3.9753963947296143, -0.6125994324684143, -3.8605117797851562, -2.587193250656128, -2.8329551219940186, -1.9915997982025146, -1.5869144201278687, -2.028959035873413, -1.7024259567260742, -2.3975462913513184, -1.3251020908355713, -1.647599458694458, -1.167653203010559, -1.4828431606292725, -0.4012978672981262, -0.48688802123069763, -0.547867476940155, 0.09686741232872009, -0.7728464007377625, 0.0016768763307482004, 0.26172468066215515, -0.8799155354499817, -0.36609289050102234, -0.02405686490237713, -0.5382399559020996, 0.24901844561100006, 0.15356461703777313, 0.5214269757270813, 0.8070628643035889, -0.12111145257949829, 0.6623119711875916, 0.2635962963104248, 0.4902113378047943, 1.5489012002944946, 0.4541928172111511, 0.31825339794158936, -0.9125222563743591, 1.0293511152267456, 0.6534992456436157, -0.15849065780639648, 0.7046650648117065, 0.8824355602264404, 0.6569909453392029, -0.05672657862305641, 0.43123185634613037, -0.32922717928886414, -0.8886439800262451, -0.053565189242362976, -0.8564479947090149, -0.48645102977752686, -0.5235024690628052, -0.40417298674583435, 0.5504145622253418, 0.21495777368545532, 0.2582917809486389, 1.1839776039123535, 0.0, 0.0, -0.0, -9.721953392028809, -10.323698043823242, -10.150055885314941, -10.277924537658691, -9.513775825500488, -9.437126159667969, -8.31549072265625, -8.053276062011719, -9.174776077270508, -6.42576789855957, -5.634652614593506, -6.208438396453857, -6.580273628234863, -6.0323872566223145, -5.439165115356445, -4.265763759613037, -5.097933769226074, -4.340780258178711, -3.6551973819732666, -3.9753963947296143, -0.6125994324684143, -3.8605117797851562, -2.587193250656128, -2.8329551219940186, -1.9915997982025146, -1.5869144201278687, -2.028959035873413, -1.7024259567260742, -2.3975462913513184, -1.3251020908355713, -1.647599458694458, -1.167653203010559, -1.4828431606292725, -0.4012978672981262, -0.48688802123069763, -0.547867476940155, 0.09686741232872009, -0.7728464007377625, 0.0016768763307482004, 0.26172468066215515, -0.8799155354499817, -0.36609289050102234, -0.02405686490237713, -0.5382399559020996, 0.24901844561100006, 0.15356461703777313, 0.5214269757270813, 0.8070628643035889, -0.12111145257949829, 0.6623119711875916, 0.2635962963104248, 0.4902113378047943, 1.5489012002944946, 0.4541928172111511, 0.31825339794158936, -0.9125222563743591, 1.0293511152267456, 0.6534992456436157, -0.15849065780639648, 0.7046650648117065, 0.8824355602264404, 0.6569909453392029, -0.05672657862305641, 0.43123185634613037, -0.32922717928886414, -0.8886439800262451, -0.053565189242362976, -0.8564479947090149, -0.48645102977752686, -0.5235024690628052, -0.40417298674583435, 0.5504145622253418, 0.21495777368545532, 0.2582917809486389, 1.1839776039123535, 0.0, 0.0], [0.0, -10.26006031036377, -10.636564254760742, -10.31364631652832, -10.374513626098633, -10.087974548339844, -9.651774406433105, -8.493800163269043, -8.46788215637207, -10.070260047912598, -7.621777534484863, -6.591652870178223, -6.915627956390381, -6.112318992614746, -5.366504192352295, -4.540929794311523, -4.890353679656982, -4.992806911468506, -4.173266410827637, -2.500711441040039, -3.910688638687134, -3.502751350402832, -2.7771222591400146, -3.146730899810791, -1.680719017982483, -4.76807165145874, -0.9962925314903259, -2.59635329246521, -1.8908740282058716, -1.6977050304412842, -0.7842602729797363, -1.3844081163406372, -1.3757587671279907, -3.793731689453125, -0.0929211750626564, -0.233734130859375, -1.3257663249969482, -1.1254459619522095, -0.5306898951530457, -0.5783278346061707, -0.600246250629425, -0.7889711856842041, -0.302444726228714, -0.6983290910720825, 0.096543088555336, -0.27956461906433105, 0.2149261236190796, 0.424746036529541, -0.20668567717075348, 0.381008505821228, 0.7248877286911011, 0.918878436088562, 1.3700871467590332, -0.2553420960903168, 0.7986700534820557, 0.6112646460533142, 1.8207181692123413, 0.8538150191307068, 0.16031858325004578, 0.40626952052116394, 1.1466248035430908, -0.5211176872253418, -0.7381384968757629, -0.12268383800983429, 2.2731130123138428, -0.7751836180686951, 0.07120111584663391, -0.9915684461593628, 0.10714778304100037, -0.01046492625027895, -0.38916897773742676, -0.23970767855644226, -0.8881807327270508, -0.11981457471847534, -0.6900535821914673, 0.20624592900276184, 0.0, 0.0, -0.0, -10.26006031036377, -10.636564254760742, -10.31364631652832, -10.374513626098633, -10.087974548339844, -9.651774406433105, -8.493800163269043, -8.46788215637207, -10.070260047912598, -7.621777534484863, -6.591652870178223, -6.915627956390381, -6.112318992614746, -5.366504192352295, -4.540929794311523, -4.890353679656982, -4.992806911468506, -4.173266410827637, -2.500711441040039, -3.910688638687134, -3.502751350402832, -2.7771222591400146, -3.146730899810791, -1.680719017982483, -4.76807165145874, -0.9962925314903259, -2.59635329246521, -1.8908740282058716, -1.6977050304412842, -0.7842602729797363, -1.3844081163406372, -1.3757587671279907, -3.793731689453125, -0.0929211750626564, -0.233734130859375, -1.3257663249969482, -1.1254459619522095, -0.5306898951530457, -0.5783278346061707, -0.600246250629425, -0.7889711856842041, -0.302444726228714, -0.6983290910720825, 0.096543088555336, -0.27956461906433105, 0.2149261236190796, 0.424746036529541, -0.20668567717075348, 0.381008505821228, 0.7248877286911011, 0.918878436088562, 1.3700871467590332, -0.2553420960903168, 0.7986700534820557, 0.6112646460533142, 1.8207181692123413, 0.8538150191307068, 0.16031858325004578, 0.40626952052116394, 1.1466248035430908, -0.5211176872253418, -0.7381384968757629, -0.12268383800983429, 2.2731130123138428, -0.7751836180686951, 0.07120111584663391, -0.9915684461593628, 0.10714778304100037, -0.01046492625027895, -0.38916897773742676, -0.23970767855644226, -0.8881807327270508, -0.11981457471847534, -0.6900535821914673, 0.20624592900276184, 0.0, 0.0], [0.0, -14.327473640441895, -11.571035385131836, -11.236577033996582, -10.688431739807129, -9.041404724121094, -9.788498878479004, -9.908258438110352, -8.445960998535156, -7.9348554611206055, -7.029091835021973, -7.071727275848389, -7.303515434265137, -6.007571220397949, -6.186108112335205, -4.770266532897949, -5.5847578048706055, -4.591916561126709, -4.4616827964782715, -4.482580661773682, -3.6226346492767334, -3.1435930728912354, -3.2919914722442627, -2.2257490158081055, -2.0469024181365967, -2.483973503112793, -2.024021625518799, -2.3301103115081787, -4.420870780944824, -1.2762764692306519, -1.2694158554077148, -1.3865501880645752, -1.0298583507537842, -0.5836706757545471, -1.499460220336914, -0.8614854216575623, -1.6038806438446045, -0.641198992729187, -0.5353097915649414, -1.5219330787658691, -0.6021539568901062, -0.6835475564002991, 0.2826484441757202, -0.6827362775802612, 0.035457976162433624, 0.649433970451355, 0.5430518388748169, -0.21467678248882294, -0.6165758371353149, 0.5107118487358093, -0.045805126428604126, 0.5015305280685425, -1.9600915908813477, -0.6037216782569885, -0.7206678986549377, -0.4946960508823395, -1.1822726726531982, 0.41398268938064575, 0.8271125555038452, 0.8375669121742249, 0.14476212859153748, -0.2417132705450058, -0.23422133922576904, 0.307420551776886, 2.400177478790283, 0.06898940354585648, -0.08548463881015778, -0.2845001220703125, 0.7742006778717041, 0.31211864948272705, -0.0035738754086196423, -0.8302821516990662, 0.7698379158973694, -0.9929226040840149, -0.564498245716095, -1.6551415920257568, 0.0, 0.0, -0.0, -14.327473640441895, -11.571035385131836, -11.236577033996582, -10.688431739807129, -9.041404724121094, -9.788498878479004, -9.908258438110352, -8.445960998535156, -7.9348554611206055, -7.029091835021973, -7.071727275848389, -7.303515434265137, -6.007571220397949, -6.186108112335205, -4.770266532897949, -5.5847578048706055, -4.591916561126709, -4.4616827964782715, -4.482580661773682, -3.6226346492767334, -3.1435930728912354, -3.2919914722442627, -2.2257490158081055, -2.0469024181365967, -2.483973503112793, -2.024021625518799, -2.3301103115081787, -4.420870780944824, -1.2762764692306519, -1.2694158554077148, -1.3865501880645752, -1.0298583507537842, -0.5836706757545471, -1.499460220336914, -0.8614854216575623, -1.6038806438446045, -0.641198992729187, -0.5353097915649414, -1.5219330787658691, -0.6021539568901062, -0.6835475564002991, 0.2826484441757202, -0.6827362775802612, 0.035457976162433624, 0.649433970451355, 0.5430518388748169, -0.21467678248882294, -0.6165758371353149, 0.5107118487358093, -0.045805126428604126, 0.5015305280685425, -1.9600915908813477, -0.6037216782569885, -0.7206678986549377, -0.4946960508823395, -1.1822726726531982, 0.41398268938064575, 0.8271125555038452, 0.8375669121742249, 0.14476212859153748, -0.2417132705450058, -0.23422133922576904, 0.307420551776886, 2.400177478790283, 0.06898940354585648, -0.08548463881015778, -0.2845001220703125, 0.7742006778717041, 0.31211864948272705, -0.0035738754086196423, -0.8302821516990662, 0.7698379158973694, -0.9929226040840149, -0.564498245716095, -1.6551415920257568, -0.0, -0.0], [0.0, -12.776491165161133, -11.970268249511719, -12.159707069396973, -11.286476135253906, -10.486532211303711, -10.695171356201172, -9.705323219299316, -8.86867618560791, -8.512920379638672, -8.96999454498291, -8.39570426940918, -6.6354193687438965, -6.691972732543945, -6.161359786987305, -6.06350564956665, -5.483178615570068, -4.72976016998291, -4.320239067077637, -4.552701473236084, -4.3276591300964355, -3.978640556335449, -3.4800469875335693, -3.2826805114746094, -1.584765911102295, -2.7758419513702393, -2.0967698097229004, -1.540718913078308, -1.9191151857376099, -1.603333592414856, -1.3961613178253174, -2.3105356693267822, -1.7944483757019043, -0.5692569017410278, -1.3188716173171997, -1.2076040506362915, -1.4518213272094727, 0.8557626605033875, -0.5528979897499084, -1.1465492248535156, -0.7917883992195129, -0.6930893659591675, -0.40005117654800415, -1.1235787868499756, -0.41283100843429565, -1.3019345998764038, 0.07651618868112564, -0.056367434561252594, -0.6494258046150208, 0.3574572205543518, -0.08091286569833755, 1.1828765869140625, 1.1169887781143188, -0.05171804130077362, 0.12187609821557999, -0.07582786679267883, -0.30290383100509644, 0.3673292100429535, -0.5452612042427063, -0.02924993634223938, 0.34522828459739685, 0.7771480679512024, 0.5387143492698669, -0.003625762416049838, 0.00968360435217619, -0.42728346586227417, -0.552419126033783, 0.7051886916160583, -0.9214672446250916, -1.6514828205108643, 0.41786059737205505, -1.617470145225525, -0.3645983934402466, -1.075162649154663, -1.0000840425491333, -1.4394553899765015, 0.0, 0.0, -0.0, -12.776491165161133, -11.970268249511719, -12.159707069396973, -11.286476135253906, -10.486532211303711, -10.695171356201172, -9.705323219299316, -8.86867618560791, -8.512920379638672, -8.96999454498291, -8.39570426940918, -6.6354193687438965, -6.691972732543945, -6.161359786987305, -6.06350564956665, -5.483178615570068, -4.72976016998291, -4.320239067077637, -4.552701473236084, -4.3276591300964355, -3.978640556335449, -3.4800469875335693, -3.2826805114746094, -1.584765911102295, -2.7758419513702393, -2.0967698097229004, -1.540718913078308, -1.9191151857376099, -1.603333592414856, -1.3961613178253174, -2.3105356693267822, -1.7944483757019043, -0.5692569017410278, -1.3188716173171997, -1.2076040506362915, -1.4518213272094727, 0.8557626605033875, -0.5528979897499084, -1.1465492248535156, -0.7917883992195129, -0.6930893659591675, -0.40005117654800415, -1.1235787868499756, -0.41283100843429565, -1.3019345998764038, 0.07651618868112564, -0.056367434561252594, -0.6494258046150208, 0.3574572205543518, -0.08091286569833755, 1.1828765869140625, 1.1169887781143188, -0.05171804130077362, 0.12187609821557999, -0.07582786679267883, -0.30290383100509644, 0.3673292100429535, -0.5452612042427063, -0.02924993634223938, 0.34522828459739685, 0.7771480679512024, 0.5387143492698669, -0.003625762416049838, 0.00968360435217619, -0.42728346586227417, -0.552419126033783, 0.7051886916160583, -0.9214672446250916, -1.6514828205108643, 0.41786059737205505, -1.617470145225525, -0.3645983934402466, -1.075162649154663, -1.0000840425491333, -1.4394553899765015, -0.0, -0.0], [0.0, -15.18891716003418, -12.884549140930176, -11.654484748840332, -11.193131446838379, -10.985305786132812, -10.002888679504395, -9.880764961242676, -8.259241104125977, -8.969381332397461, -7.532946586608887, -7.305524826049805, -7.331872940063477, -6.774289608001709, -6.628685474395752, -5.84103536605835, -5.332074165344238, -5.002808094024658, -5.017678737640381, -4.518998622894287, -4.857170104980469, -1.8558868169784546, -1.4156831502914429, -1.8340245485305786, -2.649164915084839, -1.3346002101898193, -1.9274507761001587, -2.176194429397583, -2.157648801803589, -1.7715810537338257, -3.6158621311187744, -2.5093469619750977, -1.1256754398345947, 0.10753317177295685, -1.0882346630096436, -1.8648667335510254, -1.4108161926269531, -1.7068703174591064, -1.6147326231002808, -1.0965795516967773, -1.5925214290618896, -1.3754026889801025, -1.8620411157608032, -1.3944507837295532, -0.0851542055606842, -1.4328566789627075, 0.5387683510780334, -0.969041645526886, 0.12274899333715439, 2.1490445137023926, -0.07987625896930695, 0.5088814496994019, 0.33734574913978577, -0.537691593170166, -1.0585834980010986, -0.11208587139844894, -0.5139692425727844, 0.032927364110946655, -0.12417208403348923, 0.322809100151062, 0.5471194386482239, -0.25855326652526855, -1.7870680093765259, 0.08532177656888962, -0.03344149515032768, -0.29723629355430603, -0.523857831954956, 0.5855398178100586, -0.892932653427124, -0.2726580798625946, -1.1207239627838135, -0.48048657178878784, -0.5368441343307495, -1.7045867443084717, -1.2179583311080933, -1.35123872756958, -1.7737983465194702, 0.0, -0.0, -15.18891716003418, -12.884549140930176, -11.654484748840332, -11.193131446838379, -10.985305786132812, -10.002888679504395, -9.880764961242676, -8.259241104125977, -8.969381332397461, -7.532946586608887, -7.305524826049805, -7.331872940063477, -6.774289608001709, -6.628685474395752, -5.84103536605835, -5.332074165344238, -5.002808094024658, -5.017678737640381, -4.518998622894287, -4.857170104980469, -1.8558868169784546, -1.4156831502914429, -1.8340245485305786, -2.649164915084839, -1.3346002101898193, -1.9274507761001587, -2.176194429397583, -2.157648801803589, -1.7715810537338257, -3.6158621311187744, -2.5093469619750977, -1.1256754398345947, 0.10753317177295685, -1.0882346630096436, -1.8648667335510254, -1.4108161926269531, -1.7068703174591064, -1.6147326231002808, -1.0965795516967773, -1.5925214290618896, -1.3754026889801025, -1.8620411157608032, -1.3944507837295532, -0.0851542055606842, -1.4328566789627075, 0.5387683510780334, -0.969041645526886, 0.12274899333715439, 2.1490445137023926, -0.07987625896930695, 0.5088814496994019, 0.33734574913978577, -0.537691593170166, -1.0585834980010986, -0.11208587139844894, -0.5139692425727844, 0.032927364110946655, -0.12417208403348923, 0.322809100151062, 0.5471194386482239, -0.25855326652526855, -1.7870680093765259, 0.08532177656888962, -0.03344149515032768, -0.29723629355430603, -0.523857831954956, 0.5855398178100586, -0.892932653427124, -0.2726580798625946, -1.1207239627838135, -0.48048657178878784, -0.5368441343307495, -1.7045867443084717, -1.2179583311080933, -1.35123872756958, -1.7737983465194702, -0.0], [0.0, 0.0, -13.531763076782227, -13.119489669799805, -12.626903533935547, -10.931900024414062, -10.371474266052246, -10.30624008178711, -9.825224876403809, -8.817510604858398, -8.643946647644043, -7.845016956329346, -6.7512617111206055, -7.858948707580566, -7.413424015045166, -5.471548080444336, -5.769688606262207, -5.107820987701416, -5.1509623527526855, -5.020968914031982, -5.046233654022217, -3.711472272872925, -2.7700612545013428, -4.002638816833496, -4.315169334411621, -1.8531452417373657, -1.5783284902572632, -2.3691911697387695, -3.5721676349639893, -1.839066505432129, -2.915311813354492, -2.0915050506591797, -1.6992013454437256, -2.323601722717285, -2.473552703857422, -1.6611665487289429, -3.142106056213379, -2.3522002696990967, -1.2466168403625488, -1.9777776002883911, -0.7751080393791199, -1.4478243589401245, -2.048051357269287, -1.2131165266036987, -1.1349751949310303, -1.9143738746643066, 0.9255927205085754, -1.3597545623779297, -0.9023914933204651, -1.1454166173934937, -1.0032068490982056, 0.010680883191525936, -0.8743454813957214, -0.9821357131004333, -0.1514604091644287, -0.11184396594762802, -0.5229042172431946, -0.007786290720105171, -0.633796751499176, -0.4953034520149231, 0.741018533706665, 0.05286906287074089, -0.003146891249343753, 0.09017162024974823, -0.165750190615654, -0.2735061049461365, -0.9712482690811157, -0.523404598236084, -0.9641411304473877, -1.638123631477356, -1.6159521341323853, -0.9986887574195862, -2.2690131664276123, -1.8456602096557617, -2.9288017749786377, -3.8889949321746826, 0.0, 0.0, -0.0, -0.0, -13.531763076782227, -13.119489669799805, -12.626903533935547, -10.931900024414062, -10.371474266052246, -10.30624008178711, -9.825224876403809, -8.817510604858398, -8.643946647644043, -7.845016956329346, -6.7512617111206055, -7.858948707580566, -7.413424015045166, -5.471548080444336, -5.769688606262207, -5.107820987701416, -5.1509623527526855, -5.020968914031982, -5.046233654022217, -3.711472272872925, -2.7700612545013428, -4.002638816833496, -4.315169334411621, -1.8531452417373657, -1.5783284902572632, -2.3691911697387695, -3.5721676349639893, -1.839066505432129, -2.915311813354492, -2.0915050506591797, -1.6992013454437256, -2.323601722717285, -2.473552703857422, -1.6611665487289429, -3.142106056213379, -2.3522002696990967, -1.2466168403625488, -1.9777776002883911, -0.7751080393791199, -1.4478243589401245, -2.048051357269287, -1.2131165266036987, -1.1349751949310303, -1.9143738746643066, 0.9255927205085754, -1.3597545623779297, -0.9023914933204651, -1.1454166173934937, -1.0032068490982056, 0.010680883191525936, -0.8743454813957214, -0.9821357131004333, -0.1514604091644287, -0.11184396594762802, -0.5229042172431946, -0.007786290720105171, -0.633796751499176, -0.4953034520149231, 0.741018533706665, 0.05286906287074089, -0.003146891249343753, 0.09017162024974823, -0.165750190615654, -0.2735061049461365, -0.9712482690811157, -0.523404598236084, -0.9641411304473877, -1.638123631477356, -1.6159521341323853, -0.9986887574195862, -2.2690131664276123, -1.8456602096557617, -2.9288017749786377, -3.8889949321746826, -0.0, -0.0], [0.0, 0.0, -15.080790519714355, -13.288225173950195, -12.603507041931152, -11.320089340209961, -10.731006622314453, -10.614563941955566, -9.838765144348145, -9.05044174194336, -8.821791648864746, -7.592907428741455, -8.354900360107422, -6.741959095001221, -6.38806676864624, -6.11857795715332, -5.578258514404297, -4.83942985534668, -4.741408824920654, -4.635068893432617, -3.94539475440979, -4.095150470733643, -2.837930202484131, -2.6476314067840576, -2.6259655952453613, -3.426274299621582, -3.5451669692993164, -2.931011438369751, -2.5396552085876465, -1.6700366735458374, -3.227170705795288, -2.0517964363098145, -3.053150177001953, -2.180205821990967, -3.282892942428589, -2.797001361846924, -3.7873380184173584, -2.198634386062622, -1.6350702047348022, -1.986533284187317, -2.0343942642211914, -1.13149893283844, -2.2573258876800537, -2.005354404449463, -1.3331233263015747, -0.6182757616043091, 1.6632115840911865, -1.478305459022522, -0.297025203704834, -0.9114413857460022, -0.908030092716217, -1.0691337585449219, -1.3220808506011963, -0.8069186806678772, -0.9025574922561646, -1.020452857017517, -0.40083974599838257, -1.1205075979232788, -1.2006216049194336, -0.481326162815094, -2.196524143218994, -0.3432507812976837, -0.20163540542125702, -0.432162344455719, -0.5920118689537048, -0.1806294471025467, -0.9216781854629517, 0.03968171402812004, -1.037915825843811, -1.1778372526168823, 0.15696091949939728, -1.2501672506332397, -0.7761865258216858, -1.1276246309280396, -3.9487788677215576, -2.331700325012207, 0.0, 0.0, -0.0, -0.0, -15.080790519714355, -13.288225173950195, -12.603507041931152, -11.320089340209961, -10.731006622314453, -10.614563941955566, -9.838765144348145, -9.05044174194336, -8.821791648864746, -7.592907428741455, -8.354900360107422, -6.741959095001221, -6.38806676864624, -6.11857795715332, -5.578258514404297, -4.83942985534668, -4.741408824920654, -4.635068893432617, -3.94539475440979, -4.095150470733643, -2.837930202484131, -2.6476314067840576, -2.6259655952453613, -3.426274299621582, -3.5451669692993164, -2.931011438369751, -2.5396552085876465, -1.6700366735458374, -3.227170705795288, -2.0517964363098145, -3.053150177001953, -2.180205821990967, -3.282892942428589, -2.797001361846924, -3.7873380184173584, -2.198634386062622, -1.6350702047348022, -1.986533284187317, -2.0343942642211914, -1.13149893283844, -2.2573258876800537, -2.005354404449463, -1.3331233263015747, -0.6182757616043091, 1.6632115840911865, -1.478305459022522, -0.297025203704834, -0.9114413857460022, -0.908030092716217, -1.0691337585449219, -1.3220808506011963, -0.8069186806678772, -0.9025574922561646, -1.020452857017517, -0.40083974599838257, -1.1205075979232788, -1.2006216049194336, -0.481326162815094, -2.196524143218994, -0.3432507812976837, -0.20163540542125702, -0.432162344455719, -0.5920118689537048, -0.1806294471025467, -0.9216781854629517, 0.03968171402812004, -1.037915825843811, -1.1778372526168823, 0.15696091949939728, -1.2501672506332397, -0.7761865258216858, -1.1276246309280396, -3.9487788677215576, -2.331700325012207, -0.0, -0.0], [0.0, 0.0, -15.267542839050293, -13.598410606384277, -12.610904693603516, -12.596758842468262, -11.097613334655762, -11.77463150024414, -9.306011199951172, -8.989204406738281, -7.985627174377441, -9.114530563354492, -8.315960884094238, -7.6712846755981445, -6.694803714752197, -6.532201290130615, -5.454497337341309, -5.737165451049805, -5.75672721862793, -5.293943881988525, -4.162254810333252, -2.5442209243774414, -3.940199851989746, -4.216279029846191, -4.841858863830566, -4.184537887573242, -2.661066770553589, -2.833496570587158, -2.4380688667297363, -1.8366804122924805, -3.5270094871520996, -3.1789186000823975, -3.4136979579925537, -2.49737286567688, -3.9719340801239014, -2.6557698249816895, -1.0935146808624268, -2.5434787273406982, -1.9430650472640991, -2.0824508666992188, -3.707388162612915, -2.5823512077331543, -2.606325626373291, 0.6999077796936035, -1.8355014324188232, -1.641455888748169, -1.507211685180664, -0.6372795701026917, -0.3669469952583313, 1.0390702486038208, -0.8389160633087158, -0.98947674036026, -0.8256350755691528, -0.9847580790519714, -1.0656366348266602, -0.6599606275558472, -3.1021792888641357, -1.35911226272583, 0.8480962514877319, -0.3402783274650574, -0.025874298065900803, -1.6824874877929688, -0.41214635968208313, -0.4694754481315613, -0.4305902123451233, -0.892881453037262, -1.2445836067199707, -0.922611653804779, 0.037075161933898926, -1.7279123067855835, -1.820616602897644, -1.6730135679244995, -4.396337985992432, -1.7913084030151367, -3.0919084548950195, -3.5382423400878906, 0.0, 0.0, -0.0, -0.0, -15.267542839050293, -13.598410606384277, -12.610904693603516, -12.596758842468262, -11.097613334655762, -11.77463150024414, -9.306011199951172, -8.989204406738281, -7.985627174377441, -9.114530563354492, -8.315960884094238, -7.6712846755981445, -6.694803714752197, -6.532201290130615, -5.454497337341309, -5.737165451049805, -5.75672721862793, -5.293943881988525, -4.162254810333252, -2.5442209243774414, -3.940199851989746, -4.216279029846191, -4.841858863830566, -4.184537887573242, -2.661066770553589, -2.833496570587158, -2.4380688667297363, -1.8366804122924805, -3.5270094871520996, -3.1789186000823975, -3.4136979579925537, -2.49737286567688, -3.9719340801239014, -2.6557698249816895, -1.0935146808624268, -2.5434787273406982, -1.9430650472640991, -2.0824508666992188, -3.707388162612915, -2.5823512077331543, -2.606325626373291, 0.6999077796936035, -1.8355014324188232, -1.641455888748169, -1.507211685180664, -0.6372795701026917, -0.3669469952583313, 1.0390702486038208, -0.8389160633087158, -0.98947674036026, -0.8256350755691528, -0.9847580790519714, -1.0656366348266602, -0.6599606275558472, -3.1021792888641357, -1.35911226272583, 0.8480962514877319, -0.3402783274650574, -0.025874298065900803, -1.6824874877929688, -0.41214635968208313, -0.4694754481315613, -0.4305902123451233, -0.892881453037262, -1.2445836067199707, -0.922611653804779, 0.037075161933898926, -1.7279123067855835, -1.820616602897644, -1.6730135679244995, -4.396337985992432, -1.7913084030151367, -3.0919084548950195, -3.5382423400878906, -0.0, -0.0], [0.0, 0.0, -16.196022033691406, -14.653644561767578, -13.562341690063477, -12.128716468811035, -11.710333824157715, -10.607735633850098, -9.242340087890625, -9.495312690734863, -9.888973236083984, -8.589018821716309, -7.570565223693848, -6.989804267883301, -6.8389506340026855, -6.536645412445068, -5.988617420196533, -5.3024210929870605, -5.494997501373291, -4.6023454666137695, -3.455137252807617, -3.8849987983703613, -2.884366512298584, -5.672645092010498, -3.5636796951293945, -4.500490188598633, -4.2010321617126465, -2.5299041271209717, -2.266948699951172, -3.9830989837646484, -1.7674057483673096, -2.861053943634033, -3.6130993366241455, -3.401000738143921, -3.6422765254974365, -3.4843461513519287, -3.714726686477661, -2.6859242916107178, -2.6927285194396973, -3.353360652923584, -2.6689300537109375, -2.5725929737091064, -2.7710070610046387, -0.8412606716156006, -3.706465721130371, -2.4246129989624023, -2.250018835067749, -2.2043638229370117, -1.1691420078277588, -0.7342776656150818, -1.1221650838851929, -2.143392324447632, -2.1145830154418945, -1.5040842294692993, -0.6102423667907715, -0.5200409889221191, -0.6140174865722656, 0.20134983956813812, 0.28633201122283936, 0.8121572136878967, -0.7079029083251953, -0.9636845588684082, -0.15095749497413635, -1.1534557342529297, -0.7552629709243774, -0.7457724213600159, -0.6146314144134521, -1.0598044395446777, -1.5698312520980835, -1.1095448732376099, -1.6882776021957397, -1.6432148218154907, -2.429048538208008, -2.0402863025665283, -2.529271364212036, -3.895359516143799, 0.0, 0.0, -0.0, -0.0, -16.196022033691406, -14.653644561767578, -13.562341690063477, -12.128716468811035, -11.710333824157715, -10.607735633850098, -9.242340087890625, -9.495312690734863, -9.888973236083984, -8.589018821716309, -7.570565223693848, -6.989804267883301, -6.8389506340026855, -6.536645412445068, -5.988617420196533, -5.3024210929870605, -5.494997501373291, -4.6023454666137695, -3.455137252807617, -3.8849987983703613, -2.884366512298584, -5.672645092010498, -3.5636796951293945, -4.500490188598633, -4.2010321617126465, -2.5299041271209717, -2.266948699951172, -3.9830989837646484, -1.7674057483673096, -2.861053943634033, -3.6130993366241455, -3.401000738143921, -3.6422765254974365, -3.4843461513519287, -3.714726686477661, -2.6859242916107178, -2.6927285194396973, -3.353360652923584, -2.6689300537109375, -2.5725929737091064, -2.7710070610046387, -0.8412606716156006, -3.706465721130371, -2.4246129989624023, -2.250018835067749, -2.2043638229370117, -1.1691420078277588, -0.7342776656150818, -1.1221650838851929, -2.143392324447632, -2.1145830154418945, -1.5040842294692993, -0.6102423667907715, -0.5200409889221191, -0.6140174865722656, 0.20134983956813812, 0.28633201122283936, 0.8121572136878967, -0.7079029083251953, -0.9636845588684082, -0.15095749497413635, -1.1534557342529297, -0.7552629709243774, -0.7457724213600159, -0.6146314144134521, -1.0598044395446777, -1.5698312520980835, -1.1095448732376099, -1.6882776021957397, -1.6432148218154907, -2.429048538208008, -2.0402863025665283, -2.529271364212036, -3.895359516143799, -0.0, -0.0], [0.0, 0.0, -16.47064208984375, -14.838129997253418, -14.023650169372559, -12.137932777404785, -9.183531761169434, -10.793696403503418, -11.278643608093262, -9.004033088684082, -9.286371231079102, -8.014595985412598, -7.534108638763428, -7.661052703857422, -6.139870643615723, -6.312953948974609, -6.60957145690918, -5.711532115936279, -4.968673229217529, -3.8693556785583496, -4.890170097351074, -4.6945295333862305, -3.8029394149780273, -6.069734573364258, -2.928607940673828, -1.106372594833374, -3.7680459022521973, -3.265425682067871, -2.52925443649292, -4.648047924041748, -2.945403814315796, -2.935699939727783, -4.122112274169922, -3.4951324462890625, -3.391052484512329, -4.22911262512207, -3.119050979614258, -3.721923589706421, -4.055392265319824, -3.438807964324951, -2.940394163131714, -4.024113178253174, -3.0353667736053467, -2.8840739727020264, -2.2764716148376465, -3.5466148853302, -4.506433963775635, -2.787513017654419, -4.606905937194824, -2.7139811515808105, -1.0731323957443237, -1.7350341081619263, -1.9137530326843262, -1.606016755104065, -0.5897330641746521, -1.30073082447052, -1.5250557661056519, -1.0175431966781616, -0.0571068674325943, -1.4795172214508057, -0.178029865026474, -0.6687892079353333, -1.2187179327011108, -0.731669545173645, -0.23143044114112854, -0.9023260474205017, -0.5530953407287598, -1.0303484201431274, -2.3715360164642334, -2.0220284461975098, -2.0646095275878906, -2.778573989868164, -1.9958583116531372, -2.9243133068084717, -3.879570722579956, -3.9943928718566895, 0.0, 0.0, -0.0, -0.0, -16.47064208984375, -14.838129997253418, -14.023650169372559, -12.137932777404785, -9.183531761169434, -10.793696403503418, -11.278643608093262, -9.004033088684082, -9.286371231079102, -8.014595985412598, -7.534108638763428, -7.661052703857422, -6.139870643615723, -6.312953948974609, -6.60957145690918, -5.711532115936279, -4.968673229217529, -3.8693556785583496, -4.890170097351074, -4.6945295333862305, -3.8029394149780273, -6.069734573364258, -2.928607940673828, -1.106372594833374, -3.7680459022521973, -3.265425682067871, -2.52925443649292, -4.648047924041748, -2.945403814315796, -2.935699939727783, -4.122112274169922, -3.4951324462890625, -3.391052484512329, -4.22911262512207, -3.119050979614258, -3.721923589706421, -4.055392265319824, -3.438807964324951, -2.940394163131714, -4.024113178253174, -3.0353667736053467, -2.8840739727020264, -2.2764716148376465, -3.5466148853302, -4.506433963775635, -2.787513017654419, -4.606905937194824, -2.7139811515808105, -1.0731323957443237, -1.7350341081619263, -1.9137530326843262, -1.606016755104065, -0.5897330641746521, -1.30073082447052, -1.5250557661056519, -1.0175431966781616, -0.0571068674325943, -1.4795172214508057, -0.178029865026474, -0.6687892079353333, -1.2187179327011108, -0.731669545173645, -0.23143044114112854, -0.9023260474205017, -0.5530953407287598, -1.0303484201431274, -2.3715360164642334, -2.0220284461975098, -2.0646095275878906, -2.778573989868164, -1.9958583116531372, -2.9243133068084717, -3.879570722579956, -3.9943928718566895, -0.0, -0.0], [0.0, 0.0, -16.14178466796875, -15.007489204406738, -14.082762718200684, -12.006443977355957, -12.668383598327637, -12.070032119750977, -9.498919486999512, -9.173652648925781, -8.835126876831055, -8.988561630249023, -8.640708923339844, -7.144774436950684, -6.912456035614014, -6.604418754577637, -6.471175670623779, -6.1146440505981445, -4.438659191131592, -5.403509140014648, -4.910642147064209, -4.753509998321533, -4.33272123336792, -4.1102519035339355, -4.018523693084717, -4.055492877960205, -3.1291329860687256, -4.415332317352295, -4.555124282836914, -4.046048164367676, -2.190483808517456, -5.1954216957092285, -3.8993701934814453, -4.471887111663818, -4.800741195678711, -3.89816951751709, -4.219490051269531, -4.576484680175781, -4.338596820831299, -4.142616271972656, -4.414068698883057, -3.7679519653320312, -3.9106662273406982, -4.763515472412109, -2.4366226196289062, -2.6692960262298584, -3.749652147293091, -1.2997958660125732, -2.046478271484375, -2.597818374633789, -0.0335116870701313, -1.7043684720993042, -1.4569042921066284, -1.4458186626434326, -2.513916015625, -1.4191124439239502, -1.545197606086731, -2.112577199935913, -1.1073323488235474, -0.913672685623169, -0.03455882519483566, -0.6334273815155029, -0.6951208114624023, -0.8179629445075989, -0.6376850008964539, -0.8383203148841858, -0.6084356307983398, -0.5259548425674438, -0.31730449199676514, -1.6513389348983765, -1.223611831665039, -2.0594961643218994, -3.026005744934082, -2.8208460807800293, -4.345516204833984, -3.5341947078704834, 0.0, 0.0, -0.0, -0.0, -16.14178466796875, -15.007489204406738, -14.082762718200684, -12.006443977355957, -12.668383598327637, -12.070032119750977, -9.498919486999512, -9.173652648925781, -8.835126876831055, -8.988561630249023, -8.640708923339844, -7.144774436950684, -6.912456035614014, -6.604418754577637, -6.471175670623779, -6.1146440505981445, -4.438659191131592, -5.403509140014648, -4.910642147064209, -4.753509998321533, -4.33272123336792, -4.1102519035339355, -4.018523693084717, -4.055492877960205, -3.1291329860687256, -4.415332317352295, -4.555124282836914, -4.046048164367676, -2.190483808517456, -5.1954216957092285, -3.8993701934814453, -4.471887111663818, -4.800741195678711, -3.89816951751709, -4.219490051269531, -4.576484680175781, -4.338596820831299, -4.142616271972656, -4.414068698883057, -3.7679519653320312, -3.9106662273406982, -4.763515472412109, -2.4366226196289062, -2.6692960262298584, -3.749652147293091, -1.2997958660125732, -2.046478271484375, -2.597818374633789, -0.0335116870701313, -1.7043684720993042, -1.4569042921066284, -1.4458186626434326, -2.513916015625, -1.4191124439239502, -1.545197606086731, -2.112577199935913, -1.1073323488235474, -0.913672685623169, -0.03455882519483566, -0.6334273815155029, -0.6951208114624023, -0.8179629445075989, -0.6376850008964539, -0.8383203148841858, -0.6084356307983398, -0.5259548425674438, -0.31730449199676514, -1.6513389348983765, -1.223611831665039, -2.0594961643218994, -3.026005744934082, -2.8208460807800293, -4.345516204833984, -3.5341947078704834, -0.0, -0.0], [0.0, 0.0, -17.980438232421875, -15.91618537902832, -14.569591522216797, -12.826913833618164, -11.697002410888672, -10.601547241210938, -10.425140380859375, -10.00715446472168, -9.718531608581543, -8.39892864227295, -8.015935897827148, -7.710698127746582, -6.767186641693115, -6.7129011154174805, -6.9139790534973145, -6.335063457489014, -5.675520420074463, -5.575699329376221, -5.317549228668213, -4.286919116973877, -4.43727970123291, -4.0977373123168945, -3.321934700012207, -6.082564830780029, -2.2824764251708984, -2.108466625213623, -3.5004920959472656, -6.174279689788818, -4.187029838562012, -5.49419641494751, -4.04851770401001, -5.023472785949707, -2.311149835586548, -5.081452369689941, -6.129014015197754, -4.506183624267578, -4.366067886352539, -4.894847393035889, -3.8561503887176514, -4.331174850463867, -3.492077589035034, -4.758209705352783, -4.978038787841797, -4.2659502029418945, -3.9144704341888428, -4.635754108428955, -1.0840167999267578, -3.544832229614258, -1.9427803754806519, -1.8319735527038574, -0.6531089544296265, -2.0949959754943848, -1.520021915435791, -0.8894153237342834, -2.023871421813965, -0.6760239601135254, -0.6404517889022827, -0.4339366555213928, 0.10143344104290009, -1.0944398641586304, -0.38005301356315613, -1.1501524448394775, -0.08465966582298279, -1.0651576519012451, -0.6103559732437134, -0.605297327041626, -1.601840615272522, -1.6520122289657593, -2.0843334197998047, -1.9164056777954102, -2.5924177169799805, -3.0770318508148193, -4.070530414581299, -5.095829010009766, 0.0, 0.0, -0.0, -0.0, -17.980438232421875, -15.91618537902832, -14.569591522216797, -12.826913833618164, -11.697002410888672, -10.601547241210938, -10.425140380859375, -10.00715446472168, -9.718531608581543, -8.39892864227295, -8.015935897827148, -7.710698127746582, -6.767186641693115, -6.7129011154174805, -6.9139790534973145, -6.335063457489014, -5.675520420074463, -5.575699329376221, -5.317549228668213, -4.286919116973877, -4.43727970123291, -4.0977373123168945, -3.321934700012207, -6.082564830780029, -2.2824764251708984, -2.108466625213623, -3.5004920959472656, -6.174279689788818, -4.187029838562012, -5.49419641494751, -4.04851770401001, -5.023472785949707, -2.311149835586548, -5.081452369689941, -6.129014015197754, -4.506183624267578, -4.366067886352539, -4.894847393035889, -3.8561503887176514, -4.331174850463867, -3.492077589035034, -4.758209705352783, -4.978038787841797, -4.2659502029418945, -3.9144704341888428, -4.635754108428955, -1.0840167999267578, -3.544832229614258, -1.9427803754806519, -1.8319735527038574, -0.6531089544296265, -2.0949959754943848, -1.520021915435791, -0.8894153237342834, -2.023871421813965, -0.6760239601135254, -0.6404517889022827, -0.4339366555213928, 0.10143344104290009, -1.0944398641586304, -0.38005301356315613, -1.1501524448394775, -0.08465966582298279, -1.0651576519012451, -0.6103559732437134, -0.605297327041626, -1.601840615272522, -1.6520122289657593, -2.0843334197998047, -1.9164056777954102, -2.5924177169799805, -3.0770318508148193, -4.070530414581299, -5.095829010009766, -0.0, -0.0], [0.0, 0.0, -17.451332092285156, -16.904037475585938, -14.279714584350586, -13.054938316345215, -9.051682472229004, -11.17206859588623, -11.983991622924805, -10.235368728637695, -9.315484046936035, -8.737184524536133, -8.339895248413086, -7.8116655349731445, -6.397276401519775, -7.315632343292236, -7.616184234619141, -6.326205253601074, -6.064702033996582, -5.899293899536133, -6.184295654296875, -5.163008689880371, -4.276001930236816, -4.001584529876709, -5.266971111297607, -4.719001770019531, -3.9053354263305664, -4.492527961730957, -3.0689501762390137, -4.870150089263916, -5.909066200256348, -5.35285758972168, -4.688917636871338, -4.5821428298950195, -4.2552947998046875, -4.665782928466797, -6.151910781860352, -4.304194450378418, -4.9561381340026855, -6.455098628997803, -3.9198856353759766, -5.359321117401123, -5.099809169769287, -5.293928623199463, -4.924133777618408, -4.781398296356201, -4.903411388397217, -3.7705185413360596, -2.8209760189056396, -3.0164875984191895, -3.005340337753296, -2.1485185623168945, -1.7729121446609497, -1.4829912185668945, -2.4223155975341797, -1.4336435794830322, 0.4389348030090332, -0.8612892031669617, -1.1095694303512573, -1.8620432615280151, -0.5245420932769775, -1.7602131366729736, -1.334526538848877, -1.139586091041565, -0.8885334134101868, -1.1046603918075562, -1.1779049634933472, -0.8517065048217773, -1.752022385597229, -3.8136587142944336, -2.2668418884277344, -2.8139054775238037, -2.9196279048919678, -3.4210827350616455, -4.477570056915283, -4.505601406097412, 0.0, 0.0, -0.0, -0.0, -17.451332092285156, -16.904037475585938, -14.279714584350586, -13.054938316345215, -9.051682472229004, -11.17206859588623, -11.983991622924805, -10.235368728637695, -9.315484046936035, -8.737184524536133, -8.339895248413086, -7.8116655349731445, -6.397276401519775, -7.315632343292236, -7.616184234619141, -6.326205253601074, -6.064702033996582, -5.899293899536133, -6.184295654296875, -5.163008689880371, -4.276001930236816, -4.001584529876709, -5.266971111297607, -4.719001770019531, -3.9053354263305664, -4.492527961730957, -3.0689501762390137, -4.870150089263916, -5.909066200256348, -5.35285758972168, -4.688917636871338, -4.5821428298950195, -4.2552947998046875, -4.665782928466797, -6.151910781860352, -4.304194450378418, -4.9561381340026855, -6.455098628997803, -3.9198856353759766, -5.359321117401123, -5.099809169769287, -5.293928623199463, -4.924133777618408, -4.781398296356201, -4.903411388397217, -3.7705185413360596, -2.8209760189056396, -3.0164875984191895, -3.005340337753296, -2.1485185623168945, -1.7729121446609497, -1.4829912185668945, -2.4223155975341797, -1.4336435794830322, 0.4389348030090332, -0.8612892031669617, -1.1095694303512573, -1.8620432615280151, -0.5245420932769775, -1.7602131366729736, -1.334526538848877, -1.139586091041565, -0.8885334134101868, -1.1046603918075562, -1.1779049634933472, -0.8517065048217773, -1.752022385597229, -3.8136587142944336, -2.2668418884277344, -2.8139054775238037, -2.9196279048919678, -3.4210827350616455, -4.477570056915283, -4.505601406097412, -0.0, -0.0], [0.0, 0.0, -16.653352737426758, -16.90677833557129, -14.658717155456543, -13.384735107421875, -12.006997108459473, -11.10499382019043, -11.364222526550293, -10.501787185668945, -9.433893203735352, -9.483551025390625, -8.657989501953125, -8.260544776916504, -7.192901611328125, -7.316131114959717, -7.008790969848633, -6.518016815185547, -6.22897481918335, -5.789016246795654, -5.479769706726074, -5.259079456329346, -4.472291946411133, -5.04164457321167, -5.931859016418457, -4.302844524383545, -4.446993827819824, -3.9728152751922607, -5.5514960289001465, -5.897075653076172, -4.482396602630615, -5.215527534484863, -5.605943202972412, -5.838056564331055, -5.650370121002197, -5.998860836029053, -5.459959983825684, -6.6295647621154785, -5.456251621246338, -6.181762218475342, -5.743616104125977, -5.584963798522949, -6.333981513977051, -4.056004524230957, -6.083622932434082, -5.959133148193359, -5.07333517074585, -3.7014319896698, -4.560227870941162, -2.7663350105285645, -3.111180543899536, -1.9474467039108276, -2.11173152923584, -2.4414610862731934, -1.1564275026321411, -1.992119312286377, -2.938314199447632, -0.6982033252716064, -2.009129524230957, -2.349764108657837, -0.03599643334746361, -0.24668851494789124, -1.2898139953613281, -1.038429856300354, -0.8039807677268982, -1.0431190729141235, -2.2313072681427, -2.0085456371307373, -1.1427656412124634, -2.340160846710205, -2.43135142326355, -2.7334201335906982, -2.905562400817871, -3.6385598182678223, -3.8258702754974365, -6.721211910247803, 0.0, 0.0, -0.0, -0.0, -16.653352737426758, -16.90677833557129, -14.658717155456543, -13.384735107421875, -12.006997108459473, -11.10499382019043, -11.364222526550293, -10.501787185668945, -9.433893203735352, -9.483551025390625, -8.657989501953125, -8.260544776916504, -7.192901611328125, -7.316131114959717, -7.008790969848633, -6.518016815185547, -6.22897481918335, -5.789016246795654, -5.479769706726074, -5.259079456329346, -4.472291946411133, -5.04164457321167, -5.931859016418457, -4.302844524383545, -4.446993827819824, -3.9728152751922607, -5.5514960289001465, -5.897075653076172, -4.482396602630615, -5.215527534484863, -5.605943202972412, -5.838056564331055, -5.650370121002197, -5.998860836029053, -5.459959983825684, -6.6295647621154785, -5.456251621246338, -6.181762218475342, -5.743616104125977, -5.584963798522949, -6.333981513977051, -4.056004524230957, -6.083622932434082, -5.959133148193359, -5.07333517074585, -3.7014319896698, -4.560227870941162, -2.7663350105285645, -3.111180543899536, -1.9474467039108276, -2.11173152923584, -2.4414610862731934, -1.1564275026321411, -1.992119312286377, -2.938314199447632, -0.6982033252716064, -2.009129524230957, -2.349764108657837, -0.03599643334746361, -0.24668851494789124, -1.2898139953613281, -1.038429856300354, -0.8039807677268982, -1.0431190729141235, -2.2313072681427, -2.0085456371307373, -1.1427656412124634, -2.340160846710205, -2.43135142326355, -2.7334201335906982, -2.905562400817871, -3.6385598182678223, -3.8258702754974365, -6.721211910247803, -0.0, -0.0], [0.0, 0.0, -18.715003967285156, -18.249988555908203, -15.074235916137695, -13.39382266998291, -13.191119194030762, -11.211854934692383, -9.944872856140137, -10.29898452758789, -9.119659423828125, -9.486346244812012, -8.575167655944824, -7.260969161987305, -7.109816551208496, -7.563117504119873, -6.606006622314453, -6.9396820068359375, -6.338497161865234, -5.571321487426758, -5.8730340003967285, -5.504557132720947, -4.916348934173584, -6.08234167098999, -5.112578392028809, -4.888057231903076, -6.184974193572998, -5.814174175262451, -4.815998554229736, -5.798074245452881, -5.312026500701904, -4.436639308929443, -6.368106365203857, -4.849156379699707, -6.872322082519531, -6.038320064544678, -5.821437358856201, -6.579647064208984, -8.018898010253906, -6.7012715339660645, -7.930540561676025, -5.615111827850342, -6.123332500457764, -6.805511474609375, -6.648355007171631, -6.580705165863037, -4.235903263092041, -7.046871662139893, -5.988821029663086, -4.382989883422852, -3.334502696990967, -4.820595741271973, -3.4438154697418213, -4.45302677154541, -4.043487548828125, -2.444265127182007, -4.933402061462402, -1.0030449628829956, -2.60602068901062, -2.1838042736053467, -1.5606192350387573, -1.3112138509750366, -1.1995627880096436, -1.4249801635742188, -1.4533922672271729, -1.1436882019042969, -1.4078631401062012, -1.5469138622283936, -1.4644492864608765, -2.391967296600342, -2.5192291736602783, -3.4387447834014893, -2.866910934448242, -3.7100021839141846, -4.643678188323975, 0.0, 0.0, 0.0, -0.0, -0.0, -18.715003967285156, -18.249988555908203, -15.074235916137695, -13.39382266998291, -13.191119194030762, -11.211854934692383, -9.944872856140137, -10.29898452758789, -9.119659423828125, -9.486346244812012, -8.575167655944824, -7.260969161987305, -7.109816551208496, -7.563117504119873, -6.606006622314453, -6.9396820068359375, -6.338497161865234, -5.571321487426758, -5.8730340003967285, -5.504557132720947, -4.916348934173584, -6.08234167098999, -5.112578392028809, -4.888057231903076, -6.184974193572998, -5.814174175262451, -4.815998554229736, -5.798074245452881, -5.312026500701904, -4.436639308929443, -6.368106365203857, -4.849156379699707, -6.872322082519531, -6.038320064544678, -5.821437358856201, -6.579647064208984, -8.018898010253906, -6.7012715339660645, -7.930540561676025, -5.615111827850342, -6.123332500457764, -6.805511474609375, -6.648355007171631, -6.580705165863037, -4.235903263092041, -7.046871662139893, -5.988821029663086, -4.382989883422852, -3.334502696990967, -4.820595741271973, -3.4438154697418213, -4.45302677154541, -4.043487548828125, -2.444265127182007, -4.933402061462402, -1.0030449628829956, -2.60602068901062, -2.1838042736053467, -1.5606192350387573, -1.3112138509750366, -1.1995627880096436, -1.4249801635742188, -1.4533922672271729, -1.1436882019042969, -1.4078631401062012, -1.5469138622283936, -1.4644492864608765, -2.391967296600342, -2.5192291736602783, -3.4387447834014893, -2.866910934448242, -3.7100021839141846, -4.643678188323975, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, -18.124422073364258, -15.097238540649414, -14.04126262664795, -11.989310264587402, -12.414435386657715, -12.668124198913574, -10.32246208190918, -11.190353393554688, -9.519102096557617, -8.844014167785645, -8.287860870361328, -7.907785892486572, -7.700876712799072, -6.943766117095947, -6.449321746826172, -6.5878071784973145, -6.769329071044922, -5.632760047912598, -6.338109493255615, -5.49746561050415, -6.261791229248047, -4.679205417633057, -6.0553412437438965, -5.559134006500244, -5.687901020050049, -6.788867473602295, -6.88227653503418, -6.35592794418335, -7.065646648406982, -7.274949073791504, -8.676753044128418, -8.178812026977539, -5.463476181030273, -8.279801368713379, -8.442336082458496, -6.36829948425293, -8.061945915222168, -8.492048263549805, -7.2978010177612305, -7.366695404052734, -9.352581024169922, -6.632925033569336, -7.134734153747559, -6.676653861999512, -3.409925937652588, -4.579288959503174, -7.6834540367126465, -6.126580715179443, -3.9034347534179688, -5.080734729766846, -2.9226841926574707, -2.1905460357666016, -3.3650078773498535, -2.5424721240997314, -2.940781831741333, -3.61453914642334, -0.5272107124328613, -2.557736873626709, -1.604270577430725, -2.3047468662261963, 0.5682522058486938, -1.6575435400009155, -1.6141868829727173, -1.328213095664978, -1.6578493118286133, -2.0320730209350586, -1.628629207611084, -3.1120080947875977, -3.0455482006073, -3.8723533153533936, -4.595213413238525, -4.6806745529174805, 0.0, 0.0, 1.0835707187652588, -0.0, -0.0, -0.0, -18.124422073364258, -15.097238540649414, -14.04126262664795, -11.989310264587402, -12.414435386657715, -12.668124198913574, -10.32246208190918, -11.190353393554688, -9.519102096557617, -8.844014167785645, -8.287860870361328, -7.907785892486572, -7.700876712799072, -6.943766117095947, -6.449321746826172, -6.5878071784973145, -6.769329071044922, -5.632760047912598, -6.338109493255615, -5.49746561050415, -6.261791229248047, -4.679205417633057, -6.0553412437438965, -5.559134006500244, -5.687901020050049, -6.788867473602295, -6.88227653503418, -6.35592794418335, -7.065646648406982, -7.274949073791504, -8.676753044128418, -8.178812026977539, -5.463476181030273, -8.279801368713379, -8.442336082458496, -6.36829948425293, -8.061945915222168, -8.492048263549805, -7.2978010177612305, -7.366695404052734, -9.352581024169922, -6.632925033569336, -7.134734153747559, -6.676653861999512, -3.409925937652588, -4.579288959503174, -7.6834540367126465, -6.126580715179443, -3.9034347534179688, -5.080734729766846, -2.9226841926574707, -2.1905460357666016, -3.3650078773498535, -2.5424721240997314, -2.940781831741333, -3.61453914642334, -0.5272107124328613, -2.557736873626709, -1.604270577430725, -2.3047468662261963, 0.5682522058486938, -1.6575435400009155, -1.6141868829727173, -1.328213095664978, -1.6578493118286133, -2.0320730209350586, -1.628629207611084, -3.1120080947875977, -3.0455482006073, -3.8723533153533936, -4.595213413238525, -4.6806745529174805, -0.0, -0.0, 1.0835707187652588], [0.0, 0.0, 0.0, -18.64897918701172, -14.258150100708008, -13.9363374710083, -13.348651885986328, -11.90540885925293, -10.724200248718262, -9.176960945129395, -10.712532043457031, -9.624045372009277, -10.190129280090332, -8.47344970703125, -9.309078216552734, -7.867825508117676, -7.477456569671631, -7.269073963165283, -7.240719318389893, -6.5403642654418945, -6.384552478790283, -6.1134443283081055, -5.1653523445129395, -6.380773544311523, -6.641995429992676, -6.462604999542236, -6.605083465576172, -4.303057670593262, -7.474735736846924, -6.77376127243042, -6.912909507751465, -8.839980125427246, -7.344847202301025, -8.462068557739258, -8.436629295349121, -9.540085792541504, -8.922021865844727, -9.040641784667969, -9.783920288085938, -9.631815910339355, -9.362421035766602, -8.151531219482422, -8.155345916748047, -7.250093460083008, -9.095488548278809, -7.817785739898682, -5.973032474517822, -6.443891525268555, -9.280632019042969, -6.194995403289795, -5.586925983428955, -7.109760284423828, -4.593156814575195, -4.623831748962402, -3.3785901069641113, -4.6142497062683105, -2.6229097843170166, -3.0729682445526123, -2.8314013481140137, -2.3553876876831055, -2.0499937534332275, -2.108147144317627, -1.6381322145462036, -1.7735638618469238, -1.4979090690612793, -1.5286056995391846, -1.6023805141448975, -1.3773800134658813, -2.118605136871338, -2.70449161529541, -1.469840407371521, -3.4544081687927246, -3.1026453971862793, -3.8745672702789307, -5.121908187866211, 0.0, 0.0, -0.19145824015140533, -0.0, -0.0, -0.0, -18.64897918701172, -14.258150100708008, -13.9363374710083, -13.348651885986328, -11.90540885925293, -10.724200248718262, -9.176960945129395, -10.712532043457031, -9.624045372009277, -10.190129280090332, -8.47344970703125, -9.309078216552734, -7.867825508117676, -7.477456569671631, -7.269073963165283, -7.240719318389893, -6.5403642654418945, -6.384552478790283, -6.1134443283081055, -5.1653523445129395, -6.380773544311523, -6.641995429992676, -6.462604999542236, -6.605083465576172, -4.303057670593262, -7.474735736846924, -6.77376127243042, -6.912909507751465, -8.839980125427246, -7.344847202301025, -8.462068557739258, -8.436629295349121, -9.540085792541504, -8.922021865844727, -9.040641784667969, -9.783920288085938, -9.631815910339355, -9.362421035766602, -8.151531219482422, -8.155345916748047, -7.250093460083008, -9.095488548278809, -7.817785739898682, -5.973032474517822, -6.443891525268555, -9.280632019042969, -6.194995403289795, -5.586925983428955, -7.109760284423828, -4.593156814575195, -4.623831748962402, -3.3785901069641113, -4.6142497062683105, -2.6229097843170166, -3.0729682445526123, -2.8314013481140137, -2.3553876876831055, -2.0499937534332275, -2.108147144317627, -1.6381322145462036, -1.7735638618469238, -1.4979090690612793, -1.5286056995391846, -1.6023805141448975, -1.3773800134658813, -2.118605136871338, -2.70449161529541, -1.469840407371521, -3.4544081687927246, -3.1026453971862793, -3.8745672702789307, -5.121908187866211, -0.0, -0.0, -0.19145824015140533], [0.0, 0.0, 0.0, -18.661630630493164, -16.05667495727539, -14.621696472167969, -12.92859935760498, -11.96904468536377, -10.96707820892334, -10.381856918334961, -10.223274230957031, -9.498035430908203, -9.41463851928711, -8.651019096374512, -8.26046085357666, -7.599501132965088, -7.579073905944824, -7.219812393188477, -7.76404333114624, -7.323627948760986, -6.735406875610352, -7.117229461669922, -6.708465099334717, -6.629492282867432, -6.616316318511963, -8.36358642578125, -6.367659091949463, -8.22972297668457, -7.128925323486328, -8.002861976623535, -9.765578269958496, -9.893671035766602, -8.566115379333496, -10.812074661254883, -10.157288551330566, -9.515364646911621, -9.516496658325195, -9.587824821472168, -10.542891502380371, -10.03385066986084, -12.854597091674805, -10.272619247436523, -8.200512886047363, -9.347898483276367, -8.436773300170898, -8.529130935668945, -7.155014991760254, -7.661068439483643, -7.1180572509765625, -3.483724355697632, -7.194799423217773, -5.752265453338623, -5.20754337310791, -4.511471748352051, -4.00427770614624, -4.902436256408691, -3.5040621757507324, -2.9107298851013184, -2.4713845252990723, -2.450930595397949, -3.0416531562805176, -2.784858226776123, -2.59193754196167, -1.7346373796463013, -2.8957104682922363, -1.76324462890625, -1.3290820121765137, -1.8880205154418945, -2.691483736038208, -2.062685489654541, -3.376955270767212, -3.6803743839263916, -3.2691268920898438, -4.496607303619385, -5.148787975311279, 0.0, 0.0, 3.0958142280578613, -0.0, -0.0, -0.0, -18.661630630493164, -16.05667495727539, -14.621696472167969, -12.92859935760498, -11.96904468536377, -10.96707820892334, -10.381856918334961, -10.223274230957031, -9.498035430908203, -9.41463851928711, -8.651019096374512, -8.26046085357666, -7.599501132965088, -7.579073905944824, -7.219812393188477, -7.76404333114624, -7.323627948760986, -6.735406875610352, -7.117229461669922, -6.708465099334717, -6.629492282867432, -6.616316318511963, -8.36358642578125, -6.367659091949463, -8.22972297668457, -7.128925323486328, -8.002861976623535, -9.765578269958496, -9.893671035766602, -8.566115379333496, -10.812074661254883, -10.157288551330566, -9.515364646911621, -9.516496658325195, -9.587824821472168, -10.542891502380371, -10.03385066986084, -12.854597091674805, -10.272619247436523, -8.200512886047363, -9.347898483276367, -8.436773300170898, -8.529130935668945, -7.155014991760254, -7.661068439483643, -7.1180572509765625, -3.483724355697632, -7.194799423217773, -5.752265453338623, -5.20754337310791, -4.511471748352051, -4.00427770614624, -4.902436256408691, -3.5040621757507324, -2.9107298851013184, -2.4713845252990723, -2.450930595397949, -3.0416531562805176, -2.784858226776123, -2.59193754196167, -1.7346373796463013, -2.8957104682922363, -1.76324462890625, -1.3290820121765137, -1.8880205154418945, -2.691483736038208, -2.062685489654541, -3.376955270767212, -3.6803743839263916, -3.2691268920898438, -4.496607303619385, -5.148787975311279, -0.0, -0.0, 3.0958142280578613], [-15.557534217834473, 0.0, 0.0, -19.033424377441406, -17.137527465820312, -14.801271438598633, -13.097853660583496, -11.757986068725586, -11.589488983154297, -10.264737129211426, -9.654300689697266, -9.919506072998047, -9.202634811401367, -8.356729507446289, -8.251264572143555, -7.743725299835205, -7.91027307510376, -8.426871299743652, -8.793339729309082, -7.374022006988525, -8.215933799743652, -6.466511249542236, -6.545658111572266, -6.1605939865112305, -6.858802318572998, -9.49653148651123, -7.7298150062561035, -8.41614055633545, -7.396878242492676, -8.530735969543457, -8.442306518554688, -10.495711326599121, -10.577581405639648, -8.753596305847168, -11.3868408203125, -10.49979019165039, -10.863574981689453, -9.446999549865723, -11.531052589416504, -11.08292007446289, -11.276844024658203, -11.657441139221191, -9.680294036865234, -10.918783187866211, -9.956439971923828, -9.653738975524902, -11.042174339294434, -8.653021812438965, -8.845919609069824, -7.390749931335449, -5.412342548370361, -6.314230442047119, -6.190441608428955, -5.544180393218994, -4.024928569793701, -3.5388739109039307, -4.317569732666016, -3.9217851161956787, -2.814173698425293, -3.247553586959839, -2.4841675758361816, -2.433079719543457, -2.5375313758850098, -2.001483678817749, -1.5574660301208496, -1.8530604839324951, -1.5529124736785889, -1.978257656097412, -1.4829676151275635, -2.6014113426208496, -2.958828926086426, -2.7410507202148438, -4.038577079772949, -4.647387504577637, 0.0, 0.0, 0.0, 1.9776400327682495, -15.557534217834473, -0.0, -0.0, -19.033424377441406, -17.137527465820312, -14.801271438598633, -13.097853660583496, -11.757986068725586, -11.589488983154297, -10.264737129211426, -9.654300689697266, -9.919506072998047, -9.202634811401367, -8.356729507446289, -8.251264572143555, -7.743725299835205, -7.91027307510376, -8.426871299743652, -8.793339729309082, -7.374022006988525, -8.215933799743652, -6.466511249542236, -6.545658111572266, -6.1605939865112305, -6.858802318572998, -9.49653148651123, -7.7298150062561035, -8.41614055633545, -7.396878242492676, -8.530735969543457, -8.442306518554688, -10.495711326599121, -10.577581405639648, -8.753596305847168, -11.3868408203125, -10.49979019165039, -10.863574981689453, -9.446999549865723, -11.531052589416504, -11.08292007446289, -11.276844024658203, -11.657441139221191, -9.680294036865234, -10.918783187866211, -9.956439971923828, -9.653738975524902, -11.042174339294434, -8.653021812438965, -8.845919609069824, -7.390749931335449, -5.412342548370361, -6.314230442047119, -6.190441608428955, -5.544180393218994, -4.024928569793701, -3.5388739109039307, -4.317569732666016, -3.9217851161956787, -2.814173698425293, -3.247553586959839, -2.4841675758361816, -2.433079719543457, -2.5375313758850098, -2.001483678817749, -1.5574660301208496, -1.8530604839324951, -1.5529124736785889, -1.978257656097412, -1.4829676151275635, -2.6014113426208496, -2.958828926086426, -2.7410507202148438, -4.038577079772949, -4.647387504577637, -0.0, -0.0, 0.0, 1.9776400327682495], [-16.783742904663086, 0.0, 0.0, -18.79214859008789, -16.945777893066406, -15.141160011291504, -12.817625999450684, -12.040802001953125, -11.37907886505127, -10.871792793273926, -10.18234920501709, -10.0338716506958, -9.262771606445312, -9.03882884979248, -8.33603286743164, -8.894185066223145, -7.364998817443848, -7.43099308013916, -7.969770431518555, -6.783881664276123, -7.830511093139648, -7.034646034240723, -6.303955078125, -6.869969844818115, -7.40850305557251, -10.406567573547363, -7.564213752746582, -7.088752746582031, -7.680076599121094, -8.769966125488281, -6.778526782989502, -10.799386978149414, -10.418012619018555, -10.389776229858398, -11.993781089782715, -11.354927062988281, -11.920225143432617, -12.054859161376953, -12.319308280944824, -11.361933708190918, -12.95670223236084, -13.426948547363281, -11.607417106628418, -11.642491340637207, -12.011106491088867, -9.65281867980957, -10.269947052001953, -9.5308198928833, -8.998801231384277, -8.762553215026855, -8.361215591430664, -7.428519248962402, -6.720483303070068, -5.291601181030273, -5.7846150398254395, -4.067478179931641, -3.9914183616638184, -3.058478355407715, -3.4949440956115723, -3.992570638656616, -2.6817970275878906, -2.392871379852295, -2.19380784034729, -1.7912683486938477, -1.7856043577194214, -1.8912116289138794, -2.295037031173706, -2.056131362915039, -2.143265962600708, -2.635861396789551, -3.2332589626312256, -3.588214159011841, -4.090020656585693, -4.6551513671875, 0.0, 0.0, 3.5145318508148193, 4.924001216888428, -16.783742904663086, -0.0, -0.0, -18.79214859008789, -16.945777893066406, -15.141160011291504, -12.817625999450684, -12.040802001953125, -11.37907886505127, -10.871792793273926, -10.18234920501709, -10.0338716506958, -9.262771606445312, -9.03882884979248, -8.33603286743164, -8.894185066223145, -7.364998817443848, -7.43099308013916, -7.969770431518555, -6.783881664276123, -7.830511093139648, -7.034646034240723, -6.303955078125, -6.869969844818115, -7.40850305557251, -10.406567573547363, -7.564213752746582, -7.088752746582031, -7.680076599121094, -8.769966125488281, -6.778526782989502, -10.799386978149414, -10.418012619018555, -10.389776229858398, -11.993781089782715, -11.354927062988281, -11.920225143432617, -12.054859161376953, -12.319308280944824, -11.361933708190918, -12.95670223236084, -13.426948547363281, -11.607417106628418, -11.642491340637207, -12.011106491088867, -9.65281867980957, -10.269947052001953, -9.5308198928833, -8.998801231384277, -8.762553215026855, -8.361215591430664, -7.428519248962402, -6.720483303070068, -5.291601181030273, -5.7846150398254395, -4.067478179931641, -3.9914183616638184, -3.058478355407715, -3.4949440956115723, -3.992570638656616, -2.6817970275878906, -2.392871379852295, -2.19380784034729, -1.7912683486938477, -1.7856043577194214, -1.8912116289138794, -2.295037031173706, -2.056131362915039, -2.143265962600708, -2.635861396789551, -3.2332589626312256, -3.588214159011841, -4.090020656585693, -4.6551513671875, -0.0, 0.0, 3.5145318508148193, 4.924001216888428], [-19.948213577270508, 0.0, 0.0, 0.0, -16.40816879272461, -15.33120059967041, -13.38636302947998, -12.254535675048828, -11.10108470916748, -11.802336692810059, -10.477776527404785, -9.898826599121094, -9.634031295776367, -8.440561294555664, -8.35027027130127, -7.922646999359131, -8.33653450012207, -8.132058143615723, -7.829524993896484, -7.3771233558654785, -7.2903218269348145, -7.005359649658203, -8.775845527648926, -7.797662258148193, -8.47358226776123, -8.061665534973145, -9.82256031036377, -8.481729507446289, -8.682809829711914, -9.852643966674805, -10.936314582824707, -10.367315292358398, -11.991365432739258, -10.971847534179688, -12.462326049804688, -13.107725143432617, -13.052770614624023, -11.32843017578125, -13.745487213134766, -13.829940795898438, -14.152341842651367, -15.764505386352539, -11.444308280944824, -12.987401962280273, -11.894071578979492, -11.062682151794434, -13.374550819396973, -10.903714179992676, -11.082240104675293, -8.913618087768555, -10.257434844970703, -7.945812702178955, -7.722323417663574, -6.121121883392334, -5.012620449066162, -5.18195104598999, -5.697281360626221, -4.197473049163818, -3.863574743270874, -4.075183391571045, -3.446244478225708, -3.222231388092041, -2.4644832611083984, -2.8539087772369385, -2.4736533164978027, -2.4249191284179688, -2.3525192737579346, -1.8784986734390259, -1.9049017429351807, -3.1396639347076416, -3.299957275390625, -4.19820499420166, -4.476745128631592, -5.606449127197266, 0.0, 0.0, 1.8588923215866089, 4.769834995269775, -19.948213577270508, -0.0, -0.0, -0.0, -16.40816879272461, -15.33120059967041, -13.38636302947998, -12.254535675048828, -11.10108470916748, -11.802336692810059, -10.477776527404785, -9.898826599121094, -9.634031295776367, -8.440561294555664, -8.35027027130127, -7.922646999359131, -8.33653450012207, -8.132058143615723, -7.829524993896484, -7.3771233558654785, -7.2903218269348145, -7.005359649658203, -8.775845527648926, -7.797662258148193, -8.47358226776123, -8.061665534973145, -9.82256031036377, -8.481729507446289, -8.682809829711914, -9.852643966674805, -10.936314582824707, -10.367315292358398, -11.991365432739258, -10.971847534179688, -12.462326049804688, -13.107725143432617, -13.052770614624023, -11.32843017578125, -13.745487213134766, -13.829940795898438, -14.152341842651367, -15.764505386352539, -11.444308280944824, -12.987401962280273, -11.894071578979492, -11.062682151794434, -13.374550819396973, -10.903714179992676, -11.082240104675293, -8.913618087768555, -10.257434844970703, -7.945812702178955, -7.722323417663574, -6.121121883392334, -5.012620449066162, -5.18195104598999, -5.697281360626221, -4.197473049163818, -3.863574743270874, -4.075183391571045, -3.446244478225708, -3.222231388092041, -2.4644832611083984, -2.8539087772369385, -2.4736533164978027, -2.4249191284179688, -2.3525192737579346, -1.8784986734390259, -1.9049017429351807, -3.1396639347076416, -3.299957275390625, -4.19820499420166, -4.476745128631592, -5.606449127197266, -0.0, 0.0, 1.8588923215866089, 4.769834995269775], [-19.695999145507812, 0.0, 0.0, 0.0, -17.630582809448242, -15.746711730957031, -13.483500480651855, -13.400368690490723, -12.421274185180664, -11.23992919921875, -11.409480094909668, -10.451730728149414, -9.334969520568848, -8.593904495239258, -8.57271671295166, -8.10361385345459, -8.098608016967773, -7.81274938583374, -8.545736312866211, -7.6924147605896, -7.626186847686768, -7.378625392913818, -9.498048782348633, -8.640778541564941, -7.712471008300781, -9.36103343963623, -11.608926773071289, -8.93631649017334, -10.52200984954834, -10.432580947875977, -11.238032341003418, -12.66313362121582, -12.329147338867188, -13.518953323364258, -13.590112686157227, -14.244057655334473, -14.907096862792969, -16.347698211669922, -15.10977840423584, -15.228221893310547, -14.350003242492676, -14.33259105682373, -14.183964729309082, -13.684406280517578, -15.323687553405762, -13.375173568725586, -12.3473539352417, -11.601795196533203, -11.207072257995605, -10.634095191955566, -10.921424865722656, -8.273599624633789, -6.952397346496582, -8.018386840820312, -5.768087863922119, -6.289936065673828, -5.668885231018066, -4.67430305480957, -4.7594313621521, -3.86765456199646, -5.032884120941162, -2.8905563354492188, -3.873889207839966, -3.3794057369232178, -2.8708600997924805, -2.434969425201416, -2.280691146850586, -1.9669382572174072, -1.8267828226089478, -3.9262006282806396, -3.822657346725464, -3.5437755584716797, -5.552495956420898, 0.0, 0.0, 0.0, 1.8934680223464966, 2.7520341873168945, -19.695999145507812, -0.0, -0.0, -0.0, -17.630582809448242, -15.746711730957031, -13.483500480651855, -13.400368690490723, -12.421274185180664, -11.23992919921875, -11.409480094909668, -10.451730728149414, -9.334969520568848, -8.593904495239258, -8.57271671295166, -8.10361385345459, -8.098608016967773, -7.81274938583374, -8.545736312866211, -7.6924147605896, -7.626186847686768, -7.378625392913818, -9.498048782348633, -8.640778541564941, -7.712471008300781, -9.36103343963623, -11.608926773071289, -8.93631649017334, -10.52200984954834, -10.432580947875977, -11.238032341003418, -12.66313362121582, -12.329147338867188, -13.518953323364258, -13.590112686157227, -14.244057655334473, -14.907096862792969, -16.347698211669922, -15.10977840423584, -15.228221893310547, -14.350003242492676, -14.33259105682373, -14.183964729309082, -13.684406280517578, -15.323687553405762, -13.375173568725586, -12.3473539352417, -11.601795196533203, -11.207072257995605, -10.634095191955566, -10.921424865722656, -8.273599624633789, -6.952397346496582, -8.018386840820312, -5.768087863922119, -6.289936065673828, -5.668885231018066, -4.67430305480957, -4.7594313621521, -3.86765456199646, -5.032884120941162, -2.8905563354492188, -3.873889207839966, -3.3794057369232178, -2.8708600997924805, -2.434969425201416, -2.280691146850586, -1.9669382572174072, -1.8267828226089478, -3.9262006282806396, -3.822657346725464, -3.5437755584716797, -5.552495956420898, -0.0, -0.0, 0.0, 1.8934680223464966, 2.7520341873168945], [-20.0334415435791, -22.30756187438965, 0.0, 0.0, -17.712291717529297, -16.13042640686035, -14.577845573425293, -13.385523796081543, -12.871028900146484, -11.18868637084961, -10.583477973937988, -10.82022476196289, -9.85070514678955, -9.136189460754395, -8.110243797302246, -8.649550437927246, -8.222432136535645, -8.160345077514648, -7.713088512420654, -8.453304290771484, -8.198248863220215, -7.974389553070068, -8.391258239746094, -8.196223258972168, -9.177034378051758, -9.56226921081543, -10.0324068069458, -10.223856925964355, -11.772656440734863, -11.227892875671387, -12.540253639221191, -11.432713508605957, -13.04284954071045, -13.459094047546387, -14.738167762756348, -15.933013916015625, -15.456847190856934, -17.35477638244629, -16.02589988708496, -17.12653923034668, -15.343348503112793, -16.098520278930664, -14.389532089233398, -15.08696460723877, -14.810992240905762, -15.143909454345703, -13.99952220916748, -12.857090950012207, -13.04190444946289, -13.198845863342285, -10.843646049499512, -9.776826858520508, -8.559172630310059, -8.131912231445312, -7.23676061630249, -5.296154975891113, -6.81598424911499, -5.785989284515381, -5.449108600616455, -4.13280725479126, -4.2536420822143555, -3.363785743713379, -3.0256881713867188, -3.2653980255126953, -2.6918046474456787, -2.1406915187835693, -2.5589792728424072, -2.296137571334839, -3.5556061267852783, -2.050978660583496, -3.4938340187072754, -4.746750831604004, 0.0, 0.0, 0.0, 0.0, 0.7393681406974792, 0.028888188302516937, -20.0334415435791, -22.30756187438965, -0.0, -0.0, -17.712291717529297, -16.13042640686035, -14.577845573425293, -13.385523796081543, -12.871028900146484, -11.18868637084961, -10.583477973937988, -10.82022476196289, -9.85070514678955, -9.136189460754395, -8.110243797302246, -8.649550437927246, -8.222432136535645, -8.160345077514648, -7.713088512420654, -8.453304290771484, -8.198248863220215, -7.974389553070068, -8.391258239746094, -8.196223258972168, -9.177034378051758, -9.56226921081543, -10.0324068069458, -10.223856925964355, -11.772656440734863, -11.227892875671387, -12.540253639221191, -11.432713508605957, -13.04284954071045, -13.459094047546387, -14.738167762756348, -15.933013916015625, -15.456847190856934, -17.35477638244629, -16.02589988708496, -17.12653923034668, -15.343348503112793, -16.098520278930664, -14.389532089233398, -15.08696460723877, -14.810992240905762, -15.143909454345703, -13.99952220916748, -12.857090950012207, -13.04190444946289, -13.198845863342285, -10.843646049499512, -9.776826858520508, -8.559172630310059, -8.131912231445312, -7.23676061630249, -5.296154975891113, -6.81598424911499, -5.785989284515381, -5.449108600616455, -4.13280725479126, -4.2536420822143555, -3.363785743713379, -3.0256881713867188, -3.2653980255126953, -2.6918046474456787, -2.1406915187835693, -2.5589792728424072, -2.296137571334839, -3.5556061267852783, -2.050978660583496, -3.4938340187072754, -4.746750831604004, -0.0, -0.0, 0.0, 0.0, 0.7393681406974792, 0.028888188302516937], [-19.944433212280273, -20.438417434692383, 0.0, 0.0, -14.04271411895752, -16.172658920288086, -15.248806953430176, -13.618870735168457, -12.724888801574707, -12.337846755981445, -11.55446720123291, -10.970605850219727, -10.106956481933594, -9.545266151428223, -9.281710624694824, -8.374153137207031, -8.382978439331055, -8.301478385925293, -8.232938766479492, -8.702549934387207, -8.24845027923584, -9.140607833862305, -9.2263765335083, -8.180033683776855, -9.596612930297852, -10.39296817779541, -10.710925102233887, -10.872762680053711, -11.672876358032227, -12.957924842834473, -13.233049392700195, -13.251202583312988, -15.289897918701172, -15.369237899780273, -15.216165542602539, -14.863757133483887, -17.329545974731445, -17.687118530273438, -17.693965911865234, -17.202713012695312, -18.0852108001709, -17.341978073120117, -16.676904678344727, -17.17961883544922, -16.346511840820312, -15.45768928527832, -14.354875564575195, -14.287327766418457, -14.273118019104004, -15.621072769165039, -11.667741775512695, -9.731038093566895, -9.587613105773926, -8.735937118530273, -7.270045280456543, -7.114360809326172, -5.9298272132873535, -6.104162693023682, -5.472332000732422, -4.968549728393555, -4.053735256195068, -4.209733486175537, -3.6085684299468994, -3.016303539276123, -2.013256072998047, -3.7752726078033447, -3.183940887451172, -3.6592345237731934, -3.775684356689453, -3.892784357070923, -5.165460586547852, -4.53121280670166, 0.0, 0.0, 0.0, 0.0, 1.9698078632354736, 1.698948860168457, -19.944433212280273, -20.438417434692383, -0.0, -0.0, -14.04271411895752, -16.172658920288086, -15.248806953430176, -13.618870735168457, -12.724888801574707, -12.337846755981445, -11.55446720123291, -10.970605850219727, -10.106956481933594, -9.545266151428223, -9.281710624694824, -8.374153137207031, -8.382978439331055, -8.301478385925293, -8.232938766479492, -8.702549934387207, -8.24845027923584, -9.140607833862305, -9.2263765335083, -8.180033683776855, -9.596612930297852, -10.39296817779541, -10.710925102233887, -10.872762680053711, -11.672876358032227, -12.957924842834473, -13.233049392700195, -13.251202583312988, -15.289897918701172, -15.369237899780273, -15.216165542602539, -14.863757133483887, -17.329545974731445, -17.687118530273438, -17.693965911865234, -17.202713012695312, -18.0852108001709, -17.341978073120117, -16.676904678344727, -17.17961883544922, -16.346511840820312, -15.45768928527832, -14.354875564575195, -14.287327766418457, -14.273118019104004, -15.621072769165039, -11.667741775512695, -9.731038093566895, -9.587613105773926, -8.735937118530273, -7.270045280456543, -7.114360809326172, -5.9298272132873535, -6.104162693023682, -5.472332000732422, -4.968549728393555, -4.053735256195068, -4.209733486175537, -3.6085684299468994, -3.016303539276123, -2.013256072998047, -3.7752726078033447, -3.183940887451172, -3.6592345237731934, -3.775684356689453, -3.892784357070923, -5.165460586547852, -4.53121280670166, -0.0, -0.0, -0.0, 0.0, 1.9698078632354736, 1.698948860168457], [-20.387372970581055, -20.529848098754883, 0.0, 0.0, 0.0, -17.073257446289062, -15.700057983398438, -14.171889305114746, -13.248178482055664, -11.634284973144531, -11.064144134521484, -10.892911911010742, -9.696492195129395, -9.482597351074219, -9.138856887817383, -9.320963859558105, -8.699767112731934, -8.446349143981934, -8.872183799743652, -9.313127517700195, -9.248377799987793, -9.102104187011719, -11.401823997497559, -9.398336410522461, -10.469842910766602, -10.232954978942871, -12.205232620239258, -11.537688255310059, -11.984393119812012, -13.803025245666504, -15.747505187988281, -15.397494316101074, -14.922274589538574, -16.18525505065918, -17.17765235900879, -17.779359817504883, -18.654281616210938, -18.689001083374023, -18.24479103088379, -19.962343215942383, -19.12924575805664, -18.590057373046875, -16.43330955505371, -17.90340805053711, -17.07504653930664, -17.59994888305664, -13.23396110534668, -14.680724143981934, -14.07533073425293, -12.712092399597168, -11.325980186462402, -11.336756706237793, -12.315729141235352, -9.955434799194336, -9.51294994354248, -9.407611846923828, -3.861713171005249, -5.536279201507568, -5.126824378967285, -5.6708598136901855, -4.508292198181152, -4.00490665435791, -2.8599026203155518, -3.8257627487182617, -3.315037965774536, -3.726257085800171, -3.805025577545166, -4.453503131866455, -4.383781433105469, -4.781866550445557, -6.147891044616699, 0.0, 0.0, 0.0, 0.0, -1.57008695602417, 1.6446608304977417, 2.5154685974121094, -20.387372970581055, -20.529848098754883, -0.0, -0.0, -0.0, -17.073257446289062, -15.700057983398438, -14.171889305114746, -13.248178482055664, -11.634284973144531, -11.064144134521484, -10.892911911010742, -9.696492195129395, -9.482597351074219, -9.138856887817383, -9.320963859558105, -8.699767112731934, -8.446349143981934, -8.872183799743652, -9.313127517700195, -9.248377799987793, -9.102104187011719, -11.401823997497559, -9.398336410522461, -10.469842910766602, -10.232954978942871, -12.205232620239258, -11.537688255310059, -11.984393119812012, -13.803025245666504, -15.747505187988281, -15.397494316101074, -14.922274589538574, -16.18525505065918, -17.17765235900879, -17.779359817504883, -18.654281616210938, -18.689001083374023, -18.24479103088379, -19.962343215942383, -19.12924575805664, -18.590057373046875, -16.43330955505371, -17.90340805053711, -17.07504653930664, -17.59994888305664, -13.23396110534668, -14.680724143981934, -14.07533073425293, -12.712092399597168, -11.325980186462402, -11.336756706237793, -12.315729141235352, -9.955434799194336, -9.51294994354248, -9.407611846923828, -3.861713171005249, -5.536279201507568, -5.126824378967285, -5.6708598136901855, -4.508292198181152, -4.00490665435791, -2.8599026203155518, -3.8257627487182617, -3.315037965774536, -3.726257085800171, -3.805025577545166, -4.453503131866455, -4.383781433105469, -4.781866550445557, -6.147891044616699, -0.0, -0.0, 0.0, -0.0, -1.57008695602417, 1.6446608304977417, 2.5154685974121094], [-20.722585678100586, -19.63985824584961, -20.698015213012695, 0.0, 0.0, -17.41877555847168, -16.273391723632812, -14.385042190551758, -12.920215606689453, -11.837105751037598, -10.948283195495605, -10.529739379882812, -10.125113487243652, -9.806979179382324, -9.361698150634766, -9.298200607299805, -9.841876983642578, -9.261348724365234, -8.894113540649414, -9.369471549987793, -9.21232795715332, -10.348889350891113, -10.405548095703125, -10.054255485534668, -11.193087577819824, -11.394194602966309, -12.624689102172852, -12.59123420715332, -12.93999195098877, -12.069972038269043, -14.322019577026367, -15.34964370727539, -16.587833404541016, -16.508121490478516, -18.733091354370117, -18.39495849609375, -18.8891658782959, -19.355791091918945, 0.0, 0.0, -20.410913467407227, -19.382930755615234, -19.783912658691406, -18.41745376586914, -18.506383895874023, -17.58197784423828, -16.59018898010254, -14.90839672088623, -15.108148574829102, -17.49858283996582, -14.686749458312988, -12.73046875, -11.46932315826416, -11.272558212280273, -11.060933113098145, -8.54780387878418, -6.8059611320495605, -7.5085978507995605, -7.419914245605469, -5.631866455078125, -5.715778827667236, -4.686206340789795, -5.298010349273682, -4.144162654876709, -4.612586975097656, -4.588298797607422, -4.415823459625244, -3.4776484966278076, -4.5485334396362305, -3.7741892337799072, 0.0, -5.023123264312744, 0.0, 0.0, 2.8636045455932617, 1.3721277713775635, 2.787797212600708, 1.6568973064422607, -20.722585678100586, -19.63985824584961, -20.698015213012695, -0.0, -0.0, -17.41877555847168, -16.273391723632812, -14.385042190551758, -12.920215606689453, -11.837105751037598, -10.948283195495605, -10.529739379882812, -10.125113487243652, -9.806979179382324, -9.361698150634766, -9.298200607299805, -9.841876983642578, -9.261348724365234, -8.894113540649414, -9.369471549987793, -9.21232795715332, -10.348889350891113, -10.405548095703125, -10.054255485534668, -11.193087577819824, -11.394194602966309, -12.624689102172852, -12.59123420715332, -12.93999195098877, -12.069972038269043, -14.322019577026367, -15.34964370727539, -16.587833404541016, -16.508121490478516, -18.733091354370117, -18.39495849609375, -18.8891658782959, -19.355791091918945, -0.0, -0.0, -20.410913467407227, -19.382930755615234, -19.783912658691406, -18.41745376586914, -18.506383895874023, -17.58197784423828, -16.59018898010254, -14.90839672088623, -15.108148574829102, -17.49858283996582, -14.686749458312988, -12.73046875, -11.46932315826416, -11.272558212280273, -11.060933113098145, -8.54780387878418, -6.8059611320495605, -7.5085978507995605, -7.419914245605469, -5.631866455078125, -5.715778827667236, -4.686206340789795, -5.298010349273682, -4.144162654876709, -4.612586975097656, -4.588298797607422, -4.415823459625244, -3.4776484966278076, -4.5485334396362305, -3.7741892337799072, -0.0, -5.023123264312744, -0.0, 0.0, 2.8636045455932617, 1.3721277713775635, 2.787797212600708, 1.6568973064422607], [-20.951980590820312, -20.79879379272461, -19.872390747070312, 0.0, 0.0, 0.0, -15.8646879196167, -14.881353378295898, -13.374409675598145, -12.03621768951416, -11.273880958557129, -10.530271530151367, -10.028653144836426, -10.301688194274902, -8.793513298034668, -9.538366317749023, -9.781305313110352, -9.643437385559082, -9.108338356018066, -10.269754409790039, -9.275609016418457, -9.767967224121094, -10.867560386657715, -11.472424507141113, -11.476571083068848, -12.022645950317383, -12.076383590698242, -15.728252410888672, -15.162680625915527, -15.869813919067383, -15.508785247802734, -16.50774383544922, -18.954118728637695, -18.862123489379883, -19.830968856811523, -19.992900848388672, -20.41803741455078, -20.475557327270508, 0.0, -21.944801330566406, -20.505441665649414, -21.826528549194336, -21.450040817260742, -21.32441520690918, -20.41499137878418, -20.184844970703125, -17.760622024536133, -17.41546058654785, -16.761653900146484, -13.88360595703125, -15.904844284057617, -12.076151847839355, -11.632879257202148, -10.727354049682617, -10.754140853881836, -9.851058959960938, -8.96015453338623, -7.819989204406738, -7.269744396209717, -5.258913993835449, -6.178534984588623, -6.7452521324157715, -4.955946445465088, -5.046300888061523, -3.9217617511749268, -4.150346279144287, -4.878636837005615, -3.6348862648010254, -2.3542213439941406, -4.195084571838379, -1.5198167562484741, -2.540860652923584, 0.0, 0.0, 1.7449101209640503, 1.9565373659133911, 2.7885560989379883, 3.1810104846954346, -20.951980590820312, -20.79879379272461, -19.872390747070312, -0.0, -0.0, -0.0, -15.8646879196167, -14.881353378295898, -13.374409675598145, -12.03621768951416, -11.273880958557129, -10.530271530151367, -10.028653144836426, -10.301688194274902, -8.793513298034668, -9.538366317749023, -9.781305313110352, -9.643437385559082, -9.108338356018066, -10.269754409790039, -9.275609016418457, -9.767967224121094, -10.867560386657715, -11.472424507141113, -11.476571083068848, -12.022645950317383, -12.076383590698242, -15.728252410888672, -15.162680625915527, -15.869813919067383, -15.508785247802734, -16.50774383544922, -18.954118728637695, -18.862123489379883, -19.830968856811523, -19.992900848388672, -20.41803741455078, -20.475557327270508, -0.0, -21.944801330566406, -20.505441665649414, -21.826528549194336, -21.450040817260742, -21.32441520690918, -20.41499137878418, -20.184844970703125, -17.760622024536133, -17.41546058654785, -16.761653900146484, -13.88360595703125, -15.904844284057617, -12.076151847839355, -11.632879257202148, -10.727354049682617, -10.754140853881836, -9.851058959960938, -8.96015453338623, -7.819989204406738, -7.269744396209717, -5.258913993835449, -6.178534984588623, -6.7452521324157715, -4.955946445465088, -5.046300888061523, -3.9217617511749268, -4.150346279144287, -4.878636837005615, -3.6348862648010254, -2.3542213439941406, -4.195084571838379, -1.5198167562484741, -2.540860652923584, -0.0, 0.0, 1.7449101209640503, 1.9565373659133911, 2.7885560989379883, 3.1810104846954346], [-21.344636917114258, -19.518686294555664, -19.126216888427734, 0.0, 0.0, 0.0, -12.64853572845459, -14.37103271484375, -13.414169311523438, -12.46065902709961, -10.74018669128418, -11.036962509155273, -10.509535789489746, -10.349607467651367, -9.772784233093262, -9.879110336303711, -10.052751541137695, -10.43700885772705, -9.872259140014648, -11.663272857666016, -10.165037155151367, -10.281975746154785, -9.77590274810791, -11.625792503356934, -11.547250747680664, -11.136117935180664, -12.546107292175293, -13.175673484802246, -16.298845291137695, -16.530561447143555, -16.80874252319336, -18.65030288696289, -19.491069793701172, -19.541027069091797, -20.430444717407227, -21.602497100830078, -22.190961837768555, -22.927471160888672, -24.25442123413086, -25.041582107543945, -24.19101333618164, -24.67146873474121, -24.45074462890625, -22.42485809326172, -18.9728946685791, -22.01869010925293, -20.26533317565918, -18.598834991455078, -19.126392364501953, -16.135915756225586, -14.274462699890137, -14.393115043640137, -13.617291450500488, -11.943532943725586, -9.76694107055664, -9.626136779785156, -8.910633087158203, -9.105815887451172, -6.268246650695801, -7.62389612197876, -6.8633131980896, -5.4464240074157715, -6.021756172180176, -5.502089023590088, -5.590335845947266, -4.936357021331787, -4.086091995239258, -2.2506675720214844, -1.22669517993927, 0.0, -4.34586763381958, 0.0, 0.0, 0.0, 2.9070675373077393, 3.763239622116089, 3.038064956665039, 2.462381601333618, -21.344636917114258, -19.518686294555664, -19.126216888427734, -0.0, -0.0, -0.0, -12.64853572845459, -14.37103271484375, -13.414169311523438, -12.46065902709961, -10.74018669128418, -11.036962509155273, -10.509535789489746, -10.349607467651367, -9.772784233093262, -9.879110336303711, -10.052751541137695, -10.43700885772705, -9.872259140014648, -11.663272857666016, -10.165037155151367, -10.281975746154785, -9.77590274810791, -11.625792503356934, -11.547250747680664, -11.136117935180664, -12.546107292175293, -13.175673484802246, -16.298845291137695, -16.530561447143555, -16.80874252319336, -18.65030288696289, -19.491069793701172, -19.541027069091797, -20.430444717407227, -21.602497100830078, -22.190961837768555, -22.927471160888672, -24.25442123413086, -25.041582107543945, -24.19101333618164, -24.67146873474121, -24.45074462890625, -22.42485809326172, -18.9728946685791, -22.01869010925293, -20.26533317565918, -18.598834991455078, -19.126392364501953, -16.135915756225586, -14.274462699890137, -14.393115043640137, -13.617291450500488, -11.943532943725586, -9.76694107055664, -9.626136779785156, -8.910633087158203, -9.105815887451172, -6.268246650695801, -7.62389612197876, -6.8633131980896, -5.4464240074157715, -6.021756172180176, -5.502089023590088, -5.590335845947266, -4.936357021331787, -4.086091995239258, -2.2506675720214844, -1.22669517993927, -0.0, -4.34586763381958, -0.0, -0.0, 0.0, 2.9070675373077393, 3.763239622116089, 3.038064956665039, 2.462381601333618], [-21.211519241333008, -19.8113956451416, -18.799081802368164, -17.199419021606445, -16.774953842163086, 0.0, 0.0, -14.480569839477539, -12.753803253173828, -12.915935516357422, -11.797456741333008, -10.037689208984375, -10.329474449157715, -10.448720932006836, -10.363000869750977, -9.847878456115723, -10.109521865844727, -10.913835525512695, -10.69208812713623, -9.103533744812012, -10.85543155670166, -10.866971015930176, -11.520758628845215, -12.1393461227417, -12.39295482635498, -13.696638107299805, -14.91291618347168, -15.05380630493164, -13.658742904663086, -17.39548110961914, -18.22349739074707, -21.17722511291504, -20.068525314331055, -20.955303192138672, -22.531124114990234, -22.76044464111328, -24.43877601623535, -25.388164520263672, -25.175189971923828, -24.74996566772461, -26.299118041992188, -26.753217697143555, -24.92793846130371, -22.663082122802734, -23.14975357055664, -22.3159236907959, -21.138322830200195, -21.40213966369629, -18.802885055541992, -18.213584899902344, -17.301191329956055, -16.943317413330078, -14.602682113647461, -13.091336250305176, -11.679258346557617, -9.690191268920898, -9.578088760375977, -8.769692420959473, -8.341936111450195, -6.923260688781738, -7.3604607582092285, -7.840887069702148, -5.881965160369873, -4.459578514099121, -5.248105049133301, -4.267024993896484, -3.165997266769409, -1.3987998962402344, -1.7752596139907837, -2.1032238006591797, 0.0, 0.0, 0.0, 4.227995872497559, 4.415347099304199, 3.208753824234009, 3.010289430618286, 3.47770094871521, -21.211519241333008, -19.8113956451416, -18.799081802368164, -17.199419021606445, -16.774953842163086, -0.0, -0.0, -14.480569839477539, -12.753803253173828, -12.915935516357422, -11.797456741333008, -10.037689208984375, -10.329474449157715, -10.448720932006836, -10.363000869750977, -9.847878456115723, -10.109521865844727, -10.913835525512695, -10.69208812713623, -9.103533744812012, -10.85543155670166, -10.866971015930176, -11.520758628845215, -12.1393461227417, -12.39295482635498, -13.696638107299805, -14.91291618347168, -15.05380630493164, -13.658742904663086, -17.39548110961914, -18.22349739074707, -21.17722511291504, -20.068525314331055, -20.955303192138672, -22.531124114990234, -22.76044464111328, -24.43877601623535, -25.388164520263672, -25.175189971923828, -24.74996566772461, -26.299118041992188, -26.753217697143555, -24.92793846130371, -22.663082122802734, -23.14975357055664, -22.3159236907959, -21.138322830200195, -21.40213966369629, -18.802885055541992, -18.213584899902344, -17.301191329956055, -16.943317413330078, -14.602682113647461, -13.091336250305176, -11.679258346557617, -9.690191268920898, -9.578088760375977, -8.769692420959473, -8.341936111450195, -6.923260688781738, -7.3604607582092285, -7.840887069702148, -5.881965160369873, -4.459578514099121, -5.248105049133301, -4.267024993896484, -3.165997266769409, -1.3987998962402344, -1.7752596139907837, -2.1032238006591797, -0.0, -0.0, 0.0, 4.227995872497559, 4.415347099304199, 3.208753824234009, 3.010289430618286, 3.47770094871521], [-17.226486206054688, -19.38397216796875, -18.561809539794922, -17.078550338745117, -14.964080810546875, 0.0, 0.0, 0.0, -12.629385948181152, -12.357047080993652, -11.683706283569336, -9.075244903564453, -9.40697193145752, -10.702849388122559, -10.816161155700684, -11.665176391601562, -10.654308319091797, -10.578742027282715, -10.88426399230957, -10.227543830871582, -11.121524810791016, -10.280442237854004, -12.303948402404785, -12.487953186035156, -12.923888206481934, -13.80181884765625, -14.814661979675293, -15.424656867980957, -16.618911743164062, -18.288087844848633, -17.083454132080078, -19.64779281616211, -24.461109161376953, -24.436817169189453, -23.129676818847656, -24.176790237426758, -25.925094604492188, -26.712142944335938, -26.102386474609375, -25.723939895629883, -26.459665298461914, -27.40969467163086, -26.105690002441406, -25.84979820251465, -23.994831085205078, -21.08778190612793, -22.012964248657227, -21.20461082458496, -19.86963653564453, -19.2659854888916, -17.414962768554688, -16.870145797729492, -14.790512084960938, -13.210914611816406, -12.029733657836914, -11.218620300292969, -9.139765739440918, -8.904216766357422, -8.790048599243164, -8.25866985321045, -6.8482537269592285, -7.420237064361572, -6.072811603546143, -5.5235209465026855, -4.917061805725098, -3.5646708011627197, -2.842755079269409, -1.3240673542022705, -2.0251593589782715, -2.087319850921631, 0.0, 0.0, 0.0, 5.158400058746338, 4.058732986450195, 3.77905535697937, 4.123408794403076, 1.3016551733016968, -17.226486206054688, -19.38397216796875, -18.561809539794922, -17.078550338745117, -14.964080810546875, -0.0, -0.0, -0.0, -12.629385948181152, -12.357047080993652, -11.683706283569336, -9.075244903564453, -9.40697193145752, -10.702849388122559, -10.816161155700684, -11.665176391601562, -10.654308319091797, -10.578742027282715, -10.88426399230957, -10.227543830871582, -11.121524810791016, -10.280442237854004, -12.303948402404785, -12.487953186035156, -12.923888206481934, -13.80181884765625, -14.814661979675293, -15.424656867980957, -16.618911743164062, -18.288087844848633, -17.083454132080078, -19.64779281616211, -24.461109161376953, -24.436817169189453, -23.129676818847656, -24.176790237426758, -25.925094604492188, -26.712142944335938, -26.102386474609375, -25.723939895629883, -26.459665298461914, -27.40969467163086, -26.105690002441406, -25.84979820251465, -23.994831085205078, -21.08778190612793, -22.012964248657227, -21.20461082458496, -19.86963653564453, -19.2659854888916, -17.414962768554688, -16.870145797729492, -14.790512084960938, -13.210914611816406, -12.029733657836914, -11.218620300292969, -9.139765739440918, -8.904216766357422, -8.790048599243164, -8.25866985321045, -6.8482537269592285, -7.420237064361572, -6.072811603546143, -5.5235209465026855, -4.917061805725098, -3.5646708011627197, -2.842755079269409, -1.3240673542022705, -2.0251593589782715, -2.087319850921631, -0.0, 0.0, 0.0, 5.158400058746338, 4.058732986450195, 3.77905535697937, 4.123408794403076, 1.3016551733016968], [-20.117795944213867, -19.438541412353516, -18.13324737548828, -16.340818405151367, -14.739592552185059, -14.822257041931152, -14.67074966430664, 0.0, 0.0, -10.385689735412598, -9.024192810058594, -10.485625267028809, -11.341812133789062, -11.019749641418457, -11.133359909057617, -10.881032943725586, -11.724310874938965, -11.526087760925293, -10.370537757873535, -11.861336708068848, -11.859979629516602, -13.088834762573242, -12.0912446975708, -13.05948543548584, -14.479083061218262, -15.620298385620117, -16.11347770690918, -16.39900779724121, -16.746044158935547, -18.17499351501465, -19.926916122436523, -21.736989974975586, -22.162124633789062, -23.55674934387207, -23.48541831970215, -26.371259689331055, -25.605670928955078, -26.925050735473633, -28.35379981994629, -28.26326560974121, -26.964027404785156, -28.442363739013672, -27.198802947998047, -26.58399772644043, -24.694589614868164, -24.229019165039062, -23.190519332885742, -21.33594512939453, -24.19731903076172, -19.940608978271484, -18.5607852935791, -16.702747344970703, -15.912753105163574, -14.007136344909668, -13.28818130493164, -14.37398910522461, -11.021219253540039, -9.611111640930176, -9.060307502746582, -8.415911674499512, -8.172656059265137, -7.071002006530762, -4.984560012817383, -4.985594749450684, -5.1918768882751465, -2.7242236137390137, -4.133902549743652, -3.9599483013153076, -3.837726593017578, -3.1167166233062744, -4.537020206451416, 0.0, 4.274186611175537, 5.178633213043213, 3.3697850704193115, 3.062265396118164, 5.584941387176514, 0.0, -20.117795944213867, -19.438541412353516, -18.13324737548828, -16.340818405151367, -14.739592552185059, -14.822257041931152, -14.67074966430664, -0.0, -0.0, -10.385689735412598, -9.024192810058594, -10.485625267028809, -11.341812133789062, -11.019749641418457, -11.133359909057617, -10.881032943725586, -11.724310874938965, -11.526087760925293, -10.370537757873535, -11.861336708068848, -11.859979629516602, -13.088834762573242, -12.0912446975708, -13.05948543548584, -14.479083061218262, -15.620298385620117, -16.11347770690918, -16.39900779724121, -16.746044158935547, -18.17499351501465, -19.926916122436523, -21.736989974975586, -22.162124633789062, -23.55674934387207, -23.48541831970215, -26.371259689331055, -25.605670928955078, -26.925050735473633, -28.35379981994629, -28.26326560974121, -26.964027404785156, -28.442363739013672, -27.198802947998047, -26.58399772644043, -24.694589614868164, -24.229019165039062, -23.190519332885742, -21.33594512939453, -24.19731903076172, -19.940608978271484, -18.5607852935791, -16.702747344970703, -15.912753105163574, -14.007136344909668, -13.28818130493164, -14.37398910522461, -11.021219253540039, -9.611111640930176, -9.060307502746582, -8.415911674499512, -8.172656059265137, -7.071002006530762, -4.984560012817383, -4.985594749450684, -5.1918768882751465, -2.7242236137390137, -4.133902549743652, -3.9599483013153076, -3.837726593017578, -3.1167166233062744, -4.537020206451416, 0.0, 4.274186611175537, 5.178633213043213, 3.3697850704193115, 3.062265396118164, 5.584941387176514, 0.0], [-15.304759979248047, -17.900590896606445, -18.585819244384766, -16.726030349731445, -14.991249084472656, -14.387578010559082, -12.279115676879883, -12.510459899902344, 0.0, -13.575325965881348, 0.0, -12.127058982849121, -11.824544906616211, -11.737744331359863, -12.788559913635254, -11.452829360961914, -12.141914367675781, -12.597270011901855, -12.817748069763184, -12.374907493591309, -12.391697883605957, -13.029132843017578, -15.567404747009277, -14.480561256408691, -15.714798927307129, -15.08224868774414, -15.996539115905762, -17.62569808959961, -18.458219528198242, -19.38960075378418, -19.988441467285156, -25.247638702392578, -23.045228958129883, -25.584095001220703, -25.948219299316406, -27.143957138061523, -28.494216918945312, -28.747629165649414, -28.84453773498535, -29.948135375976562, -29.570703506469727, -29.090660095214844, -29.042991638183594, -27.30904197692871, -26.761953353881836, -25.917821884155273, -24.03343963623047, -22.281505584716797, -21.96085548400879, -19.677215576171875, -19.96897315979004, -17.602237701416016, -16.665189743041992, -14.819713592529297, -12.943294525146484, -12.241375923156738, -11.998686790466309, -10.128642082214355, -8.549744606018066, -8.60211181640625, -10.875204086303711, -10.133646011352539, -6.193386077880859, -5.569276332855225, -5.025226593017578, -3.746124267578125, -4.1736955642700195, -4.902339458465576, -3.6883158683776855, -4.528715133666992, 0.0, 0.0, 0.9593400955200195, 3.9646646976470947, 3.18245267868042, 1.5999144315719604, 2.7472124099731445, 0.0, -15.304759979248047, -17.900590896606445, -18.585819244384766, -16.726030349731445, -14.991249084472656, -14.387578010559082, -12.279115676879883, -12.510459899902344, -0.0, -13.575325965881348, -0.0, -12.127058982849121, -11.824544906616211, -11.737744331359863, -12.788559913635254, -11.452829360961914, -12.141914367675781, -12.597270011901855, -12.817748069763184, -12.374907493591309, -12.391697883605957, -13.029132843017578, -15.567404747009277, -14.480561256408691, -15.714798927307129, -15.08224868774414, -15.996539115905762, -17.62569808959961, -18.458219528198242, -19.38960075378418, -19.988441467285156, -25.247638702392578, -23.045228958129883, -25.584095001220703, -25.948219299316406, -27.143957138061523, -28.494216918945312, -28.747629165649414, -28.84453773498535, -29.948135375976562, -29.570703506469727, -29.090660095214844, -29.042991638183594, -27.30904197692871, -26.761953353881836, -25.917821884155273, -24.03343963623047, -22.281505584716797, -21.96085548400879, -19.677215576171875, -19.96897315979004, -17.602237701416016, -16.665189743041992, -14.819713592529297, -12.943294525146484, -12.241375923156738, -11.998686790466309, -10.128642082214355, -8.549744606018066, -8.60211181640625, -10.875204086303711, -10.133646011352539, -6.193386077880859, -5.569276332855225, -5.025226593017578, -3.746124267578125, -4.1736955642700195, -4.902339458465576, -3.6883158683776855, -4.528715133666992, -0.0, 0.0, 0.9593400955200195, 3.9646646976470947, 3.18245267868042, 1.5999144315719604, 2.7472124099731445, 0.0], [0.0, -18.887939453125, -17.39839744567871, -18.305219650268555, -15.641827583312988, -14.83852767944336, -13.965296745300293, -13.660209655761719, -14.590082168579102, -15.853898048400879, 0.0, 0.0, 0.0, -12.169301986694336, -11.159744262695312, -13.273224830627441, -14.087215423583984, -12.95888900756836, -13.527275085449219, -13.832070350646973, -14.361693382263184, -14.068942070007324, -14.203840255737305, -14.846564292907715, -15.358959197998047, -18.790475845336914, -16.777910232543945, -17.022293090820312, -18.105064392089844, -18.979637145996094, -21.033546447753906, -23.726024627685547, -24.29184913635254, -26.650325775146484, -26.85066032409668, -29.265018463134766, -31.237422943115234, -29.662242889404297, -30.36367416381836, -30.505992889404297, -30.851503372192383, -29.85890769958496, -29.823837280273438, -28.88899040222168, -27.723485946655273, -27.21449089050293, -25.67033576965332, -25.01851463317871, -21.234216690063477, -21.323118209838867, -19.494487762451172, -19.851154327392578, -17.50286102294922, -17.936779022216797, -13.839892387390137, -14.306513786315918, -11.484092712402344, -11.485321044921875, -10.172762870788574, -9.649930953979492, -9.156909942626953, -5.763350963592529, -6.654757976531982, -5.843222618103027, -5.193569183349609, -5.501006603240967, -5.543900966644287, -5.8859944343566895, -4.673736572265625, -4.021269798278809, 0.0, 4.182765483856201, 3.777308702468872, 2.7799525260925293, 2.774324417114258, 3.8204774856567383, 3.2904229164123535, 0.0, -0.0, -18.887939453125, -17.39839744567871, -18.305219650268555, -15.641827583312988, -14.83852767944336, -13.965296745300293, -13.660209655761719, -14.590082168579102, -15.853898048400879, -0.0, -0.0, -0.0, -12.169301986694336, -11.159744262695312, -13.273224830627441, -14.087215423583984, -12.95888900756836, -13.527275085449219, -13.832070350646973, -14.361693382263184, -14.068942070007324, -14.203840255737305, -14.846564292907715, -15.358959197998047, -18.790475845336914, -16.777910232543945, -17.022293090820312, -18.105064392089844, -18.979637145996094, -21.033546447753906, -23.726024627685547, -24.29184913635254, -26.650325775146484, -26.85066032409668, -29.265018463134766, -31.237422943115234, -29.662242889404297, -30.36367416381836, -30.505992889404297, -30.851503372192383, -29.85890769958496, -29.823837280273438, -28.88899040222168, -27.723485946655273, -27.21449089050293, -25.67033576965332, -25.01851463317871, -21.234216690063477, -21.323118209838867, -19.494487762451172, -19.851154327392578, -17.50286102294922, -17.936779022216797, -13.839892387390137, -14.306513786315918, -11.484092712402344, -11.485321044921875, -10.172762870788574, -9.649930953979492, -9.156909942626953, -5.763350963592529, -6.654757976531982, -5.843222618103027, -5.193569183349609, -5.501006603240967, -5.543900966644287, -5.8859944343566895, -4.673736572265625, -4.021269798278809, 0.0, 4.182765483856201, 3.777308702468872, 2.7799525260925293, 2.774324417114258, 3.8204774856567383, 3.2904229164123535, 0.0], [-20.15330696105957, 0.0, -17.363679885864258, -15.493453979492188, -15.113115310668945, -14.889107704162598, -13.77664566040039, -14.084569931030273, -13.164363861083984, -12.716869354248047, 0.0, 0.0, 0.0, -8.439867973327637, 0.0, 0.0, 0.0, -9.979142189025879, -13.859082221984863, -13.668829917907715, -13.263360977172852, -15.600738525390625, -16.201499938964844, -17.06637191772461, -15.122875213623047, -17.385223388671875, -17.686174392700195, -18.306884765625, -18.225372314453125, -20.816898345947266, -22.712255477905273, -24.415325164794922, -26.545806884765625, -27.56317710876465, -28.53061866760254, -28.630006790161133, -30.206438064575195, -32.82963180541992, -31.508224487304688, -32.82790756225586, -32.472076416015625, -31.330820083618164, -30.527698516845703, -30.65447235107422, -29.595083236694336, -27.90557861328125, -24.070844650268555, -26.0183048248291, -23.139793395996094, -24.207347869873047, -21.840734481811523, -18.68315315246582, -18.70950698852539, -15.431937217712402, -15.087445259094238, -13.441567420959473, -10.443835258483887, -11.594338417053223, -9.883330345153809, -9.223352432250977, -8.669219970703125, -8.66561222076416, -7.377655982971191, -7.892354965209961, -6.732763290405273, -6.630863666534424, -5.8994460105896, -6.546466827392578, -3.9055569171905518, 0.0, 0.0, 3.2877423763275146, 4.855081558227539, 3.1294450759887695, 2.723294734954834, 1.8534479141235352, 0.0, 4.028179168701172, -20.15330696105957, -0.0, -17.363679885864258, -15.493453979492188, -15.113115310668945, -14.889107704162598, -13.77664566040039, -14.084569931030273, -13.164363861083984, -12.716869354248047, -0.0, -0.0, -0.0, -8.439867973327637, -0.0, -0.0, -0.0, -9.979142189025879, -13.859082221984863, -13.668829917907715, -13.263360977172852, -15.600738525390625, -16.201499938964844, -17.06637191772461, -15.122875213623047, -17.385223388671875, -17.686174392700195, -18.306884765625, -18.225372314453125, -20.816898345947266, -22.653596878051758, -24.264326095581055, -26.2702693939209, -27.428009033203125, -28.491418838500977, -28.963401794433594, -30.29416275024414, -32.28059768676758, -31.640060424804688, -32.57036209106445, -32.23988723754883, -31.39620018005371, -30.65598487854004, -30.432954788208008, -29.334260940551758, -27.852462768554688, -24.921010971069336, -25.824893951416016, -23.725311279296875, -23.6921443939209, -21.840734481811523, -18.68315315246582, -18.70950698852539, -15.431937217712402, -15.087445259094238, -13.441567420959473, -10.443835258483887, -11.594338417053223, -9.883330345153809, -9.223352432250977, -8.669219970703125, -8.66561222076416, -7.377655982971191, -7.892354965209961, -6.732763290405273, -6.630863666534424, -5.8994460105896, -6.546466827392578, -3.9055569171905518, -0.0, 0.0, 3.2877423763275146, 4.855081558227539, 3.1294450759887695, 2.723294734954834, 1.8534479141235352, 0.0, 4.028179168701172], [0.0, 0.0, -18.34562110900879, -16.54006576538086, -16.805116653442383, -14.708539962768555, -14.742592811584473, -13.348963737487793, -12.61976146697998, -11.967158317565918, -9.57329273223877, 0.0, 0.0, 0.0, 0.0, -12.330726623535156, 0.0, 0.0, -15.165936470031738, -13.776863098144531, -15.433259963989258, -18.244476318359375, -14.758478164672852, -15.921028137207031, -17.666507720947266, -17.83306884765625, -18.87327766418457, -18.64873695373535, -20.342185974121094, -21.576656341552734, -22.542879104614258, -22.188203811645508, -22.115121841430664, -28.08154296875, -29.189626693725586, -29.76081085205078, -31.07135581970215, -32.208335876464844, -32.43391036987305, -32.45756912231445, -32.78041458129883, -31.95489501953125, -31.7381591796875, -31.75571060180664, -31.114789962768555, -28.24827766418457, -28.657154083251953, -27.345922470092773, -25.41396713256836, -24.408235549926758, -23.99518585205078, -20.45075035095215, -18.24417495727539, -17.485126495361328, -16.03365707397461, -13.94278621673584, -12.100347518920898, -9.342069625854492, -6.776621341705322, -9.920282363891602, -10.896794319152832, -10.298970222473145, -9.517173767089844, -8.80880355834961, -8.665667533874512, -8.615460395812988, -6.626674652099609, -6.945713043212891, -8.107954025268555, 0.0, 2.965303659439087, 4.539000511169434, 3.085872173309326, 3.1655595302581787, 1.4494330883026123, 1.062791109085083, 0.0, 3.0808827877044678, -0.0, -0.0, -18.34562110900879, -16.54006576538086, -16.805116653442383, -14.708539962768555, -14.742592811584473, -13.348963737487793, -12.61976146697998, -11.967158317565918, -9.57329273223877, -0.0, -0.0, -0.0, -0.0, -12.330726623535156, -0.0, -0.0, -15.165936470031738, -13.776863098144531, -15.433259963989258, -18.244476318359375, -14.758478164672852, -15.921028137207031, -17.666507720947266, -17.83306884765625, -18.87327766418457, -18.64873695373535, -20.342185974121094, -21.576656341552734, -22.83216667175293, -24.75004768371582, -26.573970794677734, -28.05571174621582, -29.273719787597656, -30.265968322753906, -31.369361877441406, -32.4012451171875, -32.71758270263672, -32.99085998535156, -32.833805084228516, -32.32004928588867, -31.69940757751465, -31.078344345092773, -30.1527099609375, -28.873754501342773, -27.45655632019043, -26.766510009765625, -25.574474334716797, -24.447669982910156, -23.99518585205078, -20.45075035095215, -18.24417495727539, -17.485126495361328, -16.03365707397461, -13.94278621673584, -12.100347518920898, -9.342069625854492, -6.776621341705322, -9.920282363891602, -10.896794319152832, -10.298970222473145, -9.517173767089844, -8.80880355834961, -8.665667533874512, -8.615460395812988, -6.626674652099609, -6.945713043212891, -8.107954025268555, 0.0, 2.965303659439087, 4.539000511169434, 3.085872173309326, 3.1655595302581787, 1.4494330883026123, 1.062791109085083, 0.0, 3.0808827877044678], [-17.695146560668945, 0.0, 0.0, -16.825645446777344, -16.912982940673828, -15.33594799041748, -13.564929008483887, -13.476350784301758, -13.7169189453125, -11.97011661529541, -11.947929382324219, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.7539644241333, -15.559036254882812, -16.05377197265625, -16.792537689208984, -16.161096572875977, -17.9090518951416, -17.90797996520996, -18.496606826782227, -19.765329360961914, -20.078147888183594, -20.850112915039062, -21.138839721679688, -23.908000946044922, -25.029027938842773, -26.731914520263672, -28.80447769165039, -32.24109649658203, -32.525447845458984, -32.46270751953125, -33.286277770996094, -31.253467559814453, -34.220726013183594, -34.73676300048828, -32.82011795043945, -32.61557388305664, -32.495582580566406, -30.981901168823242, -29.783313751220703, -28.908349990844727, -29.825708389282227, -28.65752601623535, -25.830522537231445, -23.647056579589844, -21.264772415161133, -19.17535972595215, -20.67436981201172, -15.972369194030762, -13.472583770751953, -11.92992877960205, -10.682015419006348, -9.748111724853516, 0.0, 0.0, -4.942621231079102, -5.76246452331543, -8.841185569763184, -10.087102890014648, -8.869071006774902, -7.8782639503479, 0.0, 0.0, 0.0, 5.803642272949219, 3.1575286388397217, 2.608880043029785, 1.918203353881836, 2.096440553665161, 0.0, 0.0, 2.1584084033966064, -17.695146560668945, -0.0, -0.0, -16.825645446777344, -16.912982940673828, -15.33594799041748, -13.564929008483887, -13.476350784301758, -13.7169189453125, -11.97011661529541, -11.947929382324219, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.7539644241333, -15.559036254882812, -16.05377197265625, -16.792537689208984, -16.161096572875977, -17.9090518951416, -17.90797996520996, -18.496606826782227, -19.765329360961914, -20.078147888183594, -20.850112915039062, -21.138839721679688, -23.799583435058594, -25.240625381469727, -26.94883918762207, -28.585594177246094, -29.995235443115234, -31.196338653564453, -32.1489372253418, -32.85634231567383, -33.29159164428711, -33.43122100830078, -33.32109069824219, -32.9755744934082, -32.439720153808594, -31.756290435791016, -30.958112716674805, -30.002046585083008, -29.037199020385742, -28.1217098236084, -27.178802490234375, -25.796342849731445, -23.647056579589844, -21.264772415161133, -19.17535972595215, -20.67436981201172, -15.972369194030762, -13.472583770751953, -11.92992877960205, -10.682015419006348, -9.748111724853516, -0.0, -0.0, -4.942621231079102, -5.76246452331543, -8.841185569763184, -10.087102890014648, -8.869071006774902, -7.8782639503479, -0.0, -0.0, 0.0, 5.803642272949219, 3.1575286388397217, 2.608880043029785, 1.918203353881836, 2.096440553665161, 0.0, -0.0, 2.1584084033966064], [-18.395498275756836, 0.0, -18.862171173095703, 0.0, -15.85756778717041, -16.721670150756836, -14.723134994506836, -13.45315170288086, -14.242755889892578, -12.996298789978027, -12.491007804870605, -11.223345756530762, 0.0, -18.80145835876465, 0.0, 0.0, 0.0, 0.0, -15.18309497833252, 0.0, -13.131488800048828, -17.66423797607422, -18.000715255737305, -18.845474243164062, -18.779447555541992, -19.468538284301758, -20.31221580505371, -20.7323055267334, -20.903032302856445, -22.14544105529785, -23.244932174682617, -26.85845375061035, -27.524932861328125, -29.835304260253906, -30.962453842163086, -32.59089279174805, -31.929794311523438, -33.5250358581543, -33.81884002685547, -34.997013092041016, -33.69334030151367, -33.11994171142578, -30.564088821411133, -30.089374542236328, -32.3853874206543, -31.39280128479004, -29.76856803894043, -29.656911849975586, -28.100439071655273, -29.51204490661621, -24.824922561645508, -23.234729766845703, -20.334760665893555, -18.32326316833496, -16.5750789642334, -14.121780395507812, -12.41630744934082, -9.955647468566895, -8.664690971374512, 0.0, 0.0, 0.0, 0.0, 0.0, -10.640748023986816, 0.0, -4.761897563934326, 0.0, 0.0, 0.0, 2.983809232711792, 2.2713277339935303, 1.8276015520095825, 1.902379035949707, 0.0, 0.0, -3.2928364276885986, -0.20178626477718353, -18.395498275756836, -0.0, -18.862171173095703, -0.0, -15.85756778717041, -16.721670150756836, -14.723134994506836, -13.45315170288086, -14.242755889892578, -12.996298789978027, -12.491007804870605, -11.223345756530762, -0.0, -18.80145835876465, -0.0, -0.0, -0.0, -0.0, -15.18309497833252, -0.0, -13.131488800048828, -17.66423797607422, -18.000715255737305, -18.845474243164062, -18.779447555541992, -19.468538284301758, -20.31221580505371, -20.7323055267334, -20.903032302856445, -22.14544105529785, -23.479639053344727, -25.54203987121582, -27.388412475585938, -29.081539154052734, -30.560405731201172, -31.781536102294922, -32.68571472167969, -33.293296813964844, -33.658058166503906, -33.77485656738281, -33.67644119262695, -33.39286422729492, -32.94976043701172, -32.37653350830078, -31.727190017700195, -30.976072311401367, -30.138023376464844, -29.303665161132812, -28.63801383972168, -28.523622512817383, -24.824922561645508, -23.234729766845703, -20.334760665893555, -18.32326316833496, -16.5750789642334, -14.121780395507812, -12.41630744934082, -9.955647468566895, -8.664690971374512, -0.0, -0.0, -0.0, -0.0, -0.0, -10.640748023986816, -0.0, -4.761897563934326, -0.0, 0.0, 0.0, 2.983809232711792, 2.2713277339935303, 1.8276015520095825, 1.902379035949707, 0.0, -0.0, -3.2928364276885986, -0.20178626477718353], [-19.913915634155273, 0.0, -18.635393142700195, 0.0, 0.0, -16.339067459106445, -15.193102836608887, -13.808306694030762, -12.956823348999023, -14.292807579040527, -12.868233680725098, -11.34707260131836, 0.0, -18.29985809326172, 0.0, -18.340885162353516, 0.0, -12.999847412109375, -12.265299797058105, -9.019359588623047, 0.0, 0.0, -19.65010643005371, -19.809593200683594, -21.077547073364258, -21.87290382385254, -21.3271484375, -21.92819595336914, -21.2727108001709, -22.001548767089844, -24.262134552001953, -26.49599838256836, -28.179954528808594, -29.73277473449707, -29.835548400878906, -33.19927978515625, -34.099979400634766, -33.4002685546875, -35.72062301635742, -31.711084365844727, -33.72189712524414, -33.5302848815918, -32.771724700927734, -28.253324508666992, -30.246967315673828, -32.618778228759766, -32.82826232910156, -30.713075637817383, -28.90422248840332, -27.214553833007812, -25.795652389526367, -23.38678550720215, -21.89038848876953, -18.28120994567871, -16.615686416625977, -17.13138198852539, -15.747830390930176, -13.004737854003906, -13.505645751953125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0398424863815308, 0.7133849859237671, 1.3705517053604126, 1.1530439853668213, 2.0591788291931152, 0.0, 0.0, -1.0656561851501465, 0.0, -19.913915634155273, -0.0, -18.635393142700195, -0.0, -0.0, -16.339067459106445, -15.193102836608887, -13.808306694030762, -12.956823348999023, -14.292807579040527, -12.868233680725098, -11.34707260131836, -0.0, -18.29985809326172, -0.0, -18.340885162353516, -0.0, -12.999847412109375, -12.265299797058105, -9.019359588623047, -0.0, -0.0, -19.65010643005371, -19.809593200683594, -21.077547073364258, -21.87290382385254, -21.3271484375, -21.92819595336914, -21.2727108001709, -22.001548767089844, -24.317699432373047, -26.053312301635742, -27.865049362182617, -29.566017150878906, -31.03530502319336, -32.206275939941406, -33.04212951660156, -33.573974609375, -33.85856246948242, -33.9395637512207, -33.85171127319336, -33.61686325073242, -33.27336883544922, -32.84672164916992, -32.331180572509766, -31.72743034362793, -31.00594139099121, -30.187788009643555, -29.094026565551758, -27.371469497680664, -25.795652389526367, -23.38678550720215, -21.89038848876953, -18.28120994567871, -16.615686416625977, -17.13138198852539, -15.747830390930176, -13.004737854003906, -13.505645751953125, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 1.0398424863815308, 0.7133849859237671, 1.3705517053604126, 1.1530439853668213, 2.0591788291931152, 0.0, -0.0, -1.0656561851501465, -0.0], [-20.72870635986328, 0.0, -17.63982391357422, 0.0, 0.0, -16.483348846435547, -14.80821704864502, -15.010626792907715, -14.017928123474121, -13.76951789855957, -12.643041610717773, -12.45901107788086, -13.138850212097168, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.437219619750977, -21.667987823486328, -17.614971160888672, -18.375844955444336, -18.27379035949707, -21.649572372436523, -24.74281883239746, -27.3136043548584, -27.576658248901367, -30.705501556396484, -32.06727600097656, -33.41437911987305, -33.11774444580078, -30.169347763061523, -34.92024612426758, -34.517189025878906, -31.188339233398438, -34.08621597290039, -31.383272171020508, -28.523391723632812, -32.804649353027344, -33.63358688354492, -32.698143005371094, -31.616239547729492, -30.699987411499023, -27.822187423706055, -26.612394332885742, -24.251131057739258, -21.973791122436523, -20.433748245239258, -20.164649963378906, -20.91056251525879, -17.25197410583496, 0.0, 0.0, -11.846722602844238, -8.437512397766113, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.3645704984664917, 0.027183961123228073, 0.8340811729431152, -1.070057988166809, 0.0, 0.0, -1.7902069091796875, -1.3951829671859741, 0.0, -20.72870635986328, -0.0, -17.63982391357422, -0.0, -0.0, -16.483348846435547, -14.80821704864502, -15.010626792907715, -14.017928123474121, -13.76951789855957, -12.643041610717773, -12.45901107788086, -13.138850212097168, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.437219619750977, -21.667987823486328, -17.614971160888672, -18.375844955444336, -18.27379035949707, -21.649572372436523, -24.883817672729492, -26.66704750061035, -28.421878814697266, -30.099023818969727, -31.488311767578125, -32.532413482666016, -33.24898910522461, -33.67105484008789, -33.86345672607422, -33.904296875, -33.82552719116211, -33.6412239074707, -33.397891998291016, -33.12364959716797, -32.75181579589844, -32.217716217041016, -31.542484283447266, -30.750703811645508, -29.650667190551758, -28.027873992919922, -26.612394332885742, -24.251131057739258, -21.973791122436523, -20.433748245239258, -20.164649963378906, -20.91056251525879, -17.25197410583496, -0.0, -0.0, -11.846722602844238, -8.437512397766113, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.3645704984664917, 0.027183961123228073, 0.8340811729431152, -1.070057988166809, 0.0, -0.0, -1.7902069091796875, -1.3951829671859741, -0.0], [0.0, -20.07073974609375, -18.954500198364258, 0.0, 0.0, 0.0, -18.336618423461914, -15.264272689819336, -14.812996864318848, -13.395634651184082, -13.137894630432129, -13.421481132507324, -13.411733627319336, 0.0, 0.0, 0.0, 0.0, -14.854935646057129, -13.126688957214355, -10.16566276550293, -9.043209075927734, -5.941335678100586, 0.0, 0.0, -18.667701721191406, -20.89525604248047, -21.493621826171875, -19.294021606445312, -20.997516632080078, -23.174036026000977, -25.10355567932129, -28.2782039642334, -29.307273864746094, -32.441192626953125, -29.153675079345703, -31.340139389038086, -33.10866928100586, -33.26933288574219, -34.664344787597656, -35.107757568359375, -29.64754867553711, -29.376556396484375, -33.83641052246094, -34.12046813964844, -34.5989990234375, -33.74089050292969, -34.65080642700195, -32.23998260498047, -30.521453857421875, -29.5542049407959, -27.054731369018555, -24.665571212768555, -22.633525848388672, -20.33550453186035, -20.837692260742188, -19.940614700317383, -15.561574935913086, 0.0, 0.0, -13.342764854431152, 0.0, -12.663104057312012, -11.486276626586914, -11.673602104187012, 0.0, 0.0, 0.0, 0.0, 0.0, -2.240715980529785, -0.34711405634880066, -0.17747312784194946, -0.15985417366027832, 0.0, 0.0, -0.9221563935279846, -1.4201854467391968, 0.0, -0.0, -20.07073974609375, -18.954500198364258, -0.0, -0.0, -0.0, -18.336618423461914, -15.264272689819336, -14.812996864318848, -13.395634651184082, -13.137894630432129, -13.421481132507324, -13.411733627319336, -0.0, -0.0, -0.0, -0.0, -14.854935646057129, -13.126688957214355, -10.16566276550293, -9.043209075927734, -5.941335678100586, -0.0, -0.0, -18.667701721191406, -20.89525604248047, -21.493621826171875, -19.294021606445312, -20.997516632080078, -23.174036026000977, -25.47284698486328, -27.473722457885742, -29.194379806518555, -30.699495315551758, -31.906936645507812, -32.757102966308594, -33.278934478759766, -33.54713439941406, -33.65005874633789, -33.6457405090332, -33.57206344604492, -33.4515495300293, -33.30208206176758, -33.15068435668945, -32.930946350097656, -32.43686294555664, -31.73160171508789, -31.025890350341797, -30.234416961669922, -29.216623306274414, -27.054731369018555, -24.665571212768555, -22.633525848388672, -20.33550453186035, -20.837692260742188, -19.940614700317383, -15.561574935913086, -0.0, -0.0, -13.342764854431152, -0.0, -12.663104057312012, -11.486276626586914, -11.673602104187012, -0.0, -0.0, -0.0, -0.0, -0.0, -2.240715980529785, -0.34711405634880066, -0.17747312784194946, -0.15985417366027832, -0.0, -0.0, -0.9221563935279846, -1.4201854467391968, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.227697372436523, -15.869649887084961, -14.457676887512207, -14.71323299407959, -13.530089378356934, -14.19675350189209, -14.626873016357422, 0.0, 0.0, 0.0, 0.0, 0.0, -10.415507316589355, -9.867855072021484, 0.0, 0.0, -23.20332145690918, 0.0, -20.18840980529785, -22.65821075439453, -23.611921310424805, -24.585811614990234, -23.784072875976562, -25.50819206237793, -27.488859176635742, -27.83795738220215, -30.84416961669922, -31.70100212097168, -27.928537368774414, -29.911502838134766, -28.82984733581543, -34.370323181152344, -35.280548095703125, -33.85413360595703, -32.48025131225586, -33.75038528442383, -34.66558074951172, -33.61351013183594, -33.92217254638672, -34.36234664916992, -33.31276321411133, -33.42974853515625, -31.615100860595703, -30.564882278442383, -27.12968635559082, -26.422447204589844, -22.57866096496582, -21.439668655395508, -20.91499137878418, -18.65052032470703, 0.0, 0.0, 0.0, 0.0, -15.542428970336914, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -4.154191970825195, -2.145972490310669, -1.5303666591644287, -1.2935056686401367, -3.4219064712524414, 0.0, -0.7232460379600525, -3.831629753112793, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.227697372436523, -15.869649887084961, -14.457676887512207, -14.71323299407959, -13.530089378356934, -14.19675350189209, -14.626873016357422, -0.0, -0.0, -0.0, -0.0, -0.0, -10.415507316589355, -9.867855072021484, -0.0, -0.0, -23.20332145690918, -0.0, -20.18840980529785, -22.65821075439453, -23.611921310424805, -24.585811614990234, -23.784072875976562, -25.50819206237793, -27.370460510253906, -28.604087829589844, -29.99951171875, -31.253786087036133, -32.258140563964844, -32.87166213989258, -33.1029167175293, -33.22109603881836, -33.2580451965332, -33.21059036254883, -33.13135528564453, -33.04774475097656, -32.97706985473633, -32.90597915649414, -32.72829818725586, -32.34947204589844, -31.70366096496582, -31.06409454345703, -30.52726173400879, -29.884319305419922, -27.12968635559082, -26.422447204589844, -22.57866096496582, -21.439668655395508, -20.91499137878418, -18.65052032470703, -0.0, -0.0, -0.0, -0.0, -15.542428970336914, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -4.154191970825195, -2.145972490310669, -1.5303666591644287, -1.2935056686401367, -3.4219064712524414, -0.0, -0.7232460379600525, -3.831629753112793, -0.0], [0.0, 0.0, -15.02855396270752, -17.055795669555664, -16.83627700805664, 0.0, 0.0, -17.49212074279785, -15.856624603271484, -15.70139217376709, -14.99609661102295, -13.280713081359863, -14.205965995788574, 0.0, 0.0, 0.0, 0.0, 0.0, -11.329143524169922, 0.0, 0.0, 0.0, 0.0, -23.482812881469727, -23.406103134155273, 0.0, -25.569400787353516, -27.448753356933594, -26.08154296875, -27.52475929260254, -28.535335540771484, -29.739728927612305, -30.986753463745117, -30.707395553588867, -28.053491592407227, -29.883705139160156, -33.52996063232422, -34.76613998413086, -31.092329025268555, -33.65130615234375, -33.359718322753906, -34.18281173706055, -34.31150436401367, -33.04814529418945, -34.920799255371094, -34.56449508666992, -34.68727111816406, -32.63994598388672, -29.197402954101562, -30.561782836914062, -28.231264114379883, -25.95530891418457, -22.856300354003906, -21.21268081665039, -22.22154998779297, -19.70106315612793, 0.0, -16.07175636291504, 0.0, -16.06190299987793, -15.522231101989746, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.8088573217391968, -2.867560863494873, -1.670884609222412, 0.0, 0.0, -1.007716178894043, 0.0, 0.0, 0.0, -0.0, -0.0, -15.02855396270752, -17.055795669555664, -16.83627700805664, -0.0, -0.0, -17.49212074279785, -15.856624603271484, -15.70139217376709, -14.99609661102295, -13.280713081359863, -14.205965995788574, -0.0, -0.0, -0.0, -0.0, -0.0, -11.329143524169922, -0.0, -0.0, -0.0, -0.0, -23.482812881469727, -23.406103134155273, -0.0, -25.569400787353516, -27.448753356933594, -26.08154296875, -27.52475929260254, -28.398101806640625, -29.48858070373535, -30.582155227661133, -31.64132308959961, -32.393619537353516, -32.73210906982422, -32.798805236816406, -32.7708854675293, -32.70256042480469, -32.615745544433594, -32.530494689941406, -32.45644760131836, -32.3863525390625, -32.282928466796875, -32.120765686035156, -31.899566650390625, -31.454927444458008, -30.78852081298828, -30.239797592163086, -29.830032348632812, -28.231264114379883, -25.95530891418457, -22.856300354003906, -21.21268081665039, -22.22154998779297, -19.70106315612793, -0.0, -16.07175636291504, -0.0, -16.06190299987793, -15.522231101989746, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.8088573217391968, -2.867560863494873, -1.670884609222412, -0.0, -0.0, -1.007716178894043, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, -20.2698917388916, -18.054317474365234, 0.0, 0.0, 0.0, -16.765228271484375, -15.324841499328613, -15.310961723327637, -15.296700477600098, -15.387627601623535, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.13086700439453, -22.259552001953125, -22.490751266479492, -22.66754150390625, -27.265064239501953, -25.813236236572266, -27.22015380859375, -29.366701126098633, -30.024799346923828, -30.248197555541992, -31.677705764770508, -28.576187133789062, -32.494171142578125, -34.138370513916016, -36.101505279541016, -33.91149139404297, -33.38128662109375, -33.50620651245117, -33.282989501953125, -33.197269439697266, -33.46290969848633, -33.60198974609375, -33.225852966308594, -33.3266716003418, -34.69755172729492, 0.0, -26.024967193603516, -27.53673553466797, -24.24384880065918, -26.828384399414062, -23.85689926147461, 0.0, 0.0, 0.0, -17.00541877746582, -16.35690689086914, -16.65656089782715, -17.552091598510742, -15.035834312438965, -15.222402572631836, -15.28367805480957, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.535475254058838, -3.288036823272705, -3.994292974472046, 0.0, 0.0, -2.6236352920532227, -2.885850667953491, 0.0, 0.0, -0.0, -0.0, -0.0, -20.2698917388916, -18.054317474365234, -0.0, -0.0, -0.0, -16.765228271484375, -15.324841499328613, -15.310961723327637, -15.296700477600098, -15.387627601623535, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.13086700439453, -22.259552001953125, -22.490751266479492, -22.66754150390625, -27.265064239501953, -25.813236236572266, -27.22015380859375, -29.366701126098633, -29.4163875579834, -29.98699188232422, -30.8043212890625, -31.74591064453125, -32.40928268432617, -32.5428581237793, -32.41896438598633, -32.25545120239258, -32.09157180786133, -31.954307556152344, -31.839820861816406, -31.701114654541016, -31.50746726989746, -31.29038429260254, -31.203359603881836, -31.051029205322266, -30.753189086914062, -0.0, -29.299644470214844, -27.82740592956543, -24.24384880065918, -26.828384399414062, -23.85689926147461, -0.0, -0.0, -0.0, -17.00541877746582, -16.35690689086914, -16.65656089782715, -17.552091598510742, -15.035834312438965, -15.222402572631836, -15.28367805480957, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.535475254058838, -3.288036823272705, -3.994292974472046, -0.0, -0.0, -2.6236352920532227, -2.885850667953491, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -21.68946647644043, -18.76213264465332, 0.0, 0.0, -16.73301887512207, -16.19875144958496, -15.201576232910156, -13.59097671508789, -15.48066520690918, 0.0, -8.543560981750488, 0.0, 0.0, 0.0, 0.0, -18.506879806518555, -18.220951080322266, 0.0, -17.107826232910156, -24.133195877075195, -22.34004020690918, -22.262060165405273, -24.196449279785156, -25.268505096435547, 0.0, -29.730619430541992, -30.073156356811523, -30.764339447021484, -31.870973587036133, -30.752201080322266, -35.9009895324707, -34.666770935058594, -35.29751205444336, -33.820587158203125, -34.10545349121094, -32.883182525634766, -31.98396110534668, -31.247182846069336, -32.55376434326172, -34.805084228515625, -35.09758758544922, 0.0, -30.277193069458008, 0.0, -26.501596450805664, -26.721134185791016, -25.72907829284668, -23.675495147705078, 0.0, 0.0, 0.0, -14.426816940307617, -17.217281341552734, -18.912242889404297, -17.715890884399414, -16.905723571777344, -16.93397331237793, -15.59222412109375, -16.594825744628906, -15.903905868530273, 0.0, 0.0, 0.0, 0.0, 0.0, -5.876751899719238, -4.6542744636535645, -4.515911102294922, 0.0, -7.042367458343506, -5.969240188598633, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -21.68946647644043, -18.76213264465332, -0.0, -0.0, -16.73301887512207, -16.19875144958496, -15.201576232910156, -13.59097671508789, -15.48066520690918, -0.0, -8.543560981750488, -0.0, -0.0, -0.0, -0.0, -18.506879806518555, -18.220951080322266, -0.0, -17.107826232910156, -24.133195877075195, -22.34004020690918, -22.262060165405273, -24.196449279785156, -25.268505096435547, -0.0, -29.730619430541992, -29.45113754272461, -29.815168380737305, -30.66860580444336, -31.734542846679688, -32.33927536010742, -32.29453659057617, -32.07526397705078, -31.821517944335938, -31.569669723510742, -31.35550880432129, -31.175220489501953, -30.895301818847656, -30.475709915161133, -29.98636817932129, -29.84234046936035, -0.0, -29.81955909729004, -0.0, -28.272216796875, -27.747217178344727, -25.72907829284668, -23.675495147705078, -0.0, -0.0, -0.0, -14.426816940307617, -17.217281341552734, -18.912242889404297, -17.715890884399414, -16.905723571777344, -16.93397331237793, -15.59222412109375, -16.594825744628906, -15.903905868530273, -0.0, -0.0, -0.0, -0.0, -0.0, -5.876751899719238, -4.6542744636535645, -4.515911102294922, -0.0, -7.042367458343506, -5.969240188598633, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -25.047651290893555, -19.590856552124023, -18.8607120513916, 0.0, -19.009035110473633, -17.24179458618164, -15.861196517944336, -15.850656509399414, -15.685001373291016, -11.932021141052246, -11.8619384765625, -15.129912376403809, -18.7122745513916, -15.809669494628906, -14.805379867553711, -17.292804718017578, -16.491113662719727, -17.17201805114746, -17.191978454589844, 0.0, -21.821168899536133, -23.2536678314209, -21.287841796875, -27.228015899658203, -27.386978149414062, 0.0, -26.536989212036133, -28.21246337890625, -26.781980514526367, 0.0, -35.44094467163086, -34.8001708984375, -34.609161376953125, -34.613956451416016, -33.350162506103516, -31.94295310974121, -30.757259368896484, -29.718631744384766, -30.54276466369629, -33.905574798583984, -30.283554077148438, 0.0, 0.0, 0.0, -24.828062057495117, 0.0, -28.10430335998535, 0.0, 0.0, 0.0, 0.0, 0.0, -16.033227920532227, -17.3987979888916, -18.03277015686035, -18.191944122314453, -17.391796112060547, -16.964609146118164, -14.722125053405762, -18.08690643310547, -21.18331527709961, 0.0, 0.0, -10.229763984680176, 0.0, 0.0, -5.263807773590088, -1.7351269721984863, 0.0, -5.190254211425781, -8.025589942932129, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -25.047651290893555, -19.590856552124023, -18.8607120513916, -0.0, -19.009035110473633, -17.24179458618164, -15.861196517944336, -15.850656509399414, -15.685001373291016, -11.932021141052246, -11.8619384765625, -15.129912376403809, -18.7122745513916, -15.809669494628906, -14.805379867553711, -17.292804718017578, -16.491113662719727, -17.17201805114746, -17.191978454589844, -0.0, -21.821168899536133, -23.2536678314209, -21.287841796875, -27.228015899658203, -27.386978149414062, -0.0, -27.134883880615234, -29.0260066986084, -30.370174407958984, -0.0, -32.13186264038086, -32.088478088378906, -31.803478240966797, -31.474470138549805, -31.13004493713379, -30.813629150390625, -30.43316650390625, -29.994264602661133, -29.429288864135742, -28.872343063354492, -28.767475128173828, -0.0, -0.0, -0.0, -27.643774032592773, -0.0, -28.10430335998535, -0.0, -0.0, -0.0, -0.0, -0.0, -16.033227920532227, -17.3987979888916, -18.03277015686035, -18.191944122314453, -17.391796112060547, -16.964609146118164, -14.722125053405762, -18.08690643310547, -21.18331527709961, -0.0, -0.0, -10.229763984680176, -0.0, -0.0, -5.263807773590088, -1.7351269721984863, -0.0, -5.190254211425781, -8.025589942932129, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -24.459239959716797, -21.485227584838867, -20.173139572143555, 0.0, 0.0, -17.00960922241211, -17.38375473022461, -15.742574691772461, 0.0, -14.752530097961426, -14.762662887573242, -15.911492347717285, -18.23659324645996, -13.82883358001709, -16.437963485717773, -17.83192253112793, -18.334274291992188, -19.342025756835938, -19.393686294555664, -19.690818786621094, -21.252117156982422, -20.735445022583008, -23.4187068939209, 0.0, -28.75598907470703, 0.0, 0.0, -28.538890838623047, -27.822690963745117, -29.47528839111328, 0.0, 0.0, -29.885578155517578, -34.1833610534668, -32.691734313964844, -31.452070236206055, -29.09400749206543, -28.899051666259766, -29.23939323425293, -31.578344345092773, -29.020328521728516, -25.578876495361328, 0.0, 0.0, -25.445932388305664, -27.97725486755371, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.758469581604004, -18.30375099182129, -19.986677169799805, -17.78974723815918, -17.518070220947266, -18.925872802734375, -18.71224594116211, -18.11294174194336, 0.0, 0.0, -13.092801094055176, 0.0, 0.0, 0.0, -5.172062397003174, 0.0, -5.264195919036865, -8.427273750305176, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -24.459239959716797, -21.485227584838867, -20.173139572143555, -0.0, -0.0, -17.00960922241211, -17.38375473022461, -15.742574691772461, -0.0, -14.752530097961426, -14.762662887573242, -15.911492347717285, -18.23659324645996, -13.82883358001709, -16.437963485717773, -17.83192253112793, -18.334274291992188, -19.342025756835938, -19.393686294555664, -19.690818786621094, -21.252117156982422, -20.735445022583008, -23.4187068939209, -0.0, -28.75598907470703, -0.0, -0.0, -28.863710403442383, -30.09327507019043, -31.12381362915039, -0.0, -0.0, -31.620136260986328, -31.219497680664062, -30.748123168945312, -30.21624183654785, -29.629497528076172, -29.074663162231445, -28.48590087890625, -28.003761291503906, -27.980016708374023, -28.0143985748291, -0.0, -0.0, -27.46631622314453, -28.010225296020508, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.758469581604004, -18.30375099182129, -19.986677169799805, -17.78974723815918, -17.518070220947266, -18.925872802734375, -18.71224594116211, -18.11294174194336, -0.0, -0.0, -13.092801094055176, -0.0, -0.0, -0.0, -5.172062397003174, -0.0, -5.264195919036865, -8.427273750305176, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -20.825197219848633, -22.547508239746094, 0.0, 0.0, -18.707733154296875, -17.70502471923828, 0.0, -13.659407615661621, -14.894790649414062, -15.219497680664062, -16.822834014892578, -17.113632202148438, -17.028156280517578, -17.117712020874023, -17.836074829101562, -18.065784454345703, -18.57280158996582, -19.865089416503906, -20.93010139465332, -21.381534576416016, -22.449260711669922, -22.764820098876953, 0.0, 0.0, 0.0, 0.0, 0.0, -28.37041664123535, -30.555835723876953, -31.58881950378418, 0.0, -29.585811614990234, -28.516599655151367, -26.934253692626953, -30.72219467163086, -26.204187393188477, -25.586057662963867, -25.541366577148438, 0.0, -25.974767684936523, 0.0, 0.0, -28.581430435180664, -28.656789779663086, -26.0349178314209, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.69905662536621, -19.74832534790039, -18.853179931640625, -16.42772102355957, -17.91890525817871, -16.22121810913086, -19.047752380371094, -17.790620803833008, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -4.649374008178711, -8.105616569519043, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.825197219848633, -22.547508239746094, -0.0, -0.0, -18.707733154296875, -17.70502471923828, -0.0, -13.659407615661621, -14.894790649414062, -15.219497680664062, -16.822834014892578, -17.113632202148438, -17.028156280517578, -17.117712020874023, -17.836074829101562, -18.065784454345703, -18.57280158996582, -19.865089416503906, -20.93010139465332, -21.381534576416016, -22.449260711669922, -22.764820098876953, -0.0, -0.0, -0.0, -0.0, -0.0, -29.889568328857422, -30.706480026245117, -31.518064498901367, -0.0, -31.576204299926758, -31.181886672973633, -30.61637306213379, -29.928049087524414, -29.24283218383789, -28.559492111206055, -27.940366744995117, -0.0, -27.462217330932617, -0.0, -0.0, -27.18140411376953, -27.21216583251953, -26.48298454284668, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.69905662536621, -19.74832534790039, -18.853179931640625, -16.42772102355957, -17.91890525817871, -16.22121810913086, -19.047752380371094, -17.790620803833008, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -4.649374008178711, -8.105616569519043, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -24.247549057006836, -23.277481079101562, 0.0, 0.0, -18.22138214111328, 0.0, 0.0, -15.313244819641113, -16.590068817138672, -17.876543045043945, -16.108705520629883, -16.863372802734375, -18.007301330566406, -17.714313507080078, -18.53577995300293, -19.39351463317871, -19.94156265258789, -20.780906677246094, -22.166404724121094, -22.0792179107666, -22.003490447998047, -24.028648376464844, 0.0, 0.0, 0.0, 0.0, 0.0, -28.129100799560547, 0.0, 0.0, -27.076183319091797, -26.72315216064453, -26.594533920288086, -26.442764282226562, -26.63101577758789, -25.019824981689453, -23.69609260559082, 0.0, 0.0, 0.0, 0.0, -28.807092666625977, -29.341196060180664, -24.72429847717285, -27.603652954101562, 0.0, 0.0, 0.0, 0.0, -19.175878524780273, -17.603065490722656, 0.0, -20.60500144958496, -20.403818130493164, -20.583415985107422, -20.52410888671875, -20.009384155273438, -19.0783748626709, -19.49797248840332, -18.802846908569336, -18.46596336364746, 0.0, -15.751859664916992, 0.0, 0.0, 0.0, 0.0, -2.9378585815429688, -5.671245098114014, -6.415809631347656, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.247549057006836, -23.277481079101562, -0.0, -0.0, -18.22138214111328, -0.0, -0.0, -15.313244819641113, -16.590068817138672, -17.876543045043945, -16.108705520629883, -16.863372802734375, -18.007301330566406, -17.714313507080078, -18.53577995300293, -19.39351463317871, -19.94156265258789, -20.780906677246094, -22.166404724121094, -22.0792179107666, -22.003490447998047, -24.028648376464844, -0.0, -0.0, -0.0, -0.0, -0.0, -30.010765075683594, -0.0, -0.0, -31.557289123535156, -31.722578048706055, -31.36046028137207, -30.71988868713379, -30.04141616821289, -29.348350524902344, -28.359708786010742, -0.0, -0.0, -0.0, -0.0, -27.036386489868164, -27.050188064575195, -27.289934158325195, -28.14357566833496, -0.0, -0.0, -0.0, -0.0, -19.175878524780273, -17.603065490722656, -0.0, -20.60500144958496, -20.403818130493164, -20.583415985107422, -20.52410888671875, -20.009384155273438, -19.0783748626709, -19.49797248840332, -18.802846908569336, -18.46596336364746, -0.0, -15.751859664916992, -0.0, -0.0, -0.0, -0.0, -2.9378585815429688, -5.671245098114014, -6.415809631347656, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -20.758026123046875, -22.881372451782227, -23.657230377197266, 0.0, 0.0, 0.0, 0.0, -13.863765716552734, -16.539152145385742, -15.5640287399292, -17.34396743774414, -16.845966339111328, -17.680694580078125, -18.14944839477539, -18.731422424316406, -20.67105484008789, -20.435529708862305, -20.55005645751953, -22.22504997253418, -22.408035278320312, -23.263084411621094, -23.975017547607422, -25.72157859802246, 0.0, 0.0, 0.0, 0.0, -30.43675994873047, 0.0, 0.0, 0.0, 0.0, -23.561208724975586, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.433156967163086, -31.057235717773438, -30.41937828063965, -28.49979019165039, -25.602502822875977, -29.117956161499023, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.103506088256836, -23.532907485961914, -22.494476318359375, -23.463476181030273, -22.68083953857422, -21.82463836669922, -19.887195587158203, -20.242382049560547, -16.162662506103516, -17.904264450073242, -18.45755386352539, 0.0, 0.0, 0.0, 0.0, 0.0, -6.094629764556885, -6.6836419105529785, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.758026123046875, -22.881372451782227, -23.657230377197266, -0.0, -0.0, -0.0, -0.0, -13.863765716552734, -16.539152145385742, -15.5640287399292, -17.34396743774414, -16.845966339111328, -17.680694580078125, -18.14944839477539, -18.731422424316406, -20.67105484008789, -20.435529708862305, -20.55005645751953, -22.22504997253418, -22.408035278320312, -23.263084411621094, -23.975017547607422, -25.72157859802246, -0.0, -0.0, -0.0, -0.0, -29.87671661376953, -0.0, -0.0, -0.0, -0.0, -31.558486938476562, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.437503814697266, -26.612865447998047, -26.721445083618164, -26.94483757019043, -27.444974899291992, -27.868478775024414, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.103506088256836, -23.532907485961914, -22.494476318359375, -23.463476181030273, -22.68083953857422, -21.82463836669922, -19.887195587158203, -20.242382049560547, -16.162662506103516, -17.904264450073242, -18.45755386352539, -0.0, -0.0, -0.0, -0.0, -0.0, -6.094629764556885, -6.6836419105529785, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -20.20531463623047, -20.973535537719727, -25.552698135375977, -24.953758239746094, 0.0, 0.0, 0.0, -15.071398735046387, -16.863401412963867, -17.346683502197266, -16.721683502197266, -16.619373321533203, -16.856420516967773, -17.69306755065918, -18.57868194580078, -19.282989501953125, -20.874204635620117, -21.991939544677734, -23.05809211730957, -23.37704849243164, -23.848384857177734, -24.888168334960938, -25.325624465942383, 0.0, 0.0, 0.0, -29.817155838012695, 0.0, 0.0, 0.0, 0.0, 0.0, -25.973556518554688, -27.791475296020508, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.1329288482666, -26.558496475219727, -27.95608139038086, -26.71367073059082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.128881454467773, -24.961448669433594, -24.44316291809082, -23.712703704833984, -23.46858024597168, -23.978296279907227, -22.489219665527344, -21.266443252563477, 0.0, 0.0, -15.129047393798828, 0.0, 0.0, 0.0, 0.0, 0.0, -10.782475471496582, -9.064016342163086, -9.549433708190918, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.20531463623047, -20.973535537719727, -25.552698135375977, -24.953758239746094, -0.0, -0.0, -0.0, -15.071398735046387, -16.863401412963867, -17.346683502197266, -16.721683502197266, -16.619373321533203, -16.856420516967773, -17.69306755065918, -18.57868194580078, -19.282989501953125, -20.874204635620117, -21.991939544677734, -23.05809211730957, -23.37704849243164, -23.848384857177734, -24.888168334960938, -25.325624465942383, -0.0, -0.0, -0.0, -29.529972076416016, -0.0, -0.0, -0.0, -0.0, -0.0, -31.358938217163086, -30.599016189575195, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.138643264770508, -26.233139038085938, -26.66107940673828, -27.03341293334961, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.128881454467773, -24.961448669433594, -24.44316291809082, -23.712703704833984, -23.46858024597168, -23.978296279907227, -22.489219665527344, -21.266443252563477, -0.0, -0.0, -15.129047393798828, -0.0, -0.0, -0.0, -0.0, -0.0, -10.782475471496582, -9.064016342163086, -9.549433708190918, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.775346755981445, -24.28244400024414, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.482929229736328, -16.892776489257812, -15.72598934173584, -16.257877349853516, -17.380268096923828, -18.16923713684082, -19.29017448425293, -20.777841567993164, -21.94040298461914, -23.166339874267578, -24.20136070251465, -24.93390464782715, -25.70706558227539, -25.718204498291016, 0.0, 0.0, -29.238935470581055, -29.122695922851562, 0.0, 0.0, -36.956146240234375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.10774040222168, -28.730266571044922, -25.127105712890625, 0.0, 0.0, 0.0, 0.0, 0.0, -21.759780883789062, -25.57111358642578, -25.026447296142578, -24.995452880859375, -25.000585556030273, -24.16463851928711, -23.362159729003906, -23.1501407623291, -21.909671783447266, -17.896203994750977, 0.0, -11.173059463500977, 0.0, 0.0, 0.0, 0.0, 0.0, -9.918069839477539, -9.929527282714844, -11.410109519958496, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.775346755981445, -24.28244400024414, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.482929229736328, -16.892776489257812, -15.72598934173584, -16.257877349853516, -17.380268096923828, -18.16923713684082, -19.29017448425293, -20.777841567993164, -21.94040298461914, -23.166339874267578, -24.20136070251465, -24.93390464782715, -25.70706558227539, -25.718204498291016, -0.0, -0.0, -28.96267318725586, -29.201961517333984, -0.0, -0.0, -29.546308517456055, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.026649475097656, -25.46370506286621, -24.738967895507812, -0.0, -0.0, -0.0, -0.0, -0.0, -21.759780883789062, -25.57111358642578, -25.026447296142578, -24.995452880859375, -25.000585556030273, -24.16463851928711, -23.362159729003906, -23.1501407623291, -21.909671783447266, -17.896203994750977, -0.0, -11.173059463500977, -0.0, -0.0, -0.0, -0.0, -0.0, -9.918069839477539, -9.929527282714844, -11.410109519958496, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -26.16431427001953, -25.6058292388916, -21.576004028320312, 0.0, 0.0, 0.0, 0.0, -16.507705688476562, -20.002609252929688, 0.0, -15.17827320098877, -15.553959846496582, -15.60507583618164, -16.229562759399414, -17.50571060180664, -18.695528030395508, -19.82186508178711, -21.6967830657959, -22.694385528564453, -24.663970947265625, -25.737586975097656, -26.028839111328125, -26.294965744018555, -26.08029556274414, 0.0, 0.0, -28.97997283935547, 0.0, 0.0, -36.705718994140625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.031450271606445, -26.248876571655273, 0.0, 0.0, 0.0, -28.108051300048828, -26.323305130004883, -24.989656448364258, -24.79311752319336, -24.704795837402344, -25.629907608032227, -24.785842895507812, -25.28261375427246, -22.134565353393555, -21.69510841369629, -20.06553077697754, -18.40871238708496, -15.573320388793945, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.904691696166992, -10.727058410644531, -10.07020378112793, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.16431427001953, -25.6058292388916, -21.576004028320312, -0.0, -0.0, -0.0, -0.0, -16.507705688476562, -20.002609252929688, -0.0, -15.17827320098877, -15.553959846496582, -15.60507583618164, -16.229562759399414, -17.50571060180664, -18.695528030395508, -19.82186508178711, -21.6967830657959, -22.694385528564453, -24.663970947265625, -25.737586975097656, -26.028839111328125, -26.294965744018555, -26.08029556274414, -0.0, -0.0, -28.878652572631836, -0.0, -0.0, -29.487558364868164, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.487810134887695, -25.54181480407715, -0.0, -0.0, -0.0, -28.108051300048828, -26.323305130004883, -24.989656448364258, -24.79311752319336, -24.704795837402344, -25.629907608032227, -24.785842895507812, -25.28261375427246, -22.134565353393555, -21.69510841369629, -20.06553077697754, -18.40871238708496, -15.573320388793945, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -9.904691696166992, -10.727058410644531, -10.07020378112793, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -27.513792037963867, 0.0, -23.88040542602539, 0.0, 0.0, 0.0, 0.0, -15.580684661865234, -17.747417449951172, 0.0, -17.213563919067383, -15.97805118560791, -16.205181121826172, -15.619043350219727, -16.235010147094727, -17.00956916809082, -18.376750946044922, -19.98151397705078, -22.81156349182129, -24.225576400756836, -26.041601181030273, -26.43099021911621, -26.722496032714844, -27.24983024597168, 0.0, 0.0, -27.445236206054688, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -21.987396240234375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.34275245666504, -24.491708755493164, -22.09488868713379, -23.85674476623535, -24.75583839416504, -19.221181869506836, -17.72557830810547, -18.02970314025879, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.552563667297363, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.513792037963867, -0.0, -23.88040542602539, -0.0, -0.0, -0.0, -0.0, -15.580684661865234, -17.747417449951172, -0.0, -17.213563919067383, -15.97805118560791, -16.205181121826172, -15.619043350219727, -16.235010147094727, -17.00956916809082, -18.376750946044922, -19.98151397705078, -22.81156349182129, -24.225576400756836, -26.041601181030273, -26.43099021911621, -26.722496032714844, -27.24983024597168, -0.0, -0.0, -28.17282485961914, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.777759552001953, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.34275245666504, -24.491708755493164, -22.09488868713379, -23.85674476623535, -24.75583839416504, -19.221181869506836, -17.72557830810547, -18.02970314025879, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.552563667297363, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.51650047302246, -23.64883041381836, 0.0, 0.0, 0.0, 0.0, 0.0, -17.251882553100586, -17.3599853515625, -15.211772918701172, -15.178773880004883, -14.146588325500488, -15.142351150512695, -15.310286521911621, 0.0, 0.0, 0.0, -22.628671646118164, -26.25077247619629, -25.529251098632812, -26.46598243713379, -27.893556594848633, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -21.455564498901367, -19.88459587097168, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.15983009338379, -19.394041061401367, -15.258827209472656, 0.0, 0.0, 0.0, 0.0, -15.385273933410645, 0.0, 0.0, 0.0, -10.826642990112305, -13.129053115844727, -13.939286231994629, -14.478471755981445, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.51650047302246, -23.64883041381836, -0.0, -0.0, -0.0, -0.0, -0.0, -17.251882553100586, -17.3599853515625, -15.211772918701172, -15.178773880004883, -14.146588325500488, -15.142351150512695, -15.310286521911621, -0.0, -0.0, -0.0, -22.628671646118164, -26.25077247619629, -25.529251098632812, -26.46598243713379, -27.893556594848633, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.234600067138672, -20.980335235595703, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.15983009338379, -19.394041061401367, -15.258827209472656, -0.0, -0.0, -0.0, -0.0, -15.385273933410645, -0.0, -0.0, -0.0, -10.826642990112305, -13.129053115844727, -13.939286231994629, -14.478471755981445, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.236467361450195, -23.831430435180664, -21.743728637695312, 0.0, -22.302717208862305, 0.0, -11.919526100158691, 0.0, -16.52360725402832, -15.019938468933105, -14.15577220916748, -13.969533920288086, -13.505575180053711, -13.836791038513184, -13.792824745178223, -12.791620254516602, 0.0, -20.129165649414062, -20.427064895629883, -21.38568878173828, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.47644805908203, 0.0, -13.831110954284668, -11.108474731445312, -11.75252914428711, -10.844501495361328, -8.959393501281738, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.236467361450195, -23.831430435180664, -21.743728637695312, -0.0, -22.302717208862305, -0.0, -11.919526100158691, -0.0, -16.52360725402832, -15.019938468933105, -14.15577220916748, -13.969533920288086, -13.505575180053711, -13.836791038513184, -13.792824745178223, -12.791620254516602, -0.0, -20.129165649414062, -20.427064895629883, -21.38568878173828, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.47644805908203, -0.0, -13.831110954284668, -11.108474731445312, -11.75252914428711, -10.844501495361328, -8.959393501281738, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.303762435913086, -24.51702880859375, -26.73221206665039, -24.91556167602539, 0.0, -13.945371627807617, 0.0, -17.08786964416504, -15.424969673156738, 0.0, 0.0, -14.286303520202637, -13.10995864868164, -12.582575798034668, -11.963838577270508, -11.985977172851562, -18.044960021972656, -18.286701202392578, -18.107946395874023, -19.6898250579834, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.303762435913086, -24.51702880859375, -26.73221206665039, -24.91556167602539, -0.0, -13.945371627807617, -0.0, -17.08786964416504, -15.424969673156738, -0.0, -0.0, -14.286303520202637, -13.10995864868164, -12.582575798034668, -11.963838577270508, -11.985977172851562, -18.044960021972656, -18.286701202392578, -18.107946395874023, -19.6898250579834, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.881065368652344, -26.596948623657227, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.791077613830566, 0.0, 0.0, -14.774176597595215, -14.529060363769531, -19.342449188232422, -21.246034622192383, -20.145694732666016, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.881065368652344, -26.596948623657227, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.791077613830566, -0.0, -0.0, -14.774176597595215, -14.529060363769531, -19.342449188232422, -21.246034622192383, -20.145694732666016, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.01205062866211, 0.0, 0.0, -16.069229125976562, -14.429097175598145, -16.53078269958496, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.01205062866211, -0.0, -0.0, -16.069229125976562, -14.429097175598145, -16.53078269958496, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.7608642578125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.073884963989258, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.7608642578125, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -8.073884963989258, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.660749435424805, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.660749435424805, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.194524765014648, 0.0, -13.071785926818848, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.194524765014648, -0.0, -13.071785926818848, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.323217391967773, -18.284095764160156, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.323217391967773, -18.284095764160156, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.35796546936035, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.35796546936035, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.260316848754883, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.260316848754883, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0]]}, {\"colorbar\": {\"title\": {\"text\": \"B<sub>0</sub> (Hz)\"}}, \"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.3333333333333333, \"rgb(230,0,0)\"], [0.6666666666666666, \"rgb(255,210,0)\"], [1.0, \"rgb(255,255,255)\"]], \"name\": \"comparison heatmap\", \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 11.965934753417969, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 11.965934753417969, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 15.623443603515625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 15.623443603515625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 9.7981538772583, 12.589361190795898, 15.8037691116333, 14.69281005859375, 17.079442977905273, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 9.7981538772583, 12.589361190795898, 15.8037691116333, 14.69281005859375, 17.079442977905273, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 11.692877769470215, 14.92015266418457, 12.197284698486328, 12.920413970947266, 14.779388427734375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 11.692877769470215, 14.92015266418457, 12.197284698486328, 12.920413970947266, 14.779388427734375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 11.570176124572754, 11.594494819641113, 12.837481498718262, 14.860410690307617, 12.127790451049805, 10.297203063964844, 8.515278816223145, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 11.570176124572754, 11.594494819641113, 12.837481498718262, 14.860410690307617, 12.127790451049805, 10.297203063964844, 8.515278816223145, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 15.890425682067871, 0.0, 8.173261642456055, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 15.890425682067871, 0.0, 8.173261642456055, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.957759380340576, 10.227582931518555, 9.606521606445312, 6.681674003601074, 8.601164817810059, 8.122087478637695, 9.686556816101074, 8.04369068145752, 8.153039932250977, 9.428009033203125, 9.965825080871582, 6.234825611114502, 9.974674224853516, 7.909948825836182, 9.719161987304688, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.957759380340576, 10.227582931518555, 9.606521606445312, 6.681674003601074, 8.601164817810059, 8.122087478637695, 9.686556816101074, 8.04369068145752, 8.153039932250977, 9.428009033203125, 9.965825080871582, 6.234825611114502, 9.974674224853516, 7.909948825836182, 9.719161987304688, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.451583862304688, 6.679324626922607, 7.616300582885742, 5.392452239990234, 7.322044372558594, 7.508213043212891, 7.494920253753662, 6.010502815246582, 7.180608749389648, 7.619207859039307, 6.743410587310791, 6.9222002029418945, 6.623361587524414, 5.96250057220459, 7.389313220977783, 6.392689228057861, 6.6540985107421875, 5.657355785369873, 7.888793468475342, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.451583862304688, 6.679324626922607, 7.616300582885742, 5.392452239990234, 7.322044372558594, 7.508213043212891, 7.494920253753662, 6.010502815246582, 7.180608749389648, 7.619207859039307, 6.743410587310791, 6.9222002029418945, 6.623361587524414, 5.96250057220459, 7.389313220977783, 6.392689228057861, 6.6540985107421875, 5.657355785369873, 7.888793468475342, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.613353252410889, 5.140359878540039, 4.926548957824707, 5.846503734588623, 5.999287128448486, 5.405216693878174, 4.394771575927734, 6.327024936676025, 4.779153347015381, 3.2285921573638916, 3.283507823944092, 7.531735420227051, 4.937676906585693, 7.619415283203125, 0.0, 4.007124423980713, 3.7156920433044434, 5.391408920288086, 4.471646785736084, 5.6941609382629395, 5.133329391479492, 6.192070960998535, 5.7244954109191895, 5.906894207000732, 5.4408345222473145, 6.544558048248291, 5.514411449432373, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.613353252410889, 5.140359878540039, 4.926548957824707, 5.846503734588623, 5.999287128448486, 5.405216693878174, 4.394771575927734, 6.327024936676025, 4.779153347015381, 3.2285921573638916, 3.283507823944092, 7.531735420227051, 4.937676906585693, 7.619415283203125, 0.0, 4.007124423980713, 3.7156920433044434, 5.391408920288086, 4.471646785736084, 5.6941609382629395, 5.133329391479492, 6.192070960998535, 5.7244954109191895, 5.906894207000732, 5.4408345222473145, 6.544558048248291, 5.514411449432373, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.973812222480774, 4.214110851287842, 5.08030366897583, 5.053437232971191, 4.473940849304199, 2.7674758434295654, 2.4910125732421875, 3.2468371391296387, 0.0, 0.0, 4.476648807525635, 0.0, 0.0, 0.0, 0.0, 3.475569009780884, 7.3599467277526855, 6.666524410247803, 2.5771193504333496, 0.0, 6.091673374176025, 0.0, 0.0, 0.0, 0.0, 7.011929512023926, 4.712738037109375, 4.677089691162109, 5.5146307945251465, 6.871875762939453, 8.12916088104248, 5.768026828765869, 4.095025539398193, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.973812222480774, 4.214110851287842, 5.08030366897583, 5.053437232971191, 4.473940849304199, 2.7674758434295654, 2.4910125732421875, 3.2468371391296387, 0.0, 0.0, 4.476648807525635, 0.0, 0.0, 0.0, 0.0, 3.475569009780884, 7.3599467277526855, 6.666524410247803, 2.5771193504333496, 0.0, 6.091673374176025, 0.0, 0.0, 0.0, 0.0, 7.011929512023926, 4.712738037109375, 4.677089691162109, 5.5146307945251465, 6.871875762939453, 8.12916088104248, 5.768026828765869, 4.095025539398193, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.930227279663086, 5.531399250030518, 3.663745641708374, 5.1663665771484375, 5.635552406311035, 5.423942565917969, 0.0, 0.0, 0.0, 0.0, 1.9237565994262695, -1.1828200817108154, 1.1383535861968994, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.267199516296387, 0.0, 0.0, 0.0, 5.238744735717773, 6.941651821136475, 4.780300140380859, 5.974871635437012, 6.54814338684082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.930227279663086, 5.531399250030518, 3.663745641708374, 5.1663665771484375, 5.635552406311035, 5.423942565917969, 0.0, 0.0, 0.0, 0.0, 1.9237565994262695, -1.1828200817108154, 1.1383535861968994, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 8.267199516296387, 0.0, 0.0, 0.0, 5.238744735717773, 6.941651821136475, 4.780300140380859, 5.974871635437012, 6.54814338684082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.24436092376709, 3.5664327144622803, 4.654007434844971, 4.40565299987793, 1.5810363292694092, 0.0, 0.0, 0.0, 2.0670719146728516, 4.230217933654785, 4.881903171539307, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.3128243088722229, 0.0, 0.0, 0.0, 0.0, 6.0782694816589355, 5.514291286468506, 0.0, 0.0, 0.0, 5.296868324279785, 5.330333709716797, 6.724663257598877, 6.270814895629883, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.24436092376709, 3.5664327144622803, 4.654007434844971, 4.40565299987793, 1.5810363292694092, 0.0, 0.0, 0.0, 2.0670719146728516, 4.230217933654785, 4.881903171539307, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.3128243088722229, -0.0, 0.0, 0.0, 0.0, 6.0782694816589355, 5.514291286468506, 0.0, 0.0, 0.0, 5.296868324279785, 5.330333709716797, 6.724663257598877, 6.270814895629883, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.9419939517974854, 3.943463087081909, 3.5462758541107178, 3.336599826812744, 2.383026599884033, 3.3162500858306885, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.326289653778076, 0.0, 0.0, 0.0, 0.0, 0.0, -0.6952337026596069, -2.661262273788452, -0.5081387758255005, 2.984849452972412, -0.6979675889015198, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.877132415771484, 6.659774303436279, 0.0, 6.41911506652832, 4.2885589599609375, 5.195495128631592, 5.891505718231201, 6.37553071975708, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.9419939517974854, 3.943463087081909, 3.5462758541107178, 3.336599826812744, 2.383026599884033, 3.3162500858306885, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.326289653778076, 0.0, 0.0, 0.0, 0.0, -0.0, -0.6952337026596069, -2.661262273788452, -0.5081387758255005, 2.984849452972412, -0.6979675889015198, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.877132415771484, 6.659774303436279, 0.0, 6.41911506652832, 4.2885589599609375, 5.195495128631592, 5.891505718231201, 6.37553071975708, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.25303316116333, 3.460115671157837, 1.647379994392395, 3.0994205474853516, 2.32463002204895, 0.0, 2.844074010848999, 3.096909284591675, 2.5755839347839355, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.7048428058624268, 0.18281269073486328, 1.0561704635620117, 1.0028512477874756, 4.017183780670166, 0.0, 2.7463579177856445, 0.9215079545974731, 0.0654352679848671, 0.5989727973937988, 0.4814556837081909, -0.8753326535224915, 0.6639766693115234, 0.8530547618865967, 2.346391439437866, 2.1372787952423096, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.3576853275299072, 0.0, 0.0, 3.45192289352417, 2.5853769779205322, 6.911717891693115, 4.004137992858887, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.25303316116333, 3.460115671157837, 1.647379994392395, 3.0994205474853516, 2.32463002204895, 0.0, 2.844074010848999, 3.096909284591675, 2.5755839347839355, 0.0, 0.0, -0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 2.7048428058624268, 0.18281269073486328, 1.0561704635620117, 1.0028512477874756, 4.017183780670166, 0.0, 2.7463579177856445, 0.9215079545974731, 0.0654352679848671, 0.5989727973937988, 0.4814556837081909, -0.8753326535224915, 0.6639766693115234, 0.8530547618865967, 2.346391439437866, 2.1372787952423096, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 2.3576853275299072, 0.0, 0.0, 3.45192289352417, 2.5853769779205322, 6.911717891693115, 4.004137992858887, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.038973331451416, 4.130666732788086, 2.7841403484344482, -0.22332890331745148, 0.0, -0.8198340535163879, 0.062320537865161896, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.4168710708618164, 0.7797913551330566, -0.8939409852027893, 0.49448925256729126, 1.387761116027832, -0.320703387260437, -0.29311931133270264, -0.3245704770088196, -0.6165714263916016, 1.0183335542678833, 0.20151205360889435, 0.4995051622390747, 0.5603752136230469, 0.15175087749958038, 0.3107116222381592, 0.4086167514324188, 0.7464455962181091, 0.8242706656455994, 1.0441014766693115, -0.1843426525592804, -0.5292544364929199, 0.0, -2.394862651824951, 0.0, 0.0, 0.0, 0.0, 0.0, 4.72073221206665, 2.6916604042053223, 4.063568115234375, 5.719971179962158, 6.931826114654541, 6.906940460205078, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.038973331451416, 4.130666732788086, 2.7841403484344482, -0.22332890331745148, 0.0, -0.8198340535163879, 0.062320537865161896, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, -0.0, -0.0, 0.0, 0.4168710708618164, 0.7797913551330566, -0.8939409852027893, 0.49448925256729126, 1.387761116027832, -0.320703387260437, -0.29311931133270264, -0.3245704770088196, -0.6165714263916016, 1.0183335542678833, 0.20151205360889435, 0.4995051622390747, 0.5603752136230469, 0.15175087749958038, 0.3107116222381592, 0.4086167514324188, 0.7464455962181091, 0.8242706656455994, 1.0441014766693115, -0.1843426525592804, -0.5292544364929199, -0.0, -2.394862651824951, -0.0, 0.0, 0.0, 0.0, 0.0, 4.72073221206665, 2.6916604042053223, 4.063568115234375, 5.719971179962158, 6.931826114654541, 6.906940460205078, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.5777002573013306, 2.355811834335327, 1.4539191722869873, 0.0, -2.6830787658691406, -3.6322875022888184, -2.890451669692993, 0.0, 0.0, 0.0, 0.0, 0.39308232069015503, -2.289099931716919, -0.1209620013833046, 2.1849255561828613, -1.085608720779419, -2.003382682800293, 1.149756669998169, 0.4727552831172943, 0.4397439658641815, 0.31694501638412476, -1.664556860923767, -0.11751890927553177, -2.546826124191284, 0.4426756799221039, 0.4865459203720093, 0.017436733469367027, 0.47315365076065063, 0.6806119680404663, -0.16040468215942383, 0.2453441619873047, -0.11932362616062164, 0.3639126420021057, 0.3236852288246155, 0.35580337047576904, -0.7091084122657776, -0.041121091693639755, 0.026693858206272125, 0.024467317387461662, 0.14877577126026154, 0.23005546629428864, 2.4314727783203125, 0.0, 0.0, 0.0, 0.0, 0.0, 7.151886463165283, 5.967562675476074, 0.0, 4.619217395782471, 7.257842540740967, 5.94150447845459, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.5777002573013306, 2.355811834335327, 1.4539191722869873, 0.0, -2.6830787658691406, -3.6322875022888184, -2.890451669692993, 0.0, 0.0, 0.0, 0.0, 0.39308232069015503, -2.289099931716919, -0.1209620013833046, 2.1849255561828613, -1.085608720779419, -2.003382682800293, 1.149756669998169, 0.4727552831172943, 0.4397439658641815, 0.31694501638412476, -1.664556860923767, -0.11751890927553177, -2.546826124191284, 0.4426756799221039, 0.4865459203720093, 0.017436733469367027, 0.47315365076065063, 0.6806119680404663, -0.16040468215942383, 0.2453441619873047, -0.11932362616062164, 0.3639126420021057, 0.3236852288246155, 0.35580337047576904, -0.7091084122657776, -0.041121091693639755, 0.026693858206272125, 0.024467317387461662, 0.14877577126026154, 0.23005546629428864, 2.4314727783203125, 0.0, 0.0, -0.0, 0.0, 0.0, 7.151886463165283, 5.967562675476074, 0.0, 4.619217395782471, 7.257842540740967, 5.94150447845459, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.204045057296753, 1.5702013969421387, 0.4819692075252533, 0.14499624073505402, -2.459871292114258, -2.4252231121063232, -0.10765321552753448, 0.0, 0.0, 0.0, 0.0, 0.2380051463842392, 0.0, -0.7010846138000488, -1.4918675422668457, -1.3948770761489868, -1.490234136581421, -0.29388442635536194, -1.1067160367965698, -0.35943228006362915, -0.4059225022792816, -2.0069222450256348, -1.9661744832992554, -1.3557502031326294, -0.29440629482269287, -2.586242198944092, 0.7770160436630249, -0.1687200516462326, 0.10665571689605713, -0.1418365091085434, 0.01338736992329359, -0.24558353424072266, -0.5680904388427734, -0.16601386666297913, -0.5951968431472778, 0.18107715249061584, 0.3956500291824341, 0.5930017232894897, 0.28697729110717773, 0.2889128029346466, 0.18876178562641144, 0.022468071430921555, 0.5208808183670044, 0.4750804007053375, 0.2568034827709198, 0.5418531894683838, -1.168853998184204, 0.0, 0.0, 0.0, 5.353882789611816, 5.226466655731201, 3.127641439437866, 7.073984146118164, 4.6628899574279785, 5.808983325958252, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.204045057296753, 1.5702013969421387, 0.4819692075252533, 0.14499624073505402, -2.459871292114258, -2.4252231121063232, -0.10765321552753448, -0.0, -0.0, -0.0, 0.0, 0.2380051463842392, -0.0, -0.7010846138000488, -1.4918675422668457, -1.3948770761489868, -1.490234136581421, -0.29388442635536194, -1.1067160367965698, -0.35943228006362915, -0.4059225022792816, -2.0069222450256348, -1.9661744832992554, -1.3557502031326294, -0.29440629482269287, -2.586242198944092, 0.7770160436630249, -0.1687200516462326, 0.10665571689605713, -0.1418365091085434, 0.01338736992329359, -0.24558353424072266, -0.5680904388427734, -0.16601386666297913, -0.5951968431472778, 0.18107715249061584, 0.3956500291824341, 0.5930017232894897, 0.28697729110717773, 0.2889128029346466, 0.18876178562641144, 0.022468071430921555, 0.5208808183670044, 0.4750804007053375, 0.2568034827709198, 0.5418531894683838, -1.168853998184204, -0.0, -0.0, 0.0, 5.353882789611816, 5.226466655731201, 3.127641439437866, 7.073984146118164, 4.6628899574279785, 5.808983325958252, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.4077531099319458, 0.7600692510604858, -0.6396909952163696, -0.5392528772354126, 1.2701352834701538, 1.6378414630889893, 0.0, 0.0, 0.0, 0.7204602956771851, -1.5655808448791504, -0.847585916519165, -1.0967425107955933, -1.5386238098144531, -1.5838239192962646, -1.2105112075805664, -1.6920976638793945, -0.10943565517663956, -0.9909841418266296, -0.2690296173095703, -0.4157876968383789, -0.46854621171951294, -0.1260509043931961, -2.347484827041626, -0.5722496509552002, -2.095508575439453, 0.5061953067779541, -0.21482138335704803, -0.31863266229629517, -0.378263384103775, -0.3180122375488281, -0.16218499839305878, 0.23099738359451294, 0.7098122239112854, 0.23059070110321045, 0.28622809052467346, 0.03359079733490944, 0.5795784592628479, 0.3859414756298065, 0.11436367779970169, -0.21128515899181366, 1.046700119972229, 0.08047965168952942, 0.4204956293106079, -0.01590307056903839, 0.014138985425233841, 0.4413925111293793, 1.1295421123504639, 2.6702942848205566, -0.8436626195907593, 0.0, 0.0, 0.0, 5.1543660163879395, 0.0, 3.083765745162964, 4.58598518371582, 5.808509826660156, 4.361225128173828, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.4077531099319458, 0.7600692510604858, -0.6396909952163696, -0.5392528772354126, 1.2701352834701538, 1.6378414630889893, 0.0, -0.0, 0.0, 0.7204602956771851, -1.5655808448791504, -0.847585916519165, -1.0967425107955933, -1.5386238098144531, -1.5838239192962646, -1.2105112075805664, -1.6920976638793945, -0.10943565517663956, -0.9909841418266296, -0.2690296173095703, -0.4157876968383789, -0.46854621171951294, -0.1260509043931961, -2.347484827041626, -0.5722496509552002, -2.095508575439453, 0.5061953067779541, -0.21482138335704803, -0.31863266229629517, -0.378263384103775, -0.3180122375488281, -0.16218499839305878, 0.23099738359451294, 0.7098122239112854, 0.23059070110321045, 0.28622809052467346, 0.03359079733490944, 0.5795784592628479, 0.3859414756298065, 0.11436367779970169, -0.21128515899181366, 1.046700119972229, 0.08047965168952942, 0.4204956293106079, -0.01590307056903839, 0.014138985425233841, 0.4413925111293793, 1.1295421123504639, 2.6702942848205566, -0.8436626195907593, -0.0, 0.0, 0.0, 5.1543660163879395, 0.0, 3.083765745162964, 4.58598518371582, 5.808509826660156, 4.361225128173828, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.080660343170166, 0.2709188461303711, -0.18058167397975922, -0.38026970624923706, -2.6308724880218506, 0.0, 0.0, 0.0, 0.0, -3.737490177154541, -1.352836012840271, -1.0647037029266357, -1.8654634952545166, -1.0010327100753784, -0.5748445391654968, -0.3978249430656433, -1.2532057762145996, -1.4427449703216553, -0.6887013912200928, -0.4080759286880493, -0.47312355041503906, 0.02013109251856804, 0.1544637233018875, 0.08545462042093277, -0.3787077069282532, -2.688275098800659, 0.5868082642555237, 1.670580267906189, 0.9270045161247253, 0.24654527008533478, 0.8039951324462891, -0.35961511731147766, 0.3352315127849579, 0.8390952944755554, 0.653031051158905, 0.1450134515762329, 0.6064682602882385, 0.2120181918144226, 0.7067554593086243, 0.49764731526374817, 0.18406201899051666, 1.2127091884613037, 0.5825244188308716, 0.3357264995574951, 0.5299637913703918, -0.23177000880241394, 0.440723717212677, -0.02124360017478466, -0.3625558614730835, 0.31902143359184265, 0.9313329458236694, 0.0, 0.0, 0.0, 6.776220798492432, 3.871885299682617, 3.0056381225585938, 0.0, 5.131859302520752, 6.738387107849121, 7.744246482849121, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.080660343170166, 0.2709188461303711, -0.18058167397975922, -0.38026970624923706, -2.6308724880218506, 0.0, 0.0, 0.0, -0.0, -3.737490177154541, -1.352836012840271, -1.0647037029266357, -1.8654634952545166, -1.0010327100753784, -0.5748445391654968, -0.3978249430656433, -1.2532057762145996, -1.4427449703216553, -0.6887013912200928, -0.4080759286880493, -0.47312355041503906, 0.02013109251856804, 0.1544637233018875, 0.08545462042093277, -0.3787077069282532, -2.688275098800659, 0.5868082642555237, 1.670580267906189, 0.9270045161247253, 0.24654527008533478, 0.8039951324462891, -0.35961511731147766, 0.3352315127849579, 0.8390952944755554, 0.653031051158905, 0.1450134515762329, 0.6064682602882385, 0.2120181918144226, 0.7067554593086243, 0.49764731526374817, 0.18406201899051666, 1.2127091884613037, 0.5825244188308716, 0.3357264995574951, 0.5299637913703918, -0.23177000880241394, 0.440723717212677, -0.02124360017478466, -0.3625558614730835, 0.31902143359184265, 0.9313329458236694, 0.0, -0.0, 0.0, 6.776220798492432, 3.871885299682617, 3.0056381225585938, 0.0, 5.131859302520752, 6.738387107849121, 7.744246482849121, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.0830421447753906, 0.05557854473590851, 1.62739896774292, -2.136347770690918, 0.0, 1.3739534616470337, 0.49245309829711914, 0.0, 0.0, 0.0, -1.4196734428405762, -1.1352883577346802, -1.2428728342056274, -1.7756072282791138, -1.3217693567276, -0.9297606348991394, -0.5724805593490601, -1.1296616792678833, -2.279682159423828, -1.1650938987731934, -0.6655145883560181, -0.9115446209907532, -1.3072500228881836, -0.49451422691345215, -0.8506133556365967, -0.19660015404224396, -0.1233539879322052, -0.04238427057862282, 0.7779885530471802, -0.1769815981388092, 0.7785741686820984, 0.469973623752594, 1.0158499479293823, 0.22658197581768036, 0.6646121740341187, 0.6030786037445068, 0.15490533411502838, 0.4972323179244995, 0.8088825941085815, 0.9449567198753357, 0.33311590552330017, 0.03641488403081894, 0.39340415596961975, 0.16240130364894867, 0.5671007037162781, 0.6571505069732666, 0.4054632782936096, 0.47160837054252625, -0.23493477702140808, 0.14241665601730347, 0.1644744724035263, 0.28161776065826416, -0.3678353428840637, -0.20323045551776886, 0.0, 0.0, 0.0, 0.0, 6.041019439697266, 2.538463830947876, 2.1523685455322266, 4.846200466156006, 4.96451473236084, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 2.0830421447753906, 0.05557854473590851, 1.62739896774292, -2.136347770690918, -0.0, 1.3739534616470337, 0.49245309829711914, 0.0, -0.0, -0.0, -1.4196734428405762, -1.1352883577346802, -1.2428728342056274, -1.7756072282791138, -1.3217693567276, -0.9297606348991394, -0.5724805593490601, -1.1296616792678833, -2.279682159423828, -1.1650938987731934, -0.6655145883560181, -0.9115446209907532, -1.3072500228881836, -0.49451422691345215, -0.8506133556365967, -0.19660015404224396, -0.1233539879322052, -0.04238427057862282, 0.7779885530471802, -0.1769815981388092, 0.7785741686820984, 0.469973623752594, 1.0158499479293823, 0.22658197581768036, 0.6646121740341187, 0.6030786037445068, 0.15490533411502838, 0.4972323179244995, 0.8088825941085815, 0.9449567198753357, 0.33311590552330017, 0.03641488403081894, 0.39340415596961975, 0.16240130364894867, 0.5671007037162781, 0.6571505069732666, 0.4054632782936096, 0.47160837054252625, -0.23493477702140808, 0.14241665601730347, 0.1644744724035263, 0.28161776065826416, -0.3678353428840637, -0.20323045551776886, -0.0, 0.0, 0.0, 0.0, 6.041019439697266, 2.538463830947876, 2.1523685455322266, 4.846200466156006, 4.96451473236084, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.10485353320837021, -1.8380889892578125, 0.08826655149459839, 0.0, -1.7549759149551392, 0.0, 0.0, 0.0, -1.0130599737167358, -2.0095622539520264, -1.8347504138946533, -1.632190465927124, -1.6196459531784058, -1.676235556602478, -1.223605751991272, -0.9174447059631348, 0.49603962898254395, -1.0504004955291748, -0.3779091536998749, -0.7155694365501404, -0.297690212726593, -0.268995076417923, -0.08338098973035812, -0.21826142072677612, 0.5784736275672913, -0.09659109264612198, 0.04111821949481964, 0.10603836178779602, 0.04851103946566582, -0.020717546343803406, 0.03791073337197304, 0.15713047981262207, 0.4016745984554291, 0.313621461391449, 0.4306148588657379, 0.3510635495185852, 0.48486605286598206, 0.4815821647644043, 0.5896855592727661, 1.127016305923462, 0.3872279226779938, 0.38221874833106995, 0.5226064324378967, 0.9649835824966431, 0.6080912351608276, 0.9253332614898682, 0.8292085528373718, 0.7965614795684814, 0.20316006243228912, 0.6808347702026367, 0.6250725984573364, 0.5905603170394897, -0.4501008689403534, -0.6414119601249695, -0.08974213898181915, 0.0, 0.0, 0.0, 0.0, 2.9335079193115234, 0.0, 0.0, 1.0217546224594116, 5.002371788024902, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.10485353320837021, -1.8380889892578125, 0.08826655149459839, -0.0, -1.7549759149551392, 0.0, 0.0, -0.0, -1.0130599737167358, -2.0095622539520264, -1.8347504138946533, -1.632190465927124, -1.6196459531784058, -1.676235556602478, -1.223605751991272, -0.9174447059631348, 0.49603962898254395, -1.0504004955291748, -0.3779091536998749, -0.7155694365501404, -0.297690212726593, -0.268995076417923, -0.08338098973035812, -0.21826142072677612, 0.5784736275672913, -0.09659109264612198, 0.04111821949481964, 0.10603836178779602, 0.04851103946566582, -0.020717546343803406, 0.03791073337197304, 0.15713047981262207, 0.4016745984554291, 0.313621461391449, 0.4306148588657379, 0.3510635495185852, 0.48486605286598206, 0.4815821647644043, 0.5896855592727661, 1.127016305923462, 0.3872279226779938, 0.38221874833106995, 0.5226064324378967, 0.9649835824966431, 0.6080912351608276, 0.9253332614898682, 0.8292085528373718, 0.7965614795684814, 0.20316006243228912, 0.6808347702026367, 0.6250725984573364, 0.5905603170394897, -0.4501008689403534, -0.6414119601249695, -0.08974213898181915, -0.0, -0.0, 0.0, 0.0, 2.9335079193115234, 0.0, 0.0, 1.0217546224594116, 5.002371788024902, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.8284814357757568, -2.1648612022399902, 0.0, -1.2771415710449219, 0.24959410727024078, 0.0, 0.0, 0.0, -2.228179454803467, -2.1890296936035156, -2.3009772300720215, -2.526515245437622, -0.9041162729263306, -1.759193778038025, -1.9080097675323486, -0.8902122378349304, -1.3702454566955566, -1.7404645681381226, -1.2732561826705933, -1.2723088264465332, -1.1178196668624878, -0.6035826206207275, -0.21695131063461304, 0.041347604244947433, -0.5357004404067993, 0.33355167508125305, -0.16791769862174988, 0.2285221517086029, 0.10671550035476685, 0.2261853665113449, -0.11092504113912582, 0.07289019972085953, 0.46493348479270935, 0.8842753171920776, 0.8703292608261108, 0.5839458703994751, 0.9044051170349121, 0.5398030877113342, 1.3396581411361694, 0.29295504093170166, 0.9916538000106812, 0.6129759550094604, 0.9378657341003418, 1.0087964534759521, 0.6567871570587158, 0.10271629691123962, 1.2548543214797974, 0.900425910949707, 1.1857917308807373, 0.46276378631591797, 0.718501091003418, 0.05799767002463341, 0.9823139309883118, -0.12926322221755981, 0.3074251115322113, -0.3137294352054596, 0.007602091878652573, -1.5212645530700684, 0.0, 0.0, 0.0, 3.3648226261138916, 0.0, 2.574673652648926, 5.165268421173096, 4.083690166473389, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.8284814357757568, -2.1648612022399902, -0.0, -1.2771415710449219, 0.24959410727024078, 0.0, -0.0, -0.0, -2.228179454803467, -2.1890296936035156, -2.3009772300720215, -2.526515245437622, -0.9041162729263306, -1.759193778038025, -1.9080097675323486, -0.8902122378349304, -1.3702454566955566, -1.7404645681381226, -1.2732561826705933, -1.2723088264465332, -1.1178196668624878, -0.6035826206207275, -0.21695131063461304, 0.041347604244947433, -0.5357004404067993, 0.33355167508125305, -0.16791769862174988, 0.2285221517086029, 0.10671550035476685, 0.2261853665113449, -0.11092504113912582, 0.07289019972085953, 0.46493348479270935, 0.8842753171920776, 0.8703292608261108, 0.5839458703994751, 0.9044051170349121, 0.5398030877113342, 1.3396581411361694, 0.29295504093170166, 0.9916538000106812, 0.6129759550094604, 0.9378657341003418, 1.0087964534759521, 0.6567871570587158, 0.10271629691123962, 1.2548543214797974, 0.900425910949707, 1.1857917308807373, 0.46276378631591797, 0.718501091003418, 0.05799767002463341, 0.9823139309883118, -0.12926322221755981, 0.3074251115322113, -0.3137294352054596, 0.007602091878652573, -1.5212645530700684, -0.0, 0.0, 0.0, 3.3648226261138916, 0.0, 2.574673652648926, 5.165268421173096, 4.083690166473389, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.7298703193664551, -1.2545478343963623, 0.0, 0.0, 1.8611801862716675, 0.0, 0.0, 0.0, -1.8722623586654663, -1.8316218852996826, -2.4064857959747314, -2.3953583240509033, -1.5649722814559937, -2.228466510772705, -2.0209903717041016, -1.601051926612854, -0.8926016092300415, -1.7147363424301147, -0.8504359722137451, -0.799077570438385, -2.1568117141723633, -0.46526819467544556, -0.9129928946495056, -0.6912678480148315, -0.39878952503204346, 0.2614686191082001, -0.9007250666618347, 0.42280957102775574, -0.42852967977523804, -0.003301401389762759, 0.48498305678367615, -0.08826826512813568, 0.19816823303699493, 0.12808944284915924, 0.5043215751647949, 0.3421391546726227, 0.13849274814128876, 0.48247337341308594, 0.3934946358203888, -0.053921908140182495, 0.351071834564209, 0.47523701190948486, 0.4371483623981476, 0.05750330165028572, 0.48298361897468567, 0.7907246947288513, 1.6318825483322144, 0.8434796929359436, 0.5176963210105896, 0.6060351133346558, 0.3230487108230591, 0.49912840127944946, 0.9892159104347229, 0.7347297668457031, 1.2831218242645264, -0.05629356577992439, 0.6045710444450378, 0.2480214685201645, 0.7438571453094482, -0.17772065103054047, 0.0, 0.0, 0.0, 0.0, 1.8375182151794434, 1.7665618658065796, 3.43882417678833, 5.463015079498291, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.7298703193664551, -1.2545478343963623, -0.0, 0.0, 1.8611801862716675, 0.0, 0.0, -0.0, -1.8722623586654663, -1.8316218852996826, -2.4064857959747314, -2.3953583240509033, -1.5649722814559937, -2.228466510772705, -2.0209903717041016, -1.601051926612854, -0.8926016092300415, -1.7147363424301147, -0.8504359722137451, -0.799077570438385, -2.1568117141723633, -0.46526819467544556, -0.9129928946495056, -0.6912678480148315, -0.39878952503204346, 0.2614686191082001, -0.9007250666618347, 0.42280957102775574, -0.42852967977523804, -0.003301401389762759, 0.48498305678367615, -0.08826826512813568, 0.19816823303699493, 0.12808944284915924, 0.5043215751647949, 0.3421391546726227, 0.13849274814128876, 0.48247337341308594, 0.3934946358203888, -0.053921908140182495, 0.351071834564209, 0.47523701190948486, 0.4371483623981476, 0.05750330165028572, 0.48298361897468567, 0.7907246947288513, 1.6318825483322144, 0.8434796929359436, 0.5176963210105896, 0.6060351133346558, 0.3230487108230591, 0.49912840127944946, 0.9892159104347229, 0.7347297668457031, 1.2831218242645264, -0.05629356577992439, 0.6045710444450378, 0.2480214685201645, 0.7438571453094482, -0.17772065103054047, -0.0, 0.0, 0.0, 0.0, 1.8375182151794434, 1.7665618658065796, 3.43882417678833, 5.463015079498291, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -1.0307598114013672, 2.045358896255493, 2.22843337059021, 0.0, -5.108644008636475, 0.0, 0.0, 0.0, -1.5102506875991821, -1.7952367067337036, -3.1654512882232666, -3.028636932373047, -2.6896142959594727, -1.5823659896850586, -1.7662009000778198, -1.8893178701400757, -1.6366380453109741, -1.023298740386963, -1.600489616394043, -1.494432806968689, -0.3526122272014618, -1.0074617862701416, -0.6195297837257385, -0.5106410980224609, -0.6622835397720337, -0.12758490443229675, 0.14538075029850006, -0.3141636550426483, -0.5955144762992859, 0.3613007366657257, 0.49489572644233704, 1.476891279220581, 0.5411486625671387, 0.573055624961853, 1.2115117311477661, 0.3826849162578583, 0.23418697714805603, 1.032462239265442, 1.2542959451675415, 0.1937413066625595, 0.4713040292263031, 1.191957712173462, -0.016596291214227676, 0.33148065209388733, 0.3361644446849823, 0.7767128944396973, 0.5713368654251099, 1.3033349514007568, 1.3600332736968994, 0.5306697487831116, 0.35422685742378235, 0.7094170451164246, 0.16857972741127014, 0.9650797843933105, 0.7144309878349304, 0.5799791812896729, 0.45332562923431396, 0.7460101842880249, 0.7594048380851746, 0.27653953433036804, 1.2355000972747803, 0.0, 0.0, 0.0, 0.0, -0.12380386143922806, 0.5191754102706909, 1.526943564414978, 1.3114053010940552, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0307598114013672, 2.045358896255493, 2.22843337059021, 0.0, -5.108644008636475, 0.0, 0.0, -0.0, -1.5102506875991821, -1.7952367067337036, -3.1654512882232666, -3.028636932373047, -2.6896142959594727, -1.5823659896850586, -1.7662009000778198, -1.8893178701400757, -1.6366380453109741, -1.023298740386963, -1.600489616394043, -1.494432806968689, -0.3526122272014618, -1.0074617862701416, -0.6195297837257385, -0.5106410980224609, -0.6622835397720337, -0.12758490443229675, 0.14538075029850006, -0.3141636550426483, -0.5955144762992859, 0.3613007366657257, 0.49489572644233704, 1.476891279220581, 0.5411486625671387, 0.573055624961853, 1.2115117311477661, 0.3826849162578583, 0.23418697714805603, 1.032462239265442, 1.2542959451675415, 0.1937413066625595, 0.4713040292263031, 1.191957712173462, -0.016596291214227676, 0.33148065209388733, 0.3361644446849823, 0.7767128944396973, 0.5713368654251099, 1.3033349514007568, 1.3600332736968994, 0.5306697487831116, 0.35422685742378235, 0.7094170451164246, 0.16857972741127014, 0.9650797843933105, 0.7144309878349304, 0.5799791812896729, 0.45332562923431396, 0.7460101842880249, 0.7594048380851746, 0.27653953433036804, 1.2355000972747803, 0.0, 0.0, 0.0, -0.0, -0.12380386143922806, 0.5191754102706909, 1.526943564414978, 1.3114053010940552, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -1.1602743864059448, -1.2454140186309814, 1.042536973953247, 0.9750637412071228, 0.2280941903591156, 0.0, 0.0, 0.0, -2.726602077484131, -2.454454183578491, -2.765424966812134, -3.25942325592041, -2.9656147956848145, -2.698516607284546, -2.4757494926452637, -2.8923377990722656, -1.7636239528656006, -1.621914029121399, -1.398428201675415, -1.6866368055343628, -1.3798307180404663, -0.6177891492843628, -0.07326389849185944, -0.1257459968328476, -0.410469114780426, -0.9158921241760254, -0.426416277885437, -0.8199352025985718, 0.010436784476041794, -0.36490899324417114, 0.6780918836593628, 0.14559637010097504, 0.2033100426197052, 1.2500736713409424, 0.29409685730934143, -0.24720962345600128, 0.7139097452163696, 0.47702834010124207, 0.1994229406118393, 0.7739940285682678, 0.1466948390007019, 0.9886103868484497, 0.8851262927055359, 0.18401595950126648, 1.1411923170089722, 0.6656298637390137, 0.7831732034683228, 0.7144931554794312, 0.8298431038856506, 0.6290798783302307, 0.07528563588857651, 0.8219913840293884, 1.6534334421157837, 0.744763195514679, 1.1453649997711182, 0.7339876890182495, 0.8484530448913574, 2.258754014968872, 0.7036324143409729, 0.4516879916191101, 0.42190927267074585, 0.282105028629303, 0.6661334037780762, 1.3325210809707642, 0.0, 0.0, 3.8905398845672607, 3.437404155731201, 0.0, 2.6142895221710205, 7.329497814178467, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -1.1602743864059448, -1.2454140186309814, 1.042536973953247, 0.9750637412071228, 0.2280941903591156, 0.0, -0.0, -0.0, -2.726602077484131, -2.454454183578491, -2.765424966812134, -3.25942325592041, -2.9656147956848145, -2.698516607284546, -2.4757494926452637, -2.8923377990722656, -1.7636239528656006, -1.621914029121399, -1.398428201675415, -1.6866368055343628, -1.3798307180404663, -0.6177891492843628, -0.07326389849185944, -0.1257459968328476, -0.410469114780426, -0.9158921241760254, -0.426416277885437, -0.8199352025985718, 0.010436784476041794, -0.36490899324417114, 0.6780918836593628, 0.14559637010097504, 0.2033100426197052, 1.2500736713409424, 0.29409685730934143, -0.24720962345600128, 0.7139097452163696, 0.47702834010124207, 0.1994229406118393, 0.7739940285682678, 0.1466948390007019, 0.9886103868484497, 0.8851262927055359, 0.18401595950126648, 1.1411923170089722, 0.6656298637390137, 0.7831732034683228, 0.7144931554794312, 0.8298431038856506, 0.6290798783302307, 0.07528563588857651, 0.8219913840293884, 1.6534334421157837, 0.744763195514679, 1.1453649997711182, 0.7339876890182495, 0.8484530448913574, 2.258754014968872, 0.7036324143409729, 0.4516879916191101, 0.42190927267074585, 0.282105028629303, 0.6661334037780762, 1.3325210809707642, 0.0, 0.0, 3.8905398845672607, 3.437404155731201, 0.0, 2.6142895221710205, 7.329497814178467, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, -1.3727376461029053, -3.3131635189056396, 0.0, 0.0, -0.8735133409500122, -3.6401784420013428, 0.0, 0.0, -2.9762775897979736, -2.899780511856079, -3.0976357460021973, -3.0033681392669678, -3.1410748958587646, -3.434802293777466, -1.7013475894927979, -2.2509868144989014, -2.791078567504883, -1.8688496351242065, -1.8138136863708496, -1.7516900300979614, -1.253014326095581, -0.4721294641494751, -0.665620744228363, -2.0458922386169434, -0.38938942551612854, -0.3848973512649536, -0.12388375401496887, -1.0622503757476807, -0.23811686038970947, 0.20749567449092865, 0.3873278498649597, 0.009743226692080498, 0.2208724021911621, -0.4211874306201935, 0.6451723575592041, 0.27131354808807373, 0.3498583137989044, 0.06176099181175232, 1.3038703203201294, 0.8596940040588379, 1.0337252616882324, 0.8268620371818542, 0.319534033536911, 0.9518920183181763, 1.0454515218734741, -0.1801387071609497, 3.152665376663208, 0.5191003680229187, 1.0423299074172974, 0.43544822931289673, 0.8903421759605408, 1.6171897649765015, 1.2448376417160034, 2.1042826175689697, 0.13719375431537628, 0.6321678757667542, 0.44351688027381897, 0.9004158973693848, 0.9832060933113098, 0.5240894556045532, 0.3204707205295563, -0.29121971130371094, 0.680097758769989, 0.335293173789978, 0.8998802304267883, 1.3635988235473633, 0.0, 0.0, 3.7403440475463867, 1.3237831592559814, 3.383254289627075, 4.866937160491943, 6.4709577560424805, 0.0, 0.0, -0.0, -0.0, -0.0, -1.3727376461029053, -3.3131635189056396, -0.0, 0.0, -0.8735133409500122, -3.6401784420013428, -0.0, -0.0, -2.9762775897979736, -2.899780511856079, -3.0976357460021973, -3.0033681392669678, -3.1410748958587646, -3.434802293777466, -1.7013475894927979, -2.2509868144989014, -2.791078567504883, -1.8688496351242065, -1.8138136863708496, -1.7516900300979614, -1.253014326095581, -0.4721294641494751, -0.665620744228363, -2.0458922386169434, -0.38938942551612854, -0.3848973512649536, -0.12388375401496887, -1.0622503757476807, -0.23811686038970947, 0.20749567449092865, 0.3873278498649597, 0.009743226692080498, 0.2208724021911621, -0.4211874306201935, 0.6451723575592041, 0.27131354808807373, 0.3498583137989044, 0.06176099181175232, 1.3038703203201294, 0.8596940040588379, 1.0337252616882324, 0.8268620371818542, 0.319534033536911, 0.9518920183181763, 1.0454515218734741, -0.1801387071609497, 3.152665376663208, 0.5191003680229187, 1.0423299074172974, 0.43544822931289673, 0.8903421759605408, 1.6171897649765015, 1.2448376417160034, 2.1042826175689697, 0.13719375431537628, 0.6321678757667542, 0.44351688027381897, 0.9004158973693848, 0.9832060933113098, 0.5240894556045532, 0.3204707205295563, -0.29121971130371094, 0.680097758769989, 0.335293173789978, 0.8998802304267883, 1.3635988235473633, 0.0, 0.0, 3.7403440475463867, 1.3237831592559814, 3.383254289627075, 4.866937160491943, 6.4709577560424805, 0.0, 0.0], [0.0, 0.0, 0.0, -2.610642910003662, -2.461411476135254, 0.0, -0.40475571155548096, -2.3210716247558594, 0.0, 0.0, -4.5668487548828125, -3.985314130783081, -4.117300987243652, -3.3210179805755615, -3.173802614212036, -2.7039875984191895, -3.4500834941864014, -2.9410531520843506, -2.237685203552246, -3.1716203689575195, -1.7294009923934937, -1.6049680709838867, -2.003702163696289, -0.8197420239448547, -0.7780276536941528, -0.18150855600833893, -0.2167750746011734, -1.1410083770751953, 0.4251643717288971, 0.16039824485778809, -1.237381100654602, 0.22478944063186646, 0.10345476120710373, -0.13613218069076538, 0.6120143532752991, -0.4547032117843628, 0.10733410716056824, 0.5491034388542175, 0.32521572709083557, 0.42978349328041077, 0.2135525494813919, 0.8166906833648682, 0.521246075630188, 0.7388785481452942, 0.723170816898346, 1.1366746425628662, 2.437380790710449, 0.5542310476303101, 1.4890475273132324, 1.703104019165039, 1.1912875175476074, 0.8425676822662354, 0.7208344340324402, 0.8210171461105347, 0.3902744650840759, 1.237703800201416, 0.7326348423957825, 1.300217628479004, 0.434522807598114, 1.0942010879516602, 1.0684500932693481, 0.3744162917137146, 0.8992420434951782, 0.49132969975471497, 0.9054492712020874, 0.7117517590522766, 0.6066193580627441, 0.8671906590461731, 1.298654556274414, 0.6390217542648315, 0.0, 0.0, -0.49371758103370667, 1.3266798257827759, 3.7656431198120117, 4.813499927520752, 0.0, 0.0, -0.0, -0.0, -0.0, -2.610642910003662, -2.461411476135254, -0.0, -0.40475571155548096, -2.3210716247558594, -0.0, -0.0, -4.5668487548828125, -3.985314130783081, -4.117300987243652, -3.3210179805755615, -3.173802614212036, -2.7039875984191895, -3.4500834941864014, -2.9410531520843506, -2.237685203552246, -3.1716203689575195, -1.7294009923934937, -1.6049680709838867, -2.003702163696289, -0.8197420239448547, -0.7780276536941528, -0.18150855600833893, -0.2167750746011734, -1.1410083770751953, 0.4251643717288971, 0.16039824485778809, -1.237381100654602, 0.22478944063186646, 0.10345476120710373, -0.13613218069076538, 0.6120143532752991, -0.4547032117843628, 0.10733410716056824, 0.5491034388542175, 0.32521572709083557, 0.42978349328041077, 0.2135525494813919, 0.8166906833648682, 0.521246075630188, 0.7388785481452942, 0.723170816898346, 1.1366746425628662, 2.437380790710449, 0.5542310476303101, 1.4890475273132324, 1.703104019165039, 1.1912875175476074, 0.8425676822662354, 0.7208344340324402, 0.8210171461105347, 0.3902744650840759, 1.237703800201416, 0.7326348423957825, 1.300217628479004, 0.434522807598114, 1.0942010879516602, 1.0684500932693481, 0.3744162917137146, 0.8992420434951782, 0.49132969975471497, 0.9054492712020874, 0.7117517590522766, 0.6066193580627441, 0.8671906590461731, 1.298654556274414, 0.6390217542648315, 0.0, 0.0, -0.49371758103370667, 1.3266798257827759, 3.7656431198120117, 4.813499927520752, 0.0, 0.0], [0.0, 0.0, -1.770933747291565, -2.593242645263672, -1.9838759899139404, -2.0538527965545654, -2.2348790168762207, 0.0, 0.0, 0.0, -4.596036911010742, -4.851772308349609, -4.065486907958984, -3.6857688426971436, -2.986443519592285, -2.7479753494262695, -3.5046298503875732, -3.9698100090026855, -1.2436165809631348, -2.473602294921875, -1.9730342626571655, -1.9415696859359741, -1.946232557296753, -2.149803638458252, -1.3606857061386108, 0.5386971235275269, 0.08409770578145981, -1.0972521305084229, -0.14904500544071198, -0.3451646864414215, -0.3390985429286957, -0.12467434257268906, 0.4871191084384918, -0.3237067461013794, -0.10242751240730286, 0.12190684676170349, 0.14266268908977509, 0.8531486392021179, 0.6837864518165588, 0.3179757297039032, 0.6803871393203735, 0.4482317268848419, 0.7476979494094849, 0.8795794248580933, 0.8072337508201599, 0.47756749391555786, 0.6159731149673462, 0.7931875586509705, 1.1462041139602661, 1.2961571216583252, 0.8072202801704407, 1.1202797889709473, 0.8708066940307617, 0.6738078594207764, 1.453667163848877, 4.19891881942749, 0.9933170080184937, 0.8373090028762817, 0.9851803779602051, 0.7325079441070557, 0.8957384824752808, 1.0938552618026733, 1.1460402011871338, 0.7820155024528503, 0.5633147954940796, 0.9014014601707458, 0.21158212423324585, 1.0838960409164429, 1.230468511581421, 1.327175498008728, 0.0, 0.0, 1.2033509016036987, 0.649921715259552, 2.884855031967163, 0.0, 6.611615180969238, 0.0, -0.0, -0.0, -1.770933747291565, -2.593242645263672, -1.9838759899139404, -2.0538527965545654, -2.2348790168762207, -0.0, -0.0, -0.0, -4.596036911010742, -4.851772308349609, -4.065486907958984, -3.6857688426971436, -2.986443519592285, -2.7479753494262695, -3.5046298503875732, -3.9698100090026855, -1.2436165809631348, -2.473602294921875, -1.9730342626571655, -1.9415696859359741, -1.946232557296753, -2.149803638458252, -1.3606857061386108, 0.5386971235275269, 0.08409770578145981, -1.0972521305084229, -0.14904500544071198, -0.3451646864414215, -0.3390985429286957, -0.12467434257268906, 0.4871191084384918, -0.3237067461013794, -0.10242751240730286, 0.12190684676170349, 0.14266268908977509, 0.8531486392021179, 0.6837864518165588, 0.3179757297039032, 0.6803871393203735, 0.4482317268848419, 0.7476979494094849, 0.8795794248580933, 0.8072337508201599, 0.47756749391555786, 0.6159731149673462, 0.7931875586509705, 1.1462041139602661, 1.2961571216583252, 0.8072202801704407, 1.1202797889709473, 0.8708066940307617, 0.6738078594207764, 1.453667163848877, 4.19891881942749, 0.9933170080184937, 0.8373090028762817, 0.9851803779602051, 0.7325079441070557, 0.8957384824752808, 1.0938552618026733, 1.1460402011871338, 0.7820155024528503, 0.5633147954940796, 0.9014014601707458, 0.21158212423324585, 1.0838960409164429, 1.230468511581421, 1.327175498008728, 0.0, 0.0, 1.2033509016036987, 0.649921715259552, 2.884855031967163, 0.0, 6.611615180969238, 0.0], [0.0, -2.064992904663086, 0.19641585648059845, 1.0325788259506226, 0.0, -4.19377326965332, 0.0, 0.0, 0.0, -6.983715057373047, -5.453330993652344, -4.629213809967041, -4.305846691131592, -3.839528799057007, -3.6906869411468506, -3.4994993209838867, -2.937116861343384, -2.529771327972412, -2.4928057193756104, -3.0233078002929688, -2.4931724071502686, -1.6486467123031616, -2.4022231101989746, -1.4932937622070312, -2.252209424972534, -0.39745861291885376, -1.3394482135772705, 0.654992938041687, -0.36284393072128296, -1.2078131437301636, 0.13692931830883026, 0.15785661339759827, 0.6141656041145325, -0.3012726604938507, 0.5549363493919373, 0.5912407636642456, 0.24814976751804352, 0.1978936344385147, 0.667202889919281, 0.33338072896003723, 0.6321446895599365, 0.03885602951049805, 0.05203969404101372, 0.5568594336509705, 0.7838730216026306, 0.8242628574371338, 0.7249202132225037, 1.00201416015625, 0.6946196556091309, 0.32276585698127747, 1.0529183149337769, 0.7058849334716797, 1.2337868213653564, 0.7666797637939453, 1.4790606498718262, 1.3575387001037598, 1.1670362949371338, 0.35138070583343506, 0.6149569153785706, 0.8782675862312317, 1.3121885061264038, 1.3585373163223267, 1.0817999839782715, 0.12790513038635254, 0.9818671345710754, 0.846476137638092, 0.8779720067977905, 0.3566548526287079, 0.34092405438423157, 1.0034259557724, 1.0541521310806274, 0.0, 0.0, 0.0, 0.0, 0.0, 7.269169330596924, 7.672485828399658, -0.0, -2.064992904663086, 0.19641585648059845, 1.0325788259506226, -0.0, -4.19377326965332, -0.0, -0.0, -0.0, -6.983715057373047, -5.453330993652344, -4.629213809967041, -4.305846691131592, -3.839528799057007, -3.6906869411468506, -3.4994993209838867, -2.937116861343384, -2.529771327972412, -2.4928057193756104, -3.0233078002929688, -2.4931724071502686, -1.6486467123031616, -2.4022231101989746, -1.4932937622070312, -2.252209424972534, -0.39745861291885376, -1.3394482135772705, 0.654992938041687, -0.36284393072128296, -1.2078131437301636, 0.13692931830883026, 0.15785661339759827, 0.6141656041145325, -0.3012726604938507, 0.5549363493919373, 0.5912407636642456, 0.24814976751804352, 0.1978936344385147, 0.667202889919281, 0.33338072896003723, 0.6321446895599365, 0.03885602951049805, 0.05203969404101372, 0.5568594336509705, 0.7838730216026306, 0.8242628574371338, 0.7249202132225037, 1.00201416015625, 0.6946196556091309, 0.32276585698127747, 1.0529183149337769, 0.7058849334716797, 1.2337868213653564, 0.7666797637939453, 1.4790606498718262, 1.3575387001037598, 1.1670362949371338, 0.35138070583343506, 0.6149569153785706, 0.8782675862312317, 1.3121885061264038, 1.3585373163223267, 1.0817999839782715, 0.12790513038635254, 0.9818671345710754, 0.846476137638092, 0.8779720067977905, 0.3566548526287079, 0.34092405438423157, 1.0034259557724, 1.0541521310806274, 0.0, 0.0, 0.0, 0.0, 0.0, 7.269169330596924, 7.672485828399658], [0.0, -3.7425966262817383, -4.948640823364258, 0.0, -9.709470748901367, 0.0, 0.0, 0.0, -4.706563472747803, -5.573760509490967, -5.147874355316162, -4.343133449554443, -3.9564590454101562, -3.638223171234131, -3.6566860675811768, -3.7476260662078857, -3.100992202758789, -3.373012065887451, -1.8979159593582153, -1.891119360923767, -2.4168570041656494, -0.9769982695579529, -1.5318375825881958, -1.8048166036605835, -1.401602029800415, -1.582843542098999, 0.08507868647575378, -1.4223546981811523, -1.1468472480773926, -0.5545933842658997, -0.07089290022850037, -0.13891242444515228, 0.011912408284842968, -0.6877986788749695, 0.13047562539577484, 0.14320263266563416, 0.07384441047906876, 0.9255921244621277, -0.24315842986106873, 0.41254371404647827, 0.42035484313964844, 0.3744613230228424, 0.197174072265625, 0.5899893641471863, 1.2492307424545288, 0.42909446358680725, 1.330527424812317, 1.1303491592407227, 0.8569501638412476, 1.4945186376571655, 0.6618057489395142, 1.893581748008728, -0.5343999266624451, 0.9084205627441406, 1.438533067703247, 1.399253010749817, 0.44791990518569946, 1.123808741569519, 0.9027603268623352, 1.2713483572006226, 0.2606579661369324, 0.9643701314926147, 0.21368932723999023, 1.4417126178741455, 0.9837875962257385, 0.84685879945755, 1.0656254291534424, 1.142637848854065, 0.7031582593917847, 0.798378050327301, 1.2586513757705688, 0.0, 0.0, 0.0, -0.5237029790878296, 0.0, 6.042104244232178, 8.314369201660156, -0.0, -3.7425966262817383, -4.948640823364258, 0.0, -9.709470748901367, -0.0, -0.0, -0.0, -4.706563472747803, -5.573760509490967, -5.147874355316162, -4.343133449554443, -3.9564590454101562, -3.638223171234131, -3.6566860675811768, -3.7476260662078857, -3.100992202758789, -3.373012065887451, -1.8979159593582153, -1.891119360923767, -2.4168570041656494, -0.9769982695579529, -1.5318375825881958, -1.8048166036605835, -1.401602029800415, -1.582843542098999, 0.08507868647575378, -1.4223546981811523, -1.1468472480773926, -0.5545933842658997, -0.07089290022850037, -0.13891242444515228, 0.011912408284842968, -0.6877986788749695, 0.13047562539577484, 0.14320263266563416, 0.07384441047906876, 0.9255921244621277, -0.24315842986106873, 0.41254371404647827, 0.42035484313964844, 0.3744613230228424, 0.197174072265625, 0.5899893641471863, 1.2492307424545288, 0.42909446358680725, 1.330527424812317, 1.1303491592407227, 0.8569501638412476, 1.4945186376571655, 0.6618057489395142, 1.893581748008728, -0.5343999266624451, 0.9084205627441406, 1.438533067703247, 1.399253010749817, 0.44791990518569946, 1.123808741569519, 0.9027603268623352, 1.2713483572006226, 0.2606579661369324, 0.9643701314926147, 0.21368932723999023, 1.4417126178741455, 0.9837875962257385, 0.84685879945755, 1.0656254291534424, 1.142637848854065, 0.7031582593917847, 0.798378050327301, 1.2586513757705688, 0.0, 0.0, -0.0, -0.5237029790878296, 0.0, 6.042104244232178, 8.314369201660156], [-3.7014153003692627, -3.8331966400146484, -4.496755123138428, 0.0, -9.331751823425293, 0.0, 0.0, 0.0, -5.339416027069092, -5.119818687438965, -5.007824420928955, -4.663121223449707, -4.7938151359558105, -4.0745849609375, -4.0010085105896, -2.937603235244751, -2.4332339763641357, -2.715301036834717, -1.9024261236190796, -2.4627609252929688, -1.742672324180603, -2.0282323360443115, -1.2612783908843994, -1.210845947265625, -1.5544694662094116, -1.4376187324523926, -0.1142258569598198, -0.7902251482009888, 0.03327610343694687, -0.2577154338359833, -0.02399911917746067, 0.1980024129152298, 0.4682755470275879, 0.329226016998291, 0.038893572986125946, 0.0418134480714798, 0.2997608482837677, 0.286018043756485, 0.23476725816726685, -0.30056384205818176, 1.4438855648040771, -0.132865309715271, 0.49015718698501587, 0.778464138507843, 1.4906868934631348, 0.01848779432475567, 0.9503697752952576, 0.8205394744873047, 0.35029804706573486, 0.802797794342041, 0.15262877941131592, 1.17954421043396, 1.309329628944397, 1.066271424293518, 0.3747587203979492, 1.227396011352539, 0.7388407588005066, 0.9843847155570984, 0.8533297181129456, 0.6734127998352051, 1.4703972339630127, 1.2641254663467407, 0.9559361338615417, 1.4911918640136719, 0.9877339601516724, 1.3068580627441406, 0.3723052144050598, 0.671975314617157, 1.1607061624526978, 1.623002529144287, 1.2509697675704956, 3.1289076805114746, 0.0, 0.0, 0.2292301058769226, 0.0, 0.0, 8.956245422363281, -3.7014153003692627, -3.8331966400146484, -4.496755123138428, -0.0, -9.331751823425293, -0.0, -0.0, -0.0, -5.339416027069092, -5.119818687438965, -5.007824420928955, -4.663121223449707, -4.7938151359558105, -4.0745849609375, -4.0010085105896, -2.937603235244751, -2.4332339763641357, -2.715301036834717, -1.9024261236190796, -2.4627609252929688, -1.742672324180603, -2.0282323360443115, -1.2612783908843994, -1.210845947265625, -1.5544694662094116, -1.4376187324523926, -0.1142258569598198, -0.7902251482009888, 0.03327610343694687, -0.2577154338359833, -0.02399911917746067, 0.1980024129152298, 0.4682755470275879, 0.329226016998291, 0.038893572986125946, 0.0418134480714798, 0.2997608482837677, 0.286018043756485, 0.23476725816726685, -0.30056384205818176, 1.4438855648040771, -0.132865309715271, 0.49015718698501587, 0.778464138507843, 1.4906868934631348, 0.01848779432475567, 0.9503697752952576, 0.8205394744873047, 0.35029804706573486, 0.802797794342041, 0.15262877941131592, 1.17954421043396, 1.309329628944397, 1.066271424293518, 0.3747587203979492, 1.227396011352539, 0.7388407588005066, 0.9843847155570984, 0.8533297181129456, 0.6734127998352051, 1.4703972339630127, 1.2641254663467407, 0.9559361338615417, 1.4911918640136719, 0.9877339601516724, 1.3068580627441406, 0.3723052144050598, 0.671975314617157, 1.1607061624526978, 1.623002529144287, 1.2509697675704956, 3.1289076805114746, 0.0, 0.0, 0.2292301058769226, 0.0, 0.0, 8.956245422363281], [-0.5295878052711487, -3.479914665222168, 0.0, 0.0, 0.0, 0.0, 0.0, -6.537254333496094, -5.155084609985352, -5.207226753234863, -4.876969814300537, -4.404807090759277, -4.2459940910339355, -4.250341892242432, -3.4845471382141113, -3.7141096591949463, -2.4497315883636475, -2.6076295375823975, -2.3424830436706543, -2.3297839164733887, -1.9358136653900146, -1.8516830205917358, -1.1172243356704712, -1.2977690696716309, -0.8020156621932983, -0.9842173457145691, -1.0617839097976685, -1.0120007991790771, -0.5099745392799377, -0.6791998744010925, -0.1789279580116272, 0.3693161606788635, -0.8199021220207214, 1.4508670568466187, 1.7627838850021362, 0.13658437132835388, 0.19353067874908447, 1.2317731380462646, 0.4924381673336029, 0.4909732937812805, 0.005489833187311888, 0.8007713556289673, 2.0066823959350586, 0.9459337592124939, 0.7167945504188538, 0.24436290562152863, 1.5130248069763184, 0.895087480545044, 1.7473316192626953, 1.3779436349868774, 0.9528658986091614, 0.6708976030349731, 1.1939078569412231, 2.108640670776367, 0.639237642288208, 1.0401766300201416, 0.7994805574417114, 0.577551543712616, 1.577148199081421, 0.7086071968078613, 0.6624501943588257, 0.3563331067562103, 0.4214021563529968, 1.1770704984664917, 0.3996439278125763, 1.9582267999649048, 0.9865185022354126, 0.5659406185150146, 0.8938657641410828, 1.4886138439178467, 0.6112138032913208, 0.7978024482727051, 0.0, 0.0, 0.0, 0.0, 0.0, 10.284881591796875, -0.5295878052711487, -3.479914665222168, -0.0, -0.0, -0.0, -0.0, -0.0, -6.537254333496094, -5.155084609985352, -5.207226753234863, -4.876969814300537, -4.404807090759277, -4.2459940910339355, -4.250341892242432, -3.4845471382141113, -3.7141096591949463, -2.4497315883636475, -2.6076295375823975, -2.3424830436706543, -2.3297839164733887, -1.9358136653900146, -1.8516830205917358, -1.1172243356704712, -1.2977690696716309, -0.8020156621932983, -0.9842173457145691, -1.0617839097976685, -1.0120007991790771, -0.5099745392799377, -0.6791998744010925, -0.1789279580116272, 0.3693161606788635, -0.8199021220207214, 1.4508670568466187, 1.7627838850021362, 0.13658437132835388, 0.19353067874908447, 1.2317731380462646, 0.4924381673336029, 0.4909732937812805, 0.005489833187311888, 0.8007713556289673, 2.0066823959350586, 0.9459337592124939, 0.7167945504188538, 0.24436290562152863, 1.5130248069763184, 0.895087480545044, 1.7473316192626953, 1.3779436349868774, 0.9528658986091614, 0.6708976030349731, 1.1939078569412231, 2.108640670776367, 0.639237642288208, 1.0401766300201416, 0.7994805574417114, 0.577551543712616, 1.577148199081421, 0.7086071968078613, 0.6624501943588257, 0.3563331067562103, 0.4214021563529968, 1.1770704984664917, 0.3996439278125763, 1.9582267999649048, 0.9865185022354126, 0.5659406185150146, 0.8938657641410828, 1.4886138439178467, 0.6112138032913208, 0.7978024482727051, 0.0, 0.0, 0.0, 0.0, 0.0, 10.284881591796875], [-1.133698582649231, 0.0, 0.0, 0.0, 0.0, 0.0, -5.895469665527344, -6.214330196380615, -5.163033962249756, -5.020467281341553, -4.824301719665527, -4.489367485046387, -3.621838331222534, -3.831940174102783, -3.119978427886963, -2.9453699588775635, -1.908896803855896, -3.0779640674591064, -2.555650472640991, -2.952033519744873, -1.27773118019104, -0.5911240577697754, -1.300604224205017, -0.9108648896217346, -0.40685030817985535, -0.3899731934070587, -0.2855263650417328, -0.4407268464565277, -0.03909052163362503, -0.6329831480979919, -0.4546695649623871, -1.0266631841659546, -1.3118844032287598, 0.8909821510314941, 0.9555927515029907, -0.15692782402038574, 1.1361629962921143, -0.2694793939590454, 0.7295265197753906, 1.3462611436843872, -0.10350944846868515, 1.1024519205093384, 0.7686776518821716, 0.5694117546081543, 1.144514799118042, 1.5314581394195557, 0.6060941815376282, 0.9635909795761108, 1.3688652515411377, 0.3548511862754822, 1.5705745220184326, 0.7121993899345398, 1.250676155090332, 1.6157171726226807, 0.5661287903785706, 0.724057674407959, 0.5531695485115051, 1.1639184951782227, 1.4911705255508423, 1.4278950691223145, 1.146602749824524, 1.2458937168121338, 0.19266106188297272, 1.061538815498352, 2.0881335735321045, 1.5868194103240967, 1.2367405891418457, 0.7654486894607544, 1.52980637550354, 1.3314975500106812, 1.3223769664764404, 0.8714081048965454, 1.2549786567687988, 0.0, 0.0, 0.0, 0.0, 12.893119812011719, -1.133698582649231, -0.0, -0.0, -0.0, -0.0, -0.0, -5.895469665527344, -6.214330196380615, -5.163033962249756, -5.020467281341553, -4.824301719665527, -4.489367485046387, -3.621838331222534, -3.831940174102783, -3.119978427886963, -2.9453699588775635, -1.908896803855896, -3.0779640674591064, -2.555650472640991, -2.952033519744873, -1.27773118019104, -0.5911240577697754, -1.300604224205017, -0.9108648896217346, -0.40685030817985535, -0.3899731934070587, -0.2855263650417328, -0.4407268464565277, -0.03909052163362503, -0.6329831480979919, -0.4546695649623871, -1.0266631841659546, -1.3118844032287598, 0.8909821510314941, 0.9555927515029907, -0.15692782402038574, 1.1361629962921143, -0.2694793939590454, 0.7295265197753906, 1.3462611436843872, -0.10350944846868515, 1.1024519205093384, 0.7686776518821716, 0.5694117546081543, 1.144514799118042, 1.5314581394195557, 0.6060941815376282, 0.9635909795761108, 1.3688652515411377, 0.3548511862754822, 1.5705745220184326, 0.7121993899345398, 1.250676155090332, 1.6157171726226807, 0.5661287903785706, 0.724057674407959, 0.5531695485115051, 1.1639184951782227, 1.4911705255508423, 1.4278950691223145, 1.146602749824524, 1.2458937168121338, 0.19266106188297272, 1.061538815498352, 2.0881335735321045, 1.5868194103240967, 1.2367405891418457, 0.7654486894607544, 1.52980637550354, 1.3314975500106812, 1.3223769664764404, 0.8714081048965454, 1.2549786567687988, 0.0, 0.0, 0.0, 0.0, 12.893119812011719], [-2.577096462249756, 0.0, 0.0, 0.0, 0.0, 0.0, -5.806729316711426, -5.772256851196289, -4.6436028480529785, -5.217806816101074, -4.268308639526367, -4.833954811096191, -4.218749523162842, -3.865463972091675, -3.530146837234497, -3.625645875930786, -3.222991466522217, -3.0071380138397217, -2.9017698764801025, -1.661635160446167, -1.8221780061721802, -1.260232925415039, -1.1561014652252197, -1.2109295129776, -1.0703626871109009, -0.915015697479248, -0.0029753115959465504, -0.6022602915763855, -0.5598822832107544, -0.17076116800308228, -0.7529873847961426, 0.15000928938388824, 1.968462586402893, 0.9791156053543091, 0.3400690257549286, 0.34944143891334534, 1.1242964267730713, -0.23054073750972748, 0.5980985760688782, 0.10084927827119827, 0.9686563014984131, 0.4993472397327423, 0.6868932247161865, 1.1772899627685547, 0.19701266288757324, 0.8975838422775269, 1.49630868434906, 1.1357311010360718, 1.4232046604156494, 2.2099733352661133, -0.08058325946331024, -0.07559598982334137, 1.4860714673995972, 1.325345754623413, 1.5784231424331665, 2.158585786819458, 0.912122368812561, 0.7064447402954102, 0.8843924403190613, 1.440256118774414, 0.6276069283485413, 1.2980546951293945, 1.0815352201461792, 0.7937208414077759, 1.5402498245239258, 1.3557422161102295, 1.7355507612228394, 1.2405383586883545, 0.766117513179779, 1.4950147867202759, 1.6717644929885864, 0.5782827138900757, 1.3741827011108398, 0.0, 0.0, 0.0, 1.758744239807129, 0.0, -2.577096462249756, -0.0, -0.0, -0.0, -0.0, -0.0, -5.806729316711426, -5.772256851196289, -4.6436028480529785, -5.217806816101074, -4.268308639526367, -4.833954811096191, -4.218749523162842, -3.865463972091675, -3.530146837234497, -3.625645875930786, -3.222991466522217, -3.0071380138397217, -2.9017698764801025, -1.661635160446167, -1.8221780061721802, -1.260232925415039, -1.1561014652252197, -1.2109295129776, -1.0703626871109009, -0.915015697479248, -0.0029753115959465504, -0.6022602915763855, -0.5598822832107544, -0.17076116800308228, -0.7529873847961426, 0.15000928938388824, 1.968462586402893, 0.9791156053543091, 0.3400690257549286, 0.34944143891334534, 1.1242964267730713, -0.23054073750972748, 0.5980985760688782, 0.10084927827119827, 0.9686563014984131, 0.4993472397327423, 0.6868932247161865, 1.1772899627685547, 0.19701266288757324, 0.8975838422775269, 1.49630868434906, 1.1357311010360718, 1.4232046604156494, 2.2099733352661133, -0.08058325946331024, -0.07559598982334137, 1.4860714673995972, 1.325345754623413, 1.5784231424331665, 2.158585786819458, 0.912122368812561, 0.7064447402954102, 0.8843924403190613, 1.440256118774414, 0.6276069283485413, 1.2980546951293945, 1.0815352201461792, 0.7937208414077759, 1.5402498245239258, 1.3557422161102295, 1.7355507612228394, 1.2405383586883545, 0.766117513179779, 1.4950147867202759, 1.6717644929885864, 0.5782827138900757, 1.3741827011108398, 0.0, 0.0, 0.0, 1.758744239807129, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -5.373134613037109, -6.20912504196167, -5.93821382522583, -5.498246669769287, -4.832606792449951, -6.3075175285339355, -4.060095310211182, -4.544170379638672, -3.9135351181030273, -3.314293146133423, -3.582157850265503, -2.5420644283294678, -2.648405075073242, -2.509448766708374, -1.067509651184082, -1.7319109439849854, -1.7683498859405518, -0.5396876335144043, -0.8411208391189575, -0.976717472076416, -1.579490065574646, -0.2762015461921692, -1.057053565979004, -0.3019231855869293, 0.32527267932891846, -0.9595844149589539, 0.2984665632247925, 0.6258472800254822, 0.5679486989974976, 1.2950794696807861, 0.03762252628803253, 0.3968488276004791, 2.1084048748016357, 1.1369653940200806, 1.047410249710083, 0.4460698962211609, 0.9824810028076172, 0.6143524646759033, 1.1129412651062012, 1.5047411918640137, 0.8020071983337402, 2.6497201919555664, 1.540251612663269, 1.1195437908172607, 1.3557870388031006, 2.0408101081848145, 1.6659650802612305, 1.1146652698516846, 1.0409845113754272, 1.8524116277694702, 0.5344140529632568, 1.2919784784317017, 1.7386490106582642, 0.4705679714679718, 0.8829593062400818, 0.1318003237247467, 0.45981526374816895, 1.073303461074829, 1.79697847366333, 2.0053226947784424, 1.7494491338729858, 1.2676186561584473, 1.0828808546066284, 1.4419395923614502, 1.8418468236923218, 1.4493094682693481, 1.9482144117355347, 1.3350872993469238, 1.6301157474517822, 0.0, 0.0, 0.6377905011177063, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.373134613037109, -6.20912504196167, -5.93821382522583, -5.498246669769287, -4.832606792449951, -6.3075175285339355, -4.060095310211182, -4.544170379638672, -3.9135351181030273, -3.314293146133423, -3.582157850265503, -2.5420644283294678, -2.648405075073242, -2.509448766708374, -1.067509651184082, -1.7319109439849854, -1.7683498859405518, -0.5396876335144043, -0.8411208391189575, -0.976717472076416, -1.579490065574646, -0.2762015461921692, -1.057053565979004, -0.3019231855869293, 0.32527267932891846, -0.9595844149589539, 0.2984665632247925, 0.6258472800254822, 0.5679486989974976, 1.2950794696807861, 0.03762252628803253, 0.3968488276004791, 2.1084048748016357, 1.1369653940200806, 1.047410249710083, 0.4460698962211609, 0.9824810028076172, 0.6143524646759033, 1.1129412651062012, 1.5047411918640137, 0.8020071983337402, 2.6497201919555664, 1.540251612663269, 1.1195437908172607, 1.3557870388031006, 2.0408101081848145, 1.6659650802612305, 1.1146652698516846, 1.0409845113754272, 1.8524116277694702, 0.5344140529632568, 1.2919784784317017, 1.7386490106582642, 0.4705679714679718, 0.8829593062400818, 0.1318003237247467, 0.45981526374816895, 1.073303461074829, 1.79697847366333, 2.0053226947784424, 1.7494491338729858, 1.2676186561584473, 1.0828808546066284, 1.4419395923614502, 1.8418468236923218, 1.4493094682693481, 1.9482144117355347, 1.3350872993469238, 1.6301157474517822, 0.0, 0.0, 0.6377905011177063, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -6.402431964874268, -6.244073867797852, -5.506652355194092, -5.536844730377197, -5.362407207489014, -4.050273418426514, -4.554688453674316, -5.53693962097168, -3.8486154079437256, -3.674595594406128, -3.6091468334198, -2.580217123031616, -2.5053608417510986, -2.2601821422576904, -2.535111427307129, -1.1084791421890259, -1.1940451860427856, -2.067460060119629, -1.3365260362625122, -1.8173402547836304, -0.2862089276313782, 0.27387019991874695, -0.38909676671028137, 0.7776861786842346, -0.6606412529945374, 0.47676530480384827, -0.48523810505867004, -0.7736581563949585, 1.1250172853469849, 1.5455760955810547, 0.4820687472820282, 2.188971996307373, 0.14511705935001373, -0.42966532707214355, 1.7342814207077026, 1.2621840238571167, 1.2171869277954102, 1.648990273475647, 0.8441128730773926, 1.3525339365005493, 2.0272469520568848, 2.4001002311706543, 2.1894636154174805, 2.1992347240448, 1.829058051109314, 1.480349063873291, 1.7349693775177002, 2.010100841522217, 1.4499601125717163, 0.5083045959472656, 0.31816941499710083, 1.3018040657043457, 1.884082317352295, 1.6506421566009521, 0.8016816973686218, 0.7798839211463928, 0.9952756762504578, 2.3075644969940186, 1.9955692291259766, 1.1091701984405518, 1.5991605520248413, 2.1995534896850586, 1.2878084182739258, 1.2943984270095825, 1.362077236175537, 1.9711624383926392, 0.954790472984314, 1.5254251956939697, 1.7735836505889893, 0.0, 0.0, 2.5886952877044678, 4.271442413330078, 0.0, 0.0, -0.0, -0.0, -0.0, -6.402431964874268, -6.244073867797852, -5.506652355194092, -5.536844730377197, -5.362407207489014, -4.050273418426514, -4.554688453674316, -5.53693962097168, -3.8486154079437256, -3.674595594406128, -3.6091468334198, -2.580217123031616, -2.5053608417510986, -2.2601821422576904, -2.535111427307129, -1.1084791421890259, -1.1940451860427856, -2.067460060119629, -1.3365260362625122, -1.8173402547836304, -0.2862089276313782, 0.27387019991874695, -0.38909676671028137, 0.7776861786842346, -0.6606412529945374, 0.47676530480384827, -0.48523810505867004, -0.7736581563949585, 1.1250172853469849, 1.5455760955810547, 0.4820687472820282, 2.188971996307373, 0.14511705935001373, -0.42966532707214355, 1.7342814207077026, 1.2621840238571167, 1.2171869277954102, 1.648990273475647, 0.8441128730773926, 1.3525339365005493, 2.0272469520568848, 2.4001002311706543, 2.1894636154174805, 2.1992347240448, 1.829058051109314, 1.480349063873291, 1.7349693775177002, 2.010100841522217, 1.4499601125717163, 0.5083045959472656, 0.31816941499710083, 1.3018040657043457, 1.884082317352295, 1.6506421566009521, 0.8016816973686218, 0.7798839211463928, 0.9952756762504578, 2.3075644969940186, 1.9955692291259766, 1.1091701984405518, 1.5991605520248413, 2.1995534896850586, 1.2878084182739258, 1.2943984270095825, 1.362077236175537, 1.9711624383926392, 0.954790472984314, 1.5254251956939697, 1.7735836505889893, 0.0, 0.0, 2.5886952877044678, 4.271442413330078], [0.0, 0.0, 0.0, 0.0, -5.6011433601379395, -6.132323741912842, -5.719028949737549, -6.704129695892334, -5.03408145904541, -5.788212776184082, -6.0652008056640625, -5.194182872772217, -4.4478960037231445, -3.897674560546875, -2.951303005218506, -3.087996482849121, -2.252317190170288, -2.6859006881713867, -2.202674627304077, -1.956430435180664, -1.815672755241394, -1.9686981439590454, -0.6258708834648132, -0.9508016109466553, 1.0744432210922241, -0.34139832854270935, -0.5097804069519043, -0.8692214488983154, 0.46680760383605957, 0.06692230701446533, 1.0061014890670776, 0.511042594909668, 0.4693409502506256, 0.11639993637800217, 0.5633636116981506, -0.08736469596624374, -1.1637964248657227, 0.4168867766857147, -0.4992307722568512, 1.9192192554473877, 0.7104684710502625, 1.1188855171203613, 0.887398898601532, 1.4479951858520508, 1.3177536725997925, 1.836030125617981, 2.1054720878601074, 0.9938719272613525, 0.9634377956390381, 1.4169684648513794, 1.7465475797653198, 1.5866063833236694, 1.7032486200332642, 1.5940444469451904, 2.081531524658203, 1.3570008277893066, 2.5243382453918457, 1.9618161916732788, 1.171982765197754, 0.9348977208137512, -0.04481212794780731, 1.9929797649383545, 1.2148375511169434, -0.4842836558818817, 1.5048274993896484, 0.834869384765625, 0.5488638877868652, 1.298076868057251, 1.6527317762374878, 0.6282320022583008, 2.2908194065093994, 0.8070396780967712, 1.1796355247497559, 1.63264000415802, 0.0, 0.0, 0.6873517632484436, 0.0, 0.0, 0.0, -0.0, -0.0, -5.6011433601379395, -6.132323741912842, -5.719028949737549, -6.704129695892334, -5.03408145904541, -5.788212776184082, -6.0652008056640625, -5.194182872772217, -4.4478960037231445, -3.897674560546875, -2.951303005218506, -3.087996482849121, -2.252317190170288, -2.6859006881713867, -2.202674627304077, -1.956430435180664, -1.815672755241394, -1.9686981439590454, -0.6258708834648132, -0.9508016109466553, 1.0744432210922241, -0.34139832854270935, -0.5097804069519043, -0.8692214488983154, 0.46680760383605957, 0.06692230701446533, 1.0061014890670776, 0.511042594909668, 0.4693409502506256, 0.11639993637800217, 0.5633636116981506, -0.08736469596624374, -1.1637964248657227, 0.4168867766857147, -0.4992307722568512, 1.9192192554473877, 0.7104684710502625, 1.1188855171203613, 0.887398898601532, 1.4479951858520508, 1.3177536725997925, 1.836030125617981, 2.1054720878601074, 0.9938719272613525, 0.9634377956390381, 1.4169684648513794, 1.7465475797653198, 1.5866063833236694, 1.7032486200332642, 1.5940444469451904, 2.081531524658203, 1.3570008277893066, 2.5243382453918457, 1.9618161916732788, 1.171982765197754, 0.9348977208137512, -0.04481212794780731, 1.9929797649383545, 1.2148375511169434, -0.4842836558818817, 1.5048274993896484, 0.834869384765625, 0.5488638877868652, 1.298076868057251, 1.6527317762374878, 0.6282320022583008, 2.2908194065093994, 0.8070396780967712, 1.1796355247497559, 1.63264000415802, 0.0, 0.0, 0.6873517632484436, 0.0], [0.0, 0.0, 0.0, 0.0, -5.790032863616943, -6.749078750610352, -6.195628643035889, -5.385913848876953, -5.3329973220825195, -5.066922664642334, -4.997003078460693, -3.5817739963531494, -4.398897647857666, -4.684458255767822, -3.6893365383148193, -2.1199047565460205, -2.6725547313690186, -3.030827283859253, -1.1320319175720215, -2.682990789413452, -1.5715636014938354, -2.8451437950134277, -1.0286738872528076, 1.8975661993026733, -0.23169508576393127, -0.45884597301483154, -1.3947352170944214, -1.3245067596435547, 0.2893129289150238, 0.08095931261777878, -0.537677526473999, -0.02392527088522911, 0.9493387341499329, -1.542763113975525, 1.507681131362915, 0.6141213774681091, 0.3445708751678467, -0.06679106503725052, 2.1242904663085938, 0.1937892884016037, 1.1018197536468506, 0.9564667344093323, 1.1909633874893188, 1.818913459777832, 1.8341772556304932, 1.0810964107513428, 1.8427339792251587, 1.2729564905166626, 1.5766162872314453, 1.6148937940597534, 1.7489852905273438, 1.0740842819213867, 1.0206170082092285, 1.4330413341522217, 1.7251832485198975, 0.8162814378738403, 2.2633121013641357, 1.4379342794418335, 0.9925947785377502, 1.7496123313903809, 1.295217514038086, 1.7110345363616943, 1.55642569065094, 1.759347915649414, 1.1785955429077148, 1.6791155338287354, 0.6746646165847778, 1.2387969493865967, 1.5335086584091187, 2.871053457260132, 2.048222541809082, 1.6695008277893066, 1.4220902919769287, 2.0914599895477295, 2.2098331451416016, 0.0, 3.250154733657837, 3.41953444480896, 0.0, 0.0, 0.0, -0.0, -5.790032863616943, -6.749078750610352, -6.195628643035889, -5.385913848876953, -5.3329973220825195, -5.066922664642334, -4.997003078460693, -3.5817739963531494, -4.398897647857666, -4.684458255767822, -3.6893365383148193, -2.1199047565460205, -2.6725547313690186, -3.030827283859253, -1.1320319175720215, -2.682990789413452, -1.5715636014938354, -2.8451437950134277, -1.0286738872528076, 1.8975661993026733, -0.23169508576393127, -0.45884597301483154, -1.3947352170944214, -1.3245067596435547, 0.2893129289150238, 0.08095931261777878, -0.537677526473999, -0.02392527088522911, 0.9493387341499329, -1.542763113975525, 1.507681131362915, 0.6141213774681091, 0.3445708751678467, -0.06679106503725052, 2.1242904663085938, 0.1937892884016037, 1.1018197536468506, 0.9564667344093323, 1.1909633874893188, 1.818913459777832, 1.8341772556304932, 1.0810964107513428, 1.8427339792251587, 1.2729564905166626, 1.5766162872314453, 1.6148937940597534, 1.7489852905273438, 1.0740842819213867, 1.0206170082092285, 1.4330413341522217, 1.7251832485198975, 0.8162814378738403, 2.2633121013641357, 1.4379342794418335, 0.9925947785377502, 1.7496123313903809, 1.295217514038086, 1.7110345363616943, 1.55642569065094, 1.759347915649414, 1.1785955429077148, 1.6791155338287354, 0.6746646165847778, 1.2387969493865967, 1.5335086584091187, 2.871053457260132, 2.048222541809082, 1.6695008277893066, 1.4220902919769287, 2.0914599895477295, 2.2098331451416016, 0.0, 3.250154733657837, 3.41953444480896], [-1.190515160560608, 0.6322616934776306, 0.0, 0.0, -6.8804497718811035, -7.082956314086914, -6.7379631996154785, -5.877377510070801, -5.326112270355225, -4.768529891967773, -4.852379322052002, -4.484289646148682, -3.8331053256988525, -4.138152599334717, -4.306278228759766, -3.5866410732269287, -2.45814847946167, -2.6949400901794434, -1.7559651136398315, -1.2188193798065186, -1.6208125352859497, -2.1664772033691406, -1.0242822170257568, -0.9262007474899292, -0.8250478506088257, -0.5109747648239136, 0.3515496551990509, 0.6988629102706909, -0.6094112396240234, -0.6278560161590576, -0.4428151249885559, 0.4227331578731537, -1.2699549198150635, -0.4093511402606964, 0.9186311364173889, 0.5660864114761353, 0.47003787755966187, 1.171633005142212, 2.6234545707702637, 0.6526494026184082, 0.7458555698394775, 0.8192102313041687, 1.6081100702285767, 1.356034278869629, 1.1865185499191284, 1.6115034818649292, 1.5951348543167114, 1.74735689163208, 1.584771990776062, 1.1964383125305176, 1.513239860534668, 1.2485944032669067, 1.1750383377075195, 1.367966890335083, 1.4150476455688477, 1.2679331302642822, 1.479557991027832, 0.5237538814544678, 1.728210210800171, -0.999114990234375, 1.5271875858306885, 1.40806245803833, 0.9931195378303528, 1.8010035753250122, 1.6885120868682861, 1.4803165197372437, 1.1627038717269897, 1.2350305318832397, 1.5313574075698853, 1.7457274198532104, 1.217233419418335, 1.965537190437317, 1.6477041244506836, 1.8064740896224976, 2.461998462677002, 0.0, 0.0, 2.0010690689086914, -1.190515160560608, 0.6322616934776306, 0.0, -0.0, -6.8804497718811035, -7.082956314086914, -6.7379631996154785, -5.877377510070801, -5.326112270355225, -4.768529891967773, -4.852379322052002, -4.484289646148682, -3.8331053256988525, -4.138152599334717, -4.306278228759766, -3.5866410732269287, -2.45814847946167, -2.6949400901794434, -1.7559651136398315, -1.2188193798065186, -1.6208125352859497, -2.1664772033691406, -1.0242822170257568, -0.9262007474899292, -0.8250478506088257, -0.5109747648239136, 0.3515496551990509, 0.6988629102706909, -0.6094112396240234, -0.6278560161590576, -0.4428151249885559, 0.4227331578731537, -1.2699549198150635, -0.4093511402606964, 0.9186311364173889, 0.5660864114761353, 0.47003787755966187, 1.171633005142212, 2.6234545707702637, 0.6526494026184082, 0.7458555698394775, 0.8192102313041687, 1.6081100702285767, 1.356034278869629, 1.1865185499191284, 1.6115034818649292, 1.5951348543167114, 1.74735689163208, 1.584771990776062, 1.1964383125305176, 1.513239860534668, 1.2485944032669067, 1.1750383377075195, 1.367966890335083, 1.4150476455688477, 1.2679331302642822, 1.479557991027832, 0.5237538814544678, 1.728210210800171, -0.999114990234375, 1.5271875858306885, 1.40806245803833, 0.9931195378303528, 1.8010035753250122, 1.6885120868682861, 1.4803165197372437, 1.1627038717269897, 1.2350305318832397, 1.5313574075698853, 1.7457274198532104, 1.217233419418335, 1.965537190437317, 1.6477041244506836, 1.8064740896224976, 2.461998462677002, 0.0, 0.0, 2.0010690689086914], [0.0, -0.393917977809906, 0.0, -3.9192044734954834, -6.984265327453613, -6.676774978637695, -5.671513557434082, -5.968533515930176, -5.932653903961182, -5.3174357414245605, -5.559152603149414, -4.921584606170654, -3.9601542949676514, -3.5718767642974854, -2.8332366943359375, -2.5648393630981445, -2.6293933391571045, -4.1023268699646, -1.8891032934188843, -2.6664280891418457, -2.183307647705078, -1.5001025199890137, -1.7526415586471558, -1.2667406797409058, -1.7795294523239136, -0.6488612294197083, -0.5078869462013245, 0.16624002158641815, 0.5175065994262695, 1.9471935033798218, 1.0179473161697388, 0.13770896196365356, 0.07579132169485092, 0.522530734539032, 1.728414535522461, 1.812043309211731, 0.39520367980003357, 0.30776143074035645, 2.2878077030181885, -0.7130403518676758, 1.0073738098144531, 1.6983128786087036, 1.6835776567459106, 2.2786824703216553, 1.4510585069656372, 2.888650894165039, 2.1561081409454346, 1.3145182132720947, 1.661506175994873, 1.426167368888855, 1.2726970911026, 1.6707818508148193, 0.6935508251190186, 1.4587026834487915, 1.2454659938812256, 1.6697661876678467, 1.0769671201705933, 1.5421401262283325, 1.7988382577896118, 1.7005162239074707, 1.1883115768432617, 1.7337100505828857, 0.8255006074905396, 1.2409813404083252, 1.6148526668548584, 1.5905916690826416, 1.1770377159118652, 1.1356780529022217, 1.286179542541504, 1.6901097297668457, 1.8180385828018188, 0.6358296275138855, 1.9044266939163208, 1.9426811933517456, 2.1750874519348145, 0.0, 0.0, 3.9574356079101562, -0.0, -0.393917977809906, -0.0, -3.9192044734954834, -6.984265327453613, -6.676774978637695, -5.671513557434082, -5.968533515930176, -5.932653903961182, -5.3174357414245605, -5.559152603149414, -4.921584606170654, -3.9601542949676514, -3.5718767642974854, -2.8332366943359375, -2.5648393630981445, -2.6293933391571045, -4.1023268699646, -1.8891032934188843, -2.6664280891418457, -2.183307647705078, -1.5001025199890137, -1.7526415586471558, -1.2667406797409058, -1.7795294523239136, -0.6488612294197083, -0.5078869462013245, 0.16624002158641815, 0.5175065994262695, 1.9471935033798218, 1.0179473161697388, 0.13770896196365356, 0.07579132169485092, 0.522530734539032, 1.728414535522461, 1.812043309211731, 0.39520367980003357, 0.30776143074035645, 2.2878077030181885, -0.7130403518676758, 1.0073738098144531, 1.6983128786087036, 1.6835776567459106, 2.2786824703216553, 1.4510585069656372, 2.888650894165039, 2.1561081409454346, 1.3145182132720947, 1.661506175994873, 1.426167368888855, 1.2726970911026, 1.6707818508148193, 0.6935508251190186, 1.4587026834487915, 1.2454659938812256, 1.6697661876678467, 1.0769671201705933, 1.5421401262283325, 1.7988382577896118, 1.7005162239074707, 1.1883115768432617, 1.7337100505828857, 0.8255006074905396, 1.2409813404083252, 1.6148526668548584, 1.5905916690826416, 1.1770377159118652, 1.1356780529022217, 1.286179542541504, 1.6901097297668457, 1.8180385828018188, 0.6358296275138855, 1.9044266939163208, 1.9426811933517456, 2.1750874519348145, 0.0, 0.0, 3.9574356079101562], [0.0, 0.0, 0.0, -7.590540885925293, -7.027645587921143, -5.878503322601318, -5.946013450622559, -5.821823596954346, -6.053482532501221, -5.722436904907227, -4.862565994262695, -4.25475549697876, -3.018651008605957, -3.64396333694458, -3.339742660522461, -3.753117561340332, -2.539435863494873, -3.0061850547790527, -2.490372896194458, -1.5728247165679932, -1.7362335920333862, -2.404014825820923, -1.4375896453857422, -1.5771210193634033, -0.43845856189727783, -0.5518518090248108, -0.9081661701202393, -0.3021814227104187, -0.3099044859409332, -0.4715117812156677, 0.09465572237968445, 0.8141571283340454, 0.6419415473937988, 0.328998327255249, 1.7386833429336548, -0.03924298658967018, 0.26235875487327576, 0.13255029916763306, -1.626834750175476, 2.8570618629455566, 0.6380876302719116, 0.30635038018226624, 2.6847755908966064, 1.1347496509552002, 1.7276055812835693, 1.9936050176620483, 1.7448357343673706, 1.5707200765609741, 1.261812686920166, 1.698171615600586, 1.6196565628051758, 1.1274501085281372, 1.526755690574646, 1.3202141523361206, 1.2398611307144165, 1.1723334789276123, 1.5513386726379395, 0.492398738861084, 0.6855463981628418, 0.8409287333488464, 1.5895841121673584, 1.1362099647521973, 1.4222662448883057, 1.7961266040802002, 1.5811660289764404, 2.025071859359741, 1.6315584182739258, 1.075469732284546, 1.3527755737304688, 1.6938223838806152, 1.0898624658584595, 2.298360824584961, 2.1969962120056152, 1.2125506401062012, 2.7774386405944824, 0.0, 0.0, 1.840541958808899, -0.0, -0.0, -0.0, -7.590540885925293, -7.027645587921143, -5.878503322601318, -5.946013450622559, -5.821823596954346, -6.053482532501221, -5.722436904907227, -4.862565994262695, -4.25475549697876, -3.018651008605957, -3.64396333694458, -3.339742660522461, -3.753117561340332, -2.539435863494873, -3.0061850547790527, -2.490372896194458, -1.5728247165679932, -1.7362335920333862, -2.404014825820923, -1.4375896453857422, -1.5771210193634033, -0.43845856189727783, -0.5518518090248108, -0.9081661701202393, -0.3021814227104187, -0.3099044859409332, -0.4715117812156677, 0.09465572237968445, 0.8141571283340454, 0.6419415473937988, 0.328998327255249, 1.7386833429336548, -0.03924298658967018, 0.26235875487327576, 0.13255029916763306, -1.626834750175476, 2.8570618629455566, 0.6380876302719116, 0.30635038018226624, 2.6847755908966064, 1.1347496509552002, 1.7276055812835693, 1.9936050176620483, 1.7448357343673706, 1.5707200765609741, 1.261812686920166, 1.698171615600586, 1.6196565628051758, 1.1274501085281372, 1.526755690574646, 1.3202141523361206, 1.2398611307144165, 1.1723334789276123, 1.5513386726379395, 0.492398738861084, 0.6855463981628418, 0.8409287333488464, 1.5895841121673584, 1.1362099647521973, 1.4222662448883057, 1.7961266040802002, 1.5811660289764404, 2.025071859359741, 1.6315584182739258, 1.075469732284546, 1.3527755737304688, 1.6938223838806152, 1.0898624658584595, 2.298360824584961, 2.1969962120056152, 1.2125506401062012, 2.7774386405944824, 0.0, 0.0, 1.840541958808899], [-5.696908950805664, 0.0, 0.0, -6.722548007965088, -6.536459922790527, -6.28535795211792, -6.787525177001953, -5.773925304412842, -6.100311279296875, -4.752540111541748, -5.111221790313721, -4.856846809387207, -4.296782493591309, -4.539247035980225, -4.221522331237793, -3.417912721633911, -3.1267993450164795, -1.6654986143112183, -2.094886302947998, -1.4423377513885498, -1.1390830278396606, -1.3442116975784302, -1.4381897449493408, -1.2726285457611084, -0.8842628598213196, -0.5125635266304016, -0.5293439626693726, -0.6392914056777954, -0.23813647031784058, 0.2733915150165558, 0.596183180809021, 0.44359949231147766, 0.407632052898407, 1.260643482208252, 0.6475893259048462, 1.730954885482788, 0.32678189873695374, -0.5126624703407288, -0.6361645460128784, 0.7109167575836182, 0.5120497941970825, 1.2164057493209839, 1.8414613008499146, 2.4031922817230225, 2.3170440196990967, 1.5761767625808716, 1.4476344585418701, 1.5722142457962036, 1.4578500986099243, 1.3079578876495361, 1.3256207704544067, 1.193178653717041, 2.161623954772949, 1.4140427112579346, 0.8545669317245483, 1.4121060371398926, 2.650264263153076, 1.0313363075256348, 1.427476167678833, 1.1147143840789795, 1.4859914779663086, 0.9547560214996338, 1.5519212484359741, 1.4463632106781006, 1.7029495239257812, 1.9602243900299072, 1.5923755168914795, 1.232487678527832, 1.5878809690475464, 1.1706854104995728, 1.5554702281951904, 1.760459303855896, 2.175102949142456, 1.102239966392517, 2.7239818572998047, 0.0, 0.0, 4.202355861663818, -5.696908950805664, -0.0, -0.0, -6.722548007965088, -6.536459922790527, -6.28535795211792, -6.787525177001953, -5.773925304412842, -6.100311279296875, -4.752540111541748, -5.111221790313721, -4.856846809387207, -4.296782493591309, -4.539247035980225, -4.221522331237793, -3.417912721633911, -3.1267993450164795, -1.6654986143112183, -2.094886302947998, -1.4423377513885498, -1.1390830278396606, -1.3442116975784302, -1.4381897449493408, -1.2726285457611084, -0.8842628598213196, -0.5125635266304016, -0.5293439626693726, -0.6392914056777954, -0.23813647031784058, 0.2733915150165558, 0.596183180809021, 0.44359949231147766, 0.407632052898407, 1.260643482208252, 0.6475893259048462, 1.730954885482788, 0.32678189873695374, -0.5126624703407288, -0.6361645460128784, 0.7109167575836182, 0.5120497941970825, 1.2164057493209839, 1.8414613008499146, 2.4031922817230225, 2.3170440196990967, 1.5761767625808716, 1.4476344585418701, 1.5722142457962036, 1.4578500986099243, 1.3079578876495361, 1.3256207704544067, 1.193178653717041, 2.161623954772949, 1.4140427112579346, 0.8545669317245483, 1.4121060371398926, 2.650264263153076, 1.0313363075256348, 1.427476167678833, 1.1147143840789795, 1.4859914779663086, 0.9547560214996338, 1.5519212484359741, 1.4463632106781006, 1.7029495239257812, 1.9602243900299072, 1.5923755168914795, 1.232487678527832, 1.5878809690475464, 1.1706854104995728, 1.5554702281951904, 1.760459303855896, 2.175102949142456, 1.102239966392517, 2.7239818572998047, 0.0, 0.0, 4.202355861663818], [-6.659367084503174, 0.0, 0.0, -6.235471248626709, -5.906765460968018, -5.924412250518799, -6.679065704345703, -6.148285865783691, -5.626226902008057, -5.227662086486816, -4.654270172119141, -4.914569854736328, -4.262112617492676, -4.3985209465026855, -4.450436115264893, -4.102945804595947, -2.529094696044922, -3.088632583618164, -2.1691436767578125, -1.887592077255249, -1.5989017486572266, -1.3974061012268066, -1.5620275735855103, -1.2526355981826782, -0.7678018808364868, -1.0966213941574097, -0.526894211769104, -0.5811256170272827, -0.21052449941635132, -0.8589122891426086, 1.1634010076522827, 0.8028936386108398, -0.12522776424884796, -0.39257821440696716, 1.0193125009536743, -0.5649874806404114, 0.500774085521698, 0.8183006048202515, 0.7793353796005249, -1.0235859155654907, 0.6472115516662598, 1.5131381750106812, 0.4196544587612152, 2.3941543102264404, 1.1593775749206543, 1.6012369394302368, 1.427241563796997, 1.8225501775741577, 1.7326271533966064, 2.010918617248535, 1.3717879056930542, 0.9942906498908997, 1.8487471342086792, 1.489695429801941, 2.4671225547790527, 1.3785401582717896, 1.46089506149292, 0.8026950359344482, 1.3531931638717651, 1.686852216720581, 1.1568026542663574, -0.18947933614253998, 0.543620228767395, 1.7890701293945312, 1.2673723697662354, 1.7077608108520508, 1.522222638130188, 1.3593883514404297, 1.8557219505310059, 1.8311381340026855, 1.523528814315796, 2.229069948196411, 2.3396244049072266, 1.5925418138504028, 1.8938223123550415, 0.0, 0.0, 4.322330474853516, -6.659367084503174, -0.0, -0.0, -6.235471248626709, -5.906765460968018, -5.924412250518799, -6.679065704345703, -6.148285865783691, -5.626226902008057, -5.227662086486816, -4.654270172119141, -4.914569854736328, -4.262112617492676, -4.3985209465026855, -4.450436115264893, -4.102945804595947, -2.529094696044922, -3.088632583618164, -2.1691436767578125, -1.887592077255249, -1.5989017486572266, -1.3974061012268066, -1.5620275735855103, -1.2526355981826782, -0.7678018808364868, -1.0966213941574097, -0.526894211769104, -0.5811256170272827, -0.21052449941635132, -0.8589122891426086, 1.1634010076522827, 0.8028936386108398, -0.12522776424884796, -0.39257821440696716, 1.0193125009536743, -0.5649874806404114, 0.500774085521698, 0.8183006048202515, 0.7793353796005249, -1.0235859155654907, 0.6472115516662598, 1.5131381750106812, 0.4196544587612152, 2.3941543102264404, 1.1593775749206543, 1.6012369394302368, 1.427241563796997, 1.8225501775741577, 1.7326271533966064, 2.010918617248535, 1.3717879056930542, 0.9942906498908997, 1.8487471342086792, 1.489695429801941, 2.4671225547790527, 1.3785401582717896, 1.46089506149292, 0.8026950359344482, 1.3531931638717651, 1.686852216720581, 1.1568026542663574, -0.18947933614253998, 0.543620228767395, 1.7890701293945312, 1.2673723697662354, 1.7077608108520508, 1.522222638130188, 1.3593883514404297, 1.8557219505310059, 1.8311381340026855, 1.523528814315796, 2.229069948196411, 2.3396244049072266, 1.5925418138504028, 1.8938223123550415, 0.0, 0.0, 4.322330474853516], [-7.682170867919922, 0.0, 0.0, -7.253541469573975, -6.852161884307861, -6.713632583618164, -6.575198650360107, -6.138546466827393, -6.474801063537598, -5.003326416015625, -4.8763747215271, -5.190190315246582, -4.474246978759766, -3.9859135150909424, -4.133284091949463, -3.580122709274292, -3.4928786754608154, -2.8225531578063965, -1.8693276643753052, -1.348960518836975, -1.2326531410217285, -1.786878228187561, -1.1016895771026611, -1.440730094909668, -1.041856288909912, -0.9327183365821838, -0.7455605268478394, -0.687930703163147, -0.16861490905284882, -0.19879424571990967, 1.3103690147399902, 1.8780875205993652, 0.5829119086265564, 1.3980960845947266, 4.065526008605957, 0.4828657805919647, 1.3024238348007202, 1.317281723022461, 0.06279833614826202, 0.9271337985992432, -0.0282981488853693, 0.8079379796981812, 2.0042715072631836, 1.1027623414993286, 0.9810521006584167, 1.5410693883895874, 2.021303653717041, 1.8324707746505737, 1.4994102716445923, 1.189394235610962, 1.7501299381256104, 1.4015023708343506, 1.7902721166610718, 0.7717395424842834, 1.3788409233093262, 1.498338222503662, 1.313291072845459, 1.2839423418045044, 1.3625327348709106, 1.1057496070861816, 0.796984076499939, 0.965289831161499, 1.7918782234191895, 1.1556057929992676, 1.1606614589691162, 0.8767975568771362, 0.8851417303085327, 1.1006797552108765, 1.4219474792480469, 1.474403977394104, 1.8257606029510498, 1.9196434020996094, 2.1933252811431885, 2.060169219970703, 1.7885931730270386, 0.0, 0.0, 0.0, -7.682170867919922, -0.0, -0.0, -7.253541469573975, -6.852161884307861, -6.713632583618164, -6.575198650360107, -6.138546466827393, -6.474801063537598, -5.003326416015625, -4.8763747215271, -5.190190315246582, -4.474246978759766, -3.9859135150909424, -4.133284091949463, -3.580122709274292, -3.4928786754608154, -2.8225531578063965, -1.8693276643753052, -1.348960518836975, -1.2326531410217285, -1.786878228187561, -1.1016895771026611, -1.440730094909668, -1.041856288909912, -0.9327183365821838, -0.7455605268478394, -0.687930703163147, -0.16861490905284882, -0.19879424571990967, 1.3103690147399902, 1.8780875205993652, 0.5829119086265564, 1.3980960845947266, 4.065526008605957, 0.4828657805919647, 1.3024238348007202, 1.317281723022461, 0.06279833614826202, 0.9271337985992432, -0.0282981488853693, 0.8079379796981812, 2.0042715072631836, 1.1027623414993286, 0.9810521006584167, 1.5410693883895874, 2.021303653717041, 1.8324707746505737, 1.4994102716445923, 1.189394235610962, 1.7501299381256104, 1.4015023708343506, 1.7902721166610718, 0.7717395424842834, 1.3788409233093262, 1.498338222503662, 1.313291072845459, 1.2839423418045044, 1.3625327348709106, 1.1057496070861816, 0.796984076499939, 0.965289831161499, 1.7918782234191895, 1.1556057929992676, 1.1606614589691162, 0.8767975568771362, 0.8851417303085327, 1.1006797552108765, 1.4219474792480469, 1.474403977394104, 1.8257606029510498, 1.9196434020996094, 2.1933252811431885, 2.060169219970703, 1.7885931730270386, 0.0, 0.0, 0.0], [-3.687077045440674, 0.0, 0.0, -8.120649337768555, -6.8145647048950195, -6.670265197753906, -5.834169387817383, -6.808263778686523, -6.20231294631958, -5.07566499710083, -4.991730213165283, -4.969045162200928, -4.068512439727783, -4.371595859527588, -4.133605003356934, -3.827610969543457, -0.949213445186615, -3.946211338043213, -2.85941219329834, -1.4722249507904053, -2.4829108715057373, -1.9373043775558472, -1.111137866973877, -0.8824416399002075, -0.9932640790939331, -0.842704713344574, -0.756233274936676, -0.44811832904815674, -0.24089983105659485, -0.15679143369197845, 0.3807952404022217, 0.6242045164108276, 0.17434853315353394, 1.5683642625808716, 1.3823986053466797, -0.15455789864063263, 0.8722884654998779, 1.4045060873031616, 0.13719527423381805, 0.40123817324638367, 0.16955004632472992, 0.4869062304496765, 1.0083389282226562, 1.400292158126831, 1.8884025812149048, 1.4072887897491455, 1.5574605464935303, 1.1660983562469482, 1.886508822441101, 1.694053292274475, 1.8279715776443481, 1.2226148843765259, 1.654868483543396, 2.292008399963379, 0.8658740520477295, 2.7795472145080566, 1.971415638923645, 1.6614985466003418, 1.492270827293396, 1.2469124794006348, 1.8648545742034912, 1.3487104177474976, 0.7358159422874451, 1.221733808517456, 1.3848974704742432, 1.1908254623413086, 0.21884439885616302, 1.459132432937622, 1.2201592922210693, 1.242586612701416, 2.273144245147705, 1.924980640411377, 1.2433159351348877, 2.0636119842529297, 1.1730355024337769, 0.0, 0.0, 0.0, -3.687077045440674, -0.0, -0.0, -8.120649337768555, -6.8145647048950195, -6.670265197753906, -5.834169387817383, -6.808263778686523, -6.20231294631958, -5.07566499710083, -4.991730213165283, -4.969045162200928, -4.068512439727783, -4.371595859527588, -4.133605003356934, -3.827610969543457, -0.949213445186615, -3.946211338043213, -2.85941219329834, -1.4722249507904053, -2.4829108715057373, -1.9373043775558472, -1.111137866973877, -0.8824416399002075, -0.9932640790939331, -0.842704713344574, -0.756233274936676, -0.44811832904815674, -0.24089983105659485, -0.15679143369197845, 0.3807952404022217, 0.6242045164108276, 0.17434853315353394, 1.5683642625808716, 1.3823986053466797, -0.15455789864063263, 0.8722884654998779, 1.4045060873031616, 0.13719527423381805, 0.40123817324638367, 0.16955004632472992, 0.4869062304496765, 1.0083389282226562, 1.400292158126831, 1.8884025812149048, 1.4072887897491455, 1.5574605464935303, 1.1660983562469482, 1.886508822441101, 1.694053292274475, 1.8279715776443481, 1.2226148843765259, 1.654868483543396, 2.292008399963379, 0.8658740520477295, 2.7795472145080566, 1.971415638923645, 1.6614985466003418, 1.492270827293396, 1.2469124794006348, 1.8648545742034912, 1.3487104177474976, 0.7358159422874451, 1.221733808517456, 1.3848974704742432, 1.1908254623413086, 0.21884439885616302, 1.459132432937622, 1.2201592922210693, 1.242586612701416, 2.273144245147705, 1.924980640411377, 1.2433159351348877, 2.0636119842529297, 1.1730355024337769, 0.0, 0.0, 0.0], [-7.653670787811279, 0.0, 0.0, -8.027827262878418, -7.1416015625, -7.101902484893799, -6.823256015777588, -6.059229850769043, -5.594551086425781, -5.443790435791016, -5.337611198425293, -4.899623394012451, -4.346764087677002, -4.394186496734619, -5.157515048980713, -3.509465217590332, -4.241517066955566, -3.2470412254333496, -2.399729013442993, -3.7893519401550293, -1.78476083278656, -1.378355622291565, -1.7250609397888184, -1.1893054246902466, -1.0185471773147583, -0.8517943024635315, -0.9324466586112976, -0.7735495567321777, -0.5167033076286316, -0.5962756872177124, 0.015836887061595917, -0.3735538423061371, 0.9428218603134155, 0.7524917125701904, 0.42781689763069153, 0.16838575899600983, 1.7286800146102905, 0.16782280802726746, 3.0793144702911377, 0.6215567588806152, 1.2172751426696777, 0.6974694132804871, 0.6436508893966675, 1.3421835899353027, 1.15366792678833, 1.2840147018432617, 1.8775163888931274, 1.3067446947097778, 1.2084851264953613, 1.0508275032043457, 1.388146162033081, 1.3619107007980347, 1.2598165273666382, 0.9056472182273865, 1.3899118900299072, 1.9164704084396362, 1.2575101852416992, 1.731818437576294, 0.6662825345993042, 1.2368323802947998, 0.5972146391868591, 1.3265331983566284, 0.514197587966919, 1.2903907299041748, 0.7625048756599426, 0.46706852316856384, 1.0917575359344482, -0.29250824451446533, 1.3315277099609375, 1.2514349222183228, 1.6233935356140137, 1.5088295936584473, 1.0942682027816772, 1.914891004562378, 2.1228699684143066, 1.5746545791625977, 0.0, 0.0, -7.653670787811279, -0.0, -0.0, -8.027827262878418, -7.1416015625, -7.101902484893799, -6.823256015777588, -6.059229850769043, -5.594551086425781, -5.443790435791016, -5.337611198425293, -4.899623394012451, -4.346764087677002, -4.394186496734619, -5.157515048980713, -3.509465217590332, -4.241517066955566, -3.2470412254333496, -2.399729013442993, -3.7893519401550293, -1.78476083278656, -1.378355622291565, -1.7250609397888184, -1.1893054246902466, -1.0185471773147583, -0.8517943024635315, -0.9324466586112976, -0.7735495567321777, -0.5167033076286316, -0.5962756872177124, 0.015836887061595917, -0.3735538423061371, 0.9428218603134155, 0.7524917125701904, 0.42781689763069153, 0.16838575899600983, 1.7286800146102905, 0.16782280802726746, 3.0793144702911377, 0.6215567588806152, 1.2172751426696777, 0.6974694132804871, 0.6436508893966675, 1.3421835899353027, 1.15366792678833, 1.2840147018432617, 1.8775163888931274, 1.3067446947097778, 1.2084851264953613, 1.0508275032043457, 1.388146162033081, 1.3619107007980347, 1.2598165273666382, 0.9056472182273865, 1.3899118900299072, 1.9164704084396362, 1.2575101852416992, 1.731818437576294, 0.6662825345993042, 1.2368323802947998, 0.5972146391868591, 1.3265331983566284, 0.514197587966919, 1.2903907299041748, 0.7625048756599426, 0.46706852316856384, 1.0917575359344482, -0.29250824451446533, 1.3315277099609375, 1.2514349222183228, 1.6233935356140137, 1.5088295936584473, 1.0942682027816772, 1.914891004562378, 2.1228699684143066, 1.5746545791625977, 0.0, 0.0], [0.0, 0.0, -7.704247951507568, -7.819149971008301, -7.179178714752197, -6.706536293029785, -5.95112943649292, -6.891983509063721, -3.8259356021881104, -5.750300884246826, -5.689877033233643, -5.405365467071533, -4.473663806915283, -4.303966999053955, -4.877487659454346, -3.8754007816314697, -3.3853607177734375, -2.4086685180664062, -3.2450382709503174, -2.161736011505127, -2.5597286224365234, -1.751696228981018, -1.8899285793304443, -1.6969672441482544, -1.2292299270629883, -1.6864726543426514, -0.47322264313697815, 0.015637945383787155, 0.12498124688863754, -0.004980225581675768, 0.34024578332901, -0.04561258479952812, 0.2717114984989166, -0.03380243480205536, 1.169185757637024, 0.5846440196037292, 0.2792147696018219, 0.5269148945808411, 0.3453720211982727, 1.3819749355316162, 0.8539391756057739, 1.2408303022384644, 1.387606143951416, 1.4613697528839111, 1.4360625743865967, 1.4113105535507202, 1.8862019777297974, 0.9390667676925659, 1.2622706890106201, 0.9459184408187866, 1.394099473953247, 1.4754443168640137, 0.2157163769006729, 1.8511502742767334, 1.5334789752960205, 1.609167456626892, 2.251133441925049, 0.8216066360473633, 1.1104512214660645, 0.7898975610733032, 0.8950203061103821, 1.682554006576538, 1.0073322057724, 0.8240941166877747, 1.050900936126709, 1.1169387102127075, 1.147998571395874, 1.132976770401001, 0.9541192054748535, 1.3004900217056274, 1.2617433071136475, 2.1115150451660156, 1.8932560682296753, 1.5066155195236206, 2.138068675994873, 4.202040195465088, 0.0, 0.0, -0.0, -0.0, -7.704247951507568, -7.819149971008301, -7.179178714752197, -6.706536293029785, -5.95112943649292, -6.891983509063721, -3.8259356021881104, -5.750300884246826, -5.689877033233643, -5.405365467071533, -4.473663806915283, -4.303966999053955, -4.877487659454346, -3.8754007816314697, -3.3853607177734375, -2.4086685180664062, -3.2450382709503174, -2.161736011505127, -2.5597286224365234, -1.751696228981018, -1.8899285793304443, -1.6969672441482544, -1.2292299270629883, -1.6864726543426514, -0.47322264313697815, 0.015637945383787155, 0.12498124688863754, -0.004980225581675768, 0.34024578332901, -0.04561258479952812, 0.2717114984989166, -0.03380243480205536, 1.169185757637024, 0.5846440196037292, 0.2792147696018219, 0.5269148945808411, 0.3453720211982727, 1.3819749355316162, 0.8539391756057739, 1.2408303022384644, 1.387606143951416, 1.4613697528839111, 1.4360625743865967, 1.4113105535507202, 1.8862019777297974, 0.9390667676925659, 1.2622706890106201, 0.9459184408187866, 1.394099473953247, 1.4754443168640137, 0.2157163769006729, 1.8511502742767334, 1.5334789752960205, 1.609167456626892, 2.251133441925049, 0.8216066360473633, 1.1104512214660645, 0.7898975610733032, 0.8950203061103821, 1.682554006576538, 1.0073322057724, 0.8240941166877747, 1.050900936126709, 1.1169387102127075, 1.147998571395874, 1.132976770401001, 0.9541192054748535, 1.3004900217056274, 1.2617433071136475, 2.1115150451660156, 1.8932560682296753, 1.5066155195236206, 2.138068675994873, 4.202040195465088, 0.0, 0.0], [0.0, 0.0, -8.282793998718262, -8.394550323486328, -6.892147064208984, -7.500601291656494, -6.51826286315918, -6.1890177726745605, -6.026678562164307, -5.582924842834473, -5.756284713745117, -5.410963535308838, -6.7567033767700195, -5.204084396362305, -3.955911874771118, -2.8152878284454346, -3.6915841102600098, -3.157695770263672, -2.9847652912139893, -1.8359894752502441, -2.2028534412384033, -2.1231112480163574, -1.5154098272323608, -1.7737699747085571, -1.5189653635025024, -1.1649690866470337, -0.8520785570144653, -0.3368740975856781, 0.07864008098840714, 0.06448589265346527, -0.10750234872102737, 0.300529420375824, 0.17714403569698334, 0.2990924119949341, -0.0065909493714571, 0.8624451756477356, 0.5843997001647949, 1.1221696138381958, 0.5964092016220093, 0.8751155138015747, 0.45217621326446533, 0.6778601408004761, 0.8913889527320862, 1.6376371383666992, 1.2712701559066772, 1.241860270500183, 1.3342530727386475, 0.8028545379638672, 0.644791841506958, 1.5661019086837769, 1.39638090133667, 1.1281676292419434, 1.1737438440322876, 1.8207255601882935, 1.0616869926452637, 1.9135093688964844, 0.7487789988517761, 0.5128539204597473, 1.4750169515609741, 0.8850982189178467, 0.6143966317176819, 0.33048155903816223, 0.8587332963943481, 0.9402296543121338, 1.004785418510437, 1.6752076148986816, 1.7095178365707397, 1.3923447132110596, 1.5704922676086426, 1.4007631540298462, 1.4217849969863892, 3.153353691101074, 1.679029941558838, 2.2272634506225586, 2.027761220932007, 2.841043472290039, 0.0, 0.0, -0.0, -0.0, -8.282793998718262, -8.394550323486328, -6.892147064208984, -7.500601291656494, -6.51826286315918, -6.1890177726745605, -6.026678562164307, -5.582924842834473, -5.756284713745117, -5.410963535308838, -6.7567033767700195, -5.204084396362305, -3.955911874771118, -2.8152878284454346, -3.6915841102600098, -3.157695770263672, -2.9847652912139893, -1.8359894752502441, -2.2028534412384033, -2.1231112480163574, -1.5154098272323608, -1.7737699747085571, -1.5189653635025024, -1.1649690866470337, -0.8520785570144653, -0.3368740975856781, 0.07864008098840714, 0.06448589265346527, -0.10750234872102737, 0.300529420375824, 0.17714403569698334, 0.2990924119949341, -0.0065909493714571, 0.8624451756477356, 0.5843997001647949, 1.1221696138381958, 0.5964092016220093, 0.8751155138015747, 0.45217621326446533, 0.6778601408004761, 0.8913889527320862, 1.6376371383666992, 1.2712701559066772, 1.241860270500183, 1.3342530727386475, 0.8028545379638672, 0.644791841506958, 1.5661019086837769, 1.39638090133667, 1.1281676292419434, 1.1737438440322876, 1.8207255601882935, 1.0616869926452637, 1.9135093688964844, 0.7487789988517761, 0.5128539204597473, 1.4750169515609741, 0.8850982189178467, 0.6143966317176819, 0.33048155903816223, 0.8587332963943481, 0.9402296543121338, 1.004785418510437, 1.6752076148986816, 1.7095178365707397, 1.3923447132110596, 1.5704922676086426, 1.4007631540298462, 1.4217849969863892, 3.153353691101074, 1.679029941558838, 2.2272634506225586, 2.027761220932007, 2.841043472290039, 0.0, 0.0], [0.0, -8.922661781311035, -8.314977645874023, -8.387371063232422, -7.798826217651367, -6.724846363067627, -7.230915069580078, -7.764779090881348, -6.575470924377441, -6.683099746704102, -5.6123127937316895, -5.437244415283203, -5.818342685699463, -5.1272783279418945, -4.55672025680542, -4.184182167053223, -4.573887825012207, -3.5265085697174072, -1.5179108381271362, -2.8725905418395996, -1.9591401815414429, -1.5694833993911743, -1.3684839010238647, -1.5546505451202393, -1.0157780647277832, -0.6932998895645142, -0.9586166143417358, -0.8584412336349487, -0.7247304320335388, -0.6959497332572937, 0.20874878764152527, -0.48148369789123535, 0.6280919909477234, 0.33012378215789795, 0.32514917850494385, 0.5427641272544861, 0.5780630707740784, 0.7055877447128296, 0.91524338722229, 1.1143980026245117, 1.5862442255020142, 1.2196860313415527, 1.0075081586837769, 1.328382968902588, 1.2779903411865234, 0.9337896704673767, 1.2426536083221436, 0.9493890404701233, 0.7851687669754028, 0.9369966983795166, 0.8399327993392944, 0.5262102484703064, 0.9983839392662048, 0.8110615611076355, 1.2941654920578003, 1.2083334922790527, 1.0344421863555908, 1.3249249458312988, 1.2442233562469482, 1.0200622081756592, 2.048902750015259, 1.1749852895736694, 1.2604694366455078, 0.7155874371528625, 2.072235107421875, 1.3578037023544312, 1.404295802116394, 1.7655705213546753, 1.6437371969223022, 1.0826176404953003, 1.9630000591278076, 1.204406976699829, 0.8272304534912109, 1.6481316089630127, 1.8285144567489624, 1.673746109008789, 0.0, 0.0, -0.0, -8.922661781311035, -8.314977645874023, -8.387371063232422, -7.798826217651367, -6.724846363067627, -7.230915069580078, -7.764779090881348, -6.575470924377441, -6.683099746704102, -5.6123127937316895, -5.437244415283203, -5.818342685699463, -5.1272783279418945, -4.55672025680542, -4.184182167053223, -4.573887825012207, -3.5265085697174072, -1.5179108381271362, -2.8725905418395996, -1.9591401815414429, -1.5694833993911743, -1.3684839010238647, -1.5546505451202393, -1.0157780647277832, -0.6932998895645142, -0.9586166143417358, -0.8584412336349487, -0.7247304320335388, -0.6959497332572937, 0.20874878764152527, -0.48148369789123535, 0.6280919909477234, 0.33012378215789795, 0.32514917850494385, 0.5427641272544861, 0.5780630707740784, 0.7055877447128296, 0.91524338722229, 1.1143980026245117, 1.5862442255020142, 1.2196860313415527, 1.0075081586837769, 1.328382968902588, 1.2779903411865234, 0.9337896704673767, 1.2426536083221436, 0.9493890404701233, 0.7851687669754028, 0.9369966983795166, 0.8399327993392944, 0.5262102484703064, 0.9983839392662048, 0.8110615611076355, 1.2941654920578003, 1.2083334922790527, 1.0344421863555908, 1.3249249458312988, 1.2442233562469482, 1.0200622081756592, 2.048902750015259, 1.1749852895736694, 1.2604694366455078, 0.7155874371528625, 2.072235107421875, 1.3578037023544312, 1.404295802116394, 1.7655705213546753, 1.6437371969223022, 1.0826176404953003, 1.9630000591278076, 1.204406976699829, 0.8272304534912109, 1.6481316089630127, 1.8285144567489624, 1.673746109008789, 0.0, 0.0], [0.0, -9.043502807617188, -8.573396682739258, -8.487441062927246, -7.357838153839111, -7.655647277832031, -8.524145126342773, -7.147143363952637, -6.560027122497559, -6.241819381713867, -6.255091190338135, -5.7392120361328125, -5.7419114112854, -4.848457336425781, -5.00957727432251, -4.374897480010986, -3.86729097366333, -4.292447090148926, -1.7329485416412354, -2.8112289905548096, -3.0171494483947754, -2.706073522567749, -1.5111991167068481, -2.646878480911255, -1.6365433931350708, -1.3179380893707275, -0.7613641619682312, -0.9242406487464905, -0.4749581217765808, -0.17321832478046417, -0.24505363404750824, -0.9317054748535156, 0.3494584560394287, -1.0267775058746338, 0.019937537610530853, -0.274493008852005, -0.0526149719953537, 0.790886640548706, 1.0144809484481812, 0.6332124471664429, 0.822240948677063, 1.1655707359313965, 1.103691577911377, 0.883866548538208, 1.3621946573257446, 1.1002486944198608, 1.6080248355865479, 1.3424334526062012, 0.9823692440986633, 0.23483096063137054, -0.22440123558044434, 0.5546073913574219, 1.1333063840866089, 1.2098698616027832, 0.6965622901916504, 0.6601928472518921, 1.338935136795044, 0.12471377849578857, 1.1735270023345947, 0.9650282859802246, 1.4816632270812988, 0.8574326038360596, 1.039902687072754, 0.4448343515396118, 0.9333093166351318, 0.31699302792549133, 1.1552574634552002, 0.6163488626480103, 0.7394155859947205, 1.3714962005615234, 0.6421170830726624, 1.349095344543457, 1.7238632440567017, 1.7255375385284424, 2.2884161472320557, 4.984169006347656, 0.0, 0.0, -0.0, -9.043502807617188, -8.573396682739258, -8.487441062927246, -7.357838153839111, -7.655647277832031, -8.524145126342773, -7.147143363952637, -6.560027122497559, -6.241819381713867, -6.255091190338135, -5.7392120361328125, -5.7419114112854, -4.848457336425781, -5.00957727432251, -4.374897480010986, -3.86729097366333, -4.292447090148926, -1.7329485416412354, -2.8112289905548096, -3.0171494483947754, -2.706073522567749, -1.5111991167068481, -2.646878480911255, -1.6365433931350708, -1.3179380893707275, -0.7613641619682312, -0.9242406487464905, -0.4749581217765808, -0.17321832478046417, -0.24505363404750824, -0.9317054748535156, 0.3494584560394287, -1.0267775058746338, 0.019937537610530853, -0.274493008852005, -0.0526149719953537, 0.790886640548706, 1.0144809484481812, 0.6332124471664429, 0.822240948677063, 1.1655707359313965, 1.103691577911377, 0.883866548538208, 1.3621946573257446, 1.1002486944198608, 1.6080248355865479, 1.3424334526062012, 0.9823692440986633, 0.23483096063137054, -0.22440123558044434, 0.5546073913574219, 1.1333063840866089, 1.2098698616027832, 0.6965622901916504, 0.6601928472518921, 1.338935136795044, 0.12471377849578857, 1.1735270023345947, 0.9650282859802246, 1.4816632270812988, 0.8574326038360596, 1.039902687072754, 0.4448343515396118, 0.9333093166351318, 0.31699302792549133, 1.1552574634552002, 0.6163488626480103, 0.7394155859947205, 1.3714962005615234, 0.6421170830726624, 1.349095344543457, 1.7238632440567017, 1.7255375385284424, 2.2884161472320557, 4.984169006347656, 0.0, 0.0], [0.0, -9.413376808166504, -8.346802711486816, -8.049015045166016, -8.787216186523438, -7.515499591827393, -7.609078884124756, -7.66532564163208, -6.3196868896484375, -5.8008904457092285, -5.6910929679870605, -6.572115421295166, -5.496342658996582, -5.3956193923950195, -4.662580490112305, -4.39022970199585, -3.49660325050354, -3.6898319721221924, -3.0684762001037598, -3.2393438816070557, -2.369187831878662, -5.1344170570373535, -2.1188297271728516, -2.2296903133392334, -2.3983616828918457, -1.2602391242980957, -1.7223373651504517, -1.194645881652832, -0.9791393876075745, -1.925601601600647, -0.7025128602981567, -0.25544264912605286, 1.1820968389511108, 0.18528662621974945, 1.0100114345550537, 1.1752716302871704, 0.08264846354722977, -0.08840598911046982, 0.8744773864746094, 0.7436381578445435, 0.7470521926879883, 1.5316916704177856, 1.0921634435653687, 0.676782488822937, 1.0577969551086426, 1.2018251419067383, 1.240178108215332, 0.7356481552124023, 0.37889838218688965, 1.2812174558639526, 0.65040123462677, 1.151430368423462, 1.5667095184326172, 1.103731393814087, 0.8580104112625122, 0.29089242219924927, 1.1461694240570068, 0.2884867489337921, 0.8046677708625793, 1.2316019535064697, 1.2980002164840698, 0.3068952262401581, 0.48637259006500244, 0.7372806072235107, 0.9525346159934998, 0.2565504312515259, 0.37271544337272644, 1.2192792892456055, 0.9222373962402344, 1.3050408363342285, 1.1987724304199219, 1.5541002750396729, 1.8378205299377441, 1.8317980766296387, 2.301259756088257, 2.3115720748901367, 0.0, 0.0, -0.0, -9.413376808166504, -8.346802711486816, -8.049015045166016, -8.787216186523438, -7.515499591827393, -7.609078884124756, -7.66532564163208, -6.3196868896484375, -5.8008904457092285, -5.6910929679870605, -6.572115421295166, -5.496342658996582, -5.3956193923950195, -4.662580490112305, -4.39022970199585, -3.49660325050354, -3.6898319721221924, -3.0684762001037598, -3.2393438816070557, -2.369187831878662, -5.1344170570373535, -2.1188297271728516, -2.2296903133392334, -2.3983616828918457, -1.2602391242980957, -1.7223373651504517, -1.194645881652832, -0.9791393876075745, -1.925601601600647, -0.7025128602981567, -0.25544264912605286, 1.1820968389511108, 0.18528662621974945, 1.0100114345550537, 1.1752716302871704, 0.08264846354722977, -0.08840598911046982, 0.8744773864746094, 0.7436381578445435, 0.7470521926879883, 1.5316916704177856, 1.0921634435653687, 0.676782488822937, 1.0577969551086426, 1.2018251419067383, 1.240178108215332, 0.7356481552124023, 0.37889838218688965, 1.2812174558639526, 0.65040123462677, 1.151430368423462, 1.5667095184326172, 1.103731393814087, 0.8580104112625122, 0.29089242219924927, 1.1461694240570068, 0.2884867489337921, 0.8046677708625793, 1.2316019535064697, 1.2980002164840698, 0.3068952262401581, 0.48637259006500244, 0.7372806072235107, 0.9525346159934998, 0.2565504312515259, 0.37271544337272644, 1.2192792892456055, 0.9222373962402344, 1.3050408363342285, 1.1987724304199219, 1.5541002750396729, 1.8378205299377441, 1.8317980766296387, 2.301259756088257, 2.3115720748901367, 0.0, 0.0], [0.0, -8.540349960327148, -8.84433364868164, -8.392354965209961, -7.987077713012695, -7.4490065574646, -7.480515003204346, -6.613659381866455, -6.426513671875, -7.273474216461182, -6.365328311920166, -5.7919816970825195, -4.893268585205078, -4.624392509460449, -4.788185119628906, -4.09083366394043, -4.003643035888672, -3.0505099296569824, -3.6582603454589844, -3.1057939529418945, -3.758509397506714, -3.0278656482696533, -2.0340514183044434, -2.68624210357666, -1.644594669342041, -0.8753058314323425, -0.9875751733779907, -1.4961365461349487, -0.895759105682373, 0.12179237604141235, -0.6381783485412598, -0.3544164299964905, -0.45030394196510315, -0.5022652745246887, 0.47609415650367737, -0.04290642589330673, 0.8700646162033081, -0.14229409396648407, 1.3307416439056396, 1.0514711141586304, -0.5124679207801819, 0.14956612884998322, 0.8805144429206848, 0.5936790108680725, 0.7009906768798828, 1.0990244150161743, 0.24219708144664764, 0.7303615808486938, 1.5941698551177979, 0.4915967583656311, 0.5113551616668701, 0.7500703930854797, 1.474249005317688, 1.3404196500778198, 1.1649646759033203, -1.3948228359222412, -0.04076383262872696, 0.8568490743637085, -1.1050175428390503, 0.8356809020042419, 0.6042406558990479, -0.3803224563598633, -0.03036772646009922, 0.41670963168144226, 0.12319206446409225, 0.6523132920265198, 1.054253101348877, 0.7197487354278564, 0.5362416505813599, 1.2047247886657715, 1.008081316947937, 0.7225091457366943, 0.9399474263191223, 1.008245587348938, 1.2263572216033936, 1.5763851404190063, 0.0, 0.0, -0.0, -8.540349960327148, -8.84433364868164, -8.392354965209961, -7.987077713012695, -7.4490065574646, -7.480515003204346, -6.613659381866455, -6.426513671875, -7.273474216461182, -6.365328311920166, -5.7919816970825195, -4.893268585205078, -4.624392509460449, -4.788185119628906, -4.09083366394043, -4.003643035888672, -3.0505099296569824, -3.6582603454589844, -3.1057939529418945, -3.758509397506714, -3.0278656482696533, -2.0340514183044434, -2.68624210357666, -1.644594669342041, -0.8753058314323425, -0.9875751733779907, -1.4961365461349487, -0.895759105682373, 0.12179237604141235, -0.6381783485412598, -0.3544164299964905, -0.45030394196510315, -0.5022652745246887, 0.47609415650367737, -0.04290642589330673, 0.8700646162033081, -0.14229409396648407, 1.3307416439056396, 1.0514711141586304, -0.5124679207801819, 0.14956612884998322, 0.8805144429206848, 0.5936790108680725, 0.7009906768798828, 1.0990244150161743, 0.24219708144664764, 0.7303615808486938, 1.5941698551177979, 0.4915967583656311, 0.5113551616668701, 0.7500703930854797, 1.474249005317688, 1.3404196500778198, 1.1649646759033203, -1.3948228359222412, -0.04076383262872696, 0.8568490743637085, -1.1050175428390503, 0.8356809020042419, 0.6042406558990479, -0.3803224563598633, -0.03036772646009922, 0.41670963168144226, 0.12319206446409225, 0.6523132920265198, 1.054253101348877, 0.7197487354278564, 0.5362416505813599, 1.2047247886657715, 1.008081316947937, 0.7225091457366943, 0.9399474263191223, 1.008245587348938, 1.2263572216033936, 1.5763851404190063, 0.0, 0.0], [0.0, -10.266940116882324, -10.178016662597656, -9.0407133102417, -8.651795387268066, -7.907060146331787, -7.722116470336914, -7.495499134063721, -7.117518901824951, -6.270204067230225, -6.213103294372559, -5.600635528564453, -4.784696102142334, -5.759852409362793, -4.940157890319824, -4.583250045776367, -4.178893566131592, -4.384154796600342, -4.272430896759033, -2.946401834487915, -2.8269636631011963, -2.274475574493408, -1.7589343786239624, -1.5436561107635498, -1.0424753427505493, -1.6111218929290771, -0.7416856288909912, -1.7842987775802612, -1.4763963222503662, -4.217233180999756, -0.893502414226532, -0.7534202933311462, -0.8928167223930359, -0.4669552445411682, 0.7503926157951355, 0.10490288585424423, 0.8549891710281372, 1.08082914352417, 2.04337739944458, 0.456644743680954, 0.5744207501411438, 0.6250647306442261, 1.011289358139038, -0.7159451246261597, 0.6748831272125244, 1.0773099660873413, -0.767729640007019, 1.1828237771987915, 0.7058553695678711, -0.18182972073554993, 0.6776044368743896, 3.885448694229126, 1.4902576208114624, 0.6769872903823853, 1.1169216632843018, 0.5116958618164062, 0.8064194917678833, 1.3753557205200195, 1.1034579277038574, 0.7601996064186096, 0.49130621552467346, 1.0842981338500977, 1.2490147352218628, 0.005069892853498459, 0.13203661143779755, 0.20050762593746185, 0.7071226239204407, 0.660057544708252, 1.0074831247329712, 1.6712646484375, 0.8267657160758972, 0.5248273611068726, 1.9478756189346313, 1.3049798011779785, 1.4492591619491577, 2.006781578063965, 0.0, 0.0, -0.0, -10.266940116882324, -10.178016662597656, -9.0407133102417, -8.651795387268066, -7.907060146331787, -7.722116470336914, -7.495499134063721, -7.117518901824951, -6.270204067230225, -6.213103294372559, -5.600635528564453, -4.784696102142334, -5.759852409362793, -4.940157890319824, -4.583250045776367, -4.178893566131592, -4.384154796600342, -4.272430896759033, -2.946401834487915, -2.8269636631011963, -2.274475574493408, -1.7589343786239624, -1.5436561107635498, -1.0424753427505493, -1.6111218929290771, -0.7416856288909912, -1.7842987775802612, -1.4763963222503662, -4.217233180999756, -0.893502414226532, -0.7534202933311462, -0.8928167223930359, -0.4669552445411682, 0.7503926157951355, 0.10490288585424423, 0.8549891710281372, 1.08082914352417, 2.04337739944458, 0.456644743680954, 0.5744207501411438, 0.6250647306442261, 1.011289358139038, -0.7159451246261597, 0.6748831272125244, 1.0773099660873413, -0.767729640007019, 1.1828237771987915, 0.7058553695678711, -0.18182972073554993, 0.6776044368743896, 3.885448694229126, 1.4902576208114624, 0.6769872903823853, 1.1169216632843018, 0.5116958618164062, 0.8064194917678833, 1.3753557205200195, 1.1034579277038574, 0.7601996064186096, 0.49130621552467346, 1.0842981338500977, 1.2490147352218628, 0.005069892853498459, 0.13203661143779755, 0.20050762593746185, 0.7071226239204407, 0.660057544708252, 1.0074831247329712, 1.6712646484375, 0.8267657160758972, 0.5248273611068726, 1.9478756189346313, 1.3049798011779785, 1.4492591619491577, 2.006781578063965, 0.0, 0.0], [0.0, -9.918686866760254, -9.42081356048584, -9.227666854858398, -8.339009284973145, -8.408885955810547, -8.092287063598633, -7.684771537780762, -6.638497352600098, -6.237979412078857, -6.419098854064941, -6.6061553955078125, -6.492392063140869, -6.258371829986572, -5.14092493057251, -4.265668869018555, -4.512296199798584, -3.652106761932373, -4.452937602996826, -3.77557635307312, -3.216702699661255, -2.5393564701080322, -1.6160361766815186, -2.914945125579834, -2.0451760292053223, -2.218625545501709, -1.5451881885528564, -1.5713821649551392, -1.3646726608276367, -2.5273609161376953, -1.9213014841079712, -0.6152248382568359, -0.32641637325286865, -0.4680490791797638, -0.5324705839157104, -0.20281609892845154, 1.412405014038086, 0.8711271286010742, 2.450552463531494, 1.4064369201660156, 1.0217522382736206, 0.09656284749507904, -0.19049839675426483, 0.7337321043014526, 1.1288882493972778, 1.4862899780273438, 0.7424150705337524, 0.7838773727416992, -0.5155757069587708, -0.4788064658641815, 0.5973015427589417, 1.5231338739395142, 0.3585198223590851, 0.8201970458030701, 1.6491366624832153, 0.3834124505519867, 0.2688373029232025, -0.41676270961761475, -0.1360495686531067, 1.0537652969360352, 0.41317498683929443, -0.9118866920471191, 0.15637584030628204, 1.384601354598999, 0.0840064287185669, 0.22710305452346802, 0.4825575053691864, -0.3539256751537323, 0.8708471059799194, 0.9441601634025574, 1.0280174016952515, 0.6781577467918396, 1.278283953666687, 0.7596490979194641, 0.9990290403366089, 0.3756886124610901, 0.0, 0.0, -0.0, -9.918686866760254, -9.42081356048584, -9.227666854858398, -8.339009284973145, -8.408885955810547, -8.092287063598633, -7.684771537780762, -6.638497352600098, -6.237979412078857, -6.419098854064941, -6.6061553955078125, -6.492392063140869, -6.258371829986572, -5.14092493057251, -4.265668869018555, -4.512296199798584, -3.652106761932373, -4.452937602996826, -3.77557635307312, -3.216702699661255, -2.5393564701080322, -1.6160361766815186, -2.914945125579834, -2.0451760292053223, -2.218625545501709, -1.5451881885528564, -1.5713821649551392, -1.3646726608276367, -2.5273609161376953, -1.9213014841079712, -0.6152248382568359, -0.32641637325286865, -0.4680490791797638, -0.5324705839157104, -0.20281609892845154, 1.412405014038086, 0.8711271286010742, 2.450552463531494, 1.4064369201660156, 1.0217522382736206, 0.09656284749507904, -0.19049839675426483, 0.7337321043014526, 1.1288882493972778, 1.4862899780273438, 0.7424150705337524, 0.7838773727416992, -0.5155757069587708, -0.4788064658641815, 0.5973015427589417, 1.5231338739395142, 0.3585198223590851, 0.8201970458030701, 1.6491366624832153, 0.3834124505519867, 0.2688373029232025, -0.41676270961761475, -0.1360495686531067, 1.0537652969360352, 0.41317498683929443, -0.9118866920471191, 0.15637584030628204, 1.384601354598999, 0.0840064287185669, 0.22710305452346802, 0.4825575053691864, -0.3539256751537323, 0.8708471059799194, 0.9441601634025574, 1.0280174016952515, 0.6781577467918396, 1.278283953666687, 0.7596490979194641, 0.9990290403366089, 0.3756886124610901, 0.0, 0.0], [0.0, -9.034579277038574, -9.383193016052246, -9.16247272491455, -8.983112335205078, -8.358197212219238, -8.147621154785156, -6.2041215896606445, -8.112152099609375, -7.111090660095215, -6.572051048278809, -6.128321647644043, -6.511997699737549, -5.787961483001709, -5.627007961273193, -5.174672603607178, -5.2071404457092285, -3.841745615005493, -4.112181663513184, -3.8185617923736572, -3.8987574577331543, -2.883397102355957, -2.2799413204193115, -2.104372024536133, -1.8085811138153076, -3.222851037979126, -1.592347264289856, -2.007613182067871, -1.804955244064331, -1.527414083480835, -1.652976632118225, -1.3729991912841797, 0.09841133654117584, -0.9394389390945435, 0.27443021535873413, 0.05243982747197151, 0.3293476700782776, -0.786244809627533, 0.1779319792985916, 1.9408293962478638, 1.6568626165390015, 0.3237602114677429, -0.2761921286582947, 0.5355486869812012, 0.05603193864226341, 0.7344635725021362, 0.17722131311893463, -0.46379557251930237, 0.7305794358253479, 0.8656567335128784, 0.672673225402832, 1.3238444328308105, 1.0062464475631714, 1.131596565246582, 0.27150440216064453, 0.6305460333824158, 0.7060840129852295, 0.33704322576522827, 0.6998577117919922, 0.6352955102920532, 0.5220891237258911, 0.23816779255867004, -0.5290006995201111, 1.0933046340942383, 0.42783626914024353, 0.8871166706085205, 0.14841468632221222, -0.24294652044773102, 0.3907088041305542, 0.9116450548171997, 0.25740838050842285, 0.910744845867157, 0.31409287452697754, 0.10316949337720871, 0.6294222474098206, 1.1390256881713867, 0.0, 0.0, -0.0, -9.034579277038574, -9.383193016052246, -9.16247272491455, -8.983112335205078, -8.358197212219238, -8.147621154785156, -6.2041215896606445, -8.112152099609375, -7.111090660095215, -6.572051048278809, -6.128321647644043, -6.511997699737549, -5.787961483001709, -5.627007961273193, -5.174672603607178, -5.2071404457092285, -3.841745615005493, -4.112181663513184, -3.8185617923736572, -3.8987574577331543, -2.883397102355957, -2.2799413204193115, -2.104372024536133, -1.8085811138153076, -3.222851037979126, -1.592347264289856, -2.007613182067871, -1.804955244064331, -1.527414083480835, -1.652976632118225, -1.3729991912841797, 0.09841133654117584, -0.9394389390945435, 0.27443021535873413, 0.05243982747197151, 0.3293476700782776, -0.786244809627533, 0.1779319792985916, 1.9408293962478638, 1.6568626165390015, 0.3237602114677429, -0.2761921286582947, 0.5355486869812012, 0.05603193864226341, 0.7344635725021362, 0.17722131311893463, -0.46379557251930237, 0.7305794358253479, 0.8656567335128784, 0.672673225402832, 1.3238444328308105, 1.0062464475631714, 1.131596565246582, 0.27150440216064453, 0.6305460333824158, 0.7060840129852295, 0.33704322576522827, 0.6998577117919922, 0.6352955102920532, 0.5220891237258911, 0.23816779255867004, -0.5290006995201111, 1.0933046340942383, 0.42783626914024353, 0.8871166706085205, 0.14841468632221222, -0.24294652044773102, 0.3907088041305542, 0.9116450548171997, 0.25740838050842285, 0.910744845867157, 0.31409287452697754, 0.10316949337720871, 0.6294222474098206, 1.1390256881713867, 0.0, 0.0], [0.0, -10.5675630569458, -9.2445650100708, -9.282892227172852, -9.323142051696777, -9.073906898498535, -8.810064315795898, -8.978788375854492, -7.609598636627197, -8.321250915527344, -6.433879375457764, -7.243065357208252, -6.013421058654785, -6.016979694366455, -4.165529251098633, -5.221661567687988, -4.724193096160889, -3.6248409748077393, -4.5999650955200195, -3.312340497970581, -3.966670274734497, -3.4669244289398193, -2.212937355041504, -1.8581948280334473, -2.02919864654541, -2.2599167823791504, -2.038243293762207, -2.1616153717041016, -1.608758568763733, -1.071887731552124, -1.0907326936721802, -0.8846847414970398, -0.8931092023849487, -0.48467814922332764, -0.014285176992416382, -0.09234693646430969, -0.4766325056552887, -1.255096435546875, 1.0837763547897339, 0.23825521767139435, 0.50297611951828, -0.03554707020521164, 0.6302180290222168, 0.7488717436790466, 0.781470537185669, 0.9148753881454468, 0.22687286138534546, -0.03167512267827988, -0.6921130418777466, -0.20415768027305603, 1.0661524534225464, 2.0549049377441406, 0.7468354105949402, 0.19303587079048157, 1.2449820041656494, 0.3786492347717285, 0.45256608724594116, -1.3095961809158325, -0.7030741572380066, 1.4004155397415161, 0.38312238454818726, -0.3867740333080292, -0.2874806225299835, -0.7371934056282043, 0.18558776378631592, 0.26932671666145325, -0.3518858850002289, 0.5509033203125, -0.0532035268843174, 0.04798003286123276, -0.1380794495344162, 1.2712311744689941, 0.4701380133628845, 0.4774797558784485, 0.4147000014781952, 1.6638855934143066, 0.0, 0.0, -0.0, -10.5675630569458, -9.2445650100708, -9.282892227172852, -9.323142051696777, -9.073906898498535, -8.810064315795898, -8.978788375854492, -7.609598636627197, -8.321250915527344, -6.433879375457764, -7.243065357208252, -6.013421058654785, -6.016979694366455, -4.165529251098633, -5.221661567687988, -4.724193096160889, -3.6248409748077393, -4.5999650955200195, -3.312340497970581, -3.966670274734497, -3.4669244289398193, -2.212937355041504, -1.8581948280334473, -2.02919864654541, -2.2599167823791504, -2.038243293762207, -2.1616153717041016, -1.608758568763733, -1.071887731552124, -1.0907326936721802, -0.8846847414970398, -0.8931092023849487, -0.48467814922332764, -0.014285176992416382, -0.09234693646430969, -0.4766325056552887, -1.255096435546875, 1.0837763547897339, 0.23825521767139435, 0.50297611951828, -0.03554707020521164, 0.6302180290222168, 0.7488717436790466, 0.781470537185669, 0.9148753881454468, 0.22687286138534546, -0.03167512267827988, -0.6921130418777466, -0.20415768027305603, 1.0661524534225464, 2.0549049377441406, 0.7468354105949402, 0.19303587079048157, 1.2449820041656494, 0.3786492347717285, 0.45256608724594116, -1.3095961809158325, -0.7030741572380066, 1.4004155397415161, 0.38312238454818726, -0.3867740333080292, -0.2874806225299835, -0.7371934056282043, 0.18558776378631592, 0.26932671666145325, -0.3518858850002289, 0.5509033203125, -0.0532035268843174, 0.04798003286123276, -0.1380794495344162, 1.2712311744689941, 0.4701380133628845, 0.4774797558784485, 0.4147000014781952, 1.6638855934143066, 0.0, 0.0], [0.0, -10.599794387817383, -10.444924354553223, -10.088059425354004, -10.181902885437012, -8.631765365600586, -8.365377426147461, -8.102560997009277, -7.894455909729004, -7.877384185791016, -7.91541862487793, -6.067800998687744, -7.226276874542236, -6.533536911010742, -6.126345157623291, -4.760765552520752, -4.427130222320557, -5.227803707122803, -4.544413089752197, -2.8421895503997803, -3.413640022277832, -3.3707778453826904, -3.653872489929199, -2.780762195587158, -2.0078043937683105, -1.7827776670455933, -2.3932487964630127, -1.7288048267364502, -2.0999245643615723, -1.6779519319534302, -0.892218828201294, -0.9964911937713623, -0.9013440012931824, -1.3557884693145752, -1.4733506441116333, -0.47101595997810364, -0.25821489095687866, 0.37776729464530945, 0.7146806120872498, 0.0, 0.7905756235122681, -0.1197897419333458, -0.44671115279197693, 1.4995535612106323, 0.010152919217944145, 0.25584641098976135, -0.0787041112780571, -0.6812354922294617, -0.48613518476486206, -0.039331112056970596, 0.35580238699913025, 0.47383806109428406, 0.7408276200294495, 0.37201082706451416, 0.8333954215049744, 0.9164647459983826, -0.24278691411018372, 0.7502147555351257, 0.4059930145740509, 1.4823417663574219, -0.49000054597854614, 0.24153801798820496, -0.17440100014209747, -0.7162361145019531, 0.47366052865982056, 0.4248155653476715, 0.36285364627838135, -0.5603371262550354, -1.307242751121521, -0.8918105363845825, 0.7799789905548096, 0.04951375350356102, 0.2720712721347809, 0.8011839985847473, 0.6362073421478271, 0.6586443781852722, 0.0, 0.0, -0.0, -10.599794387817383, -10.444924354553223, -10.088059425354004, -10.181902885437012, -8.631765365600586, -8.365377426147461, -8.102560997009277, -7.894455909729004, -7.877384185791016, -7.91541862487793, -6.067800998687744, -7.226276874542236, -6.533536911010742, -6.126345157623291, -4.760765552520752, -4.427130222320557, -5.227803707122803, -4.544413089752197, -2.8421895503997803, -3.413640022277832, -3.3707778453826904, -3.653872489929199, -2.780762195587158, -2.0078043937683105, -1.7827776670455933, -2.3932487964630127, -1.7288048267364502, -2.0999245643615723, -1.6779519319534302, -0.892218828201294, -0.9964911937713623, -0.9013440012931824, -1.3557884693145752, -1.4733506441116333, -0.47101595997810364, -0.25821489095687866, 0.37776729464530945, 0.7146806120872498, 0.0, 0.7905756235122681, -0.1197897419333458, -0.44671115279197693, 1.4995535612106323, 0.010152919217944145, 0.25584641098976135, -0.0787041112780571, -0.6812354922294617, -0.48613518476486206, -0.039331112056970596, 0.35580238699913025, 0.47383806109428406, 0.7408276200294495, 0.37201082706451416, 0.8333954215049744, 0.9164647459983826, -0.24278691411018372, 0.7502147555351257, 0.4059930145740509, 1.4823417663574219, -0.49000054597854614, 0.24153801798820496, -0.17440100014209747, -0.7162361145019531, 0.47366052865982056, 0.4248155653476715, 0.36285364627838135, -0.5603371262550354, -1.307242751121521, -0.8918105363845825, 0.7799789905548096, 0.04951375350356102, 0.2720712721347809, 0.8011839985847473, 0.6362073421478271, 0.6586443781852722, 0.0, 0.0], [0.0, -11.700591087341309, -10.593091011047363, -10.253933906555176, -9.697681427001953, -10.289514541625977, -9.658916473388672, -9.225083351135254, -8.37089729309082, -7.893122673034668, -5.94987154006958, -6.750770568847656, -6.659271717071533, -6.287342071533203, -5.835124492645264, -5.600126266479492, -5.077733516693115, -4.699639797210693, -3.855282783508301, -3.821376085281372, -3.119555711746216, -3.5115177631378174, -3.5065271854400635, -3.4714231491088867, -2.05527925491333, -1.6087628602981567, -2.9170033931732178, -2.6376242637634277, -1.2447655200958252, -2.053129196166992, -1.6872119903564453, -1.4095289707183838, -0.5898191332817078, -1.4271841049194336, -0.5581842660903931, -0.2951756417751312, -0.11756128817796707, -1.0350185632705688, -0.33104345202445984, -1.205438494682312, -0.8540744781494141, -0.5060874819755554, 0.32600271701812744, -0.8121488690376282, 0.6960760354995728, 3.4689524173736572, -0.18430253863334656, 0.1623627245426178, 0.45498451590538025, 0.47899702191352844, -0.9511038661003113, 2.359048366546631, 0.3290446102619171, -0.4129614233970642, 0.3753780126571655, -0.5564715266227722, -2.2924680709838867, 0.26960060000419617, 0.4990489184856415, 0.29395592212677, -0.573345422744751, -0.23134522140026093, -2.630265235900879, -0.6788579225540161, -0.18082240223884583, -1.4805623292922974, 0.21703961491584778, -0.359152615070343, -0.5141921043395996, -0.4226818084716797, 0.014398915693163872, -0.2223108410835266, 0.09487879276275635, -0.031631745398044586, -0.6761108636856079, 0.5279542803764343, 0.0, 0.0, -0.0, -11.700591087341309, -10.593091011047363, -10.253933906555176, -9.697681427001953, -10.289514541625977, -9.658916473388672, -9.225083351135254, -8.37089729309082, -7.893122673034668, -5.94987154006958, -6.750770568847656, -6.659271717071533, -6.287342071533203, -5.835124492645264, -5.600126266479492, -5.077733516693115, -4.699639797210693, -3.855282783508301, -3.821376085281372, -3.119555711746216, -3.5115177631378174, -3.5065271854400635, -3.4714231491088867, -2.05527925491333, -1.6087628602981567, -2.9170033931732178, -2.6376242637634277, -1.2447655200958252, -2.053129196166992, -1.6872119903564453, -1.4095289707183838, -0.5898191332817078, -1.4271841049194336, -0.5581842660903931, -0.2951756417751312, -0.11756128817796707, -1.0350185632705688, -0.33104345202445984, -1.205438494682312, -0.8540744781494141, -0.5060874819755554, 0.32600271701812744, -0.8121488690376282, 0.6960760354995728, 3.4689524173736572, -0.18430253863334656, 0.1623627245426178, 0.45498451590538025, 0.47899702191352844, -0.9511038661003113, 2.359048366546631, 0.3290446102619171, -0.4129614233970642, 0.3753780126571655, -0.5564715266227722, -2.2924680709838867, 0.26960060000419617, 0.4990489184856415, 0.29395592212677, -0.573345422744751, -0.23134522140026093, -2.630265235900879, -0.6788579225540161, -0.18082240223884583, -1.4805623292922974, 0.21703961491584778, -0.359152615070343, -0.5141921043395996, -0.4226818084716797, 0.014398915693163872, -0.2223108410835266, 0.09487879276275635, -0.031631745398044586, -0.6761108636856079, 0.5279542803764343, 0.0, 0.0], [0.0, -12.271601676940918, -10.883404731750488, -10.84719181060791, -9.65027141571045, -10.476186752319336, -9.310689926147461, -8.130188941955566, -8.190561294555664, -7.705351829528809, -8.153985977172852, -7.086683750152588, -6.89281702041626, -5.896981239318848, -5.902634620666504, -3.7481741905212402, -4.874443054199219, -4.891871452331543, -3.376389980316162, -3.832260847091675, -3.929410696029663, -2.59439754486084, -3.752514600753784, -4.145080089569092, -2.397026777267456, -2.3309481143951416, -1.2343193292617798, -2.3601174354553223, -1.9125913381576538, -2.1031203269958496, -3.4775166511535645, -2.0242362022399902, -1.8494806289672852, -0.678099513053894, -3.9339094161987305, -2.290922164916992, -0.6118025779724121, 1.0914181470870972, -1.2128968238830566, -1.30755615234375, -0.9073556661605835, -0.8259810209274292, -1.5344403982162476, -0.8264259696006775, -0.2602737843990326, 1.285749912261963, 0.48271623253822327, 0.4942518174648285, -1.2573468685150146, -0.28301599621772766, -0.34784671664237976, 0.05457712337374687, 0.05268728733062744, 0.04745851457118988, -0.6150332689285278, -0.3175402283668518, -0.0723506286740303, -0.9695966839790344, 0.6157482266426086, -0.4177396893501282, 0.29886171221733093, 0.3621198832988739, -0.2810986638069153, -0.03820418566465378, 1.1381001472473145, -0.30710160732269287, -0.9052833318710327, -0.1399431973695755, 0.022799167782068253, -0.32628190517425537, -0.28648462891578674, -0.11615263670682907, -0.06623735278844833, -0.5751633048057556, -0.1251845359802246, -1.418237566947937, 0.0, 0.0, -0.0, -12.271601676940918, -10.883404731750488, -10.84719181060791, -9.65027141571045, -10.476186752319336, -9.310689926147461, -8.130188941955566, -8.190561294555664, -7.705351829528809, -8.153985977172852, -7.086683750152588, -6.89281702041626, -5.896981239318848, -5.902634620666504, -3.7481741905212402, -4.874443054199219, -4.891871452331543, -3.376389980316162, -3.832260847091675, -3.929410696029663, -2.59439754486084, -3.752514600753784, -4.145080089569092, -2.397026777267456, -2.3309481143951416, -1.2343193292617798, -2.3601174354553223, -1.9125913381576538, -2.1031203269958496, -3.4775166511535645, -2.0242362022399902, -1.8494806289672852, -0.678099513053894, -3.9339094161987305, -2.290922164916992, -0.6118025779724121, 1.0914181470870972, -1.2128968238830566, -1.30755615234375, -0.9073556661605835, -0.8259810209274292, -1.5344403982162476, -0.8264259696006775, -0.2602737843990326, 1.285749912261963, 0.48271623253822327, 0.4942518174648285, -1.2573468685150146, -0.28301599621772766, -0.34784671664237976, 0.05457712337374687, 0.05268728733062744, 0.04745851457118988, -0.6150332689285278, -0.3175402283668518, -0.0723506286740303, -0.9695966839790344, 0.6157482266426086, -0.4177396893501282, 0.29886171221733093, 0.3621198832988739, -0.2810986638069153, -0.03820418566465378, 1.1381001472473145, -0.30710160732269287, -0.9052833318710327, -0.1399431973695755, 0.022799167782068253, -0.32628190517425537, -0.28648462891578674, -0.11615263670682907, -0.06623735278844833, -0.5751633048057556, -0.1251845359802246, -1.418237566947937, -0.0, -0.0], [0.0, -12.666220664978027, -11.8888578414917, -11.813849449157715, -10.557209014892578, -9.366559028625488, -9.119095802307129, -7.600625038146973, -9.629846572875977, -9.002928733825684, -7.9895339012146, -7.133487224578857, -7.004805088043213, -5.757791996002197, -7.861070156097412, -5.5337300300598145, -6.140498638153076, -3.082554578781128, -4.0038838386535645, -4.929450988769531, -3.2780652046203613, -2.8395211696624756, -3.645226001739502, -3.3637301921844482, -3.333327293395996, -1.2368379831314087, -1.9738153219223022, -2.412322998046875, -1.054141640663147, -2.566884756088257, -2.4156172275543213, -2.4739573001861572, -1.649720549583435, -1.3359761238098145, -2.153637409210205, -1.0820528268814087, -1.1116496324539185, -0.9443908929824829, -0.39103931188583374, -1.5759625434875488, -1.131763219833374, -1.6759434938430786, -1.3274649381637573, -0.8011660575866699, -0.803003191947937, -0.9419782161712646, 0.4864251911640167, -0.12323655933141708, -0.943684995174408, 0.6197295188903809, 0.5726086497306824, 0.7382109761238098, -0.5673215389251709, 0.09957128018140793, 0.4904625713825226, -0.9817176461219788, -1.1807854175567627, -0.6473714709281921, 0.2145293802022934, -0.4863353371620178, -0.31583172082901, -0.364821195602417, -0.7042933106422424, 0.018138043582439423, -0.1465139538049698, -0.25581109523773193, -0.5714921355247498, -1.0817965269088745, 0.5092297792434692, -0.3476831316947937, -0.011287089437246323, -1.1018508672714233, -0.7308732271194458, -0.9566828608512878, -0.5845927596092224, -1.3193652629852295, 0.0, 0.0, -0.0, -12.666220664978027, -11.8888578414917, -11.813849449157715, -10.557209014892578, -9.366559028625488, -9.119095802307129, -7.600625038146973, -9.629846572875977, -9.002928733825684, -7.9895339012146, -7.133487224578857, -7.004805088043213, -5.757791996002197, -7.861070156097412, -5.5337300300598145, -6.140498638153076, -3.082554578781128, -4.0038838386535645, -4.929450988769531, -3.2780652046203613, -2.8395211696624756, -3.645226001739502, -3.3637301921844482, -3.333327293395996, -1.2368379831314087, -1.9738153219223022, -2.412322998046875, -1.054141640663147, -2.566884756088257, -2.4156172275543213, -2.4739573001861572, -1.649720549583435, -1.3359761238098145, -2.153637409210205, -1.0820528268814087, -1.1116496324539185, -0.9443908929824829, -0.39103931188583374, -1.5759625434875488, -1.131763219833374, -1.6759434938430786, -1.3274649381637573, -0.8011660575866699, -0.803003191947937, -0.9419782161712646, 0.4864251911640167, -0.12323655933141708, -0.943684995174408, 0.6197295188903809, 0.5726086497306824, 0.7382109761238098, -0.5673215389251709, 0.09957128018140793, 0.4904625713825226, -0.9817176461219788, -1.1807854175567627, -0.6473714709281921, 0.2145293802022934, -0.4863353371620178, -0.31583172082901, -0.364821195602417, -0.7042933106422424, 0.018138043582439423, -0.1465139538049698, -0.25581109523773193, -0.5714921355247498, -1.0817965269088745, 0.5092297792434692, -0.3476831316947937, -0.011287089437246323, -1.1018508672714233, -0.7308732271194458, -0.9566828608512878, -0.5845927596092224, -1.3193652629852295, -0.0, -0.0], [0.0, -10.90014934539795, -12.342083930969238, -11.988980293273926, -11.476744651794434, -10.922204971313477, -9.858207702636719, -8.245626449584961, -8.893189430236816, -7.993913173675537, -7.432033061981201, -6.608216762542725, -7.239717960357666, -6.634826183319092, -6.357583045959473, -5.6833086013793945, -5.114004135131836, -4.55621862411499, -5.283193111419678, -5.263189792633057, -3.5136852264404297, -3.435544013977051, -4.877022743225098, -3.357708215713501, -2.904940605163574, -2.4778685569763184, -2.5924019813537598, -1.3986635208129883, -2.0955851078033447, -2.003476619720459, -1.6021313667297363, -2.120234489440918, -1.5528570413589478, -4.227473258972168, -2.317085027694702, -1.2662265300750732, -1.481405258178711, -1.6757608652114868, -1.858936071395874, -1.669521689414978, -1.4197343587875366, -1.033517837524414, -2.034444808959961, -1.2371599674224854, -0.8943788409233093, -1.0147645473480225, -0.4872320592403412, -0.48120585083961487, -0.691439151763916, -0.5125254392623901, 2.7660093307495117, 0.36596885323524475, 0.5323152542114258, -0.8912860155105591, -2.228533983230591, 1.4386128187179565, -0.8894527554512024, -0.18429341912269592, -0.2035505175590515, 1.4880378246307373, 0.6878300309181213, -0.2493910938501358, 0.023945167660713196, -0.006273329723626375, 0.5042954683303833, -0.3353702425956726, -0.28310880064964294, -0.5823296308517456, -0.33343639969825745, -0.7635083198547363, -0.007754714228212833, -1.0143839120864868, -0.6363188028335571, -0.8668010234832764, 0.6522508859634399, -1.220949649810791, 0.0, 0.0, -0.0, -10.90014934539795, -12.342083930969238, -11.988980293273926, -11.476744651794434, -10.922204971313477, -9.858207702636719, -8.245626449584961, -8.893189430236816, -7.993913173675537, -7.432033061981201, -6.608216762542725, -7.239717960357666, -6.634826183319092, -6.357583045959473, -5.6833086013793945, -5.114004135131836, -4.55621862411499, -5.283193111419678, -5.263189792633057, -3.5136852264404297, -3.435544013977051, -4.877022743225098, -3.357708215713501, -2.904940605163574, -2.4778685569763184, -2.5924019813537598, -1.3986635208129883, -2.0955851078033447, -2.003476619720459, -1.6021313667297363, -2.120234489440918, -1.5528570413589478, -4.227473258972168, -2.317085027694702, -1.2662265300750732, -1.481405258178711, -1.6757608652114868, -1.858936071395874, -1.669521689414978, -1.4197343587875366, -1.033517837524414, -2.034444808959961, -1.2371599674224854, -0.8943788409233093, -1.0147645473480225, -0.4872320592403412, -0.48120585083961487, -0.691439151763916, -0.5125254392623901, 2.7660093307495117, 0.36596885323524475, 0.5323152542114258, -0.8912860155105591, -2.228533983230591, 1.4386128187179565, -0.8894527554512024, -0.18429341912269592, -0.2035505175590515, 1.4880378246307373, 0.6878300309181213, -0.2493910938501358, 0.023945167660713196, -0.006273329723626375, 0.5042954683303833, -0.3353702425956726, -0.28310880064964294, -0.5823296308517456, -0.33343639969825745, -0.7635083198547363, -0.007754714228212833, -1.0143839120864868, -0.6363188028335571, -0.8668010234832764, 0.6522508859634399, -1.220949649810791, -0.0, -0.0], [0.0, -12.275111198425293, -12.88188648223877, -11.906039237976074, -11.1201753616333, -10.662679672241211, -10.337127685546875, -10.354703903198242, -9.622551918029785, -9.231468200683594, -9.547245025634766, -8.062273025512695, -8.015393257141113, -8.106219291687012, -5.93858528137207, -5.96720552444458, -5.2579545974731445, -5.643604278564453, -4.799520492553711, -4.201652526855469, -5.227672100067139, -3.511925458908081, -4.517301559448242, -3.580371141433716, -3.381722927093506, -2.136530876159668, -2.252312183380127, -1.8398809432983398, -1.2379744052886963, -3.155075788497925, -2.6957595348358154, -2.5172085762023926, -0.041075896471738815, -1.8578779697418213, -2.7227349281311035, -2.1076245307922363, -2.8277974128723145, -0.9946491122245789, -2.198770761489868, -1.846280574798584, -2.1087074279785156, -2.4912970066070557, -1.565160870552063, -1.6696773767471313, 0.602302074432373, -2.219348192214966, -0.820214569568634, -0.46040743589401245, -0.873449444770813, -0.759795069694519, -0.4785749614238739, -1.2167309522628784, -0.3867608308792114, 0.0854889377951622, -1.0298800468444824, -0.9572363495826721, -0.45244893431663513, -0.4682311713695526, -0.9491555094718933, 0.0838870257139206, -1.048012137413025, -0.5258676409721375, -0.2864134609699249, 0.18670520186424255, -0.18852093815803528, -0.8770225048065186, -0.5271879434585571, 0.6399144530296326, -0.4811897873878479, -1.0304263830184937, -0.9872441291809082, -0.93635493516922, -0.8675354719161987, -1.2553642988204956, -3.671492576599121, 0.0, 0.0, 0.0, -0.0, -12.275111198425293, -12.88188648223877, -11.906039237976074, -11.1201753616333, -10.662679672241211, -10.337127685546875, -10.354703903198242, -9.622551918029785, -9.231468200683594, -9.547245025634766, -8.062273025512695, -8.015393257141113, -8.106219291687012, -5.93858528137207, -5.96720552444458, -5.2579545974731445, -5.643604278564453, -4.799520492553711, -4.201652526855469, -5.227672100067139, -3.511925458908081, -4.517301559448242, -3.580371141433716, -3.381722927093506, -2.136530876159668, -2.252312183380127, -1.8398809432983398, -1.2379744052886963, -3.155075788497925, -2.6957595348358154, -2.5172085762023926, -0.041075896471738815, -1.8578779697418213, -2.7227349281311035, -2.1076245307922363, -2.8277974128723145, -0.9946491122245789, -2.198770761489868, -1.846280574798584, -2.1087074279785156, -2.4912970066070557, -1.565160870552063, -1.6696773767471313, 0.602302074432373, -2.219348192214966, -0.820214569568634, -0.46040743589401245, -0.873449444770813, -0.759795069694519, -0.4785749614238739, -1.2167309522628784, -0.3867608308792114, 0.0854889377951622, -1.0298800468444824, -0.9572363495826721, -0.45244893431663513, -0.4682311713695526, -0.9491555094718933, 0.0838870257139206, -1.048012137413025, -0.5258676409721375, -0.2864134609699249, 0.18670520186424255, -0.18852093815803528, -0.8770225048065186, -0.5271879434585571, 0.6399144530296326, -0.4811897873878479, -1.0304263830184937, -0.9872441291809082, -0.93635493516922, -0.8675354719161987, -1.2553642988204956, -3.671492576599121, -0.0, -0.0, -0.0], [0.0, -14.02812385559082, -13.744866371154785, -12.97061824798584, -12.25536060333252, -10.077600479125977, -10.842626571655273, -10.486809730529785, -10.458220481872559, -8.279285430908203, -8.62745475769043, -7.028777122497559, -7.461307048797607, -7.440298080444336, -6.908271789550781, -6.03171968460083, -5.8929362297058105, -6.267478942871094, -4.851850986480713, -4.484810829162598, -3.7892940044403076, -2.8461053371429443, -5.17345666885376, -3.813004493713379, -4.168650150299072, -3.361215591430664, -2.0698413848876953, -1.237639307975769, -1.9224048852920532, -2.7728121280670166, -2.1967568397521973, -1.8039088249206543, -1.9672573804855347, -2.8172836303710938, -3.2882471084594727, -2.7596049308776855, -1.8971712589263916, -3.4914331436157227, -1.9433501958847046, -2.3905978202819824, -2.5593910217285156, -2.2904367446899414, -1.9898096323013306, -1.74953031539917, -0.7422255277633667, -2.277348518371582, -1.090843915939331, -1.4885810613632202, -3.6883962154388428, 0.5326458215713501, -0.2609502673149109, -0.39122000336647034, -0.6428320407867432, -0.23752988874912262, -0.18769571185112, -1.445357084274292, -1.3783611059188843, -0.3884695768356323, -3.688507080078125, -0.9024553298950195, -0.7548521161079407, -0.19558721780776978, -0.10071991384029388, -0.16212107241153717, -0.5284971594810486, -0.8360251188278198, -0.06065613403916359, -0.6739217042922974, -1.05190908908844, -2.2020747661590576, -0.6038516759872437, -0.6236119270324707, -1.3389184474945068, -1.8979485034942627, -2.966217517852783, 0.0, 0.0, 0.0, -0.0, -14.02812385559082, -13.744866371154785, -12.97061824798584, -12.25536060333252, -10.077600479125977, -10.842626571655273, -10.486809730529785, -10.458220481872559, -8.279285430908203, -8.62745475769043, -7.028777122497559, -7.461307048797607, -7.440298080444336, -6.908271789550781, -6.03171968460083, -5.8929362297058105, -6.267478942871094, -4.851850986480713, -4.484810829162598, -3.7892940044403076, -2.8461053371429443, -5.17345666885376, -3.813004493713379, -4.168650150299072, -3.361215591430664, -2.0698413848876953, -1.237639307975769, -1.9224048852920532, -2.7728121280670166, -2.1967568397521973, -1.8039088249206543, -1.9672573804855347, -2.8172836303710938, -3.2882471084594727, -2.7596049308776855, -1.8971712589263916, -3.4914331436157227, -1.9433501958847046, -2.3905978202819824, -2.5593910217285156, -2.2904367446899414, -1.9898096323013306, -1.74953031539917, -0.7422255277633667, -2.277348518371582, -1.090843915939331, -1.4885810613632202, -3.6883962154388428, 0.5326458215713501, -0.2609502673149109, -0.39122000336647034, -0.6428320407867432, -0.23752988874912262, -0.18769571185112, -1.445357084274292, -1.3783611059188843, -0.3884695768356323, -3.688507080078125, -0.9024553298950195, -0.7548521161079407, -0.19558721780776978, -0.10071991384029388, -0.16212107241153717, -0.5284971594810486, -0.8360251188278198, -0.06065613403916359, -0.6739217042922974, -1.05190908908844, -2.2020747661590576, -0.6038516759872437, -0.6236119270324707, -1.3389184474945068, -1.8979485034942627, -2.966217517852783, -0.0, -0.0, -0.0], [0.0, -16.59990882873535, -14.555431365966797, -13.487517356872559, -12.092549324035645, -10.783303260803223, -10.808534622192383, -10.25872802734375, -9.433135986328125, -9.329607963562012, -10.517660140991211, -7.75514030456543, -7.966167449951172, -7.524071216583252, -6.257869720458984, -6.690051078796387, -6.0009589195251465, -5.69838809967041, -4.968350887298584, -4.86751127243042, -4.413477420806885, -3.861628293991089, -2.7673745155334473, -4.724987030029297, -4.4568610191345215, -3.4673216342926025, -3.140791654586792, -2.605299949645996, -3.9434516429901123, -2.8184006214141846, -2.929769515991211, -2.9646522998809814, -4.771602153778076, -2.5017881393432617, -3.243168830871582, -1.8058398962020874, -2.925323963165283, -3.7529547214508057, -3.3047935962677, -2.7332818508148193, -2.8793272972106934, -3.1072745323181152, -2.609081983566284, -2.597721576690674, -2.9351747035980225, -2.141409397125244, -2.0738377571105957, -1.6597332954406738, -2.6896557807922363, -2.2893593311309814, 0.3835861384868622, 0.5369893908500671, -1.2743396759033203, -1.9461997747421265, -2.005316734313965, 0.296188622713089, -0.582687258720398, -0.8394453525543213, -0.4741438627243042, -0.6804789304733276, -0.4354484975337982, -0.08419688791036606, -1.1035194396972656, -0.953942060470581, -0.5834988355636597, -1.0452481508255005, -1.0992544889450073, -0.6419733762741089, -0.8250551819801331, -0.9755151867866516, -1.1927669048309326, 1.473178744316101, -1.1480363607406616, -1.8944779634475708, -2.747798442840576, -1.7619043588638306, 0.0, 0.0, -0.0, -16.59990882873535, -14.555431365966797, -13.487517356872559, -12.092549324035645, -10.783303260803223, -10.808534622192383, -10.25872802734375, -9.433135986328125, -9.329607963562012, -10.517660140991211, -7.75514030456543, -7.966167449951172, -7.524071216583252, -6.257869720458984, -6.690051078796387, -6.0009589195251465, -5.69838809967041, -4.968350887298584, -4.86751127243042, -4.413477420806885, -3.861628293991089, -2.7673745155334473, -4.724987030029297, -4.4568610191345215, -3.4673216342926025, -3.140791654586792, -2.605299949645996, -3.9434516429901123, -2.8184006214141846, -2.929769515991211, -2.9646522998809814, -4.771602153778076, -2.5017881393432617, -3.243168830871582, -1.8058398962020874, -2.925323963165283, -3.7529547214508057, -3.3047935962677, -2.7332818508148193, -2.8793272972106934, -3.1072745323181152, -2.609081983566284, -2.597721576690674, -2.9351747035980225, -2.141409397125244, -2.0738377571105957, -1.6597332954406738, -2.6896557807922363, -2.2893593311309814, 0.3835861384868622, 0.5369893908500671, -1.2743396759033203, -1.9461997747421265, -2.005316734313965, 0.296188622713089, -0.582687258720398, -0.8394453525543213, -0.4741438627243042, -0.6804789304733276, -0.4354484975337982, -0.08419688791036606, -1.1035194396972656, -0.953942060470581, -0.5834988355636597, -1.0452481508255005, -1.0992544889450073, -0.6419733762741089, -0.8250551819801331, -0.9755151867866516, -1.1927669048309326, 1.473178744316101, -1.1480363607406616, -1.8944779634475708, -2.747798442840576, -1.7619043588638306, -0.0, -0.0], [0.0, 0.0, -15.293465614318848, -13.639546394348145, -13.769426345825195, -11.706864356994629, -10.924567222595215, -10.8196382522583, -9.96705436706543, -9.346287727355957, -8.986209869384766, -7.864197254180908, -7.88008451461792, -7.811850547790527, -6.769804000854492, -7.048041820526123, -6.807896137237549, -5.6787919998168945, -5.697825908660889, -5.486196994781494, -5.227052688598633, -5.1030144691467285, -4.807499408721924, -5.776264667510986, -3.9673423767089844, -3.6263465881347656, -3.5711114406585693, -3.615574359893799, -5.602111339569092, -3.147522449493408, -1.7991127967834473, -3.828054666519165, -4.747310161590576, -2.6449878215789795, -4.1800150871276855, -3.36286997795105, -2.8623595237731934, -3.144784450531006, -2.6976473331451416, -3.0595314502716064, -2.9812302589416504, -3.3943605422973633, -3.670077085494995, -3.5889289379119873, -2.8863229751586914, -3.2041616439819336, -2.691350221633911, -1.4991469383239746, -1.7010502815246582, -1.3288497924804688, -0.9031886458396912, -0.4805409014225006, -1.107176661491394, -1.8333683013916016, -1.578749656677246, -1.3329644203186035, -1.7010986804962158, -0.5878584384918213, 0.8526161313056946, -0.8823314905166626, -1.5701162815093994, -0.8261340260505676, -0.6859697699546814, -0.5057401657104492, -1.4159566164016724, -0.735174298286438, -0.8709148168563843, -1.497446060180664, -0.4562242925167084, -1.0490269660949707, -0.28994396328926086, -1.3719269037246704, -2.0653185844421387, -2.5273594856262207, -3.1614859104156494, -2.982987880706787, 0.0, 0.0, -0.0, -0.0, -15.293465614318848, -13.639546394348145, -13.769426345825195, -11.706864356994629, -10.924567222595215, -10.8196382522583, -9.96705436706543, -9.346287727355957, -8.986209869384766, -7.864197254180908, -7.88008451461792, -7.811850547790527, -6.769804000854492, -7.048041820526123, -6.807896137237549, -5.6787919998168945, -5.697825908660889, -5.486196994781494, -5.227052688598633, -5.1030144691467285, -4.807499408721924, -5.776264667510986, -3.9673423767089844, -3.6263465881347656, -3.5711114406585693, -3.615574359893799, -5.602111339569092, -3.147522449493408, -1.7991127967834473, -3.828054666519165, -4.747310161590576, -2.6449878215789795, -4.1800150871276855, -3.36286997795105, -2.8623595237731934, -3.144784450531006, -2.6976473331451416, -3.0595314502716064, -2.9812302589416504, -3.3943605422973633, -3.670077085494995, -3.5889289379119873, -2.8863229751586914, -3.2041616439819336, -2.691350221633911, -1.4991469383239746, -1.7010502815246582, -1.3288497924804688, -0.9031886458396912, -0.4805409014225006, -1.107176661491394, -1.8333683013916016, -1.578749656677246, -1.3329644203186035, -1.7010986804962158, -0.5878584384918213, 0.8526161313056946, -0.8823314905166626, -1.5701162815093994, -0.8261340260505676, -0.6859697699546814, -0.5057401657104492, -1.4159566164016724, -0.735174298286438, -0.8709148168563843, -1.497446060180664, -0.4562242925167084, -1.0490269660949707, -0.28994396328926086, -1.3719269037246704, -2.0653185844421387, -2.5273594856262207, -3.1614859104156494, -2.982987880706787, -0.0, -0.0], [0.0, 0.0, -14.714016914367676, -13.72906494140625, -12.410548210144043, -11.922163009643555, -11.721060752868652, -11.590725898742676, -10.932029724121094, -9.151054382324219, -9.41711711883545, -5.4209489822387695, -7.937414646148682, -7.668581008911133, -7.031772136688232, -6.979602813720703, -6.7009453773498535, -5.91694450378418, -5.654699802398682, -3.5604941844940186, -5.019737243652344, -5.193048000335693, -4.155053615570068, -4.692018985748291, -3.3606765270233154, -4.288519859313965, -3.7488903999328613, -5.986123085021973, -3.6385884284973145, -3.3800041675567627, -3.706721305847168, -3.1406431198120117, -4.051098346710205, -4.1422810554504395, -4.775453567504883, -2.9962375164031982, -3.1439406871795654, -4.478963851928711, -4.308871746063232, -3.2070858478546143, -3.7356932163238525, -4.436641216278076, -4.0539751052856445, -3.810727596282959, -3.1262238025665283, -3.8078582286834717, -1.1851164102554321, -2.4320783615112305, -1.1756161451339722, -1.2758458852767944, -3.4069459438323975, -1.9025737047195435, -0.6848545074462891, -1.3224362134933472, -2.309866428375244, -3.4292728900909424, -0.9299710392951965, -1.8925918340682983, -1.4814293384552002, -0.9093526601791382, -0.014164216816425323, -0.9047672152519226, -0.3986259400844574, -1.1106563806533813, -1.6156470775604248, -0.6593430042266846, 2.3652427196502686, -1.3486274480819702, -1.2148293256759644, 0.114644855260849, -0.304118275642395, -1.0301052331924438, -2.1948232650756836, -2.5265696048736572, -3.115511178970337, -3.0088789463043213, 0.0, 0.0, -0.0, -0.0, -14.714016914367676, -13.72906494140625, -12.410548210144043, -11.922163009643555, -11.721060752868652, -11.590725898742676, -10.932029724121094, -9.151054382324219, -9.41711711883545, -5.4209489822387695, -7.937414646148682, -7.668581008911133, -7.031772136688232, -6.979602813720703, -6.7009453773498535, -5.91694450378418, -5.654699802398682, -3.5604941844940186, -5.019737243652344, -5.193048000335693, -4.155053615570068, -4.692018985748291, -3.3606765270233154, -4.288519859313965, -3.7488903999328613, -5.986123085021973, -3.6385884284973145, -3.3800041675567627, -3.706721305847168, -3.1406431198120117, -4.051098346710205, -4.1422810554504395, -4.775453567504883, -2.9962375164031982, -3.1439406871795654, -4.478963851928711, -4.308871746063232, -3.2070858478546143, -3.7356932163238525, -4.436641216278076, -4.0539751052856445, -3.810727596282959, -3.1262238025665283, -3.8078582286834717, -1.1851164102554321, -2.4320783615112305, -1.1756161451339722, -1.2758458852767944, -3.4069459438323975, -1.9025737047195435, -0.6848545074462891, -1.3224362134933472, -2.309866428375244, -3.4292728900909424, -0.9299710392951965, -1.8925918340682983, -1.4814293384552002, -0.9093526601791382, -0.014164216816425323, -0.9047672152519226, -0.3986259400844574, -1.1106563806533813, -1.6156470775604248, -0.6593430042266846, 2.3652427196502686, -1.3486274480819702, -1.2148293256759644, 0.114644855260849, -0.304118275642395, -1.0301052331924438, -2.1948232650756836, -2.5265696048736572, -3.115511178970337, -3.0088789463043213, -0.0, -0.0], [0.0, 0.0, -15.745556831359863, -14.241618156433105, -13.20191764831543, -12.087750434875488, -11.329434394836426, -11.067534446716309, -9.87028980255127, -9.815665245056152, -9.208654403686523, -8.359579086303711, -8.018211364746094, -7.005156517028809, -7.251554012298584, -7.375973701477051, -5.338867664337158, -5.821532249450684, -5.763225078582764, -5.336336612701416, -5.26788854598999, -4.670310020446777, -4.498299598693848, -4.757797718048096, -4.773662090301514, -3.1313846111297607, -4.702425479888916, -4.307683944702148, -4.920047760009766, -4.182473182678223, -4.354544639587402, -3.184377670288086, -4.151546478271484, -4.5593156814575195, -4.206447601318359, -4.372311592102051, -3.990126609802246, -2.8989861011505127, -4.18996000289917, -4.512883186340332, -3.4342594146728516, -4.384276866912842, -2.626734495162964, -3.9312589168548584, -4.707181930541992, -2.6504006385803223, -3.2813618183135986, -4.044698715209961, -3.0491509437561035, -0.4224786162376404, -2.640214681625366, -2.209136724472046, -2.5067684650421143, -1.9089943170547485, -2.8164405822753906, -1.277665376663208, -2.1735732555389404, -0.17797081172466278, -0.5562839508056641, -1.3842387199401855, -0.7688742280006409, -1.1045387983322144, -1.2094871997833252, -1.1231433153152466, -0.6086727976799011, -2.025846004486084, -0.025946682319045067, -0.10745737701654434, -1.1767531633377075, -1.9078677892684937, -1.2954704761505127, -1.4658130407333374, -1.514714241027832, -2.5375189781188965, -2.957491159439087, -3.2874913215637207, 0.0, 0.0, -0.0, -0.0, -15.745556831359863, -14.241618156433105, -13.20191764831543, -12.087750434875488, -11.329434394836426, -11.067534446716309, -9.87028980255127, -9.815665245056152, -9.208654403686523, -8.359579086303711, -8.018211364746094, -7.005156517028809, -7.251554012298584, -7.375973701477051, -5.338867664337158, -5.821532249450684, -5.763225078582764, -5.336336612701416, -5.26788854598999, -4.670310020446777, -4.498299598693848, -4.757797718048096, -4.773662090301514, -3.1313846111297607, -4.702425479888916, -4.307683944702148, -4.920047760009766, -4.182473182678223, -4.354544639587402, -3.184377670288086, -4.151546478271484, -4.5593156814575195, -4.206447601318359, -4.372311592102051, -3.990126609802246, -2.8989861011505127, -4.18996000289917, -4.512883186340332, -3.4342594146728516, -4.384276866912842, -2.626734495162964, -3.9312589168548584, -4.707181930541992, -2.6504006385803223, -3.2813618183135986, -4.044698715209961, -3.0491509437561035, -0.4224786162376404, -2.640214681625366, -2.209136724472046, -2.5067684650421143, -1.9089943170547485, -2.8164405822753906, -1.277665376663208, -2.1735732555389404, -0.17797081172466278, -0.5562839508056641, -1.3842387199401855, -0.7688742280006409, -1.1045387983322144, -1.2094871997833252, -1.1231433153152466, -0.6086727976799011, -2.025846004486084, -0.025946682319045067, -0.10745737701654434, -1.1767531633377075, -1.9078677892684937, -1.2954704761505127, -1.4658130407333374, -1.514714241027832, -2.5375189781188965, -2.957491159439087, -3.2874913215637207, -0.0, -0.0], [0.0, 0.0, -16.01626968383789, -14.584490776062012, -14.397397994995117, -12.793233871459961, -11.40894603729248, -11.948863983154297, -11.42669677734375, -10.153714179992676, -9.016582489013672, -9.157561302185059, -8.022644996643066, -7.075316905975342, -7.010073184967041, -7.487379550933838, -7.563873767852783, -6.082539081573486, -5.804734706878662, -5.998261451721191, -4.779175758361816, -5.499706745147705, -5.03934907913208, -5.196302890777588, -5.435390472412109, -5.226962566375732, -5.493717670440674, -4.276634216308594, -4.200289726257324, -4.199326992034912, -4.919625282287598, -4.394265651702881, -6.870578289031982, -3.390263319015503, -5.735725402832031, -4.63754415512085, -6.684355735778809, -5.2768731117248535, -4.665334701538086, -5.694822311401367, -4.413126468658447, -4.927950382232666, -4.865933895111084, -3.901873826980591, -4.756821632385254, -4.6203932762146, -5.729348182678223, -3.6485257148742676, -2.519753932952881, -3.071115732192993, -2.9147109985351562, -2.4926955699920654, -2.732996702194214, -1.8611464500427246, 0.3453097343444824, -1.361635684967041, -2.3210678100585938, -1.9237040281295776, -0.8585710525512695, -1.762231469154358, -1.105062484741211, -1.027652382850647, -0.1706884205341339, -0.5345654487609863, -0.998879075050354, -2.1857047080993652, -0.6338865160942078, -1.0701807737350464, -1.3128328323364258, -0.7628713250160217, -1.9638501405715942, -2.3514716625213623, -3.0706095695495605, -3.428645372390747, -3.279130697250366, -3.602419137954712, 0.0, 0.0, -0.0, -0.0, -16.01626968383789, -14.584490776062012, -14.397397994995117, -12.793233871459961, -11.40894603729248, -11.948863983154297, -11.42669677734375, -10.153714179992676, -9.016582489013672, -9.157561302185059, -8.022644996643066, -7.075316905975342, -7.010073184967041, -7.487379550933838, -7.563873767852783, -6.082539081573486, -5.804734706878662, -5.998261451721191, -4.779175758361816, -5.499706745147705, -5.03934907913208, -5.196302890777588, -5.435390472412109, -5.226962566375732, -5.493717670440674, -4.276634216308594, -4.200289726257324, -4.199326992034912, -4.919625282287598, -4.394265651702881, -6.870578289031982, -3.390263319015503, -5.735725402832031, -4.63754415512085, -6.684355735778809, -5.2768731117248535, -4.665334701538086, -5.694822311401367, -4.413126468658447, -4.927950382232666, -4.865933895111084, -3.901873826980591, -4.756821632385254, -4.6203932762146, -5.729348182678223, -3.6485257148742676, -2.519753932952881, -3.071115732192993, -2.9147109985351562, -2.4926955699920654, -2.732996702194214, -1.8611464500427246, 0.3453097343444824, -1.361635684967041, -2.3210678100585938, -1.9237040281295776, -0.8585710525512695, -1.762231469154358, -1.105062484741211, -1.027652382850647, -0.1706884205341339, -0.5345654487609863, -0.998879075050354, -2.1857047080993652, -0.6338865160942078, -1.0701807737350464, -1.3128328323364258, -0.7628713250160217, -1.9638501405715942, -2.3514716625213623, -3.0706095695495605, -3.428645372390747, -3.279130697250366, -3.602419137954712, -0.0, -0.0], [0.0, 0.0, -14.277715682983398, -14.51201057434082, -13.904629707336426, -12.708114624023438, -11.673322677612305, -10.528582572937012, -9.692048072814941, -9.718669891357422, -9.97365951538086, -8.280180931091309, -8.483293533325195, -7.871807098388672, -7.935459613800049, -7.5195631980896, -6.621403217315674, -6.287939071655273, -4.977748394012451, -5.803422927856445, -5.1670989990234375, -5.622652053833008, -5.003555774688721, -3.4980061054229736, -4.8592119216918945, -5.272455215454102, -3.5254476070404053, -4.029459476470947, -5.382856845855713, -2.8631856441497803, -5.1687235832214355, -6.14020299911499, -4.442288875579834, -4.93605375289917, -3.4518425464630127, -6.1209917068481445, -5.33525276184082, -5.218372344970703, -5.956020355224609, -5.635357856750488, -5.417731285095215, -5.555168151855469, -5.8776421546936035, -4.985184669494629, -6.324159622192383, -4.733482360839844, -4.373653888702393, -4.6127119064331055, -2.382415771484375, -3.909883737564087, -2.341899871826172, -2.7072811126708984, -1.6690149307250977, -2.288588047027588, -3.610969305038452, -2.4695017337799072, -1.5701706409454346, -1.6075183153152466, -2.985598087310791, -1.0396599769592285, -0.9977641105651855, -0.9237505197525024, -0.5419031381607056, -0.465451180934906, -1.2178131341934204, -1.2638959884643555, -1.0091911554336548, -0.5979484915733337, -1.3274848461151123, -1.1378003358840942, -2.3703665733337402, -2.2601003646850586, -3.4808945655822754, -3.2611372470855713, -3.2840936183929443, -6.69783878326416, 0.0, 0.0, -0.0, -0.0, -14.277715682983398, -14.51201057434082, -13.904629707336426, -12.708114624023438, -11.673322677612305, -10.528582572937012, -9.692048072814941, -9.718669891357422, -9.97365951538086, -8.280180931091309, -8.483293533325195, -7.871807098388672, -7.935459613800049, -7.5195631980896, -6.621403217315674, -6.287939071655273, -4.977748394012451, -5.803422927856445, -5.1670989990234375, -5.622652053833008, -5.003555774688721, -3.4980061054229736, -4.8592119216918945, -5.272455215454102, -3.5254476070404053, -4.029459476470947, -5.382856845855713, -2.8631856441497803, -5.1687235832214355, -6.14020299911499, -4.442288875579834, -4.93605375289917, -3.4518425464630127, -6.1209917068481445, -5.33525276184082, -5.218372344970703, -5.956020355224609, -5.635357856750488, -5.417731285095215, -5.555168151855469, -5.8776421546936035, -4.985184669494629, -6.324159622192383, -4.733482360839844, -4.373653888702393, -4.6127119064331055, -2.382415771484375, -3.909883737564087, -2.341899871826172, -2.7072811126708984, -1.6690149307250977, -2.288588047027588, -3.610969305038452, -2.4695017337799072, -1.5701706409454346, -1.6075183153152466, -2.985598087310791, -1.0396599769592285, -0.9977641105651855, -0.9237505197525024, -0.5419031381607056, -0.465451180934906, -1.2178131341934204, -1.2638959884643555, -1.0091911554336548, -0.5979484915733337, -1.3274848461151123, -1.1378003358840942, -2.3703665733337402, -2.2601003646850586, -3.4808945655822754, -3.2611372470855713, -3.2840936183929443, -6.69783878326416, -0.0, -0.0], [0.0, 0.0, -15.999642372131348, -14.749903678894043, -14.724417686462402, -12.825760841369629, -12.614887237548828, -12.289972305297852, -11.344507217407227, -9.942694664001465, -9.60522747039795, -7.979617595672607, -8.456754684448242, -8.239352226257324, -7.224100589752197, -7.635134696960449, -6.687844753265381, -7.252995014190674, -6.216525077819824, -6.069615364074707, -5.706902503967285, -5.640298843383789, -5.861512660980225, -5.1684250831604, -6.760481357574463, -4.890205383300781, -4.903470039367676, -4.95637845993042, -4.792895317077637, -3.847429037094116, -5.451558589935303, -3.231034994125366, -8.070866584777832, -5.739138603210449, -5.704074382781982, -6.908220291137695, -6.267785549163818, -7.222706317901611, -5.941906929016113, -5.606830596923828, -6.361731052398682, -5.756844997406006, -6.368501663208008, -5.237851142883301, -6.13380765914917, -8.653006553649902, -5.946343421936035, -6.770232677459717, -4.658090114593506, -3.979379177093506, -3.6443254947662354, -2.606327772140503, -1.1242748498916626, -2.739201545715332, -2.163494110107422, -2.9070277214050293, -2.370249032974243, -1.4798822402954102, -2.294135332107544, -2.176335096359253, -1.3273768424987793, -1.0498664379119873, -1.2725884914398193, -0.8768520355224609, -1.7501556873321533, -1.1220307350158691, -0.7668901085853577, -0.3132931590080261, -1.4289743900299072, -1.7231143712997437, -1.672911524772644, -2.430145740509033, -2.486781120300293, -3.4633452892303467, -2.566943407058716, 0.0, 0.0, 0.0, -0.0, -0.0, -15.999642372131348, -14.749903678894043, -14.724417686462402, -12.825760841369629, -12.614887237548828, -12.289972305297852, -11.344507217407227, -9.942694664001465, -9.60522747039795, -7.979617595672607, -8.456754684448242, -8.239352226257324, -7.224100589752197, -7.635134696960449, -6.687844753265381, -7.252995014190674, -6.216525077819824, -6.069615364074707, -5.706902503967285, -5.640298843383789, -5.861512660980225, -5.1684250831604, -6.760481357574463, -4.890205383300781, -4.903470039367676, -4.95637845993042, -4.792895317077637, -3.847429037094116, -5.451558589935303, -3.231034994125366, -8.070866584777832, -5.739138603210449, -5.704074382781982, -6.908220291137695, -6.267785549163818, -7.222706317901611, -5.941906929016113, -5.606830596923828, -6.361731052398682, -5.756844997406006, -6.368501663208008, -5.237851142883301, -6.13380765914917, -8.653006553649902, -5.946343421936035, -6.770232677459717, -4.658090114593506, -3.979379177093506, -3.6443254947662354, -2.606327772140503, -1.1242748498916626, -2.739201545715332, -2.163494110107422, -2.9070277214050293, -2.370249032974243, -1.4798822402954102, -2.294135332107544, -2.176335096359253, -1.3273768424987793, -1.0498664379119873, -1.2725884914398193, -0.8768520355224609, -1.7501556873321533, -1.1220307350158691, -0.7668901085853577, -0.3132931590080261, -1.4289743900299072, -1.7231143712997437, -1.672911524772644, -2.430145740509033, -2.486781120300293, -3.4633452892303467, -2.566943407058716, -0.0, -0.0, -0.0], [0.0, 0.0, -15.080574989318848, -14.914621353149414, -14.131972312927246, -13.426156044006348, -12.248577117919922, -10.806105613708496, -10.998872756958008, -9.958633422851562, -9.980912208557129, -7.921866416931152, -8.293307304382324, -7.934932708740234, -6.7474212646484375, -7.792617321014404, -6.775111198425293, -6.7570061683654785, -6.541153430938721, -6.35062313079834, -5.963220596313477, -4.986769676208496, -7.197275161743164, -7.391910076141357, -6.630938529968262, -4.839078903198242, -4.813063621520996, -6.295339584350586, -4.267496585845947, -5.954458236694336, -6.390411376953125, -5.881668567657471, -6.736825942993164, -6.356059551239014, -6.910637855529785, -5.509928226470947, -5.929446220397949, -6.9615020751953125, -6.650872230529785, -6.425319194793701, -6.32043981552124, -6.695941925048828, -7.564089298248291, -7.227268218994141, -6.624410629272461, -6.93643856048584, -6.955018997192383, -5.831495761871338, -5.231884479522705, -2.396538734436035, -4.174941062927246, -4.186427593231201, -4.0210652351379395, -2.536475658416748, -2.8340961933135986, -3.732419490814209, -2.361959218978882, -2.094919204711914, -1.656456470489502, -1.7303059101104736, -2.1624529361724854, -1.8220914602279663, -1.0601305961608887, -1.385092854499817, -1.5910125970840454, -1.1099791526794434, -0.8482410907745361, -1.3303205966949463, -1.2639036178588867, -1.2199227809906006, -1.7083895206451416, -2.5136611461639404, -3.3074607849121094, -2.9818971157073975, -3.9471771717071533, 0.0, 0.0, 0.0, -0.0, -0.0, -15.080574989318848, -14.914621353149414, -14.131972312927246, -13.426156044006348, -12.248577117919922, -10.806105613708496, -10.998872756958008, -9.958633422851562, -9.980912208557129, -7.921866416931152, -8.293307304382324, -7.934932708740234, -6.7474212646484375, -7.792617321014404, -6.775111198425293, -6.7570061683654785, -6.541153430938721, -6.35062313079834, -5.963220596313477, -4.986769676208496, -7.197275161743164, -7.391910076141357, -6.630938529968262, -4.839078903198242, -4.813063621520996, -6.295339584350586, -4.267496585845947, -5.954458236694336, -6.390411376953125, -5.881668567657471, -6.736825942993164, -6.356059551239014, -6.910637855529785, -5.509928226470947, -5.929446220397949, -6.9615020751953125, -6.650872230529785, -6.425319194793701, -6.32043981552124, -6.695941925048828, -7.564089298248291, -7.227268218994141, -6.624410629272461, -6.93643856048584, -6.955018997192383, -5.831495761871338, -5.231884479522705, -2.396538734436035, -4.174941062927246, -4.186427593231201, -4.0210652351379395, -2.536475658416748, -2.8340961933135986, -3.732419490814209, -2.361959218978882, -2.094919204711914, -1.656456470489502, -1.7303059101104736, -2.1624529361724854, -1.8220914602279663, -1.0601305961608887, -1.385092854499817, -1.5910125970840454, -1.1099791526794434, -0.8482410907745361, -1.3303205966949463, -1.2639036178588867, -1.2199227809906006, -1.7083895206451416, -2.5136611461639404, -3.3074607849121094, -2.9818971157073975, -3.9471771717071533, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, -15.705854415893555, -14.846321105957031, -13.73829174041748, -12.591184616088867, -12.14207649230957, -10.635858535766602, -9.938776969909668, -10.408307075500488, -9.676925659179688, -8.800010681152344, -8.435473442077637, -8.992525100708008, -7.913690090179443, -5.909946441650391, -6.3521809577941895, -7.366401672363281, -6.843092441558838, -6.328120708465576, -6.9068684577941895, -4.915565490722656, -7.450306415557861, -6.4248528480529785, -5.501373767852783, -6.422421455383301, -6.5766072273254395, -5.885695934295654, -6.820565700531006, -5.503946304321289, -6.000990867614746, -6.301880836486816, -7.514025688171387, -7.370697498321533, -7.098108768463135, -6.960651874542236, -8.056710243225098, -8.156298637390137, -7.652307033538818, -8.137338638305664, -7.1783270835876465, -8.02174186706543, -7.8335723876953125, -8.294126510620117, -6.772534370422363, -6.740355014801025, -5.933980464935303, -2.925387382507324, -4.709152698516846, -4.919270992279053, -4.545904636383057, -5.240494728088379, -4.372717380523682, -3.869314432144165, -3.928891897201538, -4.305600643157959, -2.318345546722412, -2.2134554386138916, -1.6192281246185303, -1.7085750102996826, -2.6145925521850586, -1.7896007299423218, -1.2989436388015747, -1.964142084121704, -1.188072919845581, -1.0114985704421997, -1.4624124765396118, -1.6007965803146362, -2.5282156467437744, -2.1834850311279297, -2.5324666500091553, -3.127542734146118, -3.7985870838165283, -5.435413360595703, 0.0, 0.0, 1.3095207214355469, -0.0, -0.0, -0.0, -15.705854415893555, -14.846321105957031, -13.73829174041748, -12.591184616088867, -12.14207649230957, -10.635858535766602, -9.938776969909668, -10.408307075500488, -9.676925659179688, -8.800010681152344, -8.435473442077637, -8.992525100708008, -7.913690090179443, -5.909946441650391, -6.3521809577941895, -7.366401672363281, -6.843092441558838, -6.328120708465576, -6.9068684577941895, -4.915565490722656, -7.450306415557861, -6.4248528480529785, -5.501373767852783, -6.422421455383301, -6.5766072273254395, -5.885695934295654, -6.820565700531006, -5.503946304321289, -6.000990867614746, -6.301880836486816, -7.514025688171387, -7.370697498321533, -7.098108768463135, -6.960651874542236, -8.056710243225098, -8.156298637390137, -7.652307033538818, -8.137338638305664, -7.1783270835876465, -8.02174186706543, -7.8335723876953125, -8.294126510620117, -6.772534370422363, -6.740355014801025, -5.933980464935303, -2.925387382507324, -4.709152698516846, -4.919270992279053, -4.545904636383057, -5.240494728088379, -4.372717380523682, -3.869314432144165, -3.928891897201538, -4.305600643157959, -2.318345546722412, -2.2134554386138916, -1.6192281246185303, -1.7085750102996826, -2.6145925521850586, -1.7896007299423218, -1.2989436388015747, -1.964142084121704, -1.188072919845581, -1.0114985704421997, -1.4624124765396118, -1.6007965803146362, -2.5282156467437744, -2.1834850311279297, -2.5324666500091553, -3.127542734146118, -3.7985870838165283, -5.435413360595703, -0.0, -0.0, 1.3095207214355469], [0.0, 0.0, 0.0, -16.43401336669922, -15.287206649780273, -13.293828964233398, -12.810746192932129, -11.39123249053955, -11.144070625305176, -11.013498306274414, -10.13939380645752, -9.93143367767334, -8.609355926513672, -8.293724060058594, -7.453892230987549, -7.573317527770996, -7.483238220214844, -7.3354010581970215, -7.73841667175293, -6.698366641998291, -7.164993762969971, -6.77614688873291, -6.135987281799316, -6.511449337005615, -7.696715831756592, -7.441163539886475, -6.0518317222595215, -8.583332061767578, -7.838016986846924, -6.595805644989014, -6.558032989501953, -7.6314520835876465, -7.723419666290283, -7.341662406921387, -9.595983505249023, -8.817625999450684, -10.49781608581543, -8.402113914489746, -8.599872589111328, -9.625064849853516, -9.452692985534668, -9.94645881652832, -8.399282455444336, -6.490427017211914, -8.014786720275879, -6.464968204498291, -8.067474365234375, -7.45823335647583, -6.4989824295043945, -6.053572654724121, -6.2590012550354, -4.712532043457031, -3.9255900382995605, -1.2031900882720947, -4.45892858505249, -5.547128677368164, -2.790144443511963, -2.17985200881958, -2.0142159461975098, -3.0162389278411865, -2.422184944152832, -1.6251325607299805, -2.3436551094055176, -2.6603715419769287, -2.371955394744873, -1.6344491243362427, -1.4598641395568848, -0.8135785460472107, -1.4003013372421265, -1.2958924770355225, -2.843353271484375, -2.880561351776123, -2.4913742542266846, -3.8964810371398926, -4.715359210968018, 0.0, 0.0, 4.236423492431641, -0.0, -0.0, -0.0, -16.43401336669922, -15.287206649780273, -13.293828964233398, -12.810746192932129, -11.39123249053955, -11.144070625305176, -11.013498306274414, -10.13939380645752, -9.93143367767334, -8.609355926513672, -8.293724060058594, -7.453892230987549, -7.573317527770996, -7.483238220214844, -7.3354010581970215, -7.73841667175293, -6.698366641998291, -7.164993762969971, -6.77614688873291, -6.135987281799316, -6.511449337005615, -7.696715831756592, -7.441163539886475, -6.0518317222595215, -8.583332061767578, -7.838016986846924, -6.595805644989014, -6.558032989501953, -7.6314520835876465, -7.723419666290283, -7.341662406921387, -9.595983505249023, -8.817625999450684, -10.49781608581543, -8.402113914489746, -8.599872589111328, -9.625064849853516, -9.452692985534668, -9.94645881652832, -8.399282455444336, -6.490427017211914, -8.014786720275879, -6.464968204498291, -8.067474365234375, -7.45823335647583, -6.4989824295043945, -6.053572654724121, -6.2590012550354, -4.712532043457031, -3.9255900382995605, -1.2031900882720947, -4.45892858505249, -5.547128677368164, -2.790144443511963, -2.17985200881958, -2.0142159461975098, -3.0162389278411865, -2.422184944152832, -1.6251325607299805, -2.3436551094055176, -2.6603715419769287, -2.371955394744873, -1.6344491243362427, -1.4598641395568848, -0.8135785460472107, -1.4003013372421265, -1.2958924770355225, -2.843353271484375, -2.880561351776123, -2.4913742542266846, -3.8964810371398926, -4.715359210968018, -0.0, -0.0, 4.236423492431641], [-19.398113250732422, 0.0, 0.0, -17.226329803466797, -15.39917278289795, -13.895172119140625, -13.053717613220215, -11.087699890136719, -11.917489051818848, -10.635812759399414, -9.867131233215332, -9.823406219482422, -8.880127906799316, -8.08006477355957, -8.088129997253418, -7.287933349609375, -7.691811561584473, -6.941926956176758, -6.853928089141846, -6.282491683959961, -5.583278179168701, -7.474625587463379, -6.595829010009766, -6.895597457885742, -6.859413146972656, -7.236789226531982, -7.455883502960205, -6.819401264190674, -6.086369514465332, -6.922356605529785, -8.27001953125, -8.251286506652832, -7.090594291687012, -8.569300651550293, -10.751304626464844, -10.188931465148926, -10.098740577697754, -7.544647693634033, -10.105618476867676, -9.94843578338623, -8.86123275756836, -8.744681358337402, -10.099411964416504, -10.32463264465332, -8.072792053222656, -7.6679534912109375, -9.440260887145996, -7.075626373291016, -7.294167518615723, -3.960270643234253, -6.966347694396973, -6.166582107543945, -5.052276134490967, -4.3856611251831055, -1.4136000871658325, -4.307521343231201, -5.781142711639404, -2.775383234024048, -3.1758291721343994, -3.044996738433838, -2.226881265640259, -2.3840854167938232, -2.2324907779693604, -2.650050640106201, -1.4335458278656006, -1.3217897415161133, -1.624314546585083, -1.1695809364318848, -1.144301176071167, -2.074410915374756, -3.542933225631714, -2.588203191757202, -2.8806047439575195, -3.808737277984619, 0.0, 0.0, 0.0, 3.903463125228882, -19.398113250732422, -0.0, -0.0, -17.226329803466797, -15.39917278289795, -13.895172119140625, -13.053717613220215, -11.087699890136719, -11.917489051818848, -10.635812759399414, -9.867131233215332, -9.823406219482422, -8.880127906799316, -8.08006477355957, -8.088129997253418, -7.287933349609375, -7.691811561584473, -6.941926956176758, -6.853928089141846, -6.282491683959961, -5.583278179168701, -7.474625587463379, -6.595829010009766, -6.895597457885742, -6.859413146972656, -7.236789226531982, -7.455883502960205, -6.819401264190674, -6.086369514465332, -6.922356605529785, -8.27001953125, -8.251286506652832, -7.090594291687012, -8.569300651550293, -10.751304626464844, -10.188931465148926, -10.098740577697754, -7.544647693634033, -10.105618476867676, -9.94843578338623, -8.86123275756836, -8.744681358337402, -10.099411964416504, -10.32463264465332, -8.072792053222656, -7.6679534912109375, -9.440260887145996, -7.075626373291016, -7.294167518615723, -3.960270643234253, -6.966347694396973, -6.166582107543945, -5.052276134490967, -4.3856611251831055, -1.4136000871658325, -4.307521343231201, -5.781142711639404, -2.775383234024048, -3.1758291721343994, -3.044996738433838, -2.226881265640259, -2.3840854167938232, -2.2324907779693604, -2.650050640106201, -1.4335458278656006, -1.3217897415161133, -1.624314546585083, -1.1695809364318848, -1.144301176071167, -2.074410915374756, -3.542933225631714, -2.588203191757202, -2.8806047439575195, -3.808737277984619, -0.0, -0.0, 0.0, 3.903463125228882], [-19.800132751464844, 0.0, 0.0, -16.673526763916016, -15.756449699401855, -14.733377456665039, -13.793497085571289, -12.71045970916748, -11.61429500579834, -11.15457820892334, -10.983266830444336, -9.548103332519531, -8.067389488220215, -8.871746063232422, -7.568630695343018, -7.465857982635498, -7.827930450439453, -7.8920979499816895, -6.513436794281006, -8.094118118286133, -5.982000827789307, -6.818385124206543, -6.880932807922363, -6.849710464477539, -7.122194290161133, -8.07010555267334, -6.778448581695557, -7.3237690925598145, -9.157404899597168, -8.94086742401123, -8.603864669799805, -9.027451515197754, -9.473246574401855, -9.767934799194336, -10.384220123291016, -11.08301830291748, -10.487417221069336, -10.798510551452637, -10.71304988861084, -10.115971565246582, -11.628203392028809, -10.051959991455078, -10.08459758758545, -8.770684242248535, -10.681108474731445, -12.561797142028809, -13.322487831115723, -9.25418758392334, -8.318330764770508, -6.263338565826416, -5.297345161437988, -7.116107940673828, -6.243663311004639, -6.434233665466309, -4.536206245422363, -3.442450761795044, -3.6469357013702393, -2.825469970703125, -2.721052408218384, -2.516824960708618, -3.709376573562622, -2.7319514751434326, -2.268066883087158, -2.5068202018737793, -2.002568483352661, -2.162184000015259, -1.9366341829299927, -0.6588726043701172, -1.5016344785690308, -1.7717777490615845, -2.8032665252685547, -2.5795326232910156, -2.825845718383789, -2.9866747856140137, 0.0, 0.0, 1.4728974103927612, 2.933084011077881, -19.800132751464844, -0.0, -0.0, -16.673526763916016, -15.756449699401855, -14.733377456665039, -13.793497085571289, -12.71045970916748, -11.61429500579834, -11.15457820892334, -10.983266830444336, -9.548103332519531, -8.067389488220215, -8.871746063232422, -7.568630695343018, -7.465857982635498, -7.827930450439453, -7.8920979499816895, -6.513436794281006, -8.094118118286133, -5.982000827789307, -6.818385124206543, -6.880932807922363, -6.849710464477539, -7.122194290161133, -8.07010555267334, -6.778448581695557, -7.3237690925598145, -9.157404899597168, -8.94086742401123, -8.603864669799805, -9.027451515197754, -9.473246574401855, -9.767934799194336, -10.384220123291016, -11.08301830291748, -10.487417221069336, -10.798510551452637, -10.71304988861084, -10.115971565246582, -11.628203392028809, -10.051959991455078, -10.08459758758545, -8.770684242248535, -10.681108474731445, -12.561797142028809, -13.322487831115723, -9.25418758392334, -8.318330764770508, -6.263338565826416, -5.297345161437988, -7.116107940673828, -6.243663311004639, -6.434233665466309, -4.536206245422363, -3.442450761795044, -3.6469357013702393, -2.825469970703125, -2.721052408218384, -2.516824960708618, -3.709376573562622, -2.7319514751434326, -2.268066883087158, -2.5068202018737793, -2.002568483352661, -2.162184000015259, -1.9366341829299927, -0.6588726043701172, -1.5016344785690308, -1.7717777490615845, -2.8032665252685547, -2.5795326232910156, -2.825845718383789, -2.9866747856140137, -0.0, 0.0, 1.4728974103927612, 2.933084011077881], [-20.973291397094727, 0.0, 0.0, -14.145424842834473, -15.752899169921875, -14.615588188171387, -13.02050495147705, -13.181071281433105, -11.374216079711914, -11.189525604248047, -10.395210266113281, -9.816601753234863, -9.7179594039917, -8.246896743774414, -8.72572135925293, -8.450937271118164, -6.304354667663574, -8.307577133178711, -7.52322244644165, -6.676095008850098, -7.959469318389893, -7.036778926849365, -7.213318824768066, -7.604681491851807, -6.572990894317627, -8.332283973693848, -9.592809677124023, -8.265454292297363, -9.052462577819824, -8.758060455322266, -9.124859809875488, -10.237566947937012, -10.10884952545166, -8.903738975524902, -12.005875587463379, -10.71925163269043, -11.11873722076416, -11.452131271362305, -11.738455772399902, -12.44943618774414, -12.121906280517578, -11.710387229919434, -13.398003578186035, -10.805522918701172, -9.89203929901123, -10.730083465576172, -12.142642974853516, -10.015044212341309, -10.390151023864746, -7.241555213928223, -8.696398735046387, -6.581966876983643, -6.684991836547852, -6.6831955909729, -5.1134185791015625, -5.1945295333862305, -3.100834846496582, -3.7497847080230713, -3.3277978897094727, -3.703599214553833, -3.4129748344421387, -3.2441043853759766, -2.870030403137207, -2.9756267070770264, -1.7289448976516724, -2.5019803047180176, -2.2748117446899414, -2.1537458896636963, -1.6036419868469238, -0.4015424847602844, -1.2602307796478271, -2.3492531776428223, -2.7319884300231934, -4.187804222106934, 0.0, 0.0, 4.019125938415527, 2.7007558345794678, -20.973291397094727, -0.0, -0.0, -14.145424842834473, -15.752899169921875, -14.615588188171387, -13.02050495147705, -13.181071281433105, -11.374216079711914, -11.189525604248047, -10.395210266113281, -9.816601753234863, -9.7179594039917, -8.246896743774414, -8.72572135925293, -8.450937271118164, -6.304354667663574, -8.307577133178711, -7.52322244644165, -6.676095008850098, -7.959469318389893, -7.036778926849365, -7.213318824768066, -7.604681491851807, -6.572990894317627, -8.332283973693848, -9.592809677124023, -8.265454292297363, -9.052462577819824, -8.758060455322266, -9.124859809875488, -10.237566947937012, -10.10884952545166, -8.903738975524902, -12.005875587463379, -10.71925163269043, -11.11873722076416, -11.452131271362305, -11.738455772399902, -12.44943618774414, -12.121906280517578, -11.710387229919434, -13.398003578186035, -10.805522918701172, -9.89203929901123, -10.730083465576172, -12.142642974853516, -10.015044212341309, -10.390151023864746, -7.241555213928223, -8.696398735046387, -6.581966876983643, -6.684991836547852, -6.6831955909729, -5.1134185791015625, -5.1945295333862305, -3.100834846496582, -3.7497847080230713, -3.3277978897094727, -3.703599214553833, -3.4129748344421387, -3.2441043853759766, -2.870030403137207, -2.9756267070770264, -1.7289448976516724, -2.5019803047180176, -2.2748117446899414, -2.1537458896636963, -1.6036419868469238, -0.4015424847602844, -1.2602307796478271, -2.3492531776428223, -2.7319884300231934, -4.187804222106934, -0.0, 0.0, 4.019125938415527, 2.7007558345794678], [-20.40553855895996, 0.0, 0.0, 0.0, -15.834373474121094, -14.886544227600098, -15.416913032531738, -12.663894653320312, -12.249968528747559, -10.778573989868164, -10.886761665344238, -10.121329307556152, -9.599503517150879, -8.161894798278809, -8.819218635559082, -9.02567195892334, -8.838342666625977, -8.929059982299805, -6.036038875579834, -7.487780570983887, -7.4342780113220215, -5.020634174346924, -8.248246192932129, -6.598629951477051, -8.144502639770508, -8.076569557189941, -8.367192268371582, -9.139204025268555, -9.033950805664062, -9.121692657470703, -10.738394737243652, -9.9207181930542, -11.033143043518066, -10.313377380371094, -12.047534942626953, -11.753771781921387, -12.58591079711914, -13.548731803894043, -13.060502052307129, -14.280701637268066, -12.830265998840332, -11.369287490844727, -13.6698579788208, -12.623899459838867, -12.772534370422363, -11.337532043457031, -11.051676750183105, -10.97018051147461, -10.161311149597168, -11.783182144165039, -11.329416275024414, -9.33190631866455, -8.729519844055176, -6.677788257598877, -6.446534156799316, -4.708752155303955, -5.133182525634766, -4.065705299377441, -4.235711574554443, -4.429155349731445, -3.4383718967437744, -2.5592498779296875, -2.7639048099517822, -2.417759895324707, -2.4825685024261475, -2.3144419193267822, -1.910238265991211, -2.2606263160705566, -1.4842402935028076, -4.64303731918335, -1.7638638019561768, -2.584012269973755, -3.3850467205047607, 0.0, 0.0, 0.0, 0.0, 0.4664088189601898, -20.40553855895996, -0.0, -0.0, -0.0, -15.834373474121094, -14.886544227600098, -15.416913032531738, -12.663894653320312, -12.249968528747559, -10.778573989868164, -10.886761665344238, -10.121329307556152, -9.599503517150879, -8.161894798278809, -8.819218635559082, -9.02567195892334, -8.838342666625977, -8.929059982299805, -6.036038875579834, -7.487780570983887, -7.4342780113220215, -5.020634174346924, -8.248246192932129, -6.598629951477051, -8.144502639770508, -8.076569557189941, -8.367192268371582, -9.139204025268555, -9.033950805664062, -9.121692657470703, -10.738394737243652, -9.9207181930542, -11.033143043518066, -10.313377380371094, -12.047534942626953, -11.753771781921387, -12.58591079711914, -13.548731803894043, -13.060502052307129, -14.280701637268066, -12.830265998840332, -11.369287490844727, -13.6698579788208, -12.623899459838867, -12.772534370422363, -11.337532043457031, -11.051676750183105, -10.97018051147461, -10.161311149597168, -11.783182144165039, -11.329416275024414, -9.33190631866455, -8.729519844055176, -6.677788257598877, -6.446534156799316, -4.708752155303955, -5.133182525634766, -4.065705299377441, -4.235711574554443, -4.429155349731445, -3.4383718967437744, -2.5592498779296875, -2.7639048099517822, -2.417759895324707, -2.4825685024261475, -2.3144419193267822, -1.910238265991211, -2.2606263160705566, -1.4842402935028076, -4.64303731918335, -1.7638638019561768, -2.584012269973755, -3.3850467205047607, -0.0, -0.0, 0.0, 0.0, 0.4664088189601898], [-20.47700309753418, 0.0, 0.0, 0.0, -16.241086959838867, -15.41049575805664, -13.504115104675293, -13.190238952636719, -12.613283157348633, -12.060368537902832, -10.79952335357666, -9.770784378051758, -9.25328254699707, -8.615399360656738, -8.252473831176758, -8.647444725036621, -7.829922199249268, -8.482577323913574, -9.410440444946289, -8.222654342651367, -7.427052974700928, -9.073309898376465, -8.705252647399902, -8.27535343170166, -7.8592848777771, -9.01409912109375, -9.0117826461792, -8.997278213500977, -10.944601058959961, -11.442702293395996, -10.562700271606445, -11.791367530822754, -11.127784729003906, -12.422250747680664, -12.961603164672852, -13.917947769165039, -14.400569915771484, -13.787663459777832, -14.514252662658691, -14.530024528503418, -14.777300834655762, -14.798698425292969, -14.357260704040527, -13.547301292419434, -12.668581008911133, -12.29346752166748, -12.780937194824219, -8.551202774047852, -10.56281852722168, -9.854337692260742, -9.26590347290039, -9.207879066467285, -7.9284443855285645, -7.601256370544434, -6.5317583084106445, -5.735058307647705, -5.582859039306641, -4.403203010559082, -5.430569648742676, -4.362499237060547, -4.032286643981934, -3.71354079246521, -3.4527018070220947, -2.8069345951080322, -2.253843307495117, -1.9425970315933228, -2.7208456993103027, -2.953547954559326, -1.7346527576446533, -1.932702898979187, -1.805951476097107, -2.973038673400879, 0.0, 0.0, 0.0, 0.0, 1.0797104835510254, 1.172377586364746, -20.47700309753418, -0.0, -0.0, -0.0, -16.241086959838867, -15.41049575805664, -13.504115104675293, -13.190238952636719, -12.613283157348633, -12.060368537902832, -10.79952335357666, -9.770784378051758, -9.25328254699707, -8.615399360656738, -8.252473831176758, -8.647444725036621, -7.829922199249268, -8.482577323913574, -9.410440444946289, -8.222654342651367, -7.427052974700928, -9.073309898376465, -8.705252647399902, -8.27535343170166, -7.8592848777771, -9.01409912109375, -9.0117826461792, -8.997278213500977, -10.944601058959961, -11.442702293395996, -10.562700271606445, -11.791367530822754, -11.127784729003906, -12.422250747680664, -12.961603164672852, -13.917947769165039, -14.400569915771484, -13.787663459777832, -14.514252662658691, -14.530024528503418, -14.777300834655762, -14.798698425292969, -14.357260704040527, -13.547301292419434, -12.668581008911133, -12.29346752166748, -12.780937194824219, -8.551202774047852, -10.56281852722168, -9.854337692260742, -9.26590347290039, -9.207879066467285, -7.9284443855285645, -7.601256370544434, -6.5317583084106445, -5.735058307647705, -5.582859039306641, -4.403203010559082, -5.430569648742676, -4.362499237060547, -4.032286643981934, -3.71354079246521, -3.4527018070220947, -2.8069345951080322, -2.253843307495117, -1.9425970315933228, -2.7208456993103027, -2.953547954559326, -1.7346527576446533, -1.932702898979187, -1.805951476097107, -2.973038673400879, -0.0, -0.0, 0.0, 0.0, 1.0797104835510254, 1.172377586364746], [-20.9956111907959, -21.797941207885742, 0.0, 0.0, -14.31649398803711, -15.763198852539062, -13.828825950622559, -12.743624687194824, -11.341269493103027, -11.732484817504883, -11.138069152832031, -10.664774894714355, -9.701109886169434, -9.71910572052002, -8.65202808380127, -8.629324913024902, -8.391408920288086, -8.362933158874512, -8.340706825256348, -8.706646919250488, -7.878469467163086, -7.646885395050049, -8.392583847045898, -8.334967613220215, -10.790260314941406, -10.431512832641602, -7.787437438964844, -10.866117477416992, -10.27990436553955, -12.746805191040039, -11.027779579162598, -14.312061309814453, -14.172471046447754, -13.478818893432617, -12.745439529418945, -15.389677047729492, -14.834427833557129, -15.726073265075684, -16.07353401184082, -15.69260311126709, -15.518235206604004, -15.915535926818848, -15.742825508117676, -15.406824111938477, -15.076066017150879, -14.025150299072266, -12.334545135498047, -12.785367965698242, -11.925052642822266, -12.194003105163574, -9.79621696472168, -9.610331535339355, -9.317536354064941, -7.258331298828125, -8.11645793914795, -6.695402145385742, -6.476153373718262, -4.874602317810059, -5.002815246582031, -5.214457988739014, -3.9580585956573486, -4.322876453399658, -3.504169464111328, -3.2989752292633057, -3.1029224395751953, -3.1725056171417236, -2.5932729244232178, -2.6847290992736816, -2.8636350631713867, -3.2786543369293213, -3.0010969638824463, -3.9485926628112793, -1.576401948928833, 0.0, 0.0, 0.0, 1.1204521656036377, 3.141085386276245, -20.9956111907959, -21.797941207885742, -0.0, -0.0, -14.31649398803711, -15.763198852539062, -13.828825950622559, -12.743624687194824, -11.341269493103027, -11.732484817504883, -11.138069152832031, -10.664774894714355, -9.701109886169434, -9.71910572052002, -8.65202808380127, -8.629324913024902, -8.391408920288086, -8.362933158874512, -8.340706825256348, -8.706646919250488, -7.878469467163086, -7.646885395050049, -8.392583847045898, -8.334967613220215, -10.790260314941406, -10.431512832641602, -7.787437438964844, -10.866117477416992, -10.27990436553955, -12.746805191040039, -11.027779579162598, -14.312061309814453, -14.172471046447754, -13.478818893432617, -12.745439529418945, -15.389677047729492, -14.834427833557129, -15.726073265075684, -16.07353401184082, -15.69260311126709, -15.518235206604004, -15.915535926818848, -15.742825508117676, -15.406824111938477, -15.076066017150879, -14.025150299072266, -12.334545135498047, -12.785367965698242, -11.925052642822266, -12.194003105163574, -9.79621696472168, -9.610331535339355, -9.317536354064941, -7.258331298828125, -8.11645793914795, -6.695402145385742, -6.476153373718262, -4.874602317810059, -5.002815246582031, -5.214457988739014, -3.9580585956573486, -4.322876453399658, -3.504169464111328, -3.2989752292633057, -3.1029224395751953, -3.1725056171417236, -2.5932729244232178, -2.6847290992736816, -2.8636350631713867, -3.2786543369293213, -3.0010969638824463, -3.9485926628112793, -1.576401948928833, -0.0, 0.0, 0.0, 1.1204521656036377, 3.141085386276245], [-21.309833526611328, -20.97883415222168, 0.0, 0.0, 0.0, -17.27652359008789, -14.142939567565918, -12.888619422912598, -12.766213417053223, -11.964376449584961, -11.385835647583008, -10.355844497680664, -9.809640884399414, -9.115339279174805, -8.714599609375, -8.712907791137695, -8.452423095703125, -8.819557189941406, -8.369157791137695, -8.042049407958984, -9.292359352111816, -9.892218589782715, -8.904583930969238, -8.975658416748047, -8.333488464355469, -9.494752883911133, -10.691329002380371, -10.749067306518555, -11.476544380187988, -13.633438110351562, -13.031999588012695, -14.62672233581543, -13.490281105041504, -14.504060745239258, -15.36299991607666, -16.787015914916992, -17.01289176940918, -16.834165573120117, -17.098031997680664, -16.79041290283203, -17.286048889160156, -16.3987979888916, -16.429378509521484, -15.479941368103027, -15.613268852233887, -14.181272506713867, -14.916267395019531, -14.846304893493652, -13.641350746154785, -11.979381561279297, -8.779535293579102, -9.88442611694336, -8.855631828308105, -8.247393608093262, -8.35854434967041, -7.620634078979492, -4.803440093994141, -6.463169097900391, -6.2288899421691895, -4.961048126220703, -4.243771553039551, -4.318794250488281, -3.8689215183258057, -3.4811439514160156, -3.6281607151031494, -3.418644428253174, -3.3429033756256104, -3.491889238357544, -3.788921356201172, -3.3704731464385986, -3.0382707118988037, -4.654534816741943, 0.0, 0.0, 0.0, 0.0, 1.255128026008606, 2.706470012664795, -21.309833526611328, -20.97883415222168, -0.0, -0.0, -0.0, -17.27652359008789, -14.142939567565918, -12.888619422912598, -12.766213417053223, -11.964376449584961, -11.385835647583008, -10.355844497680664, -9.809640884399414, -9.115339279174805, -8.714599609375, -8.712907791137695, -8.452423095703125, -8.819557189941406, -8.369157791137695, -8.042049407958984, -9.292359352111816, -9.892218589782715, -8.904583930969238, -8.975658416748047, -8.333488464355469, -9.494752883911133, -10.691329002380371, -10.749067306518555, -11.476544380187988, -13.633438110351562, -13.031999588012695, -14.62672233581543, -13.490281105041504, -14.504060745239258, -15.36299991607666, -16.787015914916992, -17.01289176940918, -16.834165573120117, -17.098031997680664, -16.79041290283203, -17.286048889160156, -16.3987979888916, -16.429378509521484, -15.479941368103027, -15.613268852233887, -14.181272506713867, -14.916267395019531, -14.846304893493652, -13.641350746154785, -11.979381561279297, -8.779535293579102, -9.88442611694336, -8.855631828308105, -8.247393608093262, -8.35854434967041, -7.620634078979492, -4.803440093994141, -6.463169097900391, -6.2288899421691895, -4.961048126220703, -4.243771553039551, -4.318794250488281, -3.8689215183258057, -3.4811439514160156, -3.6281607151031494, -3.418644428253174, -3.3429033756256104, -3.491889238357544, -3.788921356201172, -3.3704731464385986, -3.0382707118988037, -4.654534816741943, -0.0, -0.0, 0.0, 0.0, 1.255128026008606, 2.706470012664795], [-20.196617126464844, -20.28309440612793, 0.0, 0.0, 0.0, -14.443147659301758, -15.318009376525879, -13.945552825927734, -12.49740219116211, -12.026893615722656, -10.610105514526367, -9.914987564086914, -9.805279731750488, -9.41563892364502, -8.98190975189209, -8.863402366638184, -9.44737434387207, -9.380791664123535, -8.974310874938965, -8.948400497436523, -9.365494728088379, -9.434076309204102, -9.903319358825684, -10.526934623718262, -9.465195655822754, -10.469123840332031, -10.958617210388184, -10.50296688079834, -12.354769706726074, -13.320789337158203, -14.522156715393066, -14.24930477142334, -15.01772689819336, -16.322986602783203, -18.03632926940918, -16.53181266784668, -17.378978729248047, -17.315664291381836, -17.823434829711914, -18.29996109008789, -17.637155532836914, -18.503177642822266, -19.368152618408203, -16.14592742919922, -16.37196159362793, -15.652361869812012, -15.458535194396973, -15.385722160339355, -14.293144226074219, -13.749288558959961, -11.354365348815918, -11.865179061889648, -11.022732734680176, -8.586835861206055, -5.996415615081787, -7.538837909698486, -6.8687028884887695, -6.451152801513672, -5.835947513580322, -5.209837913513184, -4.5888190269470215, -4.50278377532959, -4.51134729385376, -4.389766693115234, -4.220955848693848, -4.181394577026367, -3.555946111679077, -3.6603236198425293, -2.652911424636841, -3.0091757774353027, -1.364285945892334, 0.0, 0.0, 0.0, 0.0, 0.3535306453704834, 2.7866623401641846, 2.7902934551239014, -20.196617126464844, -20.28309440612793, -0.0, -0.0, -0.0, -14.443147659301758, -15.318009376525879, -13.945552825927734, -12.49740219116211, -12.026893615722656, -10.610105514526367, -9.914987564086914, -9.805279731750488, -9.41563892364502, -8.98190975189209, -8.863402366638184, -9.44737434387207, -9.380791664123535, -8.974310874938965, -8.948400497436523, -9.365494728088379, -9.434076309204102, -9.903319358825684, -10.526934623718262, -9.465195655822754, -10.469123840332031, -10.958617210388184, -10.50296688079834, -12.354769706726074, -13.320789337158203, -14.522156715393066, -14.24930477142334, -15.01772689819336, -16.322986602783203, -18.03632926940918, -16.53181266784668, -17.378978729248047, -17.315664291381836, -17.823434829711914, -18.29996109008789, -17.637155532836914, -18.503177642822266, -19.368152618408203, -16.14592742919922, -16.37196159362793, -15.652361869812012, -15.458535194396973, -15.385722160339355, -14.293144226074219, -13.749288558959961, -11.354365348815918, -11.865179061889648, -11.022732734680176, -8.586835861206055, -5.996415615081787, -7.538837909698486, -6.8687028884887695, -6.451152801513672, -5.835947513580322, -5.209837913513184, -4.5888190269470215, -4.50278377532959, -4.51134729385376, -4.389766693115234, -4.220955848693848, -4.181394577026367, -3.555946111679077, -3.6603236198425293, -2.652911424636841, -3.0091757774353027, -1.364285945892334, -0.0, -0.0, 0.0, 0.0, 0.3535306453704834, 2.7866623401641846, 2.7902934551239014], [-20.973535537719727, -20.658180236816406, -20.074329376220703, 0.0, 0.0, -17.131807327270508, -16.256332397460938, -14.43963623046875, -13.231898307800293, -11.591878890991211, -10.732669830322266, -10.511137008666992, -9.784497261047363, -8.977249145507812, -9.31875228881836, -8.911101341247559, -9.750096321105957, -8.913838386535645, -9.607099533081055, -9.60171890258789, -10.122808456420898, -9.294756889343262, -10.130216598510742, -9.270658493041992, -9.744115829467773, -11.208642959594727, -12.6052885055542, -12.038500785827637, -12.118542671203613, -14.154667854309082, -15.745439529418945, -16.08907699584961, -17.109975814819336, -17.200653076171875, -17.379798889160156, -18.109262466430664, -18.71627426147461, -19.425668716430664, -20.484230041503906, -18.1518497467041, -19.56890296936035, -19.205581665039062, -19.886442184448242, -19.087778091430664, -17.227447509765625, -16.689714431762695, -16.336612701416016, -14.619807243347168, -16.403528213500977, -15.707413673400879, -13.736063003540039, -11.739596366882324, -10.442984580993652, -10.132623672485352, -7.982109546661377, -8.803351402282715, -9.986176490783691, -8.39270305633545, -7.348840713500977, -5.886237144470215, -5.178181171417236, -5.369687080383301, -3.457296133041382, -4.392693042755127, -4.221328258514404, -4.411744117736816, -3.3852410316467285, -3.574995994567871, -3.1126396656036377, -2.9826202392578125, -3.220554828643799, 0.0, 0.0, 0.0, 0.0, 1.4921269416809082, 2.533034324645996, 1.1134064197540283, -20.973535537719727, -20.658180236816406, -20.074329376220703, -0.0, -0.0, -17.131807327270508, -16.256332397460938, -14.43963623046875, -13.231898307800293, -11.591878890991211, -10.732669830322266, -10.511137008666992, -9.784497261047363, -8.977249145507812, -9.31875228881836, -8.911101341247559, -9.750096321105957, -8.913838386535645, -9.607099533081055, -9.60171890258789, -10.122808456420898, -9.294756889343262, -10.130216598510742, -9.270658493041992, -9.744115829467773, -11.208642959594727, -12.6052885055542, -12.038500785827637, -12.118542671203613, -14.154667854309082, -15.745439529418945, -16.08907699584961, -17.109975814819336, -17.200653076171875, -17.379798889160156, -18.109262466430664, -18.71627426147461, -19.425668716430664, -20.484230041503906, -18.1518497467041, -19.56890296936035, -19.205581665039062, -19.886442184448242, -19.087778091430664, -17.227447509765625, -16.689714431762695, -16.336612701416016, -14.619807243347168, -16.403528213500977, -15.707413673400879, -13.736063003540039, -11.739596366882324, -10.442984580993652, -10.132623672485352, -7.982109546661377, -8.803351402282715, -9.986176490783691, -8.39270305633545, -7.348840713500977, -5.886237144470215, -5.178181171417236, -5.369687080383301, -3.457296133041382, -4.392693042755127, -4.221328258514404, -4.411744117736816, -3.3852410316467285, -3.574995994567871, -3.1126396656036377, -2.9826202392578125, -3.220554828643799, -0.0, -0.0, 0.0, 0.0, 1.4921269416809082, 2.533034324645996, 1.1134064197540283], [-21.804779052734375, -20.01569366455078, -20.905118942260742, -20.341184616088867, 0.0, 0.0, -16.986835479736328, -14.9879789352417, -16.05658721923828, -10.883806228637695, -10.635272979736328, -10.243273735046387, -9.774252891540527, -9.759310722351074, -9.619501113891602, -9.433502197265625, -10.158754348754883, -9.891307830810547, -10.499161720275879, -10.065725326538086, -8.857356071472168, -9.906352996826172, -7.819281578063965, -11.279394149780273, -10.316435813903809, -12.107038497924805, -12.627939224243164, -13.439414978027344, -14.41801643371582, -15.461684226989746, -15.639521598815918, -16.29407501220703, -17.734477996826172, -19.087984085083008, -18.451738357543945, -20.489587783813477, -19.694164276123047, -19.337696075439453, -21.189699172973633, 0.0, -19.935373306274414, -20.685869216918945, -20.501720428466797, -20.234149932861328, -19.821735382080078, -18.8882999420166, -17.701038360595703, -16.871185302734375, -15.31882095336914, -15.222810745239258, -14.816329956054688, -9.600492477416992, -10.852238655090332, -11.259913444519043, -10.445253372192383, -9.112923622131348, -8.169797897338867, -4.809983253479004, -7.122729301452637, -6.413991928100586, -6.904881477355957, -5.407547473907471, -3.62093186378479, -4.607644081115723, -4.602025508880615, -6.257174968719482, -3.9276978969573975, -3.678999185562134, -2.561028480529785, -2.061805009841919, -2.4849348068237305, 0.0, 0.0, 0.0, 1.2252840995788574, 3.3743882179260254, 3.6327414512634277, 3.002617597579956, -21.804779052734375, -20.01569366455078, -20.905118942260742, -20.341184616088867, -0.0, -0.0, -16.986835479736328, -14.9879789352417, -16.05658721923828, -10.883806228637695, -10.635272979736328, -10.243273735046387, -9.774252891540527, -9.759310722351074, -9.619501113891602, -9.433502197265625, -10.158754348754883, -9.891307830810547, -10.499161720275879, -10.065725326538086, -8.857356071472168, -9.906352996826172, -7.819281578063965, -11.279394149780273, -10.316435813903809, -12.107038497924805, -12.627939224243164, -13.439414978027344, -14.41801643371582, -15.461684226989746, -15.639521598815918, -16.29407501220703, -17.734477996826172, -19.087984085083008, -18.451738357543945, -20.489587783813477, -19.694164276123047, -19.337696075439453, -21.189699172973633, -0.0, -19.935373306274414, -20.685869216918945, -20.501720428466797, -20.234149932861328, -19.821735382080078, -18.8882999420166, -17.701038360595703, -16.871185302734375, -15.31882095336914, -15.222810745239258, -14.816329956054688, -9.600492477416992, -10.852238655090332, -11.259913444519043, -10.445253372192383, -9.112923622131348, -8.169797897338867, -4.809983253479004, -7.122729301452637, -6.413991928100586, -6.904881477355957, -5.407547473907471, -3.62093186378479, -4.607644081115723, -4.602025508880615, -6.257174968719482, -3.9276978969573975, -3.678999185562134, -2.561028480529785, -2.061805009841919, -2.4849348068237305, -0.0, 0.0, 0.0, 1.2252840995788574, 3.3743882179260254, 3.6327414512634277, 3.002617597579956], [-21.490650177001953, -19.694761276245117, -19.40007209777832, -19.08639144897461, 0.0, 0.0, 0.0, -15.22044563293457, -13.578447341918945, -13.585287094116211, -10.011260032653809, -10.487710952758789, -10.39887809753418, -10.49427604675293, -10.452386856079102, -9.748764991760254, -10.051294326782227, -10.29626178741455, -10.17053508758545, -9.020289421081543, -10.425262451171875, -11.68427562713623, -10.437155723571777, -11.461616516113281, -11.653236389160156, -11.886980056762695, -12.639521598815918, -13.470121383666992, -13.043015480041504, -15.330041885375977, -17.04722023010254, -17.883533477783203, -17.558998107910156, -19.390092849731445, -21.32601547241211, -20.66297721862793, -21.348358154296875, -22.113557815551758, -22.882719039916992, 0.0, -21.701486587524414, -22.256832122802734, -22.602571487426758, -21.77288055419922, -20.425077438354492, -19.90848731994629, -18.733964920043945, -18.018251419067383, -18.379470825195312, -15.839237213134766, -14.000052452087402, -13.437479972839355, -11.691339492797852, -12.695905685424805, -10.521681785583496, -9.681934356689453, -8.87414264678955, -7.707555294036865, -7.771769046783447, -5.94038200378418, -6.62294340133667, -5.978227615356445, -4.515871524810791, -4.143913745880127, -4.474408149719238, -3.130930185317993, -3.274777889251709, -3.608931064605713, -2.3028268814086914, -0.5405005216598511, -1.3340590000152588, 0.0, 0.0, 0.0, 1.9207820892333984, 3.3351564407348633, 3.2716479301452637, 3.655944585800171, -21.490650177001953, -19.694761276245117, -19.40007209777832, -19.08639144897461, -0.0, -0.0, -0.0, -15.22044563293457, -13.578447341918945, -13.585287094116211, -10.011260032653809, -10.487710952758789, -10.39887809753418, -10.49427604675293, -10.452386856079102, -9.748764991760254, -10.051294326782227, -10.29626178741455, -10.17053508758545, -9.020289421081543, -10.425262451171875, -11.68427562713623, -10.437155723571777, -11.461616516113281, -11.653236389160156, -11.886980056762695, -12.639521598815918, -13.470121383666992, -13.043015480041504, -15.330041885375977, -17.04722023010254, -17.883533477783203, -17.558998107910156, -19.390092849731445, -21.32601547241211, -20.66297721862793, -21.348358154296875, -22.113557815551758, -22.882719039916992, -0.0, -21.701486587524414, -22.256832122802734, -22.602571487426758, -21.77288055419922, -20.425077438354492, -19.90848731994629, -18.733964920043945, -18.018251419067383, -18.379470825195312, -15.839237213134766, -14.000052452087402, -13.437479972839355, -11.691339492797852, -12.695905685424805, -10.521681785583496, -9.681934356689453, -8.87414264678955, -7.707555294036865, -7.771769046783447, -5.94038200378418, -6.62294340133667, -5.978227615356445, -4.515871524810791, -4.143913745880127, -4.474408149719238, -3.130930185317993, -3.274777889251709, -3.608931064605713, -2.3028268814086914, -0.5405005216598511, -1.3340590000152588, -0.0, 0.0, 0.0, 1.9207820892333984, 3.3351564407348633, 3.2716479301452637, 3.655944585800171], [-19.843429565429688, -19.40642547607422, -19.476430892944336, -17.713476181030273, 0.0, 0.0, 0.0, 0.0, -12.413726806640625, -11.658695220947266, -10.328145027160645, -10.603066444396973, -10.819622993469238, -10.580690383911133, -11.185129165649414, -9.659246444702148, -10.957969665527344, -10.629034996032715, -11.355677604675293, -11.02079963684082, -10.99966812133789, -11.213622093200684, -11.897512435913086, -12.26443099975586, -11.28170108795166, -12.566675186157227, -13.223088264465332, -14.329981803894043, -14.57343578338623, -15.903177261352539, -16.650588989257812, -18.349720001220703, -19.22899627685547, -20.011159896850586, -20.65057945251465, -21.059574127197266, -22.90871810913086, -21.932601928710938, -23.554859161376953, -23.62569808959961, -24.23821449279785, -23.090320587158203, -23.419469833374023, -24.049114227294922, -19.072608947753906, -21.099796295166016, -21.0577392578125, -20.400636672973633, -17.808496475219727, -17.210155487060547, -16.21249008178711, -14.57618236541748, -13.44760513305664, -12.745628356933594, -11.415665626525879, -9.890355110168457, -9.896515846252441, -9.297995567321777, -7.088574409484863, -8.607830047607422, -6.171000957489014, -5.715786457061768, -5.881869316101074, -4.963028430938721, -4.792832374572754, -4.057875633239746, -3.865281581878662, -3.201085329055786, -2.236581563949585, -0.5559755563735962, -0.8278321623802185, 0.0, 0.0, 0.0, 3.082437038421631, 1.8320329189300537, 3.9321439266204834, 4.788618087768555, -19.843429565429688, -19.40642547607422, -19.476430892944336, -17.713476181030273, -0.0, -0.0, -0.0, -0.0, -12.413726806640625, -11.658695220947266, -10.328145027160645, -10.603066444396973, -10.819622993469238, -10.580690383911133, -11.185129165649414, -9.659246444702148, -10.957969665527344, -10.629034996032715, -11.355677604675293, -11.02079963684082, -10.99966812133789, -11.213622093200684, -11.897512435913086, -12.26443099975586, -11.28170108795166, -12.566675186157227, -13.223088264465332, -14.329981803894043, -14.57343578338623, -15.903177261352539, -16.650588989257812, -18.349720001220703, -19.22899627685547, -20.011159896850586, -20.65057945251465, -21.059574127197266, -22.90871810913086, -21.932601928710938, -23.554859161376953, -23.62569808959961, -24.23821449279785, -23.090320587158203, -23.419469833374023, -24.049114227294922, -19.072608947753906, -21.099796295166016, -21.0577392578125, -20.400636672973633, -17.808496475219727, -17.210155487060547, -16.21249008178711, -14.57618236541748, -13.44760513305664, -12.745628356933594, -11.415665626525879, -9.890355110168457, -9.896515846252441, -9.297995567321777, -7.088574409484863, -8.607830047607422, -6.171000957489014, -5.715786457061768, -5.881869316101074, -4.963028430938721, -4.792832374572754, -4.057875633239746, -3.865281581878662, -3.201085329055786, -2.236581563949585, -0.5559755563735962, -0.8278321623802185, -0.0, 0.0, 0.0, 3.082437038421631, 1.8320329189300537, 3.9321439266204834, 4.788618087768555], [-19.981611251831055, -18.933691024780273, -17.634286880493164, -16.98653793334961, -16.57370376586914, 0.0, 0.0, 0.0, 0.0, 0.0, -13.300785064697266, -11.452919960021973, -11.654196739196777, -11.041677474975586, -11.519744873046875, -10.171253204345703, -11.165821075439453, -11.556004524230957, -10.876569747924805, -11.176736831665039, -12.35783863067627, -11.557912826538086, -11.625842094421387, -11.211935043334961, -12.61324691772461, -12.854702949523926, -15.1530122756958, -15.228978157043457, -15.775187492370605, -16.94378089904785, -17.381362915039062, -19.267868041992188, -20.394760131835938, -20.55288314819336, -21.644338607788086, -20.361797332763672, -23.5731258392334, -25.122547149658203, -24.702089309692383, -22.457456588745117, -24.877735137939453, -24.648157119750977, -23.57649803161621, -23.820241928100586, -23.337236404418945, -22.057357788085938, -19.078086853027344, -20.3187255859375, -17.535083770751953, -18.353607177734375, -15.682039260864258, -16.03975486755371, -14.36398983001709, -15.942479133605957, -11.779858589172363, -11.348684310913086, -10.794529914855957, -9.057762145996094, -8.702488899230957, -7.427675247192383, -6.787807941436768, -7.159270763397217, -6.078620433807373, -5.2286601066589355, -4.608238697052002, -3.473137378692627, -4.033245086669922, -2.489429473876953, -1.9049890041351318, -2.374195098876953, -2.3349666595458984, 0.0, 0.0, 3.336392879486084, 3.837203025817871, 1.3853849172592163, 4.887481212615967, 2.1902995109558105, -19.981611251831055, -18.933691024780273, -17.634286880493164, -16.98653793334961, -16.57370376586914, -0.0, -0.0, -0.0, -0.0, -0.0, -13.300785064697266, -11.452919960021973, -11.654196739196777, -11.041677474975586, -11.519744873046875, -10.171253204345703, -11.165821075439453, -11.556004524230957, -10.876569747924805, -11.176736831665039, -12.35783863067627, -11.557912826538086, -11.625842094421387, -11.211935043334961, -12.61324691772461, -12.854702949523926, -15.1530122756958, -15.228978157043457, -15.775187492370605, -16.94378089904785, -17.381362915039062, -19.267868041992188, -20.394760131835938, -20.55288314819336, -21.644338607788086, -20.361797332763672, -23.5731258392334, -25.122547149658203, -24.702089309692383, -22.457456588745117, -24.877735137939453, -24.648157119750977, -23.57649803161621, -23.820241928100586, -23.337236404418945, -22.057357788085938, -19.078086853027344, -20.3187255859375, -17.535083770751953, -18.353607177734375, -15.682039260864258, -16.03975486755371, -14.36398983001709, -15.942479133605957, -11.779858589172363, -11.348684310913086, -10.794529914855957, -9.057762145996094, -8.702488899230957, -7.427675247192383, -6.787807941436768, -7.159270763397217, -6.078620433807373, -5.2286601066589355, -4.608238697052002, -3.473137378692627, -4.033245086669922, -2.489429473876953, -1.9049890041351318, -2.374195098876953, -2.3349666595458984, -0.0, 0.0, 3.336392879486084, 3.837203025817871, 1.3853849172592163, 4.887481212615967, 2.1902995109558105], [-20.283334732055664, -18.586814880371094, -17.419700622558594, -16.380830764770508, -15.492615699768066, -15.012202262878418, 0.0, 0.0, 0.0, 0.0, -10.677595138549805, -13.462592124938965, -12.008843421936035, -11.0103120803833, -12.418364524841309, -12.517295837402344, -11.37937068939209, -13.849635124206543, -12.13524055480957, -11.25577449798584, -13.092140197753906, -12.581123352050781, -11.504326820373535, -13.922825813293457, -13.11263370513916, -14.10637092590332, -14.954825401306152, -15.747751235961914, -16.17255210876465, -17.14604377746582, -18.040380477905273, -19.410301208496094, -21.61149787902832, -23.482831954956055, -24.263893127441406, -24.361257553100586, -25.522939682006836, -26.09442138671875, -27.50871467590332, -26.21481704711914, -25.931324005126953, -26.22909927368164, -25.39186668395996, -25.59706687927246, -24.53186798095703, -23.328319549560547, -22.104480743408203, -22.228147506713867, -20.64006805419922, -18.894168853759766, -17.33045196533203, -16.349533081054688, -15.150634765625, -13.883811950683594, -13.268189430236816, -11.670360565185547, -10.864124298095703, -10.081435203552246, -8.510491371154785, -8.380595207214355, -7.076148509979248, -7.181794166564941, -6.6194047927856445, -6.097826957702637, -4.777740001678467, -4.848822116851807, -3.515446662902832, -3.339388370513916, -3.0543580055236816, -2.2590408325195312, -3.284639835357666, 0.0, 0.0, 3.533344030380249, 6.010609149932861, 2.689499616622925, 3.7501466274261475, 0.0, -20.283334732055664, -18.586814880371094, -17.419700622558594, -16.380830764770508, -15.492615699768066, -15.012202262878418, -0.0, -0.0, -0.0, -0.0, -10.677595138549805, -13.462592124938965, -12.008843421936035, -11.0103120803833, -12.418364524841309, -12.517295837402344, -11.37937068939209, -13.849635124206543, -12.13524055480957, -11.25577449798584, -13.092140197753906, -12.581123352050781, -11.504326820373535, -13.922825813293457, -13.11263370513916, -14.10637092590332, -14.954825401306152, -15.747751235961914, -16.17255210876465, -17.14604377746582, -18.040380477905273, -19.410301208496094, -21.61149787902832, -23.482831954956055, -24.263893127441406, -24.361257553100586, -25.522939682006836, -26.09442138671875, -27.50871467590332, -26.21481704711914, -25.931324005126953, -26.22909927368164, -25.39186668395996, -25.59706687927246, -24.53186798095703, -23.328319549560547, -22.104480743408203, -22.228147506713867, -20.64006805419922, -18.894168853759766, -17.33045196533203, -16.349533081054688, -15.150634765625, -13.883811950683594, -13.268189430236816, -11.670360565185547, -10.864124298095703, -10.081435203552246, -8.510491371154785, -8.380595207214355, -7.076148509979248, -7.181794166564941, -6.6194047927856445, -6.097826957702637, -4.777740001678467, -4.848822116851807, -3.515446662902832, -3.339388370513916, -3.0543580055236816, -2.2590408325195312, -3.284639835357666, -0.0, 0.0, 3.533344030380249, 6.010609149932861, 2.689499616622925, 3.7501466274261475, 0.0], [-17.62386703491211, -17.02238655090332, -17.85006332397461, -16.85660171508789, -15.370047569274902, -16.120513916015625, -14.537013053894043, -10.99783706665039, 0.0, 0.0, 0.0, -14.49582290649414, -13.201330184936523, -13.750801086425781, -14.913043022155762, -12.698277473449707, -12.916827201843262, -12.50801944732666, -12.313962936401367, -13.581625938415527, -11.1246976852417, -12.366388320922852, -13.873947143554688, -13.569275856018066, -15.398789405822754, -14.933938026428223, -15.732060432434082, -16.466209411621094, -16.961610794067383, -19.447296142578125, -21.1102294921875, -20.942628860473633, -22.217409133911133, -22.35162353515625, -24.746013641357422, -25.470359802246094, -25.844867706298828, -26.449634552001953, -26.375444412231445, -27.19756507873535, -27.143768310546875, -26.61065673828125, -26.722074508666992, -26.852375030517578, -25.364633560180664, -25.991518020629883, -20.54705047607422, -21.063642501831055, -20.6213321685791, -19.645225524902344, -17.065649032592773, -17.317977905273438, -14.608769416809082, -13.807415008544922, -13.667563438415527, -12.114500999450684, -11.57192325592041, -10.347304344177246, -9.278303146362305, -8.622056007385254, -7.500743389129639, -7.202004432678223, -6.122766017913818, -5.565206050872803, -4.602627277374268, -4.153408527374268, -4.816833972930908, -3.96581768989563, -3.121453285217285, -2.821816921234131, -3.420478343963623, 0.0, 3.8482091426849365, 4.404000282287598, 4.112039566040039, 3.546437978744507, 2.32505464553833, 3.53071665763855, -17.62386703491211, -17.02238655090332, -17.85006332397461, -16.85660171508789, -15.370047569274902, -16.120513916015625, -14.537013053894043, -10.99783706665039, -0.0, -0.0, -0.0, -14.49582290649414, -13.201330184936523, -13.750801086425781, -14.913043022155762, -12.698277473449707, -12.916827201843262, -12.50801944732666, -12.313962936401367, -13.581625938415527, -11.1246976852417, -12.366388320922852, -13.873947143554688, -13.569275856018066, -15.398789405822754, -14.933938026428223, -15.732060432434082, -16.466209411621094, -16.961610794067383, -19.447296142578125, -21.1102294921875, -20.942628860473633, -22.217409133911133, -22.35162353515625, -24.746013641357422, -25.470359802246094, -25.844867706298828, -26.449634552001953, -26.375444412231445, -27.19756507873535, -27.143768310546875, -26.61065673828125, -26.722074508666992, -26.852375030517578, -25.364633560180664, -25.991518020629883, -20.54705047607422, -21.063642501831055, -20.6213321685791, -19.645225524902344, -17.065649032592773, -17.317977905273438, -14.608769416809082, -13.807415008544922, -13.667563438415527, -12.114500999450684, -11.57192325592041, -10.347304344177246, -9.278303146362305, -8.622056007385254, -7.500743389129639, -7.202004432678223, -6.122766017913818, -5.565206050872803, -4.602627277374268, -4.153408527374268, -4.816833972930908, -3.96581768989563, -3.121453285217285, -2.821816921234131, -3.420478343963623, 0.0, 3.8482091426849365, 4.404000282287598, 4.112039566040039, 3.546437978744507, 2.32505464553833, 3.53071665763855], [0.0, -18.674142837524414, -17.774471282958984, -16.521446228027344, -15.912581443786621, -14.885482788085938, -13.412850379943848, -11.913169860839844, -11.075094223022461, 0.0, 0.0, -14.132564544677734, -11.370474815368652, -12.291766166687012, -14.6465425491333, -14.766932487487793, -13.190872192382812, -13.37922477722168, -12.975078582763672, -13.092779159545898, -13.555438995361328, -12.966946601867676, -15.34515380859375, -15.304594039916992, -13.881356239318848, -14.745035171508789, -15.799211502075195, -16.99985122680664, -17.23647117614746, -19.86067008972168, -20.05354881286621, -21.661514282226562, -21.362239837646484, -24.036897659301758, -22.719112396240234, -26.629152297973633, -28.077348709106445, -28.002788543701172, -28.63612937927246, -28.343839645385742, -27.826749801635742, -27.846988677978516, -26.95655059814453, -26.754032135009766, -25.979148864746094, -26.431608200073242, -25.111286163330078, -22.909883499145508, -20.814495086669922, -19.476476669311523, -19.09589958190918, -18.23282241821289, -17.224889755249023, -14.621938705444336, -13.95103645324707, -12.078548431396484, -10.951416969299316, -10.13412857055664, -9.115443229675293, -8.789202690124512, -8.376108169555664, -7.605175495147705, -7.358528137207031, -4.177738189697266, -6.204337120056152, -5.542186260223389, -5.73127555847168, -4.11049747467041, -3.7961208820343018, -2.723172187805176, 0.0, 0.0, 4.263183116912842, 4.827016353607178, 2.929940700531006, 2.7619941234588623, 0.0, 2.034205913543701, -0.0, -18.674142837524414, -17.774471282958984, -16.521446228027344, -15.912581443786621, -14.885482788085938, -13.412850379943848, -11.913169860839844, -11.075094223022461, -0.0, -0.0, -14.132564544677734, -11.370474815368652, -12.291766166687012, -14.6465425491333, -14.766932487487793, -13.190872192382812, -13.37922477722168, -12.975078582763672, -13.092779159545898, -13.555438995361328, -12.966946601867676, -15.34515380859375, -15.304594039916992, -13.881356239318848, -14.745035171508789, -15.799211502075195, -16.99985122680664, -17.23647117614746, -19.86067008972168, -20.05354881286621, -21.661514282226562, -21.362239837646484, -24.036897659301758, -22.719112396240234, -26.629152297973633, -28.077348709106445, -28.002788543701172, -28.63612937927246, -28.343839645385742, -27.826749801635742, -27.846988677978516, -26.95655059814453, -26.754032135009766, -25.979148864746094, -26.431608200073242, -25.111286163330078, -22.909883499145508, -20.814495086669922, -19.476476669311523, -19.09589958190918, -18.23282241821289, -17.224889755249023, -14.621938705444336, -13.95103645324707, -12.078548431396484, -10.951416969299316, -10.13412857055664, -9.115443229675293, -8.789202690124512, -8.376108169555664, -7.605175495147705, -7.358528137207031, -4.177738189697266, -6.204337120056152, -5.542186260223389, -5.73127555847168, -4.11049747467041, -3.7961208820343018, -2.723172187805176, -0.0, 0.0, 4.263183116912842, 4.827016353607178, 2.929940700531006, 2.7619941234588623, 0.0, 2.034205913543701], [-21.99853515625, -19.55741310119629, -16.87474822998047, -16.243282318115234, -15.355032920837402, -14.695055961608887, -14.266287803649902, -13.606409072875977, -11.809416770935059, 0.0, 0.0, 0.0, -12.55889892578125, 0.0, -13.06328296661377, -9.661230087280273, -13.696200370788574, -11.70403003692627, -12.486801147460938, -13.887163162231445, -13.66074275970459, -14.334854125976562, -15.288810729980469, -14.291022300720215, -15.223917007446289, -16.106094360351562, -17.347396850585938, -19.658231735229492, -21.622709274291992, -20.384532928466797, -19.445331573486328, -21.717130661010742, -24.12176513671875, -25.05242156982422, -25.900436401367188, -26.340030670166016, -28.52048110961914, -27.806161880493164, -28.673086166381836, -30.52370834350586, -30.810035705566406, -30.06167984008789, -28.189668655395508, -28.346582412719727, -26.932273864746094, -26.921918869018555, -24.708486557006836, -25.291378021240234, -23.103900909423828, -19.53614044189453, -20.627809524536133, -19.696365356445312, -17.19685173034668, -15.6447172164917, -14.494438171386719, -13.132392883300781, -12.140063285827637, -10.413657188415527, -9.416696548461914, -7.368276596069336, -7.53943395614624, -8.260347366333008, -7.100930690765381, -7.5674052238464355, -6.499923229217529, -5.420977592468262, -5.451227188110352, -3.5921518802642822, -3.006352663040161, -4.416462421417236, 0.0, 3.7195310592651367, 4.380033016204834, 3.8903915882110596, 2.415235996246338, 1.1048880815505981, 0.0, 0.0, -21.99853515625, -19.55741310119629, -16.87474822998047, -16.243282318115234, -15.355032920837402, -14.695055961608887, -14.266287803649902, -13.606409072875977, -11.809416770935059, -0.0, -0.0, -0.0, -12.55889892578125, -0.0, -13.06328296661377, -9.661230087280273, -13.696200370788574, -11.70403003692627, -12.486801147460938, -13.887163162231445, -13.66074275970459, -14.334854125976562, -15.288810729980469, -14.291022300720215, -15.223917007446289, -16.106094360351562, -17.347396850585938, -19.658231735229492, -21.622709274291992, -20.384532928466797, -19.445331573486328, -21.717130661010742, -24.12176513671875, -25.05242156982422, -25.900436401367188, -26.340030670166016, -28.52048110961914, -27.806161880493164, -28.673086166381836, -30.52370834350586, -30.810035705566406, -30.06167984008789, -28.189668655395508, -28.346582412719727, -26.932273864746094, -26.921918869018555, -24.708486557006836, -25.291378021240234, -23.103900909423828, -19.53614044189453, -20.627809524536133, -19.696365356445312, -17.19685173034668, -15.6447172164917, -14.494438171386719, -13.132392883300781, -12.140063285827637, -10.413657188415527, -9.416696548461914, -7.368276596069336, -7.53943395614624, -8.260347366333008, -7.100930690765381, -7.5674052238464355, -6.499923229217529, -5.420977592468262, -5.451227188110352, -3.5921518802642822, -3.006352663040161, -4.416462421417236, 0.0, 3.7195310592651367, 4.380033016204834, 3.8903915882110596, 2.415235996246338, 1.1048880815505981, 0.0, 0.0], [0.0, 0.0, -17.610092163085938, -16.280452728271484, -16.200429916381836, -14.485918998718262, -14.46544075012207, -13.08807373046875, -10.815369606018066, -10.54008960723877, 0.0, 0.0, 0.0, 0.0, -11.236093521118164, -10.311141967773438, -13.887581825256348, -12.691520690917969, -10.369959831237793, -12.413091659545898, -14.170770645141602, -15.092007637023926, -14.667462348937988, -15.835859298706055, -17.72011375427246, -16.376996994018555, -18.320817947387695, -18.021095275878906, -19.154430389404297, -20.864482879638672, -21.239959716796875, -21.963359832763672, -25.07080078125, -26.116100311279297, -30.271984100341797, -28.944364547729492, -28.847408294677734, -29.978618621826172, -30.224252700805664, -32.826053619384766, -32.84794998168945, -29.920682907104492, -30.10662841796875, -29.76761817932129, -27.936317443847656, -28.035728454589844, -26.043289184570312, -26.779022216796875, -25.30717658996582, -23.848405838012695, -22.126745223999023, -19.611270904541016, -18.22507095336914, -17.23868179321289, -15.016010284423828, -12.601332664489746, -11.830533981323242, -9.308048248291016, -9.129190444946289, -11.283233642578125, -10.033417701721191, -7.896381378173828, -7.773183822631836, -7.35832405090332, -7.183643341064453, -6.837258338928223, -6.301883220672607, -2.789696455001831, -5.530904293060303, 0.0, 0.0, 3.3476195335388184, 3.2076423168182373, 2.676781415939331, 2.583745002746582, 0.0, 0.0, 0.0, -0.0, -0.0, -17.610092163085938, -16.280452728271484, -16.200429916381836, -14.485918998718262, -14.46544075012207, -13.08807373046875, -10.815369606018066, -10.54008960723877, -0.0, -0.0, -0.0, -0.0, -11.236093521118164, -10.311141967773438, -13.887581825256348, -12.691520690917969, -10.369959831237793, -12.413091659545898, -14.170770645141602, -15.092007637023926, -14.667462348937988, -15.835859298706055, -17.72011375427246, -16.376996994018555, -18.320817947387695, -18.021095275878906, -19.154430389404297, -20.864482879638672, -21.239959716796875, -21.963359832763672, -25.07080078125, -26.116100311279297, -30.271984100341797, -28.944364547729492, -28.847408294677734, -29.978618621826172, -30.224252700805664, -32.826053619384766, -32.84794998168945, -29.920682907104492, -30.10662841796875, -29.76761817932129, -27.936317443847656, -28.035728454589844, -26.043289184570312, -26.779022216796875, -25.30717658996582, -23.848405838012695, -22.126745223999023, -19.611270904541016, -18.22507095336914, -17.23868179321289, -15.016010284423828, -12.601332664489746, -11.830533981323242, -9.308048248291016, -9.129190444946289, -11.283233642578125, -10.033417701721191, -7.896381378173828, -7.773183822631836, -7.35832405090332, -7.183643341064453, -6.837258338928223, -6.301883220672607, -2.789696455001831, -5.530904293060303, -0.0, 0.0, 3.3476195335388184, 3.2076423168182373, 2.676781415939331, 2.583745002746582, 0.0, 0.0, 0.0], [-15.142193794250488, 0.0, -18.123058319091797, -17.30909538269043, -17.36962127685547, -15.760987281799316, -15.205368041992188, -13.283768653869629, -12.48733901977539, -12.10462474822998, -11.396673202514648, 0.0, -11.705275535583496, 0.0, -13.474784851074219, -12.99999713897705, -9.37897777557373, -10.652913093566895, -11.79819107055664, -10.844863891601562, -14.702048301696777, -15.225172996520996, -14.900418281555176, -16.231718063354492, -17.250011444091797, -17.478527069091797, -17.525056838989258, -19.024784088134766, -19.519046783447266, -19.833404541015625, -22.564878463745117, -24.261842727661133, -25.903234481811523, -26.269441604614258, -28.38471031188965, -28.610410690307617, -29.256723403930664, -30.54373550415039, -31.35944366455078, -30.626991271972656, -31.64112663269043, -31.785877227783203, -29.348134994506836, -30.180307388305664, -28.54616928100586, -27.18227767944336, -27.541196823120117, -26.536272048950195, -25.091705322265625, -23.30776023864746, -21.753889083862305, -20.474288940429688, -18.787288665771484, -17.108224868774414, -16.28426170349121, -13.454450607299805, -10.61337947845459, -10.689921379089355, -8.27565860748291, -9.233244895935059, -6.3725714683532715, -3.3320372104644775, -6.888973236083984, -9.213807106018066, -7.345145225524902, -6.472420692443848, -5.977728843688965, -0.9463806748390198, 0.0, 0.0, 0.0, 2.1205015182495117, 2.4914727210998535, 0.5706743001937866, 2.542309284210205, 0.0, 0.0, 2.5107364654541016, -15.142193794250488, -0.0, -18.123058319091797, -17.30909538269043, -17.36962127685547, -15.760987281799316, -15.205368041992188, -13.283768653869629, -12.48733901977539, -12.10462474822998, -11.396673202514648, -0.0, -11.705275535583496, -0.0, -13.474784851074219, -12.99999713897705, -9.37897777557373, -10.652913093566895, -11.79819107055664, -10.844863891601562, -14.702048301696777, -15.225172996520996, -14.900418281555176, -16.231718063354492, -17.250011444091797, -17.478527069091797, -17.525056838989258, -19.024784088134766, -19.519046783447266, -19.833404541015625, -22.564878463745117, -24.261842727661133, -25.903234481811523, -26.269441604614258, -28.38471031188965, -28.610410690307617, -29.256723403930664, -30.54373550415039, -31.35944366455078, -30.626991271972656, -31.64112663269043, -31.785877227783203, -29.348134994506836, -30.180307388305664, -28.54616928100586, -27.18227767944336, -27.541196823120117, -26.536272048950195, -25.091705322265625, -23.30776023864746, -21.753889083862305, -20.474288940429688, -18.787288665771484, -17.108224868774414, -16.28426170349121, -13.454450607299805, -10.61337947845459, -10.689921379089355, -8.27565860748291, -9.233244895935059, -6.3725714683532715, -3.3320372104644775, -6.888973236083984, -9.213807106018066, -7.345145225524902, -6.472420692443848, -5.977728843688965, -0.9463806748390198, -0.0, -0.0, 0.0, 2.1205015182495117, 2.4914727210998535, 0.5706743001937866, 2.542309284210205, 0.0, -0.0, 2.5107364654541016], [-15.814570426940918, 0.0, -18.072702407836914, 0.0, -15.656556129455566, -15.76420783996582, -15.55783748626709, -14.498368263244629, -13.235713005065918, -12.790396690368652, -12.425641059875488, 0.0, 0.0, 0.0, -14.765230178833008, -14.510226249694824, -11.707642555236816, -11.59814167022705, -12.84821605682373, -12.35004711151123, -11.112430572509766, -14.170899391174316, -18.582149505615234, -18.301084518432617, -16.015132904052734, -17.222017288208008, -19.81130599975586, -19.3490047454834, -19.944555282592773, -21.283971786499023, -22.809406280517578, -24.912899017333984, -27.12944793701172, -26.942564010620117, -30.0704345703125, -29.69332504272461, -28.954513549804688, -29.38512420654297, -31.875179290771484, -31.560726165771484, -30.909921646118164, -33.385581970214844, -30.771240234375, -30.013586044311523, -29.169422149658203, -28.972393035888672, -28.743701934814453, -27.619464874267578, -23.126169204711914, -24.57365608215332, -22.44493865966797, -22.58793067932129, -19.741212844848633, -17.87599754333496, -15.780288696289062, -15.861201286315918, -13.642607688903809, -11.816603660583496, -9.500028610229492, -6.98721170425415, -7.237428665161133, -7.035310745239258, -8.091243743896484, -4.8042449951171875, 0.0, -7.13388204574585, -6.578019618988037, 0.0, 0.0, 0.0, 2.271965742111206, 2.864992141723633, 0.7590864300727844, 1.49326753616333, 0.0, 0.0, -2.6655330657958984, 0.0, -15.814570426940918, -0.0, -18.072702407836914, -0.0, -15.656556129455566, -15.76420783996582, -15.55783748626709, -14.498368263244629, -13.235713005065918, -12.790396690368652, -12.425641059875488, -0.0, -0.0, -0.0, -14.765230178833008, -14.510226249694824, -11.707642555236816, -11.59814167022705, -12.84821605682373, -12.35004711151123, -11.112430572509766, -14.170899391174316, -18.582149505615234, -18.301084518432617, -16.015132904052734, -17.222017288208008, -19.81130599975586, -19.3490047454834, -19.944555282592773, -21.283971786499023, -22.809406280517578, -24.912899017333984, -27.12944793701172, -26.942564010620117, -30.0704345703125, -29.69332504272461, -28.954513549804688, -29.38512420654297, -31.875179290771484, -31.560726165771484, -30.909921646118164, -33.385581970214844, -30.771240234375, -30.013586044311523, -29.169422149658203, -28.972393035888672, -28.743701934814453, -27.619464874267578, -23.126169204711914, -24.57365608215332, -22.44493865966797, -22.58793067932129, -19.741212844848633, -17.87599754333496, -15.780288696289062, -15.861201286315918, -13.642607688903809, -11.816603660583496, -9.500028610229492, -6.98721170425415, -7.237428665161133, -7.035310745239258, -8.091243743896484, -4.8042449951171875, -0.0, -7.13388204574585, -6.578019618988037, -0.0, -0.0, 0.0, 2.271965742111206, 2.864992141723633, 0.7590864300727844, 1.49326753616333, 0.0, -0.0, -2.6655330657958984, -0.0], [0.0, -22.70986557006836, -18.981586456298828, -19.768686294555664, 0.0, -16.240808486938477, -16.862995147705078, -14.600837707519531, -15.410741806030273, -11.685140609741211, -12.91869068145752, -12.531340599060059, 0.0, -15.230804443359375, -13.732839584350586, -16.56549072265625, -14.073945045471191, -10.889579772949219, -10.197728157043457, -9.4220552444458, 0.0, -10.912216186523438, -13.922330856323242, -14.477405548095703, -15.698317527770996, -16.668922424316406, -18.334081649780273, -18.975114822387695, -21.386459350585938, -21.103246688842773, -24.153413772583008, -25.50993537902832, -27.693574905395508, -27.642148971557617, -28.476490020751953, -31.162927627563477, -29.601179122924805, -31.345041275024414, -29.676376342773438, -31.315767288208008, -30.893619537353516, -30.685556411743164, -31.128084182739258, -31.914506912231445, -30.340179443359375, -29.42479705810547, -29.356773376464844, -27.106176376342773, -27.025901794433594, -26.378007888793945, -24.078948974609375, -21.815353393554688, -21.148168563842773, -18.49144744873047, -17.54506492614746, -15.39520263671875, -13.836669921875, -14.325446128845215, -10.573892593383789, -8.655162811279297, -7.624489784240723, -7.515487194061279, -4.642355442047119, 0.0, 0.0, 0.0, -6.021998882293701, 0.0, 0.0, 0.0, 2.6997828483581543, 1.483014464378357, 1.9222198724746704, 2.110884189605713, 0.0, -1.5358643531799316, -2.6757559776306152, 0.0, -0.0, -22.70986557006836, -18.981586456298828, -19.768686294555664, -0.0, -16.240808486938477, -16.862995147705078, -14.600837707519531, -15.410741806030273, -11.685140609741211, -12.91869068145752, -12.531340599060059, -0.0, -15.230804443359375, -13.732839584350586, -16.56549072265625, -14.073945045471191, -10.889579772949219, -10.197728157043457, -9.4220552444458, -0.0, -10.912216186523438, -13.922330856323242, -14.477405548095703, -15.698317527770996, -16.668922424316406, -18.334081649780273, -18.975114822387695, -21.386459350585938, -21.103246688842773, -24.153413772583008, -25.50993537902832, -27.133312225341797, -27.7337703704834, -28.57234001159668, -30.623703002929688, -29.823104858398438, -31.155696868896484, -30.113710403442383, -31.214141845703125, -30.92504119873047, -30.82645606994629, -31.07423210144043, -31.511999130249023, -30.364742279052734, -29.55817985534668, -29.21302604675293, -27.414640426635742, -26.95287322998047, -26.0098876953125, -24.000680923461914, -21.951175689697266, -20.736902236938477, -18.49144744873047, -17.54506492614746, -15.39520263671875, -13.836669921875, -14.325446128845215, -10.573892593383789, -8.655162811279297, -7.624489784240723, -7.515487194061279, -4.642355442047119, -0.0, -0.0, -0.0, -6.021998882293701, -0.0, -0.0, 0.0, 2.6997828483581543, 1.483014464378357, 1.9222198724746704, 2.110884189605713, -0.0, -1.5358643531799316, -2.6757559776306152, -0.0], [0.0, -21.953659057617188, -18.585657119750977, 0.0, 0.0, -17.806222915649414, -16.03045654296875, -15.299656867980957, -14.230249404907227, -13.223414421081543, -12.063794136047363, -13.277923583984375, 0.0, 0.0, -16.81880760192871, 0.0, 0.0, -15.78210163116455, -15.181239128112793, 0.0, -9.564595222473145, -13.597314834594727, -13.85201358795166, -15.299836158752441, -15.726332664489746, -16.938003540039062, -18.47042465209961, -18.825883865356445, -20.869842529296875, -23.086549758911133, -22.982940673828125, -25.459781646728516, -26.06971549987793, -28.046588897705078, -28.752578735351562, -30.25470542907715, -30.876176834106445, -32.57852554321289, -32.97451400756836, -31.08561134338379, -32.992218017578125, -31.381309509277344, -31.29840660095215, -31.9987850189209, -29.658815383911133, -30.733585357666016, -30.01361656188965, -28.960615158081055, -26.82357406616211, -23.663291931152344, -24.505413055419922, -23.37659454345703, -20.151182174682617, -19.44699478149414, -16.986103057861328, -16.765920639038086, -14.607096672058105, -13.150131225585938, -12.453927993774414, -14.173584938049316, -9.398944854736328, -7.575831890106201, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.900420904159546, 0.4680091142654419, 0.27158769965171814, 0.2453501969575882, 0.0, 0.0, 0.7658215761184692, 0.18029272556304932, 0.0, -0.0, -21.953659057617188, -18.585657119750977, -0.0, -0.0, -17.806222915649414, -16.03045654296875, -15.299656867980957, -14.230249404907227, -13.223414421081543, -12.063794136047363, -13.277923583984375, -0.0, -0.0, -16.81880760192871, -0.0, -0.0, -15.78210163116455, -15.181239128112793, -0.0, -9.564595222473145, -13.597314834594727, -13.85201358795166, -15.299836158752441, -15.726332664489746, -16.938003540039062, -18.47042465209961, -18.825883865356445, -20.869842529296875, -23.086549758911133, -22.982940673828125, -25.459781646728516, -26.568721771240234, -28.046968460083008, -29.198087692260742, -30.261096954345703, -30.64051628112793, -31.094058990478516, -31.09760093688965, -31.241378784179688, -31.208602905273438, -31.203454971313477, -31.323352813720703, -31.376766204833984, -30.90789031982422, -30.32556915283203, -29.643640518188477, -28.556751251220703, -27.503755569458008, -26.176280975341797, -24.458232879638672, -22.552152633666992, -20.5163516998291, -19.44699478149414, -16.986103057861328, -16.765920639038086, -14.607096672058105, -13.150131225585938, -12.453927993774414, -14.173584938049316, -9.398944854736328, -7.575831890106201, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -2.900420904159546, 0.4680091142654419, 0.27158769965171814, 0.2453501969575882, 0.0, 0.0, 0.7658215761184692, 0.18029272556304932, 0.0], [0.0, -21.097103118896484, -21.936025619506836, 0.0, 0.0, 0.0, -16.32323455810547, -16.17030906677246, -15.409524917602539, -14.865795135498047, -14.322622299194336, -13.299040794372559, -10.820584297180176, 0.0, -18.550905227661133, 0.0, 0.0, 0.0, -14.634873390197754, 0.0, 0.0, 0.0, -15.477011680603027, -19.636882781982422, -19.5678653717041, -20.478116989135742, -20.007080078125, -20.85260009765625, -21.77004051208496, -23.167621612548828, -24.22425651550293, -26.639244079589844, -27.496156692504883, -28.312402725219727, -29.425363540649414, -30.303897857666016, -31.435089111328125, -32.4395637512207, -31.992708206176758, -32.030853271484375, -31.751468658447266, -31.795841217041016, -31.450214385986328, -32.62693405151367, -31.575206756591797, -32.07695770263672, -30.04351043701172, -29.30742645263672, -29.56559181213379, -26.328462600708008, -26.235206604003906, -23.949678421020508, -22.008087158203125, -20.376262664794922, -18.67411994934082, -18.285757064819336, -16.249116897583008, -15.000418663024902, -11.730731010437012, -14.719738006591797, 0.0, 0.0, -8.793110847473145, -7.947540283203125, 0.0, 0.0, 0.0, 0.0, 0.0, -0.674735426902771, -0.706669807434082, -0.4325689971446991, -0.2775191366672516, 0.0, -2.1672658920288086, 0.0, -1.9674314260482788, 0.0, -0.0, -21.097103118896484, -21.936025619506836, -0.0, -0.0, -0.0, -16.32323455810547, -16.17030906677246, -15.409524917602539, -14.865795135498047, -14.322622299194336, -13.299040794372559, -10.820584297180176, -0.0, -18.550905227661133, -0.0, -0.0, -0.0, -14.634873390197754, -0.0, -0.0, -0.0, -15.477011680603027, -19.636882781982422, -19.5678653717041, -20.478116989135742, -20.007080078125, -20.85260009765625, -21.77004051208496, -23.167621612548828, -24.22425651550293, -26.639244079589844, -27.531850814819336, -28.57754135131836, -29.57082176208496, -30.377071380615234, -30.962282180786133, -31.25347137451172, -31.340787887573242, -31.276681900024414, -31.24305534362793, -31.274484634399414, -31.36097526550293, -31.384613037109375, -31.220958709716797, -30.824378967285156, -30.149526596069336, -29.237459182739258, -28.00118064880371, -26.49631118774414, -24.811969757080078, -23.085147857666016, -21.744861602783203, -20.376262664794922, -18.67411994934082, -18.285757064819336, -16.249116897583008, -15.000418663024902, -11.730731010437012, -14.719738006591797, -0.0, -0.0, -8.793110847473145, -7.947540283203125, -0.0, -0.0, -0.0, -0.0, -0.0, -0.674735426902771, -0.706669807434082, -0.4325689971446991, -0.2775191366672516, -0.0, -2.1672658920288086, 0.0, -1.9674314260482788, 0.0], [0.0, -19.371482849121094, -21.117612838745117, 0.0, 0.0, 0.0, -16.25369644165039, -16.819581985473633, -15.48426342010498, -15.013528823852539, -15.11025619506836, -14.640240669250488, -14.118097305297852, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.635221481323242, -20.44477653503418, -20.58505630493164, -20.892597198486328, -21.91690444946289, -21.17635726928711, -23.617467880249023, -25.67121124267578, -24.745073318481445, -27.48297119140625, -28.282161712646484, -27.759103775024414, -27.435861587524414, -26.805665969848633, -27.096797943115234, -31.23810577392578, -33.01435852050781, -31.578447341918945, -29.415084838867188, -31.021577835083008, -31.273635864257812, -31.180871963500977, -32.21016311645508, -31.372329711914062, -33.21214294433594, -31.061038970947266, -29.356346130371094, -28.89667320251465, -25.430809020996094, -23.137142181396484, -20.926481246948242, -21.172456741333008, -19.95962142944336, -18.7159366607666, -16.721025466918945, -17.93048667907715, -14.528738975524902, -15.223240852355957, -16.523685455322266, -15.225565910339355, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.2105422019958496, -0.9572631120681763, -0.769868791103363, -2.737168312072754, 0.0, 1.0762763023376465, -1.3871140480041504, -2.9183850288391113, 0.0, -0.0, -19.371482849121094, -21.117612838745117, -0.0, -0.0, -0.0, -16.25369644165039, -16.819581985473633, -15.48426342010498, -15.013528823852539, -15.11025619506836, -14.640240669250488, -14.118097305297852, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.635221481323242, -20.44477653503418, -20.58505630493164, -20.892597198486328, -21.91690444946289, -21.17635726928711, -23.617467880249023, -25.67121124267578, -24.745073318481445, -27.48297119140625, -28.22832489013672, -29.0817928314209, -29.932844161987305, -30.65195655822754, -31.149808883666992, -31.310510635375977, -31.255573272705078, -31.11341094970703, -31.04450035095215, -31.0854434967041, -31.19976806640625, -31.30845832824707, -31.29823112487793, -31.02421760559082, -30.497224807739258, -29.680776596069336, -28.37617301940918, -26.830299377441406, -25.046430587768555, -23.158401489257812, -21.09442138671875, -21.172456741333008, -19.95962142944336, -18.7159366607666, -16.721025466918945, -17.93048667907715, -14.528738975524902, -15.223240852355957, -16.523685455322266, -15.225565910339355, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -3.2105422019958496, -0.9572631120681763, -0.769868791103363, -2.737168312072754, 0.0, 1.0762763023376465, -1.3871140480041504, -2.9183850288391113, -0.0], [0.0, 0.0, 0.0, -17.77823829650879, -18.14102554321289, 0.0, 0.0, -16.946348190307617, -16.4810791015625, -17.537277221679688, -15.498868942260742, -14.161121368408203, -15.209803581237793, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.26322364807129, 0.0, -19.05402946472168, -21.28118896484375, -20.890052795410156, -24.055147171020508, -22.512155532836914, -23.957637786865234, -24.134239196777344, -27.11894416809082, -27.10430335998535, -26.53265380859375, -28.42302131652832, -30.057790756225586, -30.86720848083496, -31.149608612060547, -30.88125228881836, -32.3577766418457, -31.915658950805664, -31.068798065185547, -31.372819900512695, -31.31739616394043, -31.343467712402344, -32.73983383178711, -31.869213104248047, -32.664649963378906, -29.742095947265625, -31.077260971069336, -29.992801666259766, -27.594730377197266, -26.252180099487305, -23.817773818969727, -21.62349510192871, -21.01707649230957, -18.72318458557129, -20.485788345336914, -18.46683692932129, 0.0, 0.0, -14.96243667602539, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.666548728942871, -2.718245506286621, -1.1865805387496948, 0.0, 0.0, 0.0, -0.28947770595550537, 0.0, 0.0, -0.0, -0.0, -0.0, -17.77823829650879, -18.14102554321289, -0.0, -0.0, -16.946348190307617, -16.4810791015625, -17.537277221679688, -15.498868942260742, -14.161121368408203, -15.209803581237793, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.26322364807129, -0.0, -19.05402946472168, -21.28118896484375, -20.890052795410156, -24.055147171020508, -22.512155532836914, -23.957637786865234, -24.134239196777344, -27.11894416809082, -27.10430335998535, -26.53265380859375, -28.549667358398438, -29.530061721801758, -30.302322387695312, -30.91602897644043, -31.20627784729004, -31.119909286499023, -30.917177200317383, -30.718172073364258, -30.62506675720215, -30.67118263244629, -30.82552719116211, -31.022733688354492, -31.154430389404297, -31.033369064331055, -30.542207717895508, -29.74066734313965, -28.54518699645996, -27.008832931518555, -25.20444679260254, -23.33109474182129, -21.612525939941406, -21.01707649230957, -18.72318458557129, -20.485788345336914, -18.46683692932129, -0.0, -0.0, -14.96243667602539, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -2.666548728942871, -2.718245506286621, -1.1865805387496948, -0.0, 0.0, 0.0, -0.28947770595550537, -0.0, -0.0], [0.0, 0.0, 0.0, -19.146686553955078, -18.89920425415039, 0.0, 0.0, 0.0, -17.316028594970703, -16.877731323242188, -15.390420913696289, -13.789676666259766, -16.21729278564453, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.142297744750977, -16.87262725830078, -20.612102508544922, -20.2774658203125, -21.833683013916016, 0.0, -23.129810333251953, -26.070890426635742, -27.94162368774414, -27.687381744384766, -28.629840850830078, -29.597030639648438, -29.910987854003906, -31.477558135986328, -31.441362380981445, -32.16774368286133, -32.649044036865234, -31.995397567749023, -31.41875457763672, -29.88176155090332, -30.05187225341797, -30.3785457611084, -32.49439239501953, -30.896812438964844, -33.1248664855957, -30.582761764526367, -31.085325241088867, -30.536834716796875, -29.076936721801758, -26.651342391967773, -21.3211727142334, -21.78925323486328, 0.0, -21.799684524536133, -20.584875106811523, -20.080074310302734, 0.0, 0.0, 0.0, 0.0, 0.0, -19.804590225219727, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -4.791971683502197, -3.7536697387695312, -3.374206304550171, 0.0, 0.0, -2.6792349815368652, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -19.146686553955078, -18.89920425415039, -0.0, -0.0, -0.0, -17.316028594970703, -16.877731323242188, -15.390420913696289, -13.789676666259766, -16.21729278564453, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.142297744750977, -16.87262725830078, -20.612102508544922, -20.2774658203125, -21.833683013916016, -0.0, -23.129810333251953, -26.070890426635742, -27.94162368774414, -27.687381744384766, -28.629840850830078, -29.572505950927734, -30.124792098999023, -30.631370544433594, -31.017953872680664, -31.062793731689453, -30.75506591796875, -30.412477493286133, -30.145191192626953, -30.02259635925293, -30.072799682617188, -30.27302360534668, -30.56102752685547, -30.794252395629883, -30.812744140625, -30.3937931060791, -29.649986267089844, -28.597793579101562, -27.171539306640625, -25.38220977783203, -23.387653350830078, -21.69573974609375, -0.0, -21.799684524536133, -20.584875106811523, -20.080074310302734, -0.0, -0.0, -0.0, -0.0, -0.0, -19.804590225219727, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -4.791971683502197, -3.7536697387695312, -3.374206304550171, -0.0, -0.0, -2.6792349815368652, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, -21.154644012451172, -21.504650115966797, -21.38935661315918, 0.0, 0.0, -17.67774772644043, -16.985729217529297, -16.952512741088867, -15.028682708740234, -16.81964683532715, 0.0, 0.0, -17.32161521911621, 0.0, 0.0, 0.0, -14.989496231079102, 0.0, -20.525718688964844, -19.60308074951172, -20.431398391723633, -21.53569221496582, -21.301259994506836, -23.76471710205078, 0.0, -26.585657119750977, -28.59735870361328, 0.0, -31.465852737426758, -30.336803436279297, -30.04572296142578, -32.615867614746094, -32.41279602050781, -32.540565490722656, -32.252010345458984, -31.180797576904297, -30.89689064025879, -28.603483200073242, -29.643749237060547, -30.069477081298828, -30.465457916259766, -33.636199951171875, -31.011701583862305, -28.856149673461914, -31.3137149810791, -25.99737548828125, -24.42152214050293, -26.31934356689453, -22.217575073242188, -20.488292694091797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.47464370727539, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.8702404499053955, -4.223897933959961, 0.0, -3.8309640884399414, -5.136585712432861, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -21.154644012451172, -21.504650115966797, -21.38935661315918, -0.0, -0.0, -17.67774772644043, -16.985729217529297, -16.952512741088867, -15.028682708740234, -16.81964683532715, -0.0, -0.0, -17.32161521911621, -0.0, -0.0, -0.0, -14.989496231079102, -0.0, -20.525718688964844, -19.60308074951172, -20.431398391723633, -21.53569221496582, -21.301259994506836, -23.76471710205078, -0.0, -26.585657119750977, -28.59735870361328, -0.0, -31.465852737426758, -30.242477416992188, -30.686582565307617, -30.895952224731445, -31.002071380615234, -30.799251556396484, -30.294645309448242, -29.804872512817383, -29.456989288330078, -29.295106887817383, -29.344284057617188, -29.60565948486328, -29.987350463867188, -30.31655502319336, -30.406984329223633, -30.074241638183594, -29.393173217773438, -28.542856216430664, -27.388839721679688, -25.704381942749023, -23.58513832092285, -21.257490158081055, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.47464370727539, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -3.8702404499053955, -4.223897933959961, -0.0, -3.8309640884399414, -5.136585712432861, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -21.804210662841797, -18.163915634155273, -19.28907012939453, 0.0, 0.0, -17.381206512451172, -17.58435821533203, -17.261890411376953, -18.316417694091797, 0.0, -15.959546089172363, -15.020256042480469, -18.677526473999023, -16.205673217773438, -16.114906311035156, -14.528833389282227, 0.0, -17.939353942871094, -21.16488265991211, -18.498111724853516, -23.21763038635254, -20.629148483276367, -23.350858688354492, -24.33125114440918, 0.0, 0.0, -23.412004470825195, 0.0, -31.86756706237793, 0.0, 0.0, -34.19757080078125, -33.688289642333984, -31.322355270385742, -30.191802978515625, -30.09227752685547, -28.57758903503418, -28.385465621948242, -28.648345947265625, -29.60298728942871, -29.280059814453125, -26.20417022705078, -29.701553344726562, -26.558807373046875, -24.235248565673828, -23.07435417175293, -27.046058654785156, -27.510555267333984, 0.0, 0.0, 0.0, 0.0, 0.0, -17.875770568847656, 0.0, -17.508270263671875, 0.0, -18.056903839111328, -16.107942581176758, -16.6196231842041, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.907141208648682, -5.692636013031006, 0.0, -9.10390567779541, -7.516848087310791, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -21.804210662841797, -18.163915634155273, -19.28907012939453, -0.0, -0.0, -17.381206512451172, -17.58435821533203, -17.261890411376953, -18.316417694091797, -0.0, -15.959546089172363, -15.020256042480469, -18.677526473999023, -16.205673217773438, -16.114906311035156, -14.528833389282227, -0.0, -17.939353942871094, -21.16488265991211, -18.498111724853516, -23.21763038635254, -20.629148483276367, -23.350858688354492, -24.33125114440918, -0.0, -0.0, -23.412004470825195, -0.0, -31.451034545898438, -0.0, -0.0, -30.814897537231445, -30.363346099853516, -29.645357131958008, -29.021595001220703, -28.647300720214844, -28.477598190307617, -28.521696090698242, -28.814393997192383, -29.270708084106445, -29.743696212768555, -29.985044479370117, -29.694255828857422, -28.941133499145508, -28.272916793823242, -27.420495986938477, -26.417560577392578, -24.809955596923828, -0.0, -0.0, -0.0, -0.0, -0.0, -17.875770568847656, -0.0, -17.508270263671875, -0.0, -18.056903839111328, -16.107942581176758, -16.6196231842041, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.907141208648682, -5.692636013031006, -0.0, -9.10390567779541, -7.516848087310791, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -21.834964752197266, -20.30477523803711, 0.0, 0.0, -17.876379013061523, -17.43027114868164, -18.331098556518555, 0.0, 0.0, -15.741739273071289, 0.0, -17.39525604248047, -16.382177352905273, -17.909244537353516, -17.939701080322266, -17.55324363708496, 0.0, -19.572277069091797, 0.0, -19.807003021240234, -22.429758071899414, -21.788557052612305, 0.0, 0.0, 0.0, 0.0, 0.0, -32.113826751708984, -32.42024230957031, 0.0, 0.0, -27.995460510253906, -31.953237533569336, -29.690828323364258, -28.641992568969727, -27.76470947265625, -26.59947395324707, -26.385515213012695, -27.321704864501953, -29.637088775634766, -25.97794532775879, 0.0, -28.72239875793457, -26.299785614013672, -25.16476821899414, -27.91531753540039, -30.382596969604492, 0.0, 0.0, 0.0, 0.0, -20.880281448364258, -18.518529891967773, -19.824954986572266, -20.935861587524414, -18.00724220275879, -18.467113494873047, -17.245342254638672, -18.038780212402344, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.428657531738281, -6.766026020050049, 0.0, -8.097640991210938, -8.01783561706543, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -21.834964752197266, -20.30477523803711, -0.0, -0.0, -17.876379013061523, -17.43027114868164, -18.331098556518555, -0.0, -0.0, -15.741739273071289, -0.0, -17.39525604248047, -16.382177352905273, -17.909244537353516, -17.939701080322266, -17.55324363708496, -0.0, -19.572277069091797, -0.0, -19.807003021240234, -22.429758071899414, -21.788557052612305, -0.0, -0.0, -0.0, -0.0, -0.0, -31.729347229003906, -31.355342864990234, -0.0, -0.0, -29.697553634643555, -28.793106079101562, -28.13770866394043, -27.784725189208984, -27.62002944946289, -27.66758155822754, -27.9151554107666, -28.36204719543457, -28.98739242553711, -29.56223487854004, -0.0, -28.281150817871094, -27.57375717163086, -27.335845947265625, -27.317445755004883, -27.39652442932129, -0.0, -0.0, -0.0, -0.0, -20.880281448364258, -18.518529891967773, -19.824954986572266, -20.935861587524414, -18.00724220275879, -18.467113494873047, -17.245342254638672, -18.038780212402344, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.428657531738281, -6.766026020050049, -0.0, -8.097640991210938, -8.01783561706543, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -18.99011993408203, -21.93366050720215, 0.0, 0.0, -19.864578247070312, -19.96919059753418, -18.148218154907227, 0.0, 0.0, 0.0, 0.0, -18.21953773498535, -17.97977066040039, -18.83208656311035, -17.560102462768555, -19.106121063232422, -18.290802001953125, -20.182491302490234, -20.61513900756836, -21.119163513183594, -22.018095016479492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -32.016822814941406, -29.467071533203125, -29.790443420410156, 0.0, -26.52250099182129, -31.29066276550293, -29.096561431884766, -29.356870651245117, -29.269542694091797, -23.596599578857422, -23.12607192993164, -25.56079864501953, 0.0, 0.0, 0.0, -25.955368041992188, -28.9826602935791, -26.188352584838867, -23.41902732849121, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.344894409179688, -20.053194046020508, -20.513856887817383, -19.41023063659668, -19.31881332397461, -19.201990127563477, -21.03251838684082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.566023588180542, -4.475422382354736, -5.803646087646484, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.99011993408203, -21.93366050720215, -0.0, -0.0, -19.864578247070312, -19.96919059753418, -18.148218154907227, -0.0, -0.0, -0.0, -0.0, -18.21953773498535, -17.97977066040039, -18.83208656311035, -17.560102462768555, -19.106121063232422, -18.290802001953125, -20.182491302490234, -20.61513900756836, -21.119163513183594, -22.018095016479492, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -31.994277954101562, -30.98697280883789, -30.784761428833008, -0.0, -29.051517486572266, -27.992326736450195, -27.36086654663086, -26.88299560546875, -26.656208038330078, -26.75864601135254, -26.934146881103516, -27.210798263549805, -0.0, -0.0, -0.0, -27.56863021850586, -27.07646369934082, -27.471405029296875, -27.583003997802734, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.344894409179688, -20.053194046020508, -20.513856887817383, -19.41023063659668, -19.31881332397461, -19.201990127563477, -21.03251838684082, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -3.566023588180542, -4.475422382354736, -5.803646087646484, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -20.19196891784668, -23.670862197875977, -23.77666473388672, 0.0, -20.37005043029785, -20.032289505004883, 0.0, 0.0, -14.781414985656738, 0.0, 0.0, -18.715354919433594, -18.517169952392578, -18.46884536743164, -19.125703811645508, -19.494009017944336, -19.23457908630371, -19.952661514282227, -21.2839298248291, -21.757949829101562, -22.080652236938477, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.09382438659668, 0.0, -27.30005645751953, -29.313234329223633, -28.970361709594727, -29.170351028442383, 0.0, -25.047914505004883, -25.471403121948242, 0.0, 0.0, -27.475553512573242, 0.0, -27.223155975341797, -29.811250686645508, -27.222490310668945, -27.20677947998047, -25.637218475341797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.55684471130371, -23.076160430908203, -21.446046829223633, -21.865259170532227, -21.757884979248047, -21.932321548461914, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.704433441162109, -6.860802173614502, -4.670124530792236, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.19196891784668, -23.670862197875977, -23.77666473388672, -0.0, -20.37005043029785, -20.032289505004883, -0.0, -0.0, -14.781414985656738, -0.0, -0.0, -18.715354919433594, -18.517169952392578, -18.46884536743164, -19.125703811645508, -19.494009017944336, -19.23457908630371, -19.952661514282227, -21.2839298248291, -21.757949829101562, -22.080652236938477, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -30.348440170288086, -0.0, -30.179140090942383, -28.802337646484375, -27.602123260498047, -26.712636947631836, -0.0, -25.625293731689453, -25.72038459777832, -0.0, -0.0, -26.344364166259766, -0.0, -27.6741886138916, -27.140966415405273, -26.60646629333496, -26.76761817932129, -26.87165069580078, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.55684471130371, -23.076160430908203, -21.446046829223633, -21.865259170532227, -21.757884979248047, -21.932321548461914, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.704433441162109, -6.860802173614502, -4.670124530792236, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -20.687469482421875, -21.417417526245117, -23.495206832885742, 0.0, 0.0, 0.0, 0.0, 0.0, -14.398082733154297, -19.736618041992188, -19.90215492248535, -19.7443790435791, -19.29784393310547, -18.594425201416016, -18.88164710998535, -19.63379669189453, -20.981653213500977, -21.48006248474121, -22.04433822631836, -21.130870819091797, -23.122621536254883, -24.328723907470703, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.870573043823242, -24.666120529174805, 0.0, 0.0, -25.866052627563477, 0.0, 0.0, 0.0, -28.269866943359375, -26.318687438964844, -25.20009422302246, -28.01584815979004, -25.775714874267578, -24.490365982055664, -24.412508010864258, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.04292869567871, -22.79654884338379, -24.61865997314453, -23.88596534729004, -23.225210189819336, -17.434629440307617, -18.023094177246094, -16.459999084472656, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.86022424697876, -8.207759857177734, -9.968642234802246, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.687469482421875, -21.417417526245117, -23.495206832885742, -0.0, -0.0, -0.0, -0.0, -0.0, -14.398082733154297, -19.736618041992188, -19.90215492248535, -19.7443790435791, -19.29784393310547, -18.594425201416016, -18.88164710998535, -19.63379669189453, -20.981653213500977, -21.48006248474121, -22.04433822631836, -21.130870819091797, -23.122621536254883, -24.328723907470703, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.535306930541992, -27.60803985595703, -0.0, -0.0, -25.416410446166992, -0.0, -0.0, -0.0, -25.82684326171875, -26.116304397583008, -26.304027557373047, -26.242542266845703, -25.815080642700195, -25.80170249938965, -25.909645080566406, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.04292869567871, -22.79654884338379, -24.61865997314453, -23.88596534729004, -23.225210189819336, -17.434629440307617, -18.023094177246094, -16.459999084472656, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.86022424697876, -8.207759857177734, -9.968642234802246, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -19.72853660583496, -21.239152908325195, -24.290021896362305, 0.0, 0.0, 0.0, 0.0, 0.0, -14.827716827392578, 0.0, 0.0, -17.981714248657227, -17.954015731811523, -18.99128532409668, -19.57161521911621, -20.627328872680664, -21.0057315826416, -21.815853118896484, -23.032638549804688, -23.437068939208984, -24.799741744995117, -24.933513641357422, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.769519805908203, 0.0, 0.0, -26.700233459472656, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.69178009033203, -26.989587783813477, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.557558059692383, -25.762248992919922, -26.702133178710938, -27.031089782714844, -25.723098754882812, -25.023998260498047, -25.447221755981445, -19.848800659179688, -17.41351890563965, 0.0, -12.384058952331543, 0.0, 0.0, 0.0, 0.0, 0.0, -10.997946739196777, -8.915376663208008, -11.219687461853027, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.72853660583496, -21.239152908325195, -24.290021896362305, -0.0, -0.0, -0.0, -0.0, -0.0, -14.827716827392578, -0.0, -0.0, -17.981714248657227, -17.954015731811523, -18.99128532409668, -19.57161521911621, -20.627328872680664, -21.0057315826416, -21.815853118896484, -23.032638549804688, -23.437068939208984, -24.799741744995117, -24.933513641357422, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.40348243713379, -0.0, -0.0, -27.562490463256836, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.25347900390625, -25.619539260864258, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.557558059692383, -25.762248992919922, -26.702133178710938, -27.031089782714844, -25.723098754882812, -25.023998260498047, -25.447221755981445, -19.848800659179688, -17.41351890563965, -0.0, -12.384058952331543, -0.0, -0.0, -0.0, -0.0, -0.0, -10.997946739196777, -8.915376663208008, -11.219687461853027, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.557788848876953, -21.564119338989258, -25.990568161010742, 0.0, 0.0, 0.0, 0.0, 0.0, -12.940189361572266, 0.0, -16.515392303466797, -16.966209411621094, -17.66098403930664, -19.421674728393555, -21.016292572021484, -22.332881927490234, -23.680553436279297, -23.552509307861328, -25.450210571289062, -26.150320053100586, -25.38490104675293, -27.32701873779297, -26.027626037597656, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.17361831665039, -28.17241096496582, -26.353567123413086, 0.0, 0.0, 0.0, 0.0, 0.0, -27.421674728393555, -26.504690170288086, -28.008447647094727, -27.674198150634766, -27.14012908935547, -26.622520446777344, -26.085437774658203, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.474447250366211, -12.60169792175293, -11.920638084411621, -12.668915748596191, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.557788848876953, -21.564119338989258, -25.990568161010742, -0.0, -0.0, -0.0, -0.0, -0.0, -12.940189361572266, -0.0, -16.515392303466797, -16.966209411621094, -17.66098403930664, -19.421674728393555, -21.016292572021484, -22.332881927490234, -23.680553436279297, -23.552509307861328, -25.450210571289062, -26.150320053100586, -25.38490104675293, -27.32701873779297, -26.027626037597656, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.739360809326172, -26.46381950378418, -27.086301803588867, -0.0, -0.0, -0.0, -0.0, -0.0, -27.421674728393555, -26.504690170288086, -28.008447647094727, -27.674198150634766, -27.14012908935547, -26.622520446777344, -26.085437774658203, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -9.474447250366211, -12.60169792175293, -11.920638084411621, -12.668915748596191, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.94978141784668, -23.77846908569336, -25.363624572753906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.951898574829102, -16.313995361328125, -16.61275291442871, -18.555795669555664, -19.98786163330078, -21.859413146972656, -23.356651306152344, -24.833934783935547, -25.781391143798828, -26.958728790283203, -27.316415786743164, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.020517349243164, -29.281639099121094, 0.0, 0.0, 0.0, 0.0, -26.139554977416992, -27.464506149291992, -27.071041107177734, -26.79551124572754, -27.790237426757812, -24.110063552856445, 0.0, -24.473018646240234, -21.59267234802246, -16.563003540039062, -17.970151901245117, 0.0, 0.0, 0.0, 0.0, 0.0, -8.543150901794434, -11.407363891601562, -12.548279762268066, -14.017953872680664, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.94978141784668, -23.77846908569336, -25.363624572753906, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.951898574829102, -16.313995361328125, -16.61275291442871, -18.555795669555664, -19.98786163330078, -21.859413146972656, -23.356651306152344, -24.833934783935547, -25.781391143798828, -26.958728790283203, -27.316415786743164, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.067461013793945, -28.14118003845215, -0.0, -0.0, -0.0, -0.0, -26.139554977416992, -27.464506149291992, -27.071041107177734, -26.79551124572754, -27.790237426757812, -24.110063552856445, -0.0, -24.473018646240234, -21.59267234802246, -16.563003540039062, -17.970151901245117, -0.0, -0.0, -0.0, -0.0, -0.0, -8.543150901794434, -11.407363891601562, -12.548279762268066, -14.017953872680664, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -28.475475311279297, -26.135467529296875, -24.48812484741211, -26.75965118408203, 0.0, 0.0, 0.0, 0.0, 0.0, -21.158889770507812, -19.41934585571289, -19.42340850830078, -15.937060356140137, -17.068452835083008, -17.633544921875, -19.20542335510254, -20.496780395507812, -23.10098648071289, -25.237821578979492, -26.036128997802734, -27.311094284057617, -28.440128326416016, -28.456844329833984, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.905050277709961, 0.0, 0.0, 0.0, -16.27245330810547, 0.0, 0.0, 0.0, 0.0, -9.837929725646973, -11.29259204864502, -12.564581871032715, -14.941839218139648, -16.4360294342041, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.475475311279297, -26.135467529296875, -24.48812484741211, -26.75965118408203, -0.0, -0.0, -0.0, -0.0, -0.0, -21.158889770507812, -19.41934585571289, -19.42340850830078, -15.937060356140137, -17.068452835083008, -17.633544921875, -19.20542335510254, -20.496780395507812, -23.10098648071289, -25.237821578979492, -26.036128997802734, -27.311094284057617, -28.440128326416016, -28.456844329833984, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.905050277709961, -0.0, -0.0, -0.0, -16.27245330810547, -0.0, -0.0, -0.0, -0.0, -9.837929725646973, -11.29259204864502, -12.564581871032715, -14.941839218139648, -16.4360294342041, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.03572654724121, -26.179798126220703, -24.57866668701172, 0.0, 0.0, 0.0, 0.0, 0.0, -18.884065628051758, -18.65169334411621, -16.4815731048584, -15.910615921020508, -16.860464096069336, -16.535181045532227, -17.336002349853516, 0.0, -28.484939575195312, -27.759719848632812, -26.767438888549805, -27.69916343688965, -27.99675178527832, -27.255599975585938, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.363856315612793, 0.0, 0.0, 0.0, 0.0, -15.625872611999512, 0.0, 0.0, -14.675178527832031, -13.460216522216797, -13.734935760498047, -13.097620010375977, -14.550862312316895, -15.244953155517578, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.03572654724121, -26.179798126220703, -24.57866668701172, -0.0, -0.0, -0.0, -0.0, -0.0, -18.884065628051758, -18.65169334411621, -16.4815731048584, -15.910615921020508, -16.860464096069336, -16.535181045532227, -17.336002349853516, -0.0, -28.484939575195312, -27.759719848632812, -26.767438888549805, -27.69916343688965, -27.99675178527832, -27.255599975585938, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.363856315612793, -0.0, -0.0, -0.0, -0.0, -15.625872611999512, -0.0, -0.0, -14.675178527832031, -13.460216522216797, -13.734935760498047, -13.097620010375977, -14.550862312316895, -15.244953155517578, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.3043270111084, -25.115436553955078, -23.2883243560791, 0.0, 0.0, 0.0, 0.0, -21.166635513305664, -21.102384567260742, 0.0, -13.607904434204102, -12.733122825622559, -14.39067268371582, -18.620079040527344, -16.799619674682617, 0.0, 0.0, -28.015073776245117, -23.088376998901367, 0.0, -21.544878005981445, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.298916816711426, -13.17712688446045, -9.558391571044922, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.161476135253906, -13.20398235321045, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.3043270111084, -25.115436553955078, -23.2883243560791, -0.0, -0.0, -0.0, -0.0, -21.166635513305664, -21.102384567260742, -0.0, -13.607904434204102, -12.733122825622559, -14.39067268371582, -18.620079040527344, -16.799619674682617, -0.0, -0.0, -28.015073776245117, -23.088376998901367, -0.0, -21.544878005981445, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.298916816711426, -13.17712688446045, -9.558391571044922, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.161476135253906, -13.20398235321045, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.237838745117188, -23.76214027404785, 0.0, -26.399045944213867, -29.01897430419922, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.563122749328613, 0.0, 0.0, 0.0, 0.0, -21.450847625732422, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.47219181060791, -14.334348678588867, -15.232555389404297, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.237838745117188, -23.76214027404785, -0.0, -26.399045944213867, -29.01897430419922, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.563122749328613, -0.0, -0.0, -0.0, -0.0, -21.450847625732422, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.47219181060791, -14.334348678588867, -15.232555389404297, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.640335083007812, -25.130029678344727, -26.998703002929688, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.300582885742188, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.107706069946289, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.640335083007812, -25.130029678344727, -26.998703002929688, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.300582885742188, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.107706069946289, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.40667724609375, -27.92844581604004, -25.61676788330078, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.61259937286377, -6.7746806144714355, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.40667724609375, -27.92844581604004, -25.61676788330078, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -8.61259937286377, -6.7746806144714355, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.520397663116455, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.520397663116455, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.7602105140686035, -8.742080688476562, -8.875493049621582, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.7602105140686035, -8.742080688476562, -8.875493049621582, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.485821723937988, -9.02667236328125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.485821723937988, -9.02667236328125, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.859549522399902, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.859549522399902, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.824331283569336, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.824331283569336, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.292247772216797, -14.11563777923584, -15.410381317138672, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.292247772216797, -14.11563777923584, -15.410381317138672, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.260727882385254, -12.736095428466797, -17.197904586791992, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.260727882385254, -12.736095428466797, -17.197904586791992, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.901641845703125, -14.05998706817627, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.901641845703125, -14.05998706817627, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0]]}, {\"colorbar\": {\"title\": {\"text\": \"B<sub>0</sub> (Hz)\"}}, \"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.3333333333333333, \"rgb(230,0,0)\"], [0.6666666666666666, \"rgb(255,210,0)\"], [1.0, \"rgb(255,255,255)\"]], \"name\": \"comparison heatmap\", \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 9.34232234954834, 0.0, 14.690559387207031, 15.454636573791504, 18.168888092041016, 17.19249725341797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 9.34232234954834, 0.0, 14.690559387207031, 15.454636573791504, 18.168888092041016, 17.19249725341797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 14.46295166015625, 15.788264274597168, 13.766094207763672, 0.0, 0.0, 0.0, 0.0, 14.248899459838867, 16.134435653686523, 14.722389221191406, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 14.46295166015625, 15.788264274597168, 13.766094207763672, 0.0, 0.0, 0.0, 0.0, 14.248899459838867, 16.134435653686523, 14.722389221191406, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 16.687904357910156, 15.823698043823242, 0.0, 0.0, 0.0, 0.0, 0.0, 17.67000961303711, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 16.687904357910156, 15.823698043823242, 0.0, 0.0, 0.0, 0.0, 0.0, 17.67000961303711, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 14.213360786437988, 14.295931816101074, 0.0, 17.081514358520508, 0.0, 18.282440185546875, 18.54498863220215, 19.59685707092285, 18.386104583740234, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 14.213360786437988, 14.295931816101074, 0.0, 17.081514358520508, 0.0, 18.282440185546875, 18.54498863220215, 19.59685707092285, 18.386104583740234, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 16.41832160949707, 18.1240177154541, 16.161231994628906, 14.998372077941895, 14.705244064331055, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 16.41832160949707, 18.1240177154541, 16.161231994628906, 14.998372077941895, 14.705244064331055, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 12.834505081176758, 14.751853942871094, 0.0, 14.222393035888672, 0.0, 15.154871940612793, 11.508328437805176, 11.763130187988281, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 12.834505081176758, 14.751853942871094, 0.0, 14.222393035888672, 0.0, 15.154871940612793, 11.508328437805176, 11.763130187988281, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 14.637748718261719, 14.064780235290527, 12.155400276184082, 9.87022876739502, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 14.637748718261719, 14.064780235290527, 12.155400276184082, 9.87022876739502, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.222771644592285, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.222771644592285, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 9.555744171142578, 6.883336544036865, 10.58436393737793, 6.496745586395264, 4.899947166442871, 3.5207159519195557, 6.4576849937438965, 7.106412410736084, 7.731171131134033, 8.885313034057617, 11.206354141235352, 7.702980995178223, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 9.555744171142578, 6.883336544036865, 10.58436393737793, 6.496745586395264, 4.899947166442871, 3.5207159519195557, 6.4576849937438965, 7.106412410736084, 7.731171131134033, 8.885313034057617, 11.206354141235352, 7.702980995178223, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.487746715545654, 7.46236515045166, 7.023139953613281, 7.280776023864746, 7.541765213012695, 7.093616008758545, 9.113165855407715, 7.305058479309082, 5.858325481414795, 6.585829734802246, 5.85537576675415, 5.956636428833008, 6.6970720291137695, 7.094930171966553, 6.346933364868164, 7.443418502807617, 6.6723198890686035, 4.063750267028809, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.487746715545654, 7.46236515045166, 7.023139953613281, 7.280776023864746, 7.541765213012695, 7.093616008758545, 9.113165855407715, 7.305058479309082, 5.858325481414795, 6.585829734802246, 5.85537576675415, 5.956636428833008, 6.6970720291137695, 7.094930171966553, 6.346933364868164, 7.443418502807617, 6.6723198890686035, 4.063750267028809, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.973111629486084, 2.798851728439331, 6.398160457611084, 7.008164882659912, 5.669005393981934, 5.015890121459961, 5.7197675704956055, 5.291656017303467, 2.96864652633667, 4.5293354988098145, 6.31569242477417, 4.03683614730835, 3.8049724102020264, 5.966696739196777, 4.243271350860596, 4.711346626281738, 6.760146141052246, 5.287074089050293, 4.588063716888428, 5.763589859008789, 4.635308265686035, 5.174865245819092, 3.636293649673462, 5.063673973083496, 6.1467604637146, 8.255520820617676, 7.059943675994873, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.973111629486084, 2.798851728439331, 6.398160457611084, 7.008164882659912, 5.669005393981934, 5.015890121459961, 5.7197675704956055, 5.291656017303467, 2.96864652633667, 4.5293354988098145, 6.31569242477417, 4.03683614730835, 3.8049724102020264, 5.966696739196777, 4.243271350860596, 4.711346626281738, 6.760146141052246, 5.287074089050293, 4.588063716888428, 5.763589859008789, 4.635308265686035, 5.174865245819092, 3.636293649673462, 5.063673973083496, 6.1467604637146, 8.255520820617676, 7.059943675994873, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.019784927368164, 3.145909070968628, 6.2601799964904785, 4.28346586227417, 5.032520294189453, 4.419056415557861, 1.9582825899124146, 2.563225269317627, 1.433396339416504, 0.0, 0.0, 3.0416111946105957, 2.271329402923584, 4.310871601104736, 7.569327354431152, 3.888305902481079, 2.6840412616729736, 3.0623700618743896, 2.2229528427124023, 4.634758472442627, 8.154765129089355, 7.143093585968018, 4.445716381072998, 0.0, 0.0, 0.0, 2.561272621154785, 4.666625022888184, 4.535839080810547, 5.9491777420043945, 5.0188775062561035, 6.778653621673584, 6.478106498718262, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.019784927368164, 3.145909070968628, 6.2601799964904785, 4.28346586227417, 5.032520294189453, 4.419056415557861, 1.9582825899124146, 2.563225269317627, 1.433396339416504, 0.0, 0.0, 3.0416111946105957, 2.271329402923584, 4.310871601104736, 7.569327354431152, 3.888305902481079, 2.6840412616729736, 3.0623700618743896, 2.2229528427124023, 4.634758472442627, 8.154765129089355, 7.143093585968018, 4.445716381072998, 0.0, 0.0, 0.0, 2.561272621154785, 4.666625022888184, 4.535839080810547, 5.9491777420043945, 5.0188775062561035, 6.778653621673584, 6.478106498718262, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.383561134338379, 6.078619480133057, 5.224170207977295, 4.733511924743652, 6.803374290466309, 3.8228683471679688, 0.0, 0.0, 0.0, 0.0, -0.07107767462730408, 0.9758967161178589, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.982842445373535, 0.0, 0.0, 7.3950934410095215, 5.793587684631348, 6.550148010253906, 7.327884197235107, 7.993709087371826, 8.781327247619629, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.383561134338379, 6.078619480133057, 5.224170207977295, 4.733511924743652, 6.803374290466309, 3.8228683471679688, 0.0, 0.0, 0.0, 0.0, -0.07107767462730408, 0.9758967161178589, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.982842445373535, 0.0, 0.0, 7.3950934410095215, 5.793587684631348, 6.550148010253906, 7.327884197235107, 7.993709087371826, 8.781327247619629, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.4395949840545654, 4.70026969909668, 4.5715556144714355, 4.849804878234863, 3.346449375152588, 2.47322416305542, 0.0, 0.0, 2.8556814193725586, 0.7889230251312256, 1.7130669355392456, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.8172287940979, 0.0, 0.0, 0.0, 0.0, 6.602792263031006, 6.887166976928711, 6.981751918792725, 5.6921844482421875, 4.6010355949401855, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.4395949840545654, 4.70026969909668, 4.5715556144714355, 4.849804878234863, 3.346449375152588, 2.47322416305542, 0.0, 0.0, 2.8556814193725586, 0.7889230251312256, 1.7130669355392456, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.8172287940979, 0.0, 0.0, 0.0, 0.0, 6.602792263031006, 6.887166976928711, 6.981751918792725, 5.6921844482421875, 4.6010355949401855, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.719280242919922, 4.286404609680176, 4.695389747619629, 3.825352430343628, 3.0571160316467285, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.5422043800354, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.1362311840057373, 4.5746564865112305, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.499721527099609, 6.300045013427734, 7.91365385055542, 4.755014896392822, 0.0, 5.436060905456543, 6.056168556213379, 7.394289493560791, 7.604896068572998, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.719280242919922, 4.286404609680176, 4.695389747619629, 3.825352430343628, 3.0571160316467285, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 4.5422043800354, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 3.1362311840057373, 4.5746564865112305, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.499721527099609, 6.300045013427734, 7.91365385055542, 4.755014896392822, 0.0, 5.436060905456543, 6.056168556213379, 7.394289493560791, 7.604896068572998, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.5740976333618164, 3.541020154953003, 2.0739762783050537, 2.7263126373291016, 1.3372924327850342, 0.4431278109550476, 4.931574821472168, 6.631277084350586, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.623382806777954, 2.8976194858551025, 4.122980117797852, 0.0, 2.8461012840270996, 2.7726428508758545, 0.5938695669174194, -0.4480394423007965, 0.6395553350448608, 0.3400167226791382, 1.2285101413726807, 1.9178096055984497, 1.2834831476211548, 0.6242967844009399, 2.661180257797241, 0.0, 0.0, 3.662806749343872, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.175433158874512, 6.367692947387695, 7.2496795654296875, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.5740976333618164, 3.541020154953003, 2.0739762783050537, 2.7263126373291016, 1.3372924327850342, 0.4431278109550476, 4.931574821472168, 6.631277084350586, 0.0, 0.0, -0.0, -0.0, 0.0, -0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 3.623382806777954, 2.8976194858551025, 4.122980117797852, 0.0, 2.8461012840270996, 2.7726428508758545, 0.5938695669174194, -0.4480394423007965, 0.6395553350448608, 0.3400167226791382, 1.2285101413726807, 1.9178096055984497, 1.2834831476211548, 0.6242967844009399, 2.661180257797241, 0.0, 0.0, 3.662806749343872, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.175433158874512, 6.367692947387695, 7.2496795654296875, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.5576272010803223, 4.260013580322266, 2.592210054397583, 4.276097774505615, 1.0061911344528198, 0.0, -1.243104338645935, -0.511447012424469, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.9089268445968628, 0.8013298511505127, 1.7115627527236938, 2.7645938396453857, 1.6363781690597534, 0.3826770782470703, 1.3507235050201416, 1.1741164922714233, 1.174601435661316, 0.23496980965137482, 0.6841561794281006, 0.5853918194770813, 0.9851667284965515, 0.6621786952018738, 0.9265483021736145, 1.428940773010254, 1.0748133659362793, 1.0678625106811523, 0.9184315204620361, 0.9885578155517578, 0.5592695474624634, 3.3807477951049805, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.561759948730469, 1.9312326908111572, 4.272908687591553, 6.622918605804443, 6.546665668487549, 8.771410942077637, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.5576272010803223, 4.260013580322266, 2.592210054397583, 4.276097774505615, 1.0061911344528198, 0.0, -1.243104338645935, -0.511447012424469, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, -0.0, -0.0, -0.0, -0.9089268445968628, 0.8013298511505127, 1.7115627527236938, 2.7645938396453857, 1.6363781690597534, 0.3826770782470703, 1.3507235050201416, 1.1741164922714233, 1.174601435661316, 0.23496980965137482, 0.6841561794281006, 0.5853918194770813, 0.9851667284965515, 0.6621786952018738, 0.9265483021736145, 1.428940773010254, 1.0748133659362793, 1.0678625106811523, 0.9184315204620361, 0.9885578155517578, 0.5592695474624634, 3.3807477951049805, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.561759948730469, 1.9312326908111572, 4.272908687591553, 6.622918605804443, 6.546665668487549, 8.771410942077637, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.0889296531677246, 2.817429304122925, 2.711235284805298, 4.646817207336426, 0.0, -2.4319419860839844, -2.0200939178466797, -2.6497535705566406, 0.0, 0.0, 0.0, 0.0, 0.0, -0.6522231698036194, -1.5970587730407715, 1.3668513298034668, -0.8043924570083618, -0.9116572141647339, -2.514852523803711, -1.8092442750930786, 1.4004360437393188, -1.650530457496643, -1.7887349128723145, -1.1324408054351807, -3.2117490768432617, 0.3078245520591736, 0.5896363854408264, 0.03216638043522835, 0.8910412192344666, 0.8138334155082703, 0.47340863943099976, 0.13421759009361267, 0.4866046905517578, 1.1790406703948975, 0.7281221747398376, 1.0578652620315552, 1.2569471597671509, 1.0429822206497192, 0.7391748428344727, 0.6021592617034912, -0.1230713352560997, 0.8912315964698792, 1.020100474357605, 0.0, 0.0, 0.0, 0.0, 0.0, 5.311920642852783, 5.797300338745117, 0.0, 4.835186004638672, 6.140047073364258, 3.8382186889648438, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 2.0889296531677246, 2.817429304122925, 2.711235284805298, 4.646817207336426, 0.0, -2.4319419860839844, -2.0200939178466797, -2.6497535705566406, -0.0, -0.0, -0.0, -0.0, -0.0, -0.6522231698036194, -1.5970587730407715, 1.3668513298034668, -0.8043924570083618, -0.9116572141647339, -2.514852523803711, -1.8092442750930786, 1.4004360437393188, -1.650530457496643, -1.7887349128723145, -1.1324408054351807, -3.2117490768432617, 0.3078245520591736, 0.5896363854408264, 0.03216638043522835, 0.8910412192344666, 0.8138334155082703, 0.47340863943099976, 0.13421759009361267, 0.4866046905517578, 1.1790406703948975, 0.7281221747398376, 1.0578652620315552, 1.2569471597671509, 1.0429822206497192, 0.7391748428344727, 0.6021592617034912, -0.1230713352560997, 0.8912315964698792, 1.020100474357605, 0.0, 0.0, 0.0, 0.0, 0.0, 5.311920642852783, 5.797300338745117, 0.0, 4.835186004638672, 6.140047073364258, 3.8382186889648438, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.642873764038086, 1.4702612161636353, 1.6028708219528198, 0.0, 1.8190586566925049, -3.0521583557128906, -2.37642502784729, 0.0, 0.0, 0.0, -4.3844733238220215, -3.2690978050231934, -1.3869602680206299, -1.7102551460266113, -1.83798348903656, -1.9509916305541992, -1.0139906406402588, 2.315408706665039, -0.4393923580646515, -0.20716704428195953, 1.2209080457687378, 0.0, -1.5439451932907104, -1.111567735671997, -0.9870334267616272, -1.5364861488342285, -1.583744764328003, -0.5038392543792725, 0.49682003259658813, 0.7817848920822144, 0.7286060452461243, 0.3363674283027649, 0.6518537402153015, 0.5576890707015991, 0.5435105562210083, 1.102298617362976, 1.0451263189315796, 0.46948692202568054, 1.137797474861145, 0.355852872133255, 0.7587243318557739, 0.5743775367736816, 0.13714662194252014, 0.29090043902397156, 0.9026505947113037, 1.4525102376937866, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.064749240875244, 4.989569187164307, 5.507816314697266, 6.624846458435059, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 1.642873764038086, 1.4702612161636353, 1.6028708219528198, 0.0, 1.8190586566925049, -3.0521583557128906, -2.37642502784729, -0.0, -0.0, -0.0, -4.3844733238220215, -3.2690978050231934, -1.3869602680206299, -1.7102551460266113, -1.83798348903656, -1.9509916305541992, -1.0139906406402588, 2.315408706665039, -0.4393923580646515, -0.20716704428195953, 1.2209080457687378, 0.0, -1.5439451932907104, -1.111567735671997, -0.9870334267616272, -1.5364861488342285, -1.583744764328003, -0.5038392543792725, 0.49682003259658813, 0.7817848920822144, 0.7286060452461243, 0.3363674283027649, 0.6518537402153015, 0.5576890707015991, 0.5435105562210083, 1.102298617362976, 1.0451263189315796, 0.46948692202568054, 1.137797474861145, 0.355852872133255, 0.7587243318557739, 0.5743775367736816, 0.13714662194252014, 0.29090043902397156, 0.9026505947113037, 1.4525102376937866, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.064749240875244, 4.989569187164307, 5.507816314697266, 6.624846458435059, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.8169121742248535, 0.3266173303127289, 3.189945936203003, -2.087348699569702, -1.0509531497955322, 3.3314056396484375, 0.0, 0.0, 0.0, 2.8449079990386963, -0.36068782210350037, -0.8730798959732056, -0.32152029871940613, 0.14243197441101074, -1.316665768623352, -0.6157747507095337, -0.9671176671981812, -0.7524418234825134, -0.4316718578338623, -0.24510353803634644, 0.336642861366272, 0.14971794188022614, 0.6577000617980957, -2.07851243019104, -1.1348350048065186, -2.7359588146209717, 2.2836973667144775, 0.9006841778755188, 0.4168603718280792, 0.9437100887298584, 0.7707962393760681, 0.8322973847389221, 1.103084683418274, 0.9208880066871643, 0.6346274614334106, 0.7624294757843018, 0.9395201206207275, 1.3390138149261475, 0.6670435667037964, 0.28754839301109314, 0.7247625589370728, 0.8893215656280518, 0.8169838190078735, 1.0187829732894897, 1.1214520931243896, -0.22571544349193573, 0.205399751663208, 0.033717721700668335, -0.8512712121009827, 0.0, 0.0, 0.0, 3.5696794986724854, 0.0, 0.0, 4.9248199462890625, 5.878345012664795, 4.826623439788818, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.8169121742248535, 0.3266173303127289, 3.189945936203003, -2.087348699569702, -1.0509531497955322, 3.3314056396484375, 0.0, -0.0, 0.0, 2.8449079990386963, -0.36068782210350037, -0.8730798959732056, -0.32152029871940613, 0.14243197441101074, -1.316665768623352, -0.6157747507095337, -0.9671176671981812, -0.7524418234825134, -0.4316718578338623, -0.24510353803634644, 0.336642861366272, 0.14971794188022614, 0.6577000617980957, -2.07851243019104, -1.1348350048065186, -2.7359588146209717, 2.2836973667144775, 0.9006841778755188, 0.4168603718280792, 0.9437100887298584, 0.7707962393760681, 0.8322973847389221, 1.103084683418274, 0.9208880066871643, 0.6346274614334106, 0.7624294757843018, 0.9395201206207275, 1.3390138149261475, 0.6670435667037964, 0.28754839301109314, 0.7247625589370728, 0.8893215656280518, 0.8169838190078735, 1.0187829732894897, 1.1214520931243896, -0.22571544349193573, 0.205399751663208, 0.033717721700668335, -0.8512712121009827, -0.0, 0.0, 0.0, 3.5696794986724854, 0.0, 0.0, 4.9248199462890625, 5.878345012664795, 4.826623439788818, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.09849046170711517, -0.5501372814178467, 1.7904149293899536, 0.0, -3.3806216716766357, 0.0, 0.0, 0.0, 0.0, 0.47467175126075745, -0.17937220633029938, -0.7942648530006409, -0.8817758560180664, -0.7729127407073975, -0.1842883825302124, -0.5097387433052063, -0.0703650638461113, -0.6037243604660034, -0.8640657663345337, -0.15775719285011292, 0.17937971651554108, -0.2668587565422058, 0.8483768701553345, -0.7022954821586609, 0.5299657583236694, 2.4499130249023438, 0.8727884888648987, 0.5776591897010803, 0.2465880662202835, 0.6431655883789062, 1.0023702383041382, 1.0849014520645142, 0.8765811920166016, 0.7740302085876465, 0.7195286154747009, 0.7608241438865662, 1.136979341506958, 1.0633295774459839, 0.2651820182800293, 0.4382132589817047, 0.39869242906570435, 0.7897114753723145, 0.7233226895332336, 1.37703537940979, 1.063447117805481, 0.41436630487442017, 0.4008060693740845, -0.07667873054742813, 0.14619049429893494, -0.012374784797430038, 0.9889624118804932, 0.0, 0.0, 0.0, 0.0, 5.130183219909668, 4.241077423095703, 3.7393412590026855, 4.796183109283447, 5.080852031707764, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.09849046170711517, -0.5501372814178467, 1.7904149293899536, 0.0, -3.3806216716766357, -0.0, 0.0, 0.0, 0.0, 0.47467175126075745, -0.17937220633029938, -0.7942648530006409, -0.8817758560180664, -0.7729127407073975, -0.1842883825302124, -0.5097387433052063, -0.0703650638461113, -0.6037243604660034, -0.8640657663345337, -0.15775719285011292, 0.17937971651554108, -0.2668587565422058, 0.8483768701553345, -0.7022954821586609, 0.5299657583236694, 2.4499130249023438, 0.8727884888648987, 0.5776591897010803, 0.2465880662202835, 0.6431655883789062, 1.0023702383041382, 1.0849014520645142, 0.8765811920166016, 0.7740302085876465, 0.7195286154747009, 0.7608241438865662, 1.136979341506958, 1.0633295774459839, 0.2651820182800293, 0.4382132589817047, 0.39869242906570435, 0.7897114753723145, 0.7233226895332336, 1.37703537940979, 1.063447117805481, 0.41436630487442017, 0.4008060693740845, -0.07667873054742813, 0.14619049429893494, -0.012374784797430038, 0.9889624118804932, 0.0, 0.0, 0.0, 0.0, 5.130183219909668, 4.241077423095703, 3.7393412590026855, 4.796183109283447, 5.080852031707764, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.8136794567108154, -0.7895694375038147, 0.0, -0.0503421314060688, 0.35707104206085205, 0.0, 0.0, 2.8296024799346924, 2.0537352561950684, -1.3144787549972534, -0.13944029808044434, -0.6907689571380615, -1.1095805168151855, -1.3661067485809326, -0.13568411767482758, -1.5161930322647095, -1.120369791984558, -1.0974456071853638, -0.4559324383735657, -0.8287990689277649, 0.10145483165979385, -0.07982105016708374, -0.6570672392845154, 0.07603995501995087, -0.24256186187267303, 0.04074633866548538, 0.8269851207733154, 0.13050739467144012, 0.37698274850845337, 0.610191285610199, 0.4473821520805359, 0.9226148128509521, 0.9843209981918335, 0.8895700573921204, 0.6257980465888977, 0.9333580732345581, 1.2707817554473877, 0.9847911596298218, 0.7980852127075195, 0.5766192674636841, 1.2423760890960693, 0.8631020188331604, 0.7086337804794312, 0.746826171875, 1.114580750465393, 1.0387134552001953, 0.7706246376037598, 0.4551163613796234, 0.8705614805221558, -0.0642360970377922, 0.03628188371658325, 1.8690730333328247, 1.1279714107513428, 0.17489610612392426, 0.0, 0.0, 0.0, 6.124391555786133, 0.0, 0.0, 4.044435977935791, 4.931150436401367, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -1.8136794567108154, -0.7895694375038147, -0.0, -0.0503421314060688, 0.35707104206085205, -0.0, 0.0, 2.8296024799346924, 2.0537352561950684, -1.3144787549972534, -0.13944029808044434, -0.6907689571380615, -1.1095805168151855, -1.3661067485809326, -0.13568411767482758, -1.5161930322647095, -1.120369791984558, -1.0974456071853638, -0.4559324383735657, -0.8287990689277649, 0.10145483165979385, -0.07982105016708374, -0.6570672392845154, 0.07603995501995087, -0.24256186187267303, 0.04074633866548538, 0.8269851207733154, 0.13050739467144012, 0.37698274850845337, 0.610191285610199, 0.4473821520805359, 0.9226148128509521, 0.9843209981918335, 0.8895700573921204, 0.6257980465888977, 0.9333580732345581, 1.2707817554473877, 0.9847911596298218, 0.7980852127075195, 0.5766192674636841, 1.2423760890960693, 0.8631020188331604, 0.7086337804794312, 0.746826171875, 1.114580750465393, 1.0387134552001953, 0.7706246376037598, 0.4551163613796234, 0.8705614805221558, -0.0642360970377922, 0.03628188371658325, 1.8690730333328247, 1.1279714107513428, 0.17489610612392426, 0.0, 0.0, 0.0, 6.124391555786133, 0.0, 0.0, 4.044435977935791, 4.931150436401367, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.14686532318592072, -1.283453106880188, 2.5127675533294678, 0.0, 0.10079595446586609, 1.7293132543563843, 0.0, 1.5899919271469116, -0.9260625839233398, -1.153157114982605, -1.67796790599823, -2.3158159255981445, -1.48810875415802, -1.267499566078186, -1.1536180973052979, -1.395317554473877, -1.5146299600601196, -1.006388783454895, -0.6080121397972107, -1.0427777767181396, -0.40721404552459717, -0.3007793128490448, -0.21644508838653564, -0.8560568690299988, 0.5403481721878052, 0.6497930288314819, -0.4090442359447479, 0.5045385956764221, 0.6051558256149292, 0.5098644495010376, 0.589340090751648, 0.6163812875747681, 0.8118119239807129, 1.156480312347412, 0.9876251816749573, 0.6467918157577515, 0.5075857639312744, 0.4766884446144104, 1.2034294605255127, 0.8363481163978577, 0.897674560546875, 1.0139119625091553, 0.88886559009552, 0.2342974990606308, 1.0395605564117432, 1.1209205389022827, 0.5379763841629028, 1.2791229486465454, 0.8103840351104736, 0.521024763584137, 0.6610989570617676, 0.33486810326576233, 0.8911846876144409, -1.549867868423462, 0.7862634658813477, 0.0, 0.0, 0.0, 0.0, 2.0685226917266846, 0.0, 0.0, 3.7331702709198, 5.833299160003662, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.14686532318592072, -1.283453106880188, 2.5127675533294678, 0.0, 0.10079595446586609, 1.7293132543563843, 0.0, 1.5899919271469116, -0.9260625839233398, -1.153157114982605, -1.67796790599823, -2.3158159255981445, -1.48810875415802, -1.267499566078186, -1.1536180973052979, -1.395317554473877, -1.5146299600601196, -1.006388783454895, -0.6080121397972107, -1.0427777767181396, -0.40721404552459717, -0.3007793128490448, -0.21644508838653564, -0.8560568690299988, 0.5403481721878052, 0.6497930288314819, -0.4090442359447479, 0.5045385956764221, 0.6051558256149292, 0.5098644495010376, 0.589340090751648, 0.6163812875747681, 0.8118119239807129, 1.156480312347412, 0.9876251816749573, 0.6467918157577515, 0.5075857639312744, 0.4766884446144104, 1.2034294605255127, 0.8363481163978577, 0.897674560546875, 1.0139119625091553, 0.88886559009552, 0.2342974990606308, 1.0395605564117432, 1.1209205389022827, 0.5379763841629028, 1.2791229486465454, 0.8103840351104736, 0.521024763584137, 0.6610989570617676, 0.33486810326576233, 0.8911846876144409, -1.549867868423462, 0.7862634658813477, 0.0, 0.0, 0.0, 0.0, 2.0685226917266846, 0.0, 0.0, 3.7331702709198, 5.833299160003662, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0074050426483154, -1.015580177307129, 0.0, 1.4348275661468506, 0.0, 0.0, 0.0, 0.0, -1.2572274208068848, -1.1539746522903442, -1.1189229488372803, -2.039058208465576, -1.8768221139907837, -1.7895656824111938, -1.5271025896072388, -1.3717724084854126, -1.5175082683563232, -1.1894381046295166, -1.597359538078308, -1.2431855201721191, -0.8824103474617004, -0.38637569546699524, -0.36107176542282104, 0.24630942940711975, 0.1305522471666336, -0.4185046851634979, -0.2229199856519699, 0.48598966002464294, 0.5121196508407593, 0.8039534091949463, 0.5030890107154846, 0.7062761187553406, 0.6529179811477661, 0.9282683730125427, 0.9706816077232361, 0.8204282522201538, 0.4315175414085388, -0.7841062545776367, -0.37205177545547485, 0.11023050546646118, 0.4719406068325043, 0.5112959742546082, 0.6825714111328125, 1.1567639112472534, 0.9084479808807373, 0.9474191665649414, 0.6736741065979004, 0.47314000129699707, 0.7955645322799683, 0.8135454654693604, 0.8694581985473633, 0.9217603206634521, 0.10555025190114975, 0.47395065426826477, 0.4423765242099762, 0.770077645778656, 0.0, 1.704019546508789, 0.0, 0.0, 0.0, 0.6174962520599365, 3.2388792037963867, 3.2460455894470215, 2.3013572692871094, 0.9901860952377319, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -1.0074050426483154, -1.015580177307129, -0.0, 1.4348275661468506, 0.0, 0.0, 0.0, -0.0, -1.2572274208068848, -1.1539746522903442, -1.1189229488372803, -2.039058208465576, -1.8768221139907837, -1.7895656824111938, -1.5271025896072388, -1.3717724084854126, -1.5175082683563232, -1.1894381046295166, -1.597359538078308, -1.2431855201721191, -0.8824103474617004, -0.38637569546699524, -0.36107176542282104, 0.24630942940711975, 0.1305522471666336, -0.4185046851634979, -0.2229199856519699, 0.48598966002464294, 0.5121196508407593, 0.8039534091949463, 0.5030890107154846, 0.7062761187553406, 0.6529179811477661, 0.9282683730125427, 0.9706816077232361, 0.8204282522201538, 0.4315175414085388, -0.7841062545776367, -0.37205177545547485, 0.11023050546646118, 0.4719406068325043, 0.5112959742546082, 0.6825714111328125, 1.1567639112472534, 0.9084479808807373, 0.9474191665649414, 0.6736741065979004, 0.47314000129699707, 0.7955645322799683, 0.8135454654693604, 0.8694581985473633, 0.9217603206634521, 0.10555025190114975, 0.47395065426826477, 0.4423765242099762, 0.770077645778656, 0.0, 1.704019546508789, 0.0, 0.0, 0.0, 0.6174962520599365, 3.2388792037963867, 3.2460455894470215, 2.3013572692871094, 0.9901860952377319, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.06519223004579544, 0.009698591195046902, -3.5889079570770264, 0.0, 1.8049449920654297, 0.0, 0.0, 0.0, -2.916043758392334, -1.4822297096252441, -2.2612295150756836, -2.6794745922088623, -2.186767339706421, -2.5333640575408936, -1.812190055847168, -0.997729480266571, -1.6361745595932007, -1.0240404605865479, -1.0969129800796509, -0.6755814552307129, 0.29540613293647766, -0.8129935264587402, -0.4812416732311249, -0.5677751302719116, -0.016581377014517784, -0.060814183205366135, -0.7458731532096863, 0.501044750213623, -0.0848323330283165, 0.43906405568122864, -0.25234249234199524, 0.6492193937301636, 0.5521988868713379, 0.29509052634239197, 0.567602813243866, 1.1331905126571655, 1.3183904886245728, 0.5536209940910339, 0.6902931332588196, 0.6428687572479248, 0.09668464958667755, 0.3961822986602783, 1.4064005613327026, 0.9336268901824951, 1.1119877099990845, 0.6764126420021057, 1.1259735822677612, 0.29065439105033875, 0.9051480293273926, 0.02379581891000271, 0.5229165554046631, 0.9054309129714966, 0.32891497015953064, 0.36818838119506836, 0.6269063949584961, 1.1391688585281372, 0.7579846978187561, 0.512874960899353, 0.30525052547454834, 0.0, 0.0, 0.0, -0.15814714133739471, 0.0, 2.1129891872406006, 1.9306045770645142, 1.0848196744918823, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.06519223004579544, 0.009698591195046902, -3.5889079570770264, 0.0, 1.8049449920654297, 0.0, -0.0, -0.0, -2.916043758392334, -1.4822297096252441, -2.2612295150756836, -2.6794745922088623, -2.186767339706421, -2.5333640575408936, -1.812190055847168, -0.997729480266571, -1.6361745595932007, -1.0240404605865479, -1.0969129800796509, -0.6755814552307129, 0.29540613293647766, -0.8129935264587402, -0.4812416732311249, -0.5677751302719116, -0.016581377014517784, -0.060814183205366135, -0.7458731532096863, 0.501044750213623, -0.0848323330283165, 0.43906405568122864, -0.25234249234199524, 0.6492193937301636, 0.5521988868713379, 0.29509052634239197, 0.567602813243866, 1.1331905126571655, 1.3183904886245728, 0.5536209940910339, 0.6902931332588196, 0.6428687572479248, 0.09668464958667755, 0.3961822986602783, 1.4064005613327026, 0.9336268901824951, 1.1119877099990845, 0.6764126420021057, 1.1259735822677612, 0.29065439105033875, 0.9051480293273926, 0.02379581891000271, 0.5229165554046631, 0.9054309129714966, 0.32891497015953064, 0.36818838119506836, 0.6269063949584961, 1.1391688585281372, 0.7579846978187561, 0.512874960899353, 0.30525052547454834, 0.0, 0.0, -0.0, -0.15814714133739471, 0.0, 2.1129891872406006, 1.9306045770645142, 1.0848196744918823, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 1.3119004964828491, -0.42434588074684143, -1.9712594747543335, -4.193918228149414, 0.0, 0.0, 0.0, 0.0, -3.899200677871704, -3.016948699951172, -3.013895034790039, -3.1992719173431396, -2.6058154106140137, -2.527888536453247, -1.8972597122192383, -1.679496169090271, -0.9455966949462891, -1.397757887840271, -1.0839273929595947, -1.3127973079681396, -0.6863095760345459, -1.033774733543396, -1.1581251621246338, -0.7741149663925171, -0.2865878939628601, 0.5487990379333496, -0.13129675388336182, -0.05831588804721832, 0.11395156383514404, 0.22144901752471924, 1.4320863485336304, -0.5977594256401062, 0.1060987040400505, 0.7544106841087341, 0.21370919048786163, 0.22325164079666138, 0.6681820750236511, 1.2808462381362915, 0.7626854181289673, 0.5043060779571533, 0.8682612180709839, 1.624097466468811, 0.857871413230896, 0.49919188022613525, 0.708831787109375, 0.9633603096008301, 1.2856453657150269, 0.7455289363861084, 0.1360725611448288, 0.48102909326553345, 0.9005177617073059, 0.6900507211685181, 0.8419134020805359, 0.3695295751094818, 0.058077648282051086, 0.5118505954742432, 0.9364652633666992, 0.7374580502510071, 1.6702886819839478, 0.602569580078125, 0.8688567280769348, 0.0, 0.0, 0.0, 2.8464834690093994, 4.796014308929443, 0.0, 3.0167789459228516, 0.5631477236747742, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 1.3119004964828491, -0.42434588074684143, -1.9712594747543335, -4.193918228149414, -0.0, 0.0, 0.0, -0.0, -3.899200677871704, -3.016948699951172, -3.013895034790039, -3.1992719173431396, -2.6058154106140137, -2.527888536453247, -1.8972597122192383, -1.679496169090271, -0.9455966949462891, -1.397757887840271, -1.0839273929595947, -1.3127973079681396, -0.6863095760345459, -1.033774733543396, -1.1581251621246338, -0.7741149663925171, -0.2865878939628601, 0.5487990379333496, -0.13129675388336182, -0.05831588804721832, 0.11395156383514404, 0.22144901752471924, 1.4320863485336304, -0.5977594256401062, 0.1060987040400505, 0.7544106841087341, 0.21370919048786163, 0.22325164079666138, 0.6681820750236511, 1.2808462381362915, 0.7626854181289673, 0.5043060779571533, 0.8682612180709839, 1.624097466468811, 0.857871413230896, 0.49919188022613525, 0.708831787109375, 0.9633603096008301, 1.2856453657150269, 0.7455289363861084, 0.1360725611448288, 0.48102909326553345, 0.9005177617073059, 0.6900507211685181, 0.8419134020805359, 0.3695295751094818, 0.058077648282051086, 0.5118505954742432, 0.9364652633666992, 0.7374580502510071, 1.6702886819839478, 0.602569580078125, 0.8688567280769348, 0.0, -0.0, -0.0, 2.8464834690093994, 4.796014308929443, 0.0, 3.0167789459228516, 0.5631477236747742, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -0.6638845205307007, 0.07625986635684967, 3.0315732955932617, 0.0, -0.8510789275169373, 0.0, 0.0, 0.0, -4.396923065185547, -3.377241611480713, -2.6933789253234863, -2.359919548034668, -2.557100772857666, -2.185368537902832, -2.4723591804504395, -1.1865235567092896, -2.125849723815918, -1.4561676979064941, -1.7231385707855225, -1.166688084602356, -0.9226389527320862, -1.3165873289108276, -0.7336778044700623, -1.1549546718597412, -2.2971315383911133, -0.5368413925170898, -0.646584153175354, 0.3969572186470032, 0.026131918653845787, 0.7455022931098938, 0.8533969521522522, -2.4455347061157227, 0.45557087659835815, 0.3077339828014374, 0.4039997160434723, 0.4404836595058441, 1.3441740274429321, 0.5991836190223694, 1.086079716682434, 0.5898805260658264, 0.9564811587333679, 1.0421507358551025, 1.1760923862457275, 0.802765965461731, 0.8763223886489868, 0.897883415222168, 0.5594537854194641, 1.0926142930984497, 1.0222046375274658, 0.777824342250824, 2.460753917694092, 0.8800158500671387, 1.0024592876434326, 0.20977768301963806, 0.49473872780799866, 0.8659913539886475, 0.5106872320175171, 0.9000774621963501, 1.2874058485031128, 0.4717060923576355, 0.6948314905166626, 0.5320435762405396, 0.31110450625419617, 0.0, 0.0, 0.0, 3.9850804805755615, 0.0, 2.0790467262268066, 3.054957628250122, 5.594725131988525, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.6638845205307007, 0.07625986635684967, 3.0315732955932617, -0.0, -0.8510789275169373, -0.0, -0.0, -0.0, -4.396923065185547, -3.377241611480713, -2.6933789253234863, -2.359919548034668, -2.557100772857666, -2.185368537902832, -2.4723591804504395, -1.1865235567092896, -2.125849723815918, -1.4561676979064941, -1.7231385707855225, -1.166688084602356, -0.9226389527320862, -1.3165873289108276, -0.7336778044700623, -1.1549546718597412, -2.2971315383911133, -0.5368413925170898, -0.646584153175354, 0.3969572186470032, 0.026131918653845787, 0.7455022931098938, 0.8533969521522522, -2.4455347061157227, 0.45557087659835815, 0.3077339828014374, 0.4039997160434723, 0.4404836595058441, 1.3441740274429321, 0.5991836190223694, 1.086079716682434, 0.5898805260658264, 0.9564811587333679, 1.0421507358551025, 1.1760923862457275, 0.802765965461731, 0.8763223886489868, 0.897883415222168, 0.5594537854194641, 1.0926142930984497, 1.0222046375274658, 0.777824342250824, 2.460753917694092, 0.8800158500671387, 1.0024592876434326, 0.20977768301963806, 0.49473872780799866, 0.8659913539886475, 0.5106872320175171, 0.9000774621963501, 1.2874058485031128, 0.4717060923576355, 0.6948314905166626, 0.5320435762405396, 0.31110450625419617, 0.0, 0.0, 0.0, 3.9850804805755615, 0.0, 2.0790467262268066, 3.054957628250122, 5.594725131988525, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -1.829229474067688, -3.6725566387176514, 0.8922972679138184, -1.5036439895629883, -3.0826950073242188, 0.0, 0.0, -5.124680042266846, -3.6265711784362793, -2.946629524230957, -3.1789135932922363, -3.552842617034912, -3.0497689247131348, -2.087705612182617, -2.23818039894104, -2.478508949279785, -1.918803334236145, -1.6271858215332031, -1.6243832111358643, -0.7838035225868225, -1.6912169456481934, -0.8977981209754944, -1.070146918296814, -1.0874336957931519, -0.439101904630661, -0.08984057605266571, -0.3834221661090851, 0.44037097692489624, -0.020027251914143562, 0.3640768527984619, -0.12127361446619034, 0.37388837337493896, 0.5991683006286621, 0.7893534302711487, 0.7981723546981812, 0.2725452184677124, 0.7801692485809326, 0.013117189519107342, 0.9919866323471069, 1.0540003776550293, 0.9903753995895386, 0.5749664306640625, 0.841739296913147, 0.7421437501907349, 0.8910995721817017, 1.4127206802368164, 1.875840187072754, 1.3095836639404297, 1.3894137144088745, 1.3729963302612305, 0.7127829790115356, 0.7823269963264465, 1.2398262023925781, 0.17977724969387054, 0.9860507845878601, 1.3305102586746216, 0.39800310134887695, 0.8626919984817505, -0.012259501963853836, 0.4613931477069855, -0.14191463589668274, 0.8820177912712097, 1.0634042024612427, 0.7475162744522095, 2.9700264930725098, 0.0, 0.0, 4.364466667175293, 0.2954176366329193, 2.1953766345977783, 4.528357028961182, 5.843574047088623, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -1.829229474067688, -3.6725566387176514, 0.8922972679138184, -1.5036439895629883, -3.0826950073242188, -0.0, -0.0, -5.124680042266846, -3.6265711784362793, -2.946629524230957, -3.1789135932922363, -3.552842617034912, -3.0497689247131348, -2.087705612182617, -2.23818039894104, -2.478508949279785, -1.918803334236145, -1.6271858215332031, -1.6243832111358643, -0.7838035225868225, -1.6912169456481934, -0.8977981209754944, -1.070146918296814, -1.0874336957931519, -0.439101904630661, -0.08984057605266571, -0.3834221661090851, 0.44037097692489624, -0.020027251914143562, 0.3640768527984619, -0.12127361446619034, 0.37388837337493896, 0.5991683006286621, 0.7893534302711487, 0.7981723546981812, 0.2725452184677124, 0.7801692485809326, 0.013117189519107342, 0.9919866323471069, 1.0540003776550293, 0.9903753995895386, 0.5749664306640625, 0.841739296913147, 0.7421437501907349, 0.8910995721817017, 1.4127206802368164, 1.875840187072754, 1.3095836639404297, 1.3894137144088745, 1.3729963302612305, 0.7127829790115356, 0.7823269963264465, 1.2398262023925781, 0.17977724969387054, 0.9860507845878601, 1.3305102586746216, 0.39800310134887695, 0.8626919984817505, -0.012259501963853836, 0.4613931477069855, -0.14191463589668274, 0.8820177912712097, 1.0634042024612427, 0.7475162744522095, 2.9700264930725098, 0.0, 0.0, 4.364466667175293, 0.2954176366329193, 2.1953766345977783, 4.528357028961182, 5.843574047088623, 0.0, 0.0], [0.0, 0.0, 0.0, -1.6272296905517578, -2.2107882499694824, -2.189581871032715, -2.7922561168670654, -4.261618137359619, 0.0, 0.0, -4.144981861114502, -3.4217679500579834, -3.005786180496216, -3.663825750350952, -2.704838991165161, -2.8280210494995117, -3.3191683292388916, -2.675016164779663, -2.0336294174194336, -2.0378992557525635, -0.4862898588180542, -1.5435863733291626, -1.1805527210235596, -0.17617017030715942, -0.725375771522522, -0.7999191284179688, -0.5648420453071594, 0.1868637353181839, -0.516783595085144, -0.7727012634277344, -0.30623170733451843, 0.5750942230224609, 0.47940385341644287, -0.004145432263612747, 0.38541483879089355, -0.10284809023141861, 0.6301968097686768, 0.35015618801116943, 0.5933114886283875, 1.063686728477478, 1.1095356941223145, 0.9798954129219055, 0.2810015380382538, 0.8647118210792542, 1.1983375549316406, 0.7351540327072144, 0.6584041118621826, 1.5593143701553345, 1.2526586055755615, 0.44471362233161926, 0.7014228701591492, 1.2692675590515137, 1.0103983879089355, 1.6478716135025024, 0.24464820325374603, 1.1199254989624023, -0.0006843567243777215, 0.695236086845398, 0.8900755047798157, 0.9849557876586914, 0.23554784059524536, 0.6547887325286865, 1.5377733707427979, 0.3750811815261841, 0.33967798948287964, 0.7173160910606384, 0.7555965185165405, 0.2827909290790558, 1.2113239765167236, 0.86305832862854, 0.0, 0.0, -0.2214665412902832, 0.0, 3.506073236465454, 6.438591003417969, 0.0, 0.0, -0.0, -0.0, -0.0, -1.6272296905517578, -2.2107882499694824, -2.189581871032715, -2.7922561168670654, -4.261618137359619, -0.0, -0.0, -4.144981861114502, -3.4217679500579834, -3.005786180496216, -3.663825750350952, -2.704838991165161, -2.8280210494995117, -3.3191683292388916, -2.675016164779663, -2.0336294174194336, -2.0378992557525635, -0.4862898588180542, -1.5435863733291626, -1.1805527210235596, -0.17617017030715942, -0.725375771522522, -0.7999191284179688, -0.5648420453071594, 0.1868637353181839, -0.516783595085144, -0.7727012634277344, -0.30623170733451843, 0.5750942230224609, 0.47940385341644287, -0.004145432263612747, 0.38541483879089355, -0.10284809023141861, 0.6301968097686768, 0.35015618801116943, 0.5933114886283875, 1.063686728477478, 1.1095356941223145, 0.9798954129219055, 0.2810015380382538, 0.8647118210792542, 1.1983375549316406, 0.7351540327072144, 0.6584041118621826, 1.5593143701553345, 1.2526586055755615, 0.44471362233161926, 0.7014228701591492, 1.2692675590515137, 1.0103983879089355, 1.6478716135025024, 0.24464820325374603, 1.1199254989624023, -0.0006843567243777215, 0.695236086845398, 0.8900755047798157, 0.9849557876586914, 0.23554784059524536, 0.6547887325286865, 1.5377733707427979, 0.3750811815261841, 0.33967798948287964, 0.7173160910606384, 0.7555965185165405, 0.2827909290790558, 1.2113239765167236, 0.86305832862854, 0.0, 0.0, -0.2214665412902832, 0.0, 3.506073236465454, 6.438591003417969, 0.0, 0.0], [0.0, 0.0, -1.3764851093292236, -2.515683174133301, -5.436068534851074, 0.0, -3.225043535232544, 0.0, 0.0, 0.0, -4.206660270690918, -3.824986219406128, -3.7091922760009766, -4.281700611114502, -2.597677230834961, -2.982544422149658, -3.479360342025757, -2.1473476886749268, -3.3892502784729004, -2.4379918575286865, -2.5192744731903076, -2.019166946411133, -1.9672752618789673, -1.2449467182159424, -0.9113935828208923, -0.7558069229125977, -0.8081990480422974, -0.06601126492023468, -0.8152052760124207, -0.2724388837814331, 0.4842662513256073, 0.31223297119140625, 0.4236534535884857, 0.11311407387256622, 0.3056018650531769, 0.3490864038467407, -0.26977792382240295, 0.5474610328674316, 0.528134286403656, 0.25493359565734863, 0.05828220769762993, 1.014893651008606, 1.4785737991333008, 0.49255990982055664, 1.3097755908966064, 1.1284340620040894, 1.7842907905578613, 1.6192725896835327, 1.5709151029586792, 1.5221506357192993, 1.8743802309036255, 0.4763234257698059, 1.125184178352356, 1.0862574577331543, 0.5319468975067139, 0.974390983581543, 1.397135615348816, 1.0114703178405762, 0.40979093313217163, 0.6951777338981628, 0.6850249767303467, 0.8607611656188965, -0.3621881306171417, 0.44820329546928406, 0.7313365340232849, 0.4813922345638275, 0.8812692761421204, 1.7606643438339233, 0.47549551725387573, 1.7300782203674316, 0.0, 0.0, 0.0, 2.203242778778076, 2.7594964504241943, 4.38897705078125, 7.5476484298706055, 0.0, -0.0, -0.0, -1.3764851093292236, -2.515683174133301, -5.436068534851074, -0.0, -3.225043535232544, -0.0, -0.0, -0.0, -4.206660270690918, -3.824986219406128, -3.7091922760009766, -4.281700611114502, -2.597677230834961, -2.982544422149658, -3.479360342025757, -2.1473476886749268, -3.3892502784729004, -2.4379918575286865, -2.5192744731903076, -2.019166946411133, -1.9672752618789673, -1.2449467182159424, -0.9113935828208923, -0.7558069229125977, -0.8081990480422974, -0.06601126492023468, -0.8152052760124207, -0.2724388837814331, 0.4842662513256073, 0.31223297119140625, 0.4236534535884857, 0.11311407387256622, 0.3056018650531769, 0.3490864038467407, -0.26977792382240295, 0.5474610328674316, 0.528134286403656, 0.25493359565734863, 0.05828220769762993, 1.014893651008606, 1.4785737991333008, 0.49255990982055664, 1.3097755908966064, 1.1284340620040894, 1.7842907905578613, 1.6192725896835327, 1.5709151029586792, 1.5221506357192993, 1.8743802309036255, 0.4763234257698059, 1.125184178352356, 1.0862574577331543, 0.5319468975067139, 0.974390983581543, 1.397135615348816, 1.0114703178405762, 0.40979093313217163, 0.6951777338981628, 0.6850249767303467, 0.8607611656188965, -0.3621881306171417, 0.44820329546928406, 0.7313365340232849, 0.4813922345638275, 0.8812692761421204, 1.7606643438339233, 0.47549551725387573, 1.7300782203674316, 0.0, -0.0, -0.0, 2.203242778778076, 2.7594964504241943, 4.38897705078125, 7.5476484298706055, 0.0], [0.0, -1.841351866722107, -0.9790473580360413, 0.0, 0.0, -7.255149841308594, 0.0, 0.0, 0.0, -4.862281322479248, -4.005532264709473, -3.878000497817993, -3.700052261352539, -3.732795000076294, -3.666705846786499, -2.678406238555908, -1.9158635139465332, -1.692393183708191, -1.5786845684051514, -1.187309741973877, -1.9284310340881348, -1.0543303489685059, -1.1255043745040894, -1.7422252893447876, -1.7859398126602173, -0.6381243467330933, -0.06040308251976967, -0.263370156288147, -0.9456998705863953, 0.308700829744339, 0.16985857486724854, 0.24569496512413025, 0.07693039625883102, 0.3183399736881256, 0.745404064655304, -0.27608296275138855, -0.28583526611328125, 0.4354659616947174, 0.9987927675247192, 0.5664854645729065, 0.704945981502533, 1.169146180152893, 0.48720425367355347, 1.6744110584259033, 0.8126876950263977, 0.8568987846374512, 0.15829570591449738, -0.2932501435279846, 0.6667600870132446, 1.336362361907959, 1.424092411994934, 2.4129106998443604, -0.10122857987880707, 0.8260256052017212, 1.1288524866104126, -0.6205469369888306, 1.0614806413650513, 1.0311552286148071, 0.2189609259366989, 1.3071763515472412, 1.1339219808578491, 0.48455289006233215, 0.7467751502990723, 1.5079982280731201, 1.4484117031097412, 0.6269805431365967, 1.0722588300704956, 0.7400604486465454, 1.8908418416976929, 0.8247203826904297, -0.8202395439147949, 0.0, 0.0, 4.2964277267456055, 0.5816320776939392, 0.0, 6.694048881530762, 0.0, -0.0, -1.841351866722107, -0.9790473580360413, -0.0, -0.0, -7.255149841308594, -0.0, -0.0, -0.0, -4.862281322479248, -4.005532264709473, -3.878000497817993, -3.700052261352539, -3.732795000076294, -3.666705846786499, -2.678406238555908, -1.9158635139465332, -1.692393183708191, -1.5786845684051514, -1.187309741973877, -1.9284310340881348, -1.0543303489685059, -1.1255043745040894, -1.7422252893447876, -1.7859398126602173, -0.6381243467330933, -0.06040308251976967, -0.263370156288147, -0.9456998705863953, 0.308700829744339, 0.16985857486724854, 0.24569496512413025, 0.07693039625883102, 0.3183399736881256, 0.745404064655304, -0.27608296275138855, -0.28583526611328125, 0.4354659616947174, 0.9987927675247192, 0.5664854645729065, 0.704945981502533, 1.169146180152893, 0.48720425367355347, 1.6744110584259033, 0.8126876950263977, 0.8568987846374512, 0.15829570591449738, -0.2932501435279846, 0.6667600870132446, 1.336362361907959, 1.424092411994934, 2.4129106998443604, -0.10122857987880707, 0.8260256052017212, 1.1288524866104126, -0.6205469369888306, 1.0614806413650513, 1.0311552286148071, 0.2189609259366989, 1.3071763515472412, 1.1339219808578491, 0.48455289006233215, 0.7467751502990723, 1.5079982280731201, 1.4484117031097412, 0.6269805431365967, 1.0722588300704956, 0.7400604486465454, 1.8908418416976929, 0.8247203826904297, -0.8202395439147949, -0.0, 0.0, 4.2964277267456055, 0.5816320776939392, 0.0, 6.694048881530762, 0.0], [0.0, -1.6945356130599976, -0.7941248416900635, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.048547744750977, -4.255057334899902, -3.857464551925659, -3.557065963745117, -4.486660957336426, -3.8810832500457764, -3.8039846420288086, -1.8697072267532349, -3.646658420562744, -1.31199312210083, -1.746199607849121, -1.4029827117919922, -2.8917653560638428, -1.0884943008422852, -0.9912896156311035, 0.1780424863100052, -0.9006975293159485, -1.0453745126724243, -0.9926855564117432, -0.7830429673194885, -0.06739084422588348, -0.15144802629947662, 0.8386658430099487, -0.3465037941932678, 0.473758727312088, 0.6476374864578247, 0.3011636435985565, 1.178877353668213, -0.521344780921936, 0.5970916152000427, 1.8342795372009277, 0.24349620938301086, 0.7763091325759888, 1.61506986618042, 1.6394890546798706, 1.4248484373092651, 1.2926337718963623, 1.378232717514038, 1.25832200050354, 1.0308201313018799, 1.3133134841918945, 1.0034303665161133, 1.5351005792617798, 1.3098711967468262, -0.5108293294906616, 1.0478568077087402, 0.7184942364692688, 1.242295742034912, 0.7558002471923828, 2.7125768661499023, 1.1534690856933594, 0.9557936191558838, 0.8526636362075806, 1.2144603729248047, 0.4830768406391144, 1.0027544498443604, 1.0697739124298096, 0.4254515469074249, 0.9625717401504517, 0.6955944895744324, 1.460973858833313, 1.947672963142395, 0.0, 0.0, 0.0, -1.4985556602478027, 0.0, 4.75236701965332, 7.602309226989746, -0.0, -1.6945356130599976, -0.7941248416900635, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.048547744750977, -4.255057334899902, -3.857464551925659, -3.557065963745117, -4.486660957336426, -3.8810832500457764, -3.8039846420288086, -1.8697072267532349, -3.646658420562744, -1.31199312210083, -1.746199607849121, -1.4029827117919922, -2.8917653560638428, -1.0884943008422852, -0.9912896156311035, 0.1780424863100052, -0.9006975293159485, -1.0453745126724243, -0.9926855564117432, -0.7830429673194885, -0.06739084422588348, -0.15144802629947662, 0.8386658430099487, -0.3465037941932678, 0.473758727312088, 0.6476374864578247, 0.3011636435985565, 1.178877353668213, -0.521344780921936, 0.5970916152000427, 1.8342795372009277, 0.24349620938301086, 0.7763091325759888, 1.61506986618042, 1.6394890546798706, 1.4248484373092651, 1.2926337718963623, 1.378232717514038, 1.25832200050354, 1.0308201313018799, 1.3133134841918945, 1.0034303665161133, 1.5351005792617798, 1.3098711967468262, -0.5108293294906616, 1.0478568077087402, 0.7184942364692688, 1.242295742034912, 0.7558002471923828, 2.7125768661499023, 1.1534690856933594, 0.9557936191558838, 0.8526636362075806, 1.2144603729248047, 0.4830768406391144, 1.0027544498443604, 1.0697739124298096, 0.4254515469074249, 0.9625717401504517, 0.6955944895744324, 1.460973858833313, 1.947672963142395, 0.0, 0.0, 0.0, -1.4985556602478027, 0.0, 4.75236701965332, 7.602309226989746], [0.6545663475990295, 0.171931192278862, 0.0, 0.0, -8.833128929138184, 0.0, 0.0, 0.0, -4.950003147125244, -4.787413597106934, -4.864211559295654, -4.284267425537109, -4.595980167388916, -4.372522354125977, -3.5304737091064453, -2.8733983039855957, -3.1778347492218018, -2.9926934242248535, -2.6617956161499023, -2.362133026123047, -0.8529956340789795, -0.2356947958469391, -1.3971641063690186, -1.2315531969070435, -0.22580944001674652, -1.3801013231277466, -0.0018676738254725933, -0.45241761207580566, -0.7399330735206604, -0.10269825160503387, 0.39445313811302185, 0.5953181982040405, 0.2574867606163025, 1.3401317596435547, 0.8434743881225586, 0.4478446841239929, 0.35927513241767883, 0.3871181905269623, 1.3250350952148438, -0.032754331827163696, 2.193441867828369, 0.926215410232544, 1.2522697448730469, 0.8302369713783264, 1.7915645837783813, 1.5735597610473633, 1.110613465309143, 1.5155408382415771, 1.5152548551559448, -0.7342946529388428, 1.4270484447479248, -0.018613534048199654, 0.09773577749729156, 1.3693205118179321, 1.8797391653060913, 2.418234348297119, 2.056739330291748, -0.5281528830528259, 0.9296872019767761, 0.9229711890220642, 1.4790387153625488, 1.1479930877685547, 1.3411986827850342, 0.9829028844833374, 0.8855413198471069, 0.45748957991600037, 1.2255325317382812, 1.2392246723175049, 0.8542051315307617, 1.1101622581481934, 1.3317581415176392, 2.5635933876037598, 0.0, 0.0, 2.4115676879882812, 0.0, 0.0, 6.068604469299316, 0.6545663475990295, 0.171931192278862, -0.0, -0.0, -8.833128929138184, -0.0, -0.0, -0.0, -4.950003147125244, -4.787413597106934, -4.864211559295654, -4.284267425537109, -4.595980167388916, -4.372522354125977, -3.5304737091064453, -2.8733983039855957, -3.1778347492218018, -2.9926934242248535, -2.6617956161499023, -2.362133026123047, -0.8529956340789795, -0.2356947958469391, -1.3971641063690186, -1.2315531969070435, -0.22580944001674652, -1.3801013231277466, -0.0018676738254725933, -0.45241761207580566, -0.7399330735206604, -0.10269825160503387, 0.39445313811302185, 0.5953181982040405, 0.2574867606163025, 1.3401317596435547, 0.8434743881225586, 0.4478446841239929, 0.35927513241767883, 0.3871181905269623, 1.3250350952148438, -0.032754331827163696, 2.193441867828369, 0.926215410232544, 1.2522697448730469, 0.8302369713783264, 1.7915645837783813, 1.5735597610473633, 1.110613465309143, 1.5155408382415771, 1.5152548551559448, -0.7342946529388428, 1.4270484447479248, -0.018613534048199654, 0.09773577749729156, 1.3693205118179321, 1.8797391653060913, 2.418234348297119, 2.056739330291748, -0.5281528830528259, 0.9296872019767761, 0.9229711890220642, 1.4790387153625488, 1.1479930877685547, 1.3411986827850342, 0.9829028844833374, 0.8855413198471069, 0.45748957991600037, 1.2255325317382812, 1.2392246723175049, 0.8542051315307617, 1.1101622581481934, 1.3317581415176392, 2.5635933876037598, 0.0, 0.0, 2.4115676879882812, 0.0, 0.0, 6.068604469299316], [-2.0366134643554688, -3.080246686935425, 0.0, 0.0, 0.0, 0.0, 0.0, -3.108917236328125, -5.3641438484191895, -5.042685031890869, -5.281196117401123, -4.685874938964844, -4.161942005157471, -3.5623488426208496, -3.1644668579101562, -3.557457685470581, -3.698369264602661, -2.3145625591278076, -2.4065146446228027, -1.6755701303482056, -1.518032193183899, -2.0788896083831787, -0.857688844203949, -0.9648083448410034, -0.8314244151115417, -0.495735228061676, -0.29227057099342346, -0.7743478417396545, -0.3731679916381836, 0.563889741897583, 0.394512802362442, -2.231123447418213, 0.7292665839195251, 1.0176446437835693, 0.2932753264904022, 0.7290205359458923, 0.6354875564575195, 0.9563620686531067, 1.0205028057098389, 1.011034607887268, 1.011582851409912, 1.2267080545425415, 0.8218531012535095, 0.9913650155067444, 0.8329628705978394, 1.285644769668579, -0.09648609161376953, 1.5634642839431763, 1.579945683479309, 1.273439645767212, 1.3098350763320923, 0.7156369686126709, 1.8890520334243774, 1.0450090169906616, 1.9065276384353638, 0.8067241311073303, 2.5318074226379395, 2.165992498397827, 2.3929874897003174, 0.2957617938518524, 0.5748307704925537, 0.5449492931365967, 1.7453534603118896, 1.0934633016586304, 1.3709502220153809, 1.290358304977417, 1.3396031856536865, 1.3284533023834229, 1.126468300819397, 0.7097343802452087, 2.1176671981811523, 0.8773173689842224, 0.0, 0.0, 0.0, 0.0, 0.0, 7.453318119049072, -2.0366134643554688, -3.080246686935425, -0.0, -0.0, -0.0, -0.0, -0.0, -3.108917236328125, -5.3641438484191895, -5.042685031890869, -5.281196117401123, -4.685874938964844, -4.161942005157471, -3.5623488426208496, -3.1644668579101562, -3.557457685470581, -3.698369264602661, -2.3145625591278076, -2.4065146446228027, -1.6755701303482056, -1.518032193183899, -2.0788896083831787, -0.857688844203949, -0.9648083448410034, -0.8314244151115417, -0.495735228061676, -0.29227057099342346, -0.7743478417396545, -0.3731679916381836, 0.563889741897583, 0.394512802362442, -2.231123447418213, 0.7292665839195251, 1.0176446437835693, 0.2932753264904022, 0.7290205359458923, 0.6354875564575195, 0.9563620686531067, 1.0205028057098389, 1.011034607887268, 1.011582851409912, 1.2267080545425415, 0.8218531012535095, 0.9913650155067444, 0.8329628705978394, 1.285644769668579, -0.09648609161376953, 1.5634642839431763, 1.579945683479309, 1.273439645767212, 1.3098350763320923, 0.7156369686126709, 1.8890520334243774, 1.0450090169906616, 1.9065276384353638, 0.8067241311073303, 2.5318074226379395, 2.165992498397827, 2.3929874897003174, 0.2957617938518524, 0.5748307704925537, 0.5449492931365967, 1.7453534603118896, 1.0934633016586304, 1.3709502220153809, 1.290358304977417, 1.3396031856536865, 1.3284533023834229, 1.126468300819397, 0.7097343802452087, 2.1176671981811523, 0.8773173689842224, 0.0, 0.0, 0.0, 0.0, 0.0, 7.453318119049072], [-2.3396401405334473, 0.0, 0.0, 0.0, 0.0, 0.0, -6.967948913574219, -5.127636432647705, -5.190616607666016, -5.110410213470459, -4.98205041885376, -4.731895446777344, -4.214020252227783, -3.961592435836792, -3.8888847827911377, -3.6940810680389404, -2.8325002193450928, -2.3662679195404053, -2.1620821952819824, -2.130825996398926, -2.3843722343444824, -1.653207540512085, -0.5657182931900024, -0.6108073592185974, -1.1542314291000366, -0.8534250259399414, -1.022203803062439, -1.6787049770355225, -0.1087213009595871, -0.15258893370628357, 0.009479528293013573, 0.6083937883377075, 0.5837203860282898, 1.3233140707015991, 1.1159451007843018, 0.4573551416397095, 0.6435034275054932, 1.1486635208129883, 1.534443736076355, 0.896446943283081, 1.2252471446990967, 1.0237139463424683, 1.1955763101577759, 0.9500495791435242, 1.1588501930236816, 1.3335330486297607, 1.2985668182373047, 0.9881671071052551, 1.7582006454467773, 2.3145432472229004, 1.1610171794891357, 1.2576243877410889, 1.44501531124115, 1.2826343774795532, 0.893192708492279, 1.7654434442520142, 0.8726240396499634, 1.416093349456787, 0.3337804973125458, 0.23916305601596832, 0.9180049896240234, 0.4506828188896179, 0.6860296726226807, 1.7125351428985596, 1.074817180633545, 1.9105826616287231, 1.4491592645645142, 0.4104362726211548, 1.3643240928649902, 0.9231976866722107, 0.9648073315620422, 1.0189322233200073, 2.1992392539978027, 0.0, 0.0, 0.0, 0.0, 0.0, -2.3396401405334473, -0.0, -0.0, -0.0, -0.0, -0.0, -6.967948913574219, -5.127636432647705, -5.190616607666016, -5.110410213470459, -4.98205041885376, -4.731895446777344, -4.214020252227783, -3.961592435836792, -3.8888847827911377, -3.6940810680389404, -2.8325002193450928, -2.3662679195404053, -2.1620821952819824, -2.130825996398926, -2.3843722343444824, -1.653207540512085, -0.5657182931900024, -0.6108073592185974, -1.1542314291000366, -0.8534250259399414, -1.022203803062439, -1.6787049770355225, -0.1087213009595871, -0.15258893370628357, 0.009479528293013573, 0.6083937883377075, 0.5837203860282898, 1.3233140707015991, 1.1159451007843018, 0.4573551416397095, 0.6435034275054932, 1.1486635208129883, 1.534443736076355, 0.896446943283081, 1.2252471446990967, 1.0237139463424683, 1.1955763101577759, 0.9500495791435242, 1.1588501930236816, 1.3335330486297607, 1.2985668182373047, 0.9881671071052551, 1.7582006454467773, 2.3145432472229004, 1.1610171794891357, 1.2576243877410889, 1.44501531124115, 1.2826343774795532, 0.893192708492279, 1.7654434442520142, 0.8726240396499634, 1.416093349456787, 0.3337804973125458, 0.23916305601596832, 0.9180049896240234, 0.4506828188896179, 0.6860296726226807, 1.7125351428985596, 1.074817180633545, 1.9105826616287231, 1.4491592645645142, 0.4104362726211548, 1.3643240928649902, 0.9231976866722107, 0.9648073315620422, 1.0189322233200073, 2.1992392539978027, 0.0, 0.0, 0.0, 0.0, 0.0], [-3.3206636905670166, 0.0, 0.0, 0.0, 0.0, 0.0, -6.1431498527526855, -5.192053318023682, -5.736830234527588, -4.945400238037109, -4.70377254486084, -5.0683746337890625, -4.478945732116699, -3.321453332901001, -3.193493127822876, -3.045278310775757, -3.526871681213379, -3.408226251602173, -2.35714054107666, -1.8650847673416138, -1.876094102859497, -2.0533862113952637, -1.0404329299926758, -0.380109041929245, -0.36358100175857544, -0.22075603902339935, -0.48947224020957947, -0.31385666131973267, 0.277248352766037, -0.3483436703681946, -0.4575507640838623, 1.043749213218689, 0.8289002776145935, 1.4098762273788452, 0.7267743945121765, 0.13487260043621063, 2.692011594772339, 0.6178018450737, 1.3781673908233643, 1.6926316022872925, 1.2262883186340332, -0.17026621103286743, 0.9399487972259521, 0.3532325327396393, 0.8402379751205444, 1.7286778688430786, 0.8693425059318542, 1.4070994853973389, 1.7666471004486084, 1.5586787462234497, 2.0410032272338867, 1.5930241346359253, 1.1577523946762085, 1.6847003698349, 1.2361946105957031, 1.6125383377075195, 1.1695114374160767, 4.084223747253418, 1.496944785118103, 1.6673059463500977, 0.22693488001823425, 1.2829011678695679, 1.7588527202606201, 1.7365368604660034, 1.5541542768478394, 0.9613648056983948, 1.2235119342803955, 2.107558250427246, 1.5196852684020996, 2.1074862480163574, 1.1975431442260742, 1.2643895149230957, 1.0544713735580444, 0.0, 0.0, 0.0, 0.0, 5.970630645751953, -3.3206636905670166, -0.0, -0.0, -0.0, -0.0, -0.0, -6.1431498527526855, -5.192053318023682, -5.736830234527588, -4.945400238037109, -4.70377254486084, -5.0683746337890625, -4.478945732116699, -3.321453332901001, -3.193493127822876, -3.045278310775757, -3.526871681213379, -3.408226251602173, -2.35714054107666, -1.8650847673416138, -1.876094102859497, -2.0533862113952637, -1.0404329299926758, -0.380109041929245, -0.36358100175857544, -0.22075603902339935, -0.48947224020957947, -0.31385666131973267, 0.277248352766037, -0.3483436703681946, -0.4575507640838623, 1.043749213218689, 0.8289002776145935, 1.4098762273788452, 0.7267743945121765, 0.13487260043621063, 2.692011594772339, 0.6178018450737, 1.3781673908233643, 1.6926316022872925, 1.2262883186340332, -0.17026621103286743, 0.9399487972259521, 0.3532325327396393, 0.8402379751205444, 1.7286778688430786, 0.8693425059318542, 1.4070994853973389, 1.7666471004486084, 1.5586787462234497, 2.0410032272338867, 1.5930241346359253, 1.1577523946762085, 1.6847003698349, 1.2361946105957031, 1.6125383377075195, 1.1695114374160767, 4.084223747253418, 1.496944785118103, 1.6673059463500977, 0.22693488001823425, 1.2829011678695679, 1.7588527202606201, 1.7365368604660034, 1.5541542768478394, 0.9613648056983948, 1.2235119342803955, 2.107558250427246, 1.5196852684020996, 2.1074862480163574, 1.1975431442260742, 1.2643895149230957, 1.0544713735580444, 0.0, 0.0, 0.0, 0.0, 5.970630645751953], [-4.455216884613037, 0.0, 0.0, 0.0, 0.0, -6.228845119476318, -6.06533670425415, -5.593516826629639, -5.779987812042236, -5.730405330657959, -4.7742390632629395, -4.678010940551758, -4.013530731201172, -4.102992534637451, -3.779583692550659, -2.9067654609680176, -2.802917242050171, -2.5005741119384766, -1.386526107788086, -2.12988543510437, -2.0015528202056885, -0.18994899094104767, -1.1337798833847046, -0.581724226474762, -0.2844862639904022, -1.2283496856689453, -0.8318173885345459, -0.48725390434265137, -0.21031054854393005, -0.35289230942726135, 0.5293224453926086, -0.7718995809555054, 0.8324492573738098, 0.6193010807037354, -0.08659543842077255, 0.2607558071613312, 1.0309252738952637, 1.3010625839233398, 2.714420795440674, 0.7344833016395569, 0.9999626874923706, 0.7399876117706299, 0.7007102966308594, 0.5379793643951416, 1.371533751487732, 0.9117472171783447, 1.0254584550857544, 1.8462560176849365, 2.6364643573760986, 3.6212589740753174, 2.092132568359375, 0.550527036190033, 1.6961798667907715, 1.2828094959259033, 0.6650155782699585, 1.5196864604949951, 1.2823530435562134, 1.3578946590423584, 0.8258538246154785, 1.0910654067993164, 1.5768743753433228, 2.163520336151123, 1.449963927268982, 1.4953700304031372, 0.05997574329376221, 1.840814471244812, 1.1489533185958862, 1.786265254020691, 0.74468994140625, 1.5698591470718384, 1.7902148962020874, 1.7225639820098877, 1.7353010177612305, 1.6073304414749146, 0.0, 0.0, 0.0, 5.8101325035095215, -4.455216884613037, -0.0, -0.0, -0.0, -0.0, -6.228845119476318, -6.06533670425415, -5.593516826629639, -5.779987812042236, -5.730405330657959, -4.7742390632629395, -4.678010940551758, -4.013530731201172, -4.102992534637451, -3.779583692550659, -2.9067654609680176, -2.802917242050171, -2.5005741119384766, -1.386526107788086, -2.12988543510437, -2.0015528202056885, -0.18994899094104767, -1.1337798833847046, -0.581724226474762, -0.2844862639904022, -1.2283496856689453, -0.8318173885345459, -0.48725390434265137, -0.21031054854393005, -0.35289230942726135, 0.5293224453926086, -0.7718995809555054, 0.8324492573738098, 0.6193010807037354, -0.08659543842077255, 0.2607558071613312, 1.0309252738952637, 1.3010625839233398, 2.714420795440674, 0.7344833016395569, 0.9999626874923706, 0.7399876117706299, 0.7007102966308594, 0.5379793643951416, 1.371533751487732, 0.9117472171783447, 1.0254584550857544, 1.8462560176849365, 2.6364643573760986, 3.6212589740753174, 2.092132568359375, 0.550527036190033, 1.6961798667907715, 1.2828094959259033, 0.6650155782699585, 1.5196864604949951, 1.2823530435562134, 1.3578946590423584, 0.8258538246154785, 1.0910654067993164, 1.5768743753433228, 2.163520336151123, 1.449963927268982, 1.4953700304031372, 0.05997574329376221, 1.840814471244812, 1.1489533185958862, 1.786265254020691, 0.74468994140625, 1.5698591470718384, 1.7902148962020874, 1.7225639820098877, 1.7353010177612305, 1.6073304414749146, 0.0, 0.0, 0.0, 5.8101325035095215], [-2.3271713256835938, 0.0, 0.0, 0.0, 0.0, -5.849406719207764, -5.749656677246094, -6.87743616104126, -5.454838275909424, -4.9789018630981445, -4.743384838104248, -4.52039909362793, -3.6593079566955566, -3.589142084121704, -2.612926483154297, -3.252429246902466, -2.147049903869629, -2.6730010509490967, -1.7796237468719482, -1.4004298448562622, -1.1150662899017334, -1.6700944900512695, -0.31966927647590637, -0.22612018883228302, -0.5569196343421936, -0.11908833682537079, -0.32834264636039734, -1.182195782661438, -0.29731759428977966, -0.6464444398880005, -0.23426388204097748, 0.38597238063812256, -0.3895687758922577, 1.5500842332839966, 0.5288646221160889, 1.1534594297409058, 1.2672505378723145, 0.18492861092090607, 2.1254003047943115, 0.4568266272544861, 1.1980135440826416, 1.8961225748062134, 1.3688182830810547, 1.386816143989563, 1.2084769010543823, 1.616812825202942, 1.3774607181549072, 1.2246118783950806, 2.015653610229492, 1.7087727785110474, 1.942023754119873, 1.5935593843460083, 1.8634388446807861, 1.7396608591079712, 2.2627713680267334, 1.3607529401779175, 1.250922441482544, 2.3665990829467773, 1.8826183080673218, 0.7077077627182007, 1.585182785987854, 1.1401159763336182, 1.3953924179077148, 1.84228515625, 1.1184850931167603, 1.5221415758132935, 1.2900924682617188, 0.798312783241272, 1.0690988302230835, 1.6894659996032715, 1.7771607637405396, 1.411007285118103, 2.0833351612091064, 1.553383231163025, 0.0, 0.0, 0.0, 0.0, -2.3271713256835938, -0.0, -0.0, -0.0, -0.0, -5.849406719207764, -5.749656677246094, -6.87743616104126, -5.454838275909424, -4.9789018630981445, -4.743384838104248, -4.52039909362793, -3.6593079566955566, -3.589142084121704, -2.612926483154297, -3.252429246902466, -2.147049903869629, -2.6730010509490967, -1.7796237468719482, -1.4004298448562622, -1.1150662899017334, -1.6700944900512695, -0.31966927647590637, -0.22612018883228302, -0.5569196343421936, -0.11908833682537079, -0.32834264636039734, -1.182195782661438, -0.29731759428977966, -0.6464444398880005, -0.23426388204097748, 0.38597238063812256, -0.3895687758922577, 1.5500842332839966, 0.5288646221160889, 1.1534594297409058, 1.2672505378723145, 0.18492861092090607, 2.1254003047943115, 0.4568266272544861, 1.1980135440826416, 1.8961225748062134, 1.3688182830810547, 1.386816143989563, 1.2084769010543823, 1.616812825202942, 1.3774607181549072, 1.2246118783950806, 2.015653610229492, 1.7087727785110474, 1.942023754119873, 1.5935593843460083, 1.8634388446807861, 1.7396608591079712, 2.2627713680267334, 1.3607529401779175, 1.250922441482544, 2.3665990829467773, 1.8826183080673218, 0.7077077627182007, 1.585182785987854, 1.1401159763336182, 1.3953924179077148, 1.84228515625, 1.1184850931167603, 1.5221415758132935, 1.2900924682617188, 0.798312783241272, 1.0690988302230835, 1.6894659996032715, 1.7771607637405396, 1.411007285118103, 2.0833351612091064, 1.553383231163025, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -5.343619346618652, -5.7019453048706055, -5.574665546417236, -5.299008369445801, -5.648210048675537, -5.238868713378906, -5.358224391937256, -3.892725944519043, -3.6790096759796143, -3.4076805114746094, -3.6159839630126953, -2.825493574142456, -3.22590708732605, -1.8232494592666626, -3.031388998031616, -2.5973501205444336, -2.714437246322632, -1.2128969430923462, -0.8326176404953003, -1.6841533184051514, -0.5231069922447205, -0.6847525238990784, -0.748292863368988, -0.6193851232528687, 0.3790835738182068, -0.14046324789524078, -0.09412282705307007, 0.7445049285888672, 0.7278101444244385, 0.34698596596717834, 0.8153677582740784, 1.0126960277557373, 1.2943006753921509, 1.842239499092102, -1.9267252683639526, 0.9887970089912415, 1.6927165985107422, 0.7071762681007385, 1.371161937713623, 1.55270254611969, 1.5544666051864624, 0.264496386051178, 1.638623595237732, 2.2735910415649414, 1.5263714790344238, 1.7146028280258179, 1.7078920602798462, 1.8351619243621826, 1.225628137588501, 0.8421080112457275, 1.384804129600525, 1.0369815826416016, 1.754887580871582, 1.9625529050827026, 1.4537198543548584, 1.642171859741211, 1.1543970108032227, 1.1061724424362183, 1.268957257270813, 1.0336889028549194, 1.1283082962036133, 0.8570919036865234, 2.1269707679748535, 0.9821018576622009, 0.7116174697875977, 1.483163595199585, 1.250227928161621, 2.213291645050049, 1.5980075597763062, 1.8657490015029907, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -5.343619346618652, -5.7019453048706055, -5.574665546417236, -5.299008369445801, -5.648210048675537, -5.238868713378906, -5.358224391937256, -3.892725944519043, -3.6790096759796143, -3.4076805114746094, -3.6159839630126953, -2.825493574142456, -3.22590708732605, -1.8232494592666626, -3.031388998031616, -2.5973501205444336, -2.714437246322632, -1.2128969430923462, -0.8326176404953003, -1.6841533184051514, -0.5231069922447205, -0.6847525238990784, -0.748292863368988, -0.6193851232528687, 0.3790835738182068, -0.14046324789524078, -0.09412282705307007, 0.7445049285888672, 0.7278101444244385, 0.34698596596717834, 0.8153677582740784, 1.0126960277557373, 1.2943006753921509, 1.842239499092102, -1.9267252683639526, 0.9887970089912415, 1.6927165985107422, 0.7071762681007385, 1.371161937713623, 1.55270254611969, 1.5544666051864624, 0.264496386051178, 1.638623595237732, 2.2735910415649414, 1.5263714790344238, 1.7146028280258179, 1.7078920602798462, 1.8351619243621826, 1.225628137588501, 0.8421080112457275, 1.384804129600525, 1.0369815826416016, 1.754887580871582, 1.9625529050827026, 1.4537198543548584, 1.642171859741211, 1.1543970108032227, 1.1061724424362183, 1.268957257270813, 1.0336889028549194, 1.1283082962036133, 0.8570919036865234, 2.1269707679748535, 0.9821018576622009, 0.7116174697875977, 1.483163595199585, 1.250227928161621, 2.213291645050049, 1.5980075597763062, 1.8657490015029907, 0.0, 0.0, 0.0, 0.0], [-3.9196231365203857, 0.0, 0.0, 0.0, -6.716807842254639, -6.589306831359863, -5.914121627807617, -5.784829139709473, -5.539895057678223, -4.747439384460449, -5.185297012329102, -4.529271125793457, -4.747401714324951, -3.765964984893799, -3.760256767272949, -3.134096145629883, -2.2320752143859863, -1.4025218486785889, -3.781463384628296, -2.5223453044891357, -1.8556448221206665, -1.320647954940796, -2.1415011882781982, -1.1081069707870483, -0.4390208125114441, 0.25615227222442627, -0.5930982232093811, 0.5547095537185669, 0.16574832797050476, -1.394705057144165, 0.1890600323677063, 0.31929564476013184, 0.00029455425101332366, 1.1105446815490723, 0.28159070014953613, -0.27270564436912537, 0.9828392267227173, 2.4361705780029297, -0.6384351253509521, 1.6005275249481201, 2.3813459873199463, 1.1563466787338257, 1.644633412361145, 0.6821810603141785, 1.2335137128829956, 1.9999213218688965, 1.6510474681854248, 0.5745295286178589, 1.659249186515808, 1.618296504020691, 1.7636713981628418, 1.4385366439819336, 0.6718279719352722, 1.2366969585418701, 1.409334421157837, 1.6195341348648071, 1.8586173057556152, 1.8143671751022339, 1.1667178869247437, 1.9376531839370728, 1.4334315061569214, 1.0099903345108032, 1.626884937286377, 1.9393068552017212, 1.8222570419311523, 1.3840670585632324, 1.5594561100006104, 0.8708731532096863, 0.8158327341079712, 1.858315110206604, 2.5606539249420166, 2.2250702381134033, 1.9135196208953857, 2.292456865310669, 2.36079740524292, 0.0, 0.0, 2.559770107269287, -3.9196231365203857, -0.0, -0.0, -0.0, -6.716807842254639, -6.589306831359863, -5.914121627807617, -5.784829139709473, -5.539895057678223, -4.747439384460449, -5.185297012329102, -4.529271125793457, -4.747401714324951, -3.765964984893799, -3.760256767272949, -3.134096145629883, -2.2320752143859863, -1.4025218486785889, -3.781463384628296, -2.5223453044891357, -1.8556448221206665, -1.320647954940796, -2.1415011882781982, -1.1081069707870483, -0.4390208125114441, 0.25615227222442627, -0.5930982232093811, 0.5547095537185669, 0.16574832797050476, -1.394705057144165, 0.1890600323677063, 0.31929564476013184, 0.00029455425101332366, 1.1105446815490723, 0.28159070014953613, -0.27270564436912537, 0.9828392267227173, 2.4361705780029297, -0.6384351253509521, 1.6005275249481201, 2.3813459873199463, 1.1563466787338257, 1.644633412361145, 0.6821810603141785, 1.2335137128829956, 1.9999213218688965, 1.6510474681854248, 0.5745295286178589, 1.659249186515808, 1.618296504020691, 1.7636713981628418, 1.4385366439819336, 0.6718279719352722, 1.2366969585418701, 1.409334421157837, 1.6195341348648071, 1.8586173057556152, 1.8143671751022339, 1.1667178869247437, 1.9376531839370728, 1.4334315061569214, 1.0099903345108032, 1.626884937286377, 1.9393068552017212, 1.8222570419311523, 1.3840670585632324, 1.5594561100006104, 0.8708731532096863, 0.8158327341079712, 1.858315110206604, 2.5606539249420166, 2.2250702381134033, 1.9135196208953857, 2.292456865310669, 2.36079740524292, 0.0, 0.0, 2.559770107269287], [-4.106567859649658, 0.0, 0.0, -5.482391834259033, -6.118828296661377, -6.490947723388672, -6.622121334075928, -5.871531963348389, -5.7301716804504395, -4.677621841430664, -4.498199939727783, -3.983848810195923, -2.9471633434295654, -3.299731492996216, -3.881390333175659, -3.5744471549987793, -1.548216462135315, -2.1214780807495117, -2.2048754692077637, -2.328213691711426, -2.2678065299987793, -1.722200870513916, -3.0154170989990234, -1.7319903373718262, -0.8828812837600708, -0.6786823272705078, -0.14079080522060394, -0.6378657817840576, -0.3059370815753937, 0.3006129562854767, -0.38472869992256165, 0.5226511359214783, -0.04525149613618851, -0.039933718740940094, 1.099350094795227, 0.3780907392501831, 0.6346757411956787, 0.03665975481271744, 0.45797842741012573, 1.6805673837661743, 0.9416797757148743, 1.3398919105529785, 0.9088391661643982, 1.2829768657684326, 1.4619117975234985, 1.9017908573150635, 0.6685771346092224, 1.1989448070526123, 1.924437403678894, 1.5489375591278076, 1.5281208753585815, 1.7516019344329834, 1.7417656183242798, 1.7414793968200684, 2.316009283065796, 1.737326741218567, 1.1089112758636475, 1.9826855659484863, 3.0074968338012695, -0.7736528515815735, 3.5975921154022217, 1.0133039951324463, 0.8722054958343506, 1.7800039052963257, 1.288223385810852, 1.7561569213867188, 1.4355278015136719, 1.3965303897857666, 1.1938546895980835, 1.0547696352005005, 1.4529767036437988, 1.8657866716384888, 1.6283975839614868, 2.221437931060791, 3.1999523639678955, 0.0, 0.0, 2.365866184234619, -4.106567859649658, -0.0, -0.0, -5.482391834259033, -6.118828296661377, -6.490947723388672, -6.622121334075928, -5.871531963348389, -5.7301716804504395, -4.677621841430664, -4.498199939727783, -3.983848810195923, -2.9471633434295654, -3.299731492996216, -3.881390333175659, -3.5744471549987793, -1.548216462135315, -2.1214780807495117, -2.2048754692077637, -2.328213691711426, -2.2678065299987793, -1.722200870513916, -3.0154170989990234, -1.7319903373718262, -0.8828812837600708, -0.6786823272705078, -0.14079080522060394, -0.6378657817840576, -0.3059370815753937, 0.3006129562854767, -0.38472869992256165, 0.5226511359214783, -0.04525149613618851, -0.039933718740940094, 1.099350094795227, 0.3780907392501831, 0.6346757411956787, 0.03665975481271744, 0.45797842741012573, 1.6805673837661743, 0.9416797757148743, 1.3398919105529785, 0.9088391661643982, 1.2829768657684326, 1.4619117975234985, 1.9017908573150635, 0.6685771346092224, 1.1989448070526123, 1.924437403678894, 1.5489375591278076, 1.5281208753585815, 1.7516019344329834, 1.7417656183242798, 1.7414793968200684, 2.316009283065796, 1.737326741218567, 1.1089112758636475, 1.9826855659484863, 3.0074968338012695, -0.7736528515815735, 3.5975921154022217, 1.0133039951324463, 0.8722054958343506, 1.7800039052963257, 1.288223385810852, 1.7561569213867188, 1.4355278015136719, 1.3965303897857666, 1.1938546895980835, 1.0547696352005005, 1.4529767036437988, 1.8657866716384888, 1.6283975839614868, 2.221437931060791, 3.1999523639678955, 0.0, 0.0, 2.365866184234619], [-5.64854097366333, 0.0, 0.0, -4.417187690734863, -6.064605236053467, -6.6160173416137695, -6.976248264312744, -5.846667766571045, -5.1703572273254395, -4.731143951416016, -5.227575778961182, -4.475758075714111, -4.827722072601318, -3.959714651107788, -5.694034099578857, -3.6881351470947266, -3.409639358520508, -3.2252447605133057, -4.260290145874023, -0.7410775423049927, -1.6877137422561646, -1.604105830192566, -0.27129313349723816, -1.4927974939346313, -1.338451623916626, -1.1699786186218262, -0.5665427446365356, 0.4480270445346832, -1.058879017829895, 0.4605587422847748, 0.05982238054275513, 0.4167090356349945, -0.5749517679214478, 0.24542297422885895, 0.058754242956638336, 0.6536440253257751, 0.23202857375144958, 0.0534258671104908, 2.1107332706451416, 0.6194144487380981, 0.7541630864143372, 1.179662823677063, 1.7845642566680908, 1.8089450597763062, 1.2147897481918335, 4.76495885848999, 1.479412317276001, 1.4431021213531494, 1.6198718547821045, 1.6915366649627686, 1.763635516166687, 2.437018871307373, 1.5678906440734863, 1.5238854885101318, 2.1429097652435303, 1.6368982791900635, 1.2488476037979126, 1.741165041923523, 1.322576880455017, 0.8699265122413635, 1.6526159048080444, 1.4364887475967407, 1.9360496997833252, 0.5037065744400024, 0.7407853603363037, 1.7364245653152466, 1.7395073175430298, 1.8864418268203735, 1.4688435792922974, 1.6779003143310547, 1.6920223236083984, 1.5992988348007202, 2.5973896980285645, 1.8259553909301758, 2.3101019859313965, 0.0, 0.0, 5.160834312438965, -5.64854097366333, -0.0, -0.0, -4.417187690734863, -6.064605236053467, -6.6160173416137695, -6.976248264312744, -5.846667766571045, -5.1703572273254395, -4.731143951416016, -5.227575778961182, -4.475758075714111, -4.827722072601318, -3.959714651107788, -5.694034099578857, -3.6881351470947266, -3.409639358520508, -3.2252447605133057, -4.260290145874023, -0.7410775423049927, -1.6877137422561646, -1.604105830192566, -0.27129313349723816, -1.4927974939346313, -1.338451623916626, -1.1699786186218262, -0.5665427446365356, 0.4480270445346832, -1.058879017829895, 0.4605587422847748, 0.05982238054275513, 0.4167090356349945, -0.5749517679214478, 0.24542297422885895, 0.058754242956638336, 0.6536440253257751, 0.23202857375144958, 0.0534258671104908, 2.1107332706451416, 0.6194144487380981, 0.7541630864143372, 1.179662823677063, 1.7845642566680908, 1.8089450597763062, 1.2147897481918335, 4.76495885848999, 1.479412317276001, 1.4431021213531494, 1.6198718547821045, 1.6915366649627686, 1.763635516166687, 2.437018871307373, 1.5678906440734863, 1.5238854885101318, 2.1429097652435303, 1.6368982791900635, 1.2488476037979126, 1.741165041923523, 1.322576880455017, 0.8699265122413635, 1.6526159048080444, 1.4364887475967407, 1.9360496997833252, 0.5037065744400024, 0.7407853603363037, 1.7364245653152466, 1.7395073175430298, 1.8864418268203735, 1.4688435792922974, 1.6779003143310547, 1.6920223236083984, 1.5992988348007202, 2.5973896980285645, 1.8259553909301758, 2.3101019859313965, 0.0, 0.0, 5.160834312438965], [-6.900298118591309, 0.0, 0.0, -7.132500171661377, -6.55062198638916, -6.922369003295898, -6.277925491333008, -5.576720714569092, -5.334785461425781, -5.145968914031982, -5.114928722381592, -4.117048263549805, -4.599193096160889, -4.096957206726074, -3.749016046524048, -4.125354766845703, -2.5567142963409424, -2.1633384227752686, -2.5671675205230713, -2.377450942993164, -1.6553657054901123, -1.7199771404266357, -1.2570436000823975, -0.7662172317504883, -1.0005334615707397, -0.7381401658058167, -0.5842036604881287, -0.7228189706802368, 0.037110336124897, 0.5589874386787415, 0.701224148273468, 0.15388651192188263, -0.5139715075492859, 0.6291584372520447, 0.8214303851127625, 0.041468556970357895, 0.3391539752483368, 0.8281114101409912, 1.1753093004226685, 0.08121681958436966, 1.471426010131836, 2.0063538551330566, 2.5262410640716553, 1.3476052284240723, 1.5321210622787476, 1.3523176908493042, 1.4220004081726074, 1.3581559658050537, 1.3479554653167725, 1.6976838111877441, 1.582203984260559, 1.8315623998641968, 1.6869771480560303, 1.5165406465530396, 1.5710914134979248, 1.5828040838241577, 1.6416136026382446, 1.1580382585525513, 1.4839704036712646, 1.6683248281478882, 1.8223941326141357, 2.0373425483703613, 1.0520908832550049, 0.6672295928001404, 1.8889973163604736, 1.5351238250732422, 1.9633663892745972, 2.1403121948242188, 1.561181902885437, 1.7567692995071411, 1.7921252250671387, 1.8762930631637573, 2.0146937370300293, 2.325083017349243, 2.903568744659424, 0.0, 0.0, 4.608039855957031, -6.900298118591309, -0.0, -0.0, -7.132500171661377, -6.55062198638916, -6.922369003295898, -6.277925491333008, -5.576720714569092, -5.334785461425781, -5.145968914031982, -5.114928722381592, -4.117048263549805, -4.599193096160889, -4.096957206726074, -3.749016046524048, -4.125354766845703, -2.5567142963409424, -2.1633384227752686, -2.5671675205230713, -2.377450942993164, -1.6553657054901123, -1.7199771404266357, -1.2570436000823975, -0.7662172317504883, -1.0005334615707397, -0.7381401658058167, -0.5842036604881287, -0.7228189706802368, 0.037110336124897, 0.5589874386787415, 0.701224148273468, 0.15388651192188263, -0.5139715075492859, 0.6291584372520447, 0.8214303851127625, 0.041468556970357895, 0.3391539752483368, 0.8281114101409912, 1.1753093004226685, 0.08121681958436966, 1.471426010131836, 2.0063538551330566, 2.5262410640716553, 1.3476052284240723, 1.5321210622787476, 1.3523176908493042, 1.4220004081726074, 1.3581559658050537, 1.3479554653167725, 1.6976838111877441, 1.582203984260559, 1.8315623998641968, 1.6869771480560303, 1.5165406465530396, 1.5710914134979248, 1.5828040838241577, 1.6416136026382446, 1.1580382585525513, 1.4839704036712646, 1.6683248281478882, 1.8223941326141357, 2.0373425483703613, 1.0520908832550049, 0.6672295928001404, 1.8889973163604736, 1.5351238250732422, 1.9633663892745972, 2.1403121948242188, 1.561181902885437, 1.7567692995071411, 1.7921252250671387, 1.8762930631637573, 2.0146937370300293, 2.325083017349243, 2.903568744659424, 0.0, 0.0, 4.608039855957031], [-8.199018478393555, 0.0, 0.0, -6.444091320037842, -6.807536602020264, -6.103333950042725, -6.700697898864746, -5.911192417144775, -5.378620624542236, -5.273070335388184, -4.8534255027771, -4.4858574867248535, -4.597166538238525, -3.9998586177825928, -3.283411741256714, -3.181201219558716, -2.5821759700775146, -2.5825953483581543, -2.226616382598877, -1.7613922357559204, -2.416767120361328, -2.349940299987793, -1.8301022052764893, -1.5255156755447388, -0.7689042687416077, -0.7308928370475769, -0.4676964581012726, -0.19635188579559326, -0.4046081602573395, 0.9751784801483154, 1.037603735923767, 0.3113229274749756, 2.5585360527038574, 0.27286815643310547, 1.209028720855713, 0.4763983488082886, 1.2032063007354736, 0.06113043054938316, 1.4698235988616943, 0.5885486602783203, 1.9641343355178833, 1.6294023990631104, 2.3837504386901855, 0.7379170060157776, 1.189725637435913, 2.070648193359375, 1.001297950744629, 1.5489534139633179, 1.204726219177246, 1.8635505437850952, 1.7496024370193481, 2.0363121032714844, 1.591714859008789, 1.7598984241485596, 1.6787916421890259, 2.550015449523926, 1.7695209980010986, 1.4399220943450928, 1.2109051942825317, 1.3681358098983765, 0.735913097858429, 1.4822384119033813, 1.4982833862304688, 1.307337999343872, 1.7806318998336792, 0.8730489015579224, 0.8427616953849792, 1.4265873432159424, 1.52752685546875, 1.1708850860595703, 1.5838210582733154, 1.952859878540039, 1.819987177848816, 3.338679790496826, 2.652733325958252, 0.0, 0.0, 4.283633708953857, -8.199018478393555, -0.0, -0.0, -6.444091320037842, -6.807536602020264, -6.103333950042725, -6.700697898864746, -5.911192417144775, -5.378620624542236, -5.273070335388184, -4.8534255027771, -4.4858574867248535, -4.597166538238525, -3.9998586177825928, -3.283411741256714, -3.181201219558716, -2.5821759700775146, -2.5825953483581543, -2.226616382598877, -1.7613922357559204, -2.416767120361328, -2.349940299987793, -1.8301022052764893, -1.5255156755447388, -0.7689042687416077, -0.7308928370475769, -0.4676964581012726, -0.19635188579559326, -0.4046081602573395, 0.9751784801483154, 1.037603735923767, 0.3113229274749756, 2.5585360527038574, 0.27286815643310547, 1.209028720855713, 0.4763983488082886, 1.2032063007354736, 0.06113043054938316, 1.4698235988616943, 0.5885486602783203, 1.9641343355178833, 1.6294023990631104, 2.3837504386901855, 0.7379170060157776, 1.189725637435913, 2.070648193359375, 1.001297950744629, 1.5489534139633179, 1.204726219177246, 1.8635505437850952, 1.7496024370193481, 2.0363121032714844, 1.591714859008789, 1.7598984241485596, 1.6787916421890259, 2.550015449523926, 1.7695209980010986, 1.4399220943450928, 1.2109051942825317, 1.3681358098983765, 0.735913097858429, 1.4822384119033813, 1.4982833862304688, 1.307337999343872, 1.7806318998336792, 0.8730489015579224, 0.8427616953849792, 1.4265873432159424, 1.52752685546875, 1.1708850860595703, 1.5838210582733154, 1.952859878540039, 1.819987177848816, 3.338679790496826, 2.652733325958252, 0.0, 0.0, 4.283633708953857], [-3.9452521800994873, 0.0, 0.0, -6.868017196655273, -6.698948383331299, -5.851447582244873, -6.608944416046143, -6.15520715713501, -6.009496688842773, -5.405550956726074, -5.2695112228393555, -4.268204212188721, -4.232578277587891, -4.202232837677002, -3.1970462799072266, -3.723457098007202, -2.693427085876465, -2.6022818088531494, -3.358980178833008, -2.184894561767578, -1.8086549043655396, -1.7350050210952759, -0.8179845213890076, -1.1664760112762451, -1.2387869358062744, -1.1330071687698364, -0.5011277198791504, -0.21009711921215057, -0.5219753384590149, 2.1243033409118652, 1.2843525409698486, -1.8362144231796265, 1.5371037721633911, 0.5057764053344727, 0.12175466865301132, 0.8149541020393372, 1.4994481801986694, 0.8880789875984192, 0.5027073621749878, 0.9498529434204102, 3.727620840072632, 1.6028794050216675, 2.458678960800171, 1.633824348449707, 1.1111671924591064, 1.0610456466674805, 1.6219890117645264, 1.6473249197006226, 1.5651105642318726, 1.6995338201522827, 1.4978384971618652, 1.4098355770111084, 1.4938074350357056, 1.6227227449417114, 1.6023757457733154, 1.3924328088760376, 0.9587166905403137, 1.4356801509857178, 2.3684298992156982, 1.5219941139221191, -0.30117180943489075, 1.3802821636199951, 1.8027136325836182, 0.12875212728977203, 1.2568217515945435, 1.316274881362915, 0.7158175110816956, 1.2976676225662231, 2.4440011978149414, 1.9477031230926514, 2.199876070022583, 1.6741416454315186, 2.299771308898926, 2.7477481365203857, 1.5175772905349731, 0.0, 0.0, 0.0, -3.9452521800994873, -0.0, -0.0, -6.868017196655273, -6.698948383331299, -5.851447582244873, -6.608944416046143, -6.15520715713501, -6.009496688842773, -5.405550956726074, -5.2695112228393555, -4.268204212188721, -4.232578277587891, -4.202232837677002, -3.1970462799072266, -3.723457098007202, -2.693427085876465, -2.6022818088531494, -3.358980178833008, -2.184894561767578, -1.8086549043655396, -1.7350050210952759, -0.8179845213890076, -1.1664760112762451, -1.2387869358062744, -1.1330071687698364, -0.5011277198791504, -0.21009711921215057, -0.5219753384590149, 2.1243033409118652, 1.2843525409698486, -1.8362144231796265, 1.5371037721633911, 0.5057764053344727, 0.12175466865301132, 0.8149541020393372, 1.4994481801986694, 0.8880789875984192, 0.5027073621749878, 0.9498529434204102, 3.727620840072632, 1.6028794050216675, 2.458678960800171, 1.633824348449707, 1.1111671924591064, 1.0610456466674805, 1.6219890117645264, 1.6473249197006226, 1.5651105642318726, 1.6995338201522827, 1.4978384971618652, 1.4098355770111084, 1.4938074350357056, 1.6227227449417114, 1.6023757457733154, 1.3924328088760376, 0.9587166905403137, 1.4356801509857178, 2.3684298992156982, 1.5219941139221191, -0.30117180943489075, 1.3802821636199951, 1.8027136325836182, 0.12875212728977203, 1.2568217515945435, 1.316274881362915, 0.7158175110816956, 1.2976676225662231, 2.4440011978149414, 1.9477031230926514, 2.199876070022583, 1.6741416454315186, 2.299771308898926, 2.7477481365203857, 1.5175772905349731, 0.0, 0.0, 0.0], [-4.936814785003662, 0.0, 0.0, -6.8296637535095215, -6.7681708335876465, -6.589568138122559, -5.877605438232422, -6.646568775177002, -3.0852859020233154, -5.549923419952393, -5.208951950073242, -4.824575424194336, -4.497404098510742, -3.0136845111846924, -3.3743133544921875, -2.9544477462768555, -3.2414941787719727, -2.064018487930298, -2.9749531745910645, -1.8858622312545776, -3.625337600708008, -0.8663613200187683, -1.6815634965896606, -1.0917121171951294, -0.8086609244346619, -0.7129482626914978, -0.6489729881286621, -0.6911989450454712, -0.7192302942276001, 0.13480669260025024, -0.27139419317245483, -0.4687437117099762, 0.815065860748291, 0.31745636463165283, 2.393556594848633, 0.23354871571063995, 1.6410975456237793, 0.4374527335166931, 0.600388765335083, 1.1634029150009155, 0.1079123392701149, -0.17103132605552673, 1.1797338724136353, 2.004136085510254, 0.9093854427337646, 2.204507827758789, 1.850502371788025, 1.2031469345092773, 1.849625587463379, 1.5767313241958618, 1.4475719928741455, 1.330155372619629, 1.1847013235092163, 1.6410884857177734, 1.9614002704620361, 1.20726478099823, 1.4779715538024902, 1.520681619644165, 2.024557590484619, 0.9095368385314941, 2.129772186279297, 1.5693416595458984, 1.8666490316390991, 1.3776944875717163, 1.2687418460845947, 1.126896858215332, 1.316102147102356, 1.4752988815307617, 2.224233865737915, 1.5758535861968994, 1.6709569692611694, 1.3340959548950195, 2.9125020503997803, 2.9920525550842285, 2.6474862098693848, 0.0, 0.0, 0.0, -4.936814785003662, -0.0, -0.0, -6.8296637535095215, -6.7681708335876465, -6.589568138122559, -5.877605438232422, -6.646568775177002, -3.0852859020233154, -5.549923419952393, -5.208951950073242, -4.824575424194336, -4.497404098510742, -3.0136845111846924, -3.3743133544921875, -2.9544477462768555, -3.2414941787719727, -2.064018487930298, -2.9749531745910645, -1.8858622312545776, -3.625337600708008, -0.8663613200187683, -1.6815634965896606, -1.0917121171951294, -0.8086609244346619, -0.7129482626914978, -0.6489729881286621, -0.6911989450454712, -0.7192302942276001, 0.13480669260025024, -0.27139419317245483, -0.4687437117099762, 0.815065860748291, 0.31745636463165283, 2.393556594848633, 0.23354871571063995, 1.6410975456237793, 0.4374527335166931, 0.600388765335083, 1.1634029150009155, 0.1079123392701149, -0.17103132605552673, 1.1797338724136353, 2.004136085510254, 0.9093854427337646, 2.204507827758789, 1.850502371788025, 1.2031469345092773, 1.849625587463379, 1.5767313241958618, 1.4475719928741455, 1.330155372619629, 1.1847013235092163, 1.6410884857177734, 1.9614002704620361, 1.20726478099823, 1.4779715538024902, 1.520681619644165, 2.024557590484619, 0.9095368385314941, 2.129772186279297, 1.5693416595458984, 1.8666490316390991, 1.3776944875717163, 1.2687418460845947, 1.126896858215332, 1.316102147102356, 1.4752988815307617, 2.224233865737915, 1.5758535861968994, 1.6709569692611694, 1.3340959548950195, 2.9125020503997803, 2.9920525550842285, 2.6474862098693848, 0.0, 0.0, 0.0], [-6.354399681091309, 0.0, 0.0, -6.665012359619141, -6.987937927246094, -6.498379230499268, -6.563243865966797, -6.091903209686279, -6.045166969299316, -5.5650529861450195, -5.570574760437012, -4.7684431076049805, -4.921703338623047, -4.274085998535156, -4.044978618621826, -3.1006643772125244, -3.8010592460632324, -3.1263949871063232, -2.7995166778564453, -2.530503749847412, -3.15323805809021, -1.3409498929977417, -1.1652913093566895, -1.6048091650009155, -0.9102442264556885, -0.9473286867141724, -0.5617870688438416, -0.29889899492263794, -0.08256953954696655, -0.18380719423294067, 0.22314316034317017, 0.21298378705978394, 0.29039865732192993, 0.6234356760978699, 0.06630502641201019, 2.0253589153289795, 1.4669642448425293, 1.2570090293884277, 1.0689425468444824, 0.04293319955468178, 0.718000054359436, 1.3780107498168945, 1.2266497611999512, 1.4833500385284424, 1.4592280387878418, 1.1894181966781616, 1.90570867061615, 1.686041235923767, 1.4454677104949951, 1.5622378587722778, 0.9300052523612976, 1.114795446395874, 1.202040672302246, 1.1797223091125488, 0.0003599928168114275, 1.6123281717300415, 1.6890015602111816, 0.6518454551696777, 1.8597804307937622, 1.2872331142425537, 1.547697901725769, 1.1062222719192505, 1.2194690704345703, 1.211477518081665, 0.6412123441696167, 1.2668867111206055, 0.8842024803161621, 1.0286225080490112, 1.4688711166381836, 3.1939778327941895, 1.6179492473602295, 1.2670888900756836, 2.7019410133361816, 2.667236804962158, 1.9223583936691284, 0.0, 0.0, 0.0, -6.354399681091309, -0.0, -0.0, -6.665012359619141, -6.987937927246094, -6.498379230499268, -6.563243865966797, -6.091903209686279, -6.045166969299316, -5.5650529861450195, -5.570574760437012, -4.7684431076049805, -4.921703338623047, -4.274085998535156, -4.044978618621826, -3.1006643772125244, -3.8010592460632324, -3.1263949871063232, -2.7995166778564453, -2.530503749847412, -3.15323805809021, -1.3409498929977417, -1.1652913093566895, -1.6048091650009155, -0.9102442264556885, -0.9473286867141724, -0.5617870688438416, -0.29889899492263794, -0.08256953954696655, -0.18380719423294067, 0.22314316034317017, 0.21298378705978394, 0.29039865732192993, 0.6234356760978699, 0.06630502641201019, 2.0253589153289795, 1.4669642448425293, 1.2570090293884277, 1.0689425468444824, 0.04293319955468178, 0.718000054359436, 1.3780107498168945, 1.2266497611999512, 1.4833500385284424, 1.4592280387878418, 1.1894181966781616, 1.90570867061615, 1.686041235923767, 1.4454677104949951, 1.5622378587722778, 0.9300052523612976, 1.114795446395874, 1.202040672302246, 1.1797223091125488, 0.0003599928168114275, 1.6123281717300415, 1.6890015602111816, 0.6518454551696777, 1.8597804307937622, 1.2872331142425537, 1.547697901725769, 1.1062222719192505, 1.2194690704345703, 1.211477518081665, 0.6412123441696167, 1.2668867111206055, 0.8842024803161621, 1.0286225080490112, 1.4688711166381836, 3.1939778327941895, 1.6179492473602295, 1.2670888900756836, 2.7019410133361816, 2.667236804962158, 1.9223583936691284, 0.0, 0.0, 0.0], [-6.79053258895874, 0.0, 0.0, -7.015683650970459, -6.917229652404785, -6.42636775970459, -6.836511135101318, -5.217781066894531, -3.0272257328033447, -5.964130401611328, -4.749344348907471, -5.181572437286377, -5.382842540740967, -4.20737361907959, -4.01439094543457, -5.42811918258667, -3.385676860809326, -2.6763055324554443, -2.653984546661377, -2.2239878177642822, -1.6408519744873047, -0.7057482600212097, -1.6500921249389648, -1.403957486152649, -0.9862605333328247, -0.21547700464725494, -0.7640852928161621, 0.14265044033527374, -0.20818586647510529, -0.26775094866752625, 0.6310719847679138, -0.019029511138796806, 0.5585872530937195, 0.8828089237213135, 0.8287748694419861, 0.898261308670044, 0.7349111437797546, 0.9430188536643982, 1.09739351272583, 2.0685629844665527, 1.5512596368789673, 1.1182823181152344, 1.9610235691070557, 1.2804118394851685, 0.9487610459327698, 1.245624303817749, 0.7306373119354248, 1.4684650897979736, 1.3915438652038574, 1.8076547384262085, 1.1521379947662354, 1.5347017049789429, 1.1498167514801025, 1.901558518409729, 0.6937477588653564, 1.967213749885559, 1.1804684400558472, 2.939002752304077, 1.2412095069885254, 1.300874948501587, 1.2294492721557617, 1.1505995988845825, 0.5682317614555359, 1.1905654668807983, 0.7843565940856934, 1.5557934045791626, 0.9431383013725281, 1.4989991188049316, 0.8033414483070374, 1.263925313949585, 1.1606080532073975, 1.8575648069381714, 2.012277126312256, 1.9544187784194946, 2.2012178897857666, 1.8395302295684814, 0.0, 0.0, -6.79053258895874, -0.0, -0.0, -7.015683650970459, -6.917229652404785, -6.42636775970459, -6.836511135101318, -5.217781066894531, -3.0272257328033447, -5.964130401611328, -4.749344348907471, -5.181572437286377, -5.382842540740967, -4.20737361907959, -4.01439094543457, -5.42811918258667, -3.385676860809326, -2.6763055324554443, -2.653984546661377, -2.2239878177642822, -1.6408519744873047, -0.7057482600212097, -1.6500921249389648, -1.403957486152649, -0.9862605333328247, -0.21547700464725494, -0.7640852928161621, 0.14265044033527374, -0.20818586647510529, -0.26775094866752625, 0.6310719847679138, -0.019029511138796806, 0.5585872530937195, 0.8828089237213135, 0.8287748694419861, 0.898261308670044, 0.7349111437797546, 0.9430188536643982, 1.09739351272583, 2.0685629844665527, 1.5512596368789673, 1.1182823181152344, 1.9610235691070557, 1.2804118394851685, 0.9487610459327698, 1.245624303817749, 0.7306373119354248, 1.4684650897979736, 1.3915438652038574, 1.8076547384262085, 1.1521379947662354, 1.5347017049789429, 1.1498167514801025, 1.901558518409729, 0.6937477588653564, 1.967213749885559, 1.1804684400558472, 2.939002752304077, 1.2412095069885254, 1.300874948501587, 1.2294492721557617, 1.1505995988845825, 0.5682317614555359, 1.1905654668807983, 0.7843565940856934, 1.5557934045791626, 0.9431383013725281, 1.4989991188049316, 0.8033414483070374, 1.263925313949585, 1.1606080532073975, 1.8575648069381714, 2.012277126312256, 1.9544187784194946, 2.2012178897857666, 1.8395302295684814, 0.0, 0.0], [0.0, 0.0, -7.8611226081848145, -8.212221145629883, -7.517705917358398, -6.694338321685791, -6.618788242340088, -6.908671855926514, -6.202049255371094, -5.869625568389893, -4.970299243927002, -5.692484378814697, -4.791619777679443, -3.626652479171753, -3.6298375129699707, -4.2775421142578125, -2.77184796333313, -4.154990196228027, -2.9232382774353027, -2.6816775798797607, -2.3244307041168213, -2.6550796031951904, -1.8119564056396484, -1.2642250061035156, -1.2449724674224854, -0.678961992263794, -0.7332900762557983, -0.24433544278144836, -0.5370383262634277, 0.20684300363063812, -0.37908679246902466, 0.16596995294094086, 0.09518462419509888, 0.38095417618751526, -0.05804499238729477, 0.053764279931783676, 0.8924387097358704, 0.24632160365581512, 0.8532680869102478, 0.8909456133842468, 0.7571079134941101, 1.115859031677246, 0.4877709746360779, 0.7524283528327942, 1.7178559303283691, 1.382396936416626, 1.0753200054168701, 0.6263856887817383, 0.8142241835594177, 1.0971629619598389, 1.2774780988693237, 1.3986605405807495, 1.452529788017273, 1.115413784980774, 1.459327220916748, 2.5077128410339355, 1.7694947719573975, 1.0340954065322876, 0.9865062832832336, 1.3751227855682373, 0.8500516414642334, 1.1613869667053223, 1.7069998979568481, 1.2298216819763184, 1.3093559741973877, 1.415684700012207, 1.3117331266403198, 1.9679242372512817, 0.47426068782806396, 1.8947926759719849, 1.4281030893325806, 1.8904789686203003, 2.4226813316345215, 2.179849624633789, 2.8127849102020264, 1.951318383216858, 0.0, 0.0, -0.0, -0.0, -7.8611226081848145, -8.212221145629883, -7.517705917358398, -6.694338321685791, -6.618788242340088, -6.908671855926514, -6.202049255371094, -5.869625568389893, -4.970299243927002, -5.692484378814697, -4.791619777679443, -3.626652479171753, -3.6298375129699707, -4.2775421142578125, -2.77184796333313, -4.154990196228027, -2.9232382774353027, -2.6816775798797607, -2.3244307041168213, -2.6550796031951904, -1.8119564056396484, -1.2642250061035156, -1.2449724674224854, -0.678961992263794, -0.7332900762557983, -0.24433544278144836, -0.5370383262634277, 0.20684300363063812, -0.37908679246902466, 0.16596995294094086, 0.09518462419509888, 0.38095417618751526, -0.05804499238729477, 0.053764279931783676, 0.8924387097358704, 0.24632160365581512, 0.8532680869102478, 0.8909456133842468, 0.7571079134941101, 1.115859031677246, 0.4877709746360779, 0.7524283528327942, 1.7178559303283691, 1.382396936416626, 1.0753200054168701, 0.6263856887817383, 0.8142241835594177, 1.0971629619598389, 1.2774780988693237, 1.3986605405807495, 1.452529788017273, 1.115413784980774, 1.459327220916748, 2.5077128410339355, 1.7694947719573975, 1.0340954065322876, 0.9865062832832336, 1.3751227855682373, 0.8500516414642334, 1.1613869667053223, 1.7069998979568481, 1.2298216819763184, 1.3093559741973877, 1.415684700012207, 1.3117331266403198, 1.9679242372512817, 0.47426068782806396, 1.8947926759719849, 1.4281030893325806, 1.8904789686203003, 2.4226813316345215, 2.179849624633789, 2.8127849102020264, 1.951318383216858, 0.0, 0.0], [0.0, 0.0, -8.273967742919922, -8.470146179199219, -7.966670513153076, -7.15464448928833, -6.943785190582275, -6.498387336730957, -7.792255878448486, -6.257081985473633, -6.712823390960693, -3.9846460819244385, -4.686771869659424, -4.787647247314453, -4.221040725708008, -4.062499523162842, -4.55010986328125, -3.453148603439331, -3.1494059562683105, -3.208054780960083, -1.8903056383132935, -2.0430989265441895, 1.0557276010513306, -1.0871676206588745, -1.2541747093200684, -0.7876536846160889, -0.31412196159362793, -1.3967087268829346, -0.1952020525932312, 0.14325952529907227, -0.06063878908753395, 0.04335703328251839, 0.45715805888175964, -0.17457208037376404, 0.829099714756012, 1.0213825702667236, 0.972651481628418, 0.8734302520751953, -0.48065173625946045, 0.8249726295471191, 1.4685473442077637, 1.4344677925109863, 1.776097059249878, 1.0627743005752563, 1.1845687627792358, 1.0092442035675049, 1.6986618041992188, 1.32637619972229, 1.6752071380615234, 1.1748768091201782, 1.326415777206421, 1.1737680435180664, 2.381071090698242, 1.3717178106307983, 2.20536732673645, 1.8911126852035522, 1.1321042776107788, 0.8070318698883057, 0.37841519713401794, 1.0677913427352905, 0.5711976289749146, 1.7571053504943848, 1.3006157875061035, 0.6649380326271057, 1.324405312538147, 0.9562707543373108, 1.0938667058944702, 1.9065691232681274, 1.118687391281128, 1.0727511644363403, 1.400589942932129, 1.6613043546676636, 1.8424822092056274, 2.7337489128112793, 1.9404304027557373, 1.4303971529006958, 0.0, 0.0, -0.0, -0.0, -8.273967742919922, -8.470146179199219, -7.966670513153076, -7.15464448928833, -6.943785190582275, -6.498387336730957, -7.792255878448486, -6.257081985473633, -6.712823390960693, -3.9846460819244385, -4.686771869659424, -4.787647247314453, -4.221040725708008, -4.062499523162842, -4.55010986328125, -3.453148603439331, -3.1494059562683105, -3.208054780960083, -1.8903056383132935, -2.0430989265441895, 1.0557276010513306, -1.0871676206588745, -1.2541747093200684, -0.7876536846160889, -0.31412196159362793, -1.3967087268829346, -0.1952020525932312, 0.14325952529907227, -0.06063878908753395, 0.04335703328251839, 0.45715805888175964, -0.17457208037376404, 0.829099714756012, 1.0213825702667236, 0.972651481628418, 0.8734302520751953, -0.48065173625946045, 0.8249726295471191, 1.4685473442077637, 1.4344677925109863, 1.776097059249878, 1.0627743005752563, 1.1845687627792358, 1.0092442035675049, 1.6986618041992188, 1.32637619972229, 1.6752071380615234, 1.1748768091201782, 1.326415777206421, 1.1737680435180664, 2.381071090698242, 1.3717178106307983, 2.20536732673645, 1.8911126852035522, 1.1321042776107788, 0.8070318698883057, 0.37841519713401794, 1.0677913427352905, 0.5711976289749146, 1.7571053504943848, 1.3006157875061035, 0.6649380326271057, 1.324405312538147, 0.9562707543373108, 1.0938667058944702, 1.9065691232681274, 1.118687391281128, 1.0727511644363403, 1.400589942932129, 1.6613043546676636, 1.8424822092056274, 2.7337489128112793, 1.9404304027557373, 1.4303971529006958, 0.0, 0.0], [0.0, 0.0, -8.641990661621094, -8.720212936401367, -8.073323249816895, -7.769037246704102, -7.213685512542725, -6.917686939239502, -7.0756754875183105, -6.144968509674072, -6.115751266479492, -5.318332195281982, -4.225937366485596, -4.363914489746094, -5.313101768493652, -3.785400629043579, -3.6874210834503174, -3.2478349208831787, -2.3889875411987305, -3.7344515323638916, -2.3420565128326416, -1.5808324813842773, -1.1023939847946167, -0.6313320994377136, -0.8790175914764404, -1.4156341552734375, -1.0205711126327515, -1.3510770797729492, -1.1917104721069336, -0.6046311855316162, -0.0547485277056694, -0.3803860545158386, -0.7697306871414185, -0.06632353365421295, 0.478916198015213, 0.03167211264371872, 0.45772838592529297, 0.6003615856170654, 0.5276852250099182, 0.9745269417762756, 1.144560694694519, 1.4064204692840576, 1.001965045928955, 1.1382273435592651, 1.3150614500045776, 1.1027076244354248, 1.0160136222839355, 1.1292107105255127, 1.4768867492675781, 0.9445596933364868, 2.021378993988037, 1.0860704183578491, 0.20279942452907562, 1.0508418083190918, 1.4033749103546143, 0.3950043022632599, 1.1907539367675781, 0.6146487593650818, 1.0172661542892456, 2.071748733520508, 1.2174022197723389, 1.190967082977295, 0.75621098279953, 1.7233284711837769, 0.72312331199646, 0.5157055258750916, 0.5279167890548706, 0.6773365139961243, 0.3427201509475708, 0.9583969116210938, 1.4973981380462646, 2.0103349685668945, 1.223872184753418, 1.6972264051437378, 1.6194044351577759, 0.5741674900054932, 0.0, 0.0, -0.0, -0.0, -8.641990661621094, -8.720212936401367, -8.073323249816895, -7.769037246704102, -7.213685512542725, -6.917686939239502, -7.0756754875183105, -6.144968509674072, -6.115751266479492, -5.318332195281982, -4.225937366485596, -4.363914489746094, -5.313101768493652, -3.785400629043579, -3.6874210834503174, -3.2478349208831787, -2.3889875411987305, -3.7344515323638916, -2.3420565128326416, -1.5808324813842773, -1.1023939847946167, -0.6313320994377136, -0.8790175914764404, -1.4156341552734375, -1.0205711126327515, -1.3510770797729492, -1.1917104721069336, -0.6046311855316162, -0.0547485277056694, -0.3803860545158386, -0.7697306871414185, -0.06632353365421295, 0.478916198015213, 0.03167211264371872, 0.45772838592529297, 0.6003615856170654, 0.5276852250099182, 0.9745269417762756, 1.144560694694519, 1.4064204692840576, 1.001965045928955, 1.1382273435592651, 1.3150614500045776, 1.1027076244354248, 1.0160136222839355, 1.1292107105255127, 1.4768867492675781, 0.9445596933364868, 2.021378993988037, 1.0860704183578491, 0.20279942452907562, 1.0508418083190918, 1.4033749103546143, 0.3950043022632599, 1.1907539367675781, 0.6146487593650818, 1.0172661542892456, 2.071748733520508, 1.2174022197723389, 1.190967082977295, 0.75621098279953, 1.7233284711837769, 0.72312331199646, 0.5157055258750916, 0.5279167890548706, 0.6773365139961243, 0.3427201509475708, 0.9583969116210938, 1.4973981380462646, 2.0103349685668945, 1.223872184753418, 1.6972264051437378, 1.6194044351577759, 0.5741674900054932, 0.0, 0.0], [0.0, 0.0, -8.802974700927734, -8.323148727416992, -7.8365020751953125, -7.5905256271362305, -6.801219463348389, -7.694171905517578, -6.872624397277832, -6.93057918548584, -5.39113187789917, -5.554734230041504, -5.867660045623779, -4.83213472366333, -5.225581645965576, -4.346023082733154, -3.6228301525115967, -3.585653305053711, -3.4117844104766846, -3.243619918823242, -1.8003123998641968, -2.8193652629852295, -1.2451374530792236, -0.7680692076683044, -1.462576985359192, -1.2115519046783447, -1.1106650829315186, -0.7816779017448425, -1.2695105075836182, -0.3108890950679779, -0.16106683015823364, -0.8058167695999146, -0.07252661138772964, 0.17790663242340088, 0.41599175333976746, 0.6683642268180847, 0.8909536004066467, 0.6276943683624268, 0.8477959632873535, 0.5323619842529297, 1.2283824682235718, 0.6860840320587158, 1.0630402565002441, 1.2528231143951416, 1.3960446119308472, 1.000568151473999, 0.6421935558319092, 0.9254410862922668, 0.3048463463783264, 0.6398894786834717, 2.037644386291504, 0.1342948079109192, 1.5107775926589966, 1.5629135370254517, 1.144066572189331, 1.2900664806365967, -0.25982338190078735, 0.15769271552562714, 0.5117627382278442, 0.8035519123077393, 1.5958014726638794, 1.0033739805221558, 0.9727794528007507, 0.5037713050842285, 0.5193241238594055, 1.1734451055526733, 0.32921186089515686, 0.2849158048629761, 0.7597290277481079, 1.2098736763000488, 0.6204338073730469, 1.0507311820983887, 1.918664813041687, 1.3648873567581177, 0.7578930258750916, 2.0334067344665527, 0.0, 0.0, -0.0, -0.0, -8.802974700927734, -8.323148727416992, -7.8365020751953125, -7.5905256271362305, -6.801219463348389, -7.694171905517578, -6.872624397277832, -6.93057918548584, -5.39113187789917, -5.554734230041504, -5.867660045623779, -4.83213472366333, -5.225581645965576, -4.346023082733154, -3.6228301525115967, -3.585653305053711, -3.4117844104766846, -3.243619918823242, -1.8003123998641968, -2.8193652629852295, -1.2451374530792236, -0.7680692076683044, -1.462576985359192, -1.2115519046783447, -1.1106650829315186, -0.7816779017448425, -1.2695105075836182, -0.3108890950679779, -0.16106683015823364, -0.8058167695999146, -0.07252661138772964, 0.17790663242340088, 0.41599175333976746, 0.6683642268180847, 0.8909536004066467, 0.6276943683624268, 0.8477959632873535, 0.5323619842529297, 1.2283824682235718, 0.6860840320587158, 1.0630402565002441, 1.2528231143951416, 1.3960446119308472, 1.000568151473999, 0.6421935558319092, 0.9254410862922668, 0.3048463463783264, 0.6398894786834717, 2.037644386291504, 0.1342948079109192, 1.5107775926589966, 1.5629135370254517, 1.144066572189331, 1.2900664806365967, -0.25982338190078735, 0.15769271552562714, 0.5117627382278442, 0.8035519123077393, 1.5958014726638794, 1.0033739805221558, 0.9727794528007507, 0.5037713050842285, 0.5193241238594055, 1.1734451055526733, 0.32921186089515686, 0.2849158048629761, 0.7597290277481079, 1.2098736763000488, 0.6204338073730469, 1.0507311820983887, 1.918664813041687, 1.3648873567581177, 0.7578930258750916, 2.0334067344665527, 0.0, 0.0], [0.0, 0.0, -9.369927406311035, -8.565364837646484, -8.21967601776123, -7.867001056671143, -6.99569034576416, -7.286456108093262, -6.400213241577148, -6.407867431640625, -6.253462791442871, -5.766151428222656, -5.544313907623291, -5.013139724731445, -4.865030765533447, -4.097561836242676, -3.8900604248046875, -3.2737693786621094, -3.7180850505828857, -2.8277904987335205, -4.074548721313477, -1.8696831464767456, -2.4529991149902344, -1.1327629089355469, -0.9447510838508606, -0.4794407784938812, -1.2361063957214355, -1.1690951585769653, -0.16030222177505493, -0.10321825742721558, -1.0415774583816528, -0.405245304107666, -0.7867223024368286, -0.003698314307257533, 0.5858263373374939, 0.07061260938644409, -0.275616854429245, -0.24262231588363647, 0.5197644829750061, 0.7957248687744141, 0.9834986925125122, 0.8436938524246216, 0.6472400426864624, 1.3563975095748901, 0.8914194703102112, 0.8296418786048889, 1.1357786655426025, 0.6656047105789185, -1.9448972940444946, 1.1572980880737305, 0.7200198769569397, 0.20444701611995697, 0.7015453577041626, 1.2616649866104126, 0.8484509587287903, 0.8830682635307312, 1.3619441986083984, 1.4581760168075562, 1.3115167617797852, 0.2716953456401825, 1.305747389793396, 0.7013995051383972, 1.1729577779769897, 1.2123762369155884, 0.9945058226585388, 0.5640907883644104, 0.72765052318573, 0.149408221244812, 0.6212209463119507, 0.7337461709976196, 0.8340328931808472, 1.219818115234375, 1.1938834190368652, 1.321704626083374, 1.3557438850402832, 1.5773775577545166, 0.0, 0.0, -0.0, -0.0, -9.369927406311035, -8.565364837646484, -8.21967601776123, -7.867001056671143, -6.99569034576416, -7.286456108093262, -6.400213241577148, -6.407867431640625, -6.253462791442871, -5.766151428222656, -5.544313907623291, -5.013139724731445, -4.865030765533447, -4.097561836242676, -3.8900604248046875, -3.2737693786621094, -3.7180850505828857, -2.8277904987335205, -4.074548721313477, -1.8696831464767456, -2.4529991149902344, -1.1327629089355469, -0.9447510838508606, -0.4794407784938812, -1.2361063957214355, -1.1690951585769653, -0.16030222177505493, -0.10321825742721558, -1.0415774583816528, -0.405245304107666, -0.7867223024368286, -0.003698314307257533, 0.5858263373374939, 0.07061260938644409, -0.275616854429245, -0.24262231588363647, 0.5197644829750061, 0.7957248687744141, 0.9834986925125122, 0.8436938524246216, 0.6472400426864624, 1.3563975095748901, 0.8914194703102112, 0.8296418786048889, 1.1357786655426025, 0.6656047105789185, -1.9448972940444946, 1.1572980880737305, 0.7200198769569397, 0.20444701611995697, 0.7015453577041626, 1.2616649866104126, 0.8484509587287903, 0.8830682635307312, 1.3619441986083984, 1.4581760168075562, 1.3115167617797852, 0.2716953456401825, 1.305747389793396, 0.7013995051383972, 1.1729577779769897, 1.2123762369155884, 0.9945058226585388, 0.5640907883644104, 0.72765052318573, 0.149408221244812, 0.6212209463119507, 0.7337461709976196, 0.8340328931808472, 1.219818115234375, 1.1938834190368652, 1.321704626083374, 1.3557438850402832, 1.5773775577545166, 0.0, 0.0], [0.0, -7.778353691101074, -9.52311897277832, -9.364595413208008, -8.12236499786377, -8.088497161865234, -7.820099830627441, -6.894088268280029, -7.688715934753418, -6.5372819900512695, -6.425333023071289, -6.219767093658447, -5.415050506591797, -5.760499477386475, -4.729930877685547, -4.9443159103393555, -4.341367244720459, -3.505748987197876, -3.0990636348724365, -3.500516653060913, -3.0440433025360107, -2.6832473278045654, -1.7998605966567993, -1.5256881713867188, -0.40144258737564087, -2.131316661834717, -2.0169153213500977, -1.775339126586914, -1.053366780281067, -1.8839606046676636, 0.535524845123291, -0.31965094804763794, -0.20180192589759827, -0.10322600603103638, 0.04204355552792549, 0.3526068925857544, -0.12775462865829468, -0.14706186950206757, -0.34247276186943054, 0.5361882448196411, 0.6368151903152466, 2.1301443576812744, 0.5079302787780762, 1.362185001373291, 1.132763147354126, 1.5288413763046265, 0.7888821363449097, 1.002730131149292, 0.15656276047229767, -0.27402469515800476, 0.03882179781794548, 0.97874516248703, 0.5548074245452881, 1.1621791124343872, 0.8016829490661621, 1.0129756927490234, 1.4075744152069092, 1.4306515455245972, 0.5131949782371521, 0.880542516708374, 0.9457567930221558, 0.013916238211095333, 1.2509348392486572, 0.38531628251075745, 0.5433719158172607, 0.4665548503398895, 1.215665340423584, 0.4746968746185303, 1.3360673189163208, 0.986398458480835, 1.407549262046814, 1.0275908708572388, 0.5521337389945984, 0.8806195855140686, 0.9486071467399597, 1.7091461420059204, 0.0, 0.0, -0.0, -7.778353691101074, -9.52311897277832, -9.364595413208008, -8.12236499786377, -8.088497161865234, -7.820099830627441, -6.894088268280029, -7.688715934753418, -6.5372819900512695, -6.425333023071289, -6.219767093658447, -5.415050506591797, -5.760499477386475, -4.729930877685547, -4.9443159103393555, -4.341367244720459, -3.505748987197876, -3.0990636348724365, -3.500516653060913, -3.0440433025360107, -2.6832473278045654, -1.7998605966567993, -1.5256881713867188, -0.40144258737564087, -2.131316661834717, -2.0169153213500977, -1.775339126586914, -1.053366780281067, -1.8839606046676636, 0.535524845123291, -0.31965094804763794, -0.20180192589759827, -0.10322600603103638, 0.04204355552792549, 0.3526068925857544, -0.12775462865829468, -0.14706186950206757, -0.34247276186943054, 0.5361882448196411, 0.6368151903152466, 2.1301443576812744, 0.5079302787780762, 1.362185001373291, 1.132763147354126, 1.5288413763046265, 0.7888821363449097, 1.002730131149292, 0.15656276047229767, -0.27402469515800476, 0.03882179781794548, 0.97874516248703, 0.5548074245452881, 1.1621791124343872, 0.8016829490661621, 1.0129756927490234, 1.4075744152069092, 1.4306515455245972, 0.5131949782371521, 0.880542516708374, 0.9457567930221558, 0.013916238211095333, 1.2509348392486572, 0.38531628251075745, 0.5433719158172607, 0.4665548503398895, 1.215665340423584, 0.4746968746185303, 1.3360673189163208, 0.986398458480835, 1.407549262046814, 1.0275908708572388, 0.5521337389945984, 0.8806195855140686, 0.9486071467399597, 1.7091461420059204, 0.0, 0.0], [0.0, 0.0, -9.170738220214844, -9.131446838378906, -8.941454887390137, -8.074084281921387, -6.631767272949219, -7.682749271392822, -7.471770763397217, -6.827678680419922, -6.405357837677002, -5.785335063934326, -5.528541564941406, -5.315946102142334, -4.996557712554932, -5.050358295440674, -4.87036657333374, -4.1195220947265625, -2.9095799922943115, -2.8397016525268555, -2.523231029510498, -2.1117146015167236, -2.3574953079223633, -2.7738122940063477, -1.5083783864974976, -1.5029891729354858, -1.4734314680099487, -1.2742688655853271, -1.1211414337158203, -0.9207549691200256, -1.917884349822998, -0.48528537154197693, -0.7586644291877747, 0.020211506634950638, -0.49870526790618896, 0.3309434652328491, -0.15879344940185547, -0.22544199228286743, 0.18682639300823212, 0.14743724465370178, 0.9226534962654114, 1.143389105796814, 0.268702894449234, 0.24885407090187073, 1.0433801412582397, -0.11225246638059616, 0.9846839904785156, 0.855866551399231, -0.07105744630098343, 0.7386919260025024, 1.1977589130401611, 0.6178994178771973, 0.384896457195282, 0.556379497051239, 0.24910371005535126, 1.1622308492660522, 2.067725658416748, -0.3183349370956421, 1.7893348932266235, 0.4300924241542816, 0.31346696615219116, 0.7053430080413818, 1.206037998199463, 0.9234755635261536, 0.4871564507484436, 1.2169709205627441, 1.0335112810134888, -0.2725219130516052, 1.109535574913025, 0.45217975974082947, 1.1129688024520874, 1.0774524211883545, 0.4405572712421417, 0.29171472787857056, 0.6072311401367188, 0.6712651252746582, 0.0, 0.0, -0.0, -0.0, -9.170738220214844, -9.131446838378906, -8.941454887390137, -8.074084281921387, -6.631767272949219, -7.682749271392822, -7.471770763397217, -6.827678680419922, -6.405357837677002, -5.785335063934326, -5.528541564941406, -5.315946102142334, -4.996557712554932, -5.050358295440674, -4.87036657333374, -4.1195220947265625, -2.9095799922943115, -2.8397016525268555, -2.523231029510498, -2.1117146015167236, -2.3574953079223633, -2.7738122940063477, -1.5083783864974976, -1.5029891729354858, -1.4734314680099487, -1.2742688655853271, -1.1211414337158203, -0.9207549691200256, -1.917884349822998, -0.48528537154197693, -0.7586644291877747, 0.020211506634950638, -0.49870526790618896, 0.3309434652328491, -0.15879344940185547, -0.22544199228286743, 0.18682639300823212, 0.14743724465370178, 0.9226534962654114, 1.143389105796814, 0.268702894449234, 0.24885407090187073, 1.0433801412582397, -0.11225246638059616, 0.9846839904785156, 0.855866551399231, -0.07105744630098343, 0.7386919260025024, 1.1977589130401611, 0.6178994178771973, 0.384896457195282, 0.556379497051239, 0.24910371005535126, 1.1622308492660522, 2.067725658416748, -0.3183349370956421, 1.7893348932266235, 0.4300924241542816, 0.31346696615219116, 0.7053430080413818, 1.206037998199463, 0.9234755635261536, 0.4871564507484436, 1.2169709205627441, 1.0335112810134888, -0.2725219130516052, 1.109535574913025, 0.45217975974082947, 1.1129688024520874, 1.0774524211883545, 0.4405572712421417, 0.29171472787857056, 0.6072311401367188, 0.6712651252746582, 0.0, 0.0], [0.0, -8.754754066467285, -9.230622291564941, -8.736506462097168, -8.45197868347168, -7.466645240783691, -7.663841724395752, -7.286459445953369, -7.039610385894775, -6.7009992599487305, -6.429357051849365, -5.536426067352295, -6.246118545532227, -4.991693496704102, -6.70305871963501, -5.178481578826904, -4.453022480010986, -3.381072759628296, -3.487152576446533, -0.6888611316680908, -4.070808410644531, -3.352945566177368, -2.214414358139038, -2.4768128395080566, -0.8863509893417358, -1.9865702390670776, -1.7021127939224243, -1.7121020555496216, -2.4815452098846436, -1.8606235980987549, -0.8528889417648315, -1.0722675323486328, -0.9365887641906738, -0.26421305537223816, 0.41643378138542175, -0.1473378986120224, 0.6053079962730408, 0.12117662280797958, 0.3410978615283966, 0.6164975166320801, 0.3659893274307251, 0.6033620834350586, 0.5712116360664368, 1.5165045261383057, -0.06838001310825348, 1.2497156858444214, 0.45129284262657166, 0.4710506200790405, -0.07970386743545532, 0.7412774562835693, 1.2448786497116089, 1.0647658109664917, 0.6674934029579163, 0.7202066779136658, 1.1735361814498901, 0.25561094284057617, 0.04481128603219986, -0.07170942425727844, 1.3424162864685059, 0.9373569488525391, 0.8926136493682861, 1.895825982093811, 0.11628805845975876, 0.810979425907135, 1.4715616703033447, 1.2002171277999878, 0.6797439455986023, 0.3869337737560272, -0.35426944494247437, 0.31839945912361145, 0.6585379242897034, 0.05237618833780289, 0.7631012201309204, 0.5711271166801453, 0.9048841595649719, 0.5222938060760498, 0.0, 0.0, -0.0, -8.754754066467285, -9.230622291564941, -8.736506462097168, -8.45197868347168, -7.466645240783691, -7.663841724395752, -7.286459445953369, -7.039610385894775, -6.7009992599487305, -6.429357051849365, -5.536426067352295, -6.246118545532227, -4.991693496704102, -6.70305871963501, -5.178481578826904, -4.453022480010986, -3.381072759628296, -3.487152576446533, -0.6888611316680908, -4.070808410644531, -3.352945566177368, -2.214414358139038, -2.4768128395080566, -0.8863509893417358, -1.9865702390670776, -1.7021127939224243, -1.7121020555496216, -2.4815452098846436, -1.8606235980987549, -0.8528889417648315, -1.0722675323486328, -0.9365887641906738, -0.26421305537223816, 0.41643378138542175, -0.1473378986120224, 0.6053079962730408, 0.12117662280797958, 0.3410978615283966, 0.6164975166320801, 0.3659893274307251, 0.6033620834350586, 0.5712116360664368, 1.5165045261383057, -0.06838001310825348, 1.2497156858444214, 0.45129284262657166, 0.4710506200790405, -0.07970386743545532, 0.7412774562835693, 1.2448786497116089, 1.0647658109664917, 0.6674934029579163, 0.7202066779136658, 1.1735361814498901, 0.25561094284057617, 0.04481128603219986, -0.07170942425727844, 1.3424162864685059, 0.9373569488525391, 0.8926136493682861, 1.895825982093811, 0.11628805845975876, 0.810979425907135, 1.4715616703033447, 1.2002171277999878, 0.6797439455986023, 0.3869337737560272, -0.35426944494247437, 0.31839945912361145, 0.6585379242897034, 0.05237618833780289, 0.7631012201309204, 0.5711271166801453, 0.9048841595649719, 0.5222938060760498, 0.0, 0.0], [0.0, -9.598135948181152, -8.893555641174316, -9.638985633850098, -8.971263885498047, -8.137981414794922, -7.7642927169799805, -7.6630425453186035, -7.589567184448242, -6.466950416564941, -6.740289688110352, -6.507189750671387, -6.24446964263916, -5.461273670196533, -4.9483160972595215, -5.700745582580566, -4.471099853515625, -3.974224805831909, -4.2500834465026855, -3.392136573791504, -3.050147294998169, -3.687530279159546, -2.464508056640625, -2.650419235229492, -2.681023120880127, -2.004796028137207, -1.5591684579849243, -1.7089452743530273, -1.2746871709823608, -3.4297537803649902, -1.5968462228775024, -1.4642413854599, -1.0308563709259033, -0.1916743665933609, -0.6060518622398376, 0.16110175848007202, 1.0811723470687866, -1.3379783630371094, 1.0062512159347534, -1.7698694467544556, 1.0048227310180664, 0.34410977363586426, 0.25057947635650635, 0.971065878868103, 0.14346307516098022, 0.17100182175636292, -0.09383375942707062, 0.407654732465744, 0.5319924354553223, 0.8537209630012512, -0.13769859075546265, 0.870762050151825, 0.7777151465415955, 0.6841826438903809, 0.026030980050563812, 0.048228733241558075, 0.7656518816947937, -0.10949522256851196, 0.044696856290102005, 1.454529047012329, -0.30749931931495667, 0.8850370645523071, 0.3034861981868744, -0.9626407027244568, 0.047876205295324326, -0.4413696825504303, -0.3932250440120697, 1.1795434951782227, 1.0792236328125, 0.06872664391994476, 0.716187596321106, 0.45938366651535034, 0.20287853479385376, -0.18235546350479126, -1.3087776899337769, -0.1038150042295456, 0.0, 0.0, -0.0, -9.598135948181152, -8.893555641174316, -9.638985633850098, -8.971263885498047, -8.137981414794922, -7.7642927169799805, -7.6630425453186035, -7.589567184448242, -6.466950416564941, -6.740289688110352, -6.507189750671387, -6.24446964263916, -5.461273670196533, -4.9483160972595215, -5.700745582580566, -4.471099853515625, -3.974224805831909, -4.2500834465026855, -3.392136573791504, -3.050147294998169, -3.687530279159546, -2.464508056640625, -2.650419235229492, -2.681023120880127, -2.004796028137207, -1.5591684579849243, -1.7089452743530273, -1.2746871709823608, -3.4297537803649902, -1.5968462228775024, -1.4642413854599, -1.0308563709259033, -0.1916743665933609, -0.6060518622398376, 0.16110175848007202, 1.0811723470687866, -1.3379783630371094, 1.0062512159347534, -1.7698694467544556, 1.0048227310180664, 0.34410977363586426, 0.25057947635650635, 0.971065878868103, 0.14346307516098022, 0.17100182175636292, -0.09383375942707062, 0.407654732465744, 0.5319924354553223, 0.8537209630012512, -0.13769859075546265, 0.870762050151825, 0.7777151465415955, 0.6841826438903809, 0.026030980050563812, 0.048228733241558075, 0.7656518816947937, -0.10949522256851196, 0.044696856290102005, 1.454529047012329, -0.30749931931495667, 0.8850370645523071, 0.3034861981868744, -0.9626407027244568, 0.047876205295324326, -0.4413696825504303, -0.3932250440120697, 1.1795434951782227, 1.0792236328125, 0.06872664391994476, 0.716187596321106, 0.45938366651535034, 0.20287853479385376, -0.18235546350479126, -1.3087776899337769, -0.1038150042295456, -0.0, -0.0], [0.0, -10.165791511535645, -9.447160720825195, -9.946877479553223, -8.926399230957031, -9.137617111206055, -8.11205768585205, -8.371681213378906, -7.261142730712891, -7.644083023071289, -7.656816005706787, -5.03342342376709, -6.15886116027832, -6.948020935058594, -5.0324225425720215, -5.808988094329834, -3.9036903381347656, -4.765220642089844, -3.4964044094085693, -4.024202346801758, -3.274844169616699, -3.0508484840393066, -1.203426718711853, -1.3011164665222168, -2.3410158157348633, -2.454390525817871, -1.8906149864196777, -3.6541647911071777, -1.1130361557006836, -1.3313597440719604, -1.3878153562545776, -1.0162872076034546, -0.8502256870269775, -0.20375628769397736, -0.7029391527175903, -0.5022838711738586, -0.03417588770389557, 0.7511042356491089, 0.24116194248199463, 1.6233028173446655, 1.0986697673797607, 0.4095021188259125, 0.2709530293941498, -0.8168622255325317, 0.6548671126365662, 0.44959568977355957, 1.839643120765686, 0.9051330089569092, 1.2208079099655151, 0.008805601857602596, -0.7708714008331299, 0.3245128393173218, -0.083436518907547, -0.1836140900850296, -0.30640652775764465, 0.44016510248184204, 0.6950219869613647, 0.22887220978736877, 0.6212378740310669, 0.4076254963874817, -1.5088478326797485, 0.877634584903717, -0.12355704605579376, 0.9627442359924316, 0.366143137216568, 0.5462040901184082, -0.1851838380098343, 0.615113377571106, 0.9917559623718262, 0.8992310762405396, 0.2335171401500702, -0.5605086088180542, -1.1043322086334229, -0.004209269303828478, -0.5526952743530273, -0.17015720903873444, 0.0, 0.0, -0.0, -10.165791511535645, -9.447160720825195, -9.946877479553223, -8.926399230957031, -9.137617111206055, -8.11205768585205, -8.371681213378906, -7.261142730712891, -7.644083023071289, -7.656816005706787, -5.03342342376709, -6.15886116027832, -6.948020935058594, -5.0324225425720215, -5.808988094329834, -3.9036903381347656, -4.765220642089844, -3.4964044094085693, -4.024202346801758, -3.274844169616699, -3.0508484840393066, -1.203426718711853, -1.3011164665222168, -2.3410158157348633, -2.454390525817871, -1.8906149864196777, -3.6541647911071777, -1.1130361557006836, -1.3313597440719604, -1.3878153562545776, -1.0162872076034546, -0.8502256870269775, -0.20375628769397736, -0.7029391527175903, -0.5022838711738586, -0.03417588770389557, 0.7511042356491089, 0.24116194248199463, 1.6233028173446655, 1.0986697673797607, 0.4095021188259125, 0.2709530293941498, -0.8168622255325317, 0.6548671126365662, 0.44959568977355957, 1.839643120765686, 0.9051330089569092, 1.2208079099655151, 0.008805601857602596, -0.7708714008331299, 0.3245128393173218, -0.083436518907547, -0.1836140900850296, -0.30640652775764465, 0.44016510248184204, 0.6950219869613647, 0.22887220978736877, 0.6212378740310669, 0.4076254963874817, -1.5088478326797485, 0.877634584903717, -0.12355704605579376, 0.9627442359924316, 0.366143137216568, 0.5462040901184082, -0.1851838380098343, 0.615113377571106, 0.9917559623718262, 0.8992310762405396, 0.2335171401500702, -0.5605086088180542, -1.1043322086334229, -0.004209269303828478, -0.5526952743530273, -0.17015720903873444, -0.0, -0.0], [0.0, -13.33687686920166, -11.092744827270508, -10.49930191040039, -10.556166648864746, -9.718091011047363, -9.206709861755371, -8.424763679504395, -8.15654182434082, -7.409705638885498, -7.044726848602295, -6.76424503326416, -6.407004356384277, -5.380265712738037, -5.483306407928467, -4.858963966369629, -4.406960487365723, -3.526745319366455, -3.972365617752075, -4.460107326507568, -3.1376562118530273, -3.5287363529205322, -2.1267547607421875, -1.8341909646987915, -3.0268540382385254, -0.7755314707756042, -1.7838120460510254, -1.8901351690292358, -1.6247317790985107, 0.17266474664211273, -0.9928098917007446, -0.5393342971801758, -1.3865375518798828, -1.5681804418563843, -0.5995385646820068, -0.7072682976722717, -0.32168081402778625, -0.9854354858398438, -0.9967126846313477, 0.0, 1.7811506986618042, -0.3837696611881256, -0.5075937509536743, 0.11186152696609497, -2.28066086769104, -0.3398154675960541, -0.5918079018592834, 0.7410150170326233, 0.8407673835754395, -0.5772872567176819, 1.762795090675354, -1.8396549224853516, 1.0466526746749878, 0.7028561234474182, 0.49016642570495605, -1.0357122421264648, 0.2761857509613037, 0.08713036775588989, 0.25097209215164185, 0.4619555175304413, 0.1414112150669098, 0.7356497049331665, 0.14792053401470184, 0.8091629147529602, 2.9814038276672363, -0.48800766468048096, 0.08685453236103058, 1.124029278755188, 0.57851642370224, 2.635254383087158, -0.001692150137387216, -0.33929234743118286, -0.5286968350410461, -0.10070018470287323, 0.06878849118947983, -0.8613468408584595, 0.0, 0.0, -0.0, -13.33687686920166, -11.092744827270508, -10.49930191040039, -10.556166648864746, -9.718091011047363, -9.206709861755371, -8.424763679504395, -8.15654182434082, -7.409705638885498, -7.044726848602295, -6.76424503326416, -6.407004356384277, -5.380265712738037, -5.483306407928467, -4.858963966369629, -4.406960487365723, -3.526745319366455, -3.972365617752075, -4.460107326507568, -3.1376562118530273, -3.5287363529205322, -2.1267547607421875, -1.8341909646987915, -3.0268540382385254, -0.7755314707756042, -1.7838120460510254, -1.8901351690292358, -1.6247317790985107, 0.17266474664211273, -0.9928098917007446, -0.5393342971801758, -1.3865375518798828, -1.5681804418563843, -0.5995385646820068, -0.7072682976722717, -0.32168081402778625, -0.9854354858398438, -0.9967126846313477, 0.0, 1.7811506986618042, -0.3837696611881256, -0.5075937509536743, 0.11186152696609497, -2.28066086769104, -0.3398154675960541, -0.5918079018592834, 0.7410150170326233, 0.8407673835754395, -0.5772872567176819, 1.762795090675354, -1.8396549224853516, 1.0466526746749878, 0.7028561234474182, 0.49016642570495605, -1.0357122421264648, 0.2761857509613037, 0.08713036775588989, 0.25097209215164185, 0.4619555175304413, 0.1414112150669098, 0.7356497049331665, 0.14792053401470184, 0.8091629147529602, 2.9814038276672363, -0.48800766468048096, 0.08685453236103058, 1.124029278755188, 0.57851642370224, 2.635254383087158, -0.001692150137387216, -0.33929234743118286, -0.5286968350410461, -0.10070018470287323, 0.06878849118947983, -0.8613468408584595, -0.0, -0.0], [0.0, -10.190899848937988, -10.594175338745117, -10.579687118530273, -8.843899726867676, -9.47130012512207, -9.383440017700195, -8.591851234436035, -7.906827449798584, -8.120339393615723, -8.023213386535645, -7.011340141296387, -6.237733840942383, -6.188204765319824, -4.723757266998291, -5.4076738357543945, -4.8823652267456055, -5.455541610717773, -3.7259726524353027, -4.661717414855957, -3.670142412185669, -3.3479669094085693, -3.2731478214263916, -2.181319236755371, -2.785404920578003, -2.303462505340576, -1.1362658739089966, -1.6828200817108154, 0.051970597356557846, -1.4624277353286743, -1.2560515403747559, -1.991753339767456, -0.2656911015510559, -1.3799073696136475, -2.2747275829315186, -0.7464509010314941, -0.9429735541343689, -1.7585495710372925, -0.9617074728012085, 2.5879108905792236, 1.1204816102981567, 0.052590712904930115, -0.9416942596435547, 2.0039992332458496, 0.1826592981815338, 0.5215266346931458, -0.6021851301193237, 0.9722129106521606, -0.1382422149181366, -0.14584797620773315, -0.4553307592868805, 0.9538346529006958, 1.5103915929794312, 0.9513249397277832, -0.2882188558578491, -0.6188554763793945, -0.0092318095266819, 0.5862610340118408, 0.11111196875572205, 0.13823625445365906, -0.8334304094314575, 0.8532335162162781, 0.6195657849311829, 0.4214865565299988, 0.07811367511749268, -1.0490113496780396, 0.31691208481788635, 0.07401615381240845, 0.8974982500076294, -0.013656772673130035, -0.8036755919456482, 0.24169018864631653, -0.07019191235303879, -0.16549839079380035, -0.552931547164917, -0.11660552769899368, 0.0, 0.0, -0.0, -10.190899848937988, -10.594175338745117, -10.579687118530273, -8.843899726867676, -9.47130012512207, -9.383440017700195, -8.591851234436035, -7.906827449798584, -8.120339393615723, -8.023213386535645, -7.011340141296387, -6.237733840942383, -6.188204765319824, -4.723757266998291, -5.4076738357543945, -4.8823652267456055, -5.455541610717773, -3.7259726524353027, -4.661717414855957, -3.670142412185669, -3.3479669094085693, -3.2731478214263916, -2.181319236755371, -2.785404920578003, -2.303462505340576, -1.1362658739089966, -1.6828200817108154, 0.051970597356557846, -1.4624277353286743, -1.2560515403747559, -1.991753339767456, -0.2656911015510559, -1.3799073696136475, -2.2747275829315186, -0.7464509010314941, -0.9429735541343689, -1.7585495710372925, -0.9617074728012085, 2.5879108905792236, 1.1204816102981567, 0.052590712904930115, -0.9416942596435547, 2.0039992332458496, 0.1826592981815338, 0.5215266346931458, -0.6021851301193237, 0.9722129106521606, -0.1382422149181366, -0.14584797620773315, -0.4553307592868805, 0.9538346529006958, 1.5103915929794312, 0.9513249397277832, -0.2882188558578491, -0.6188554763793945, -0.0092318095266819, 0.5862610340118408, 0.11111196875572205, 0.13823625445365906, -0.8334304094314575, 0.8532335162162781, 0.6195657849311829, 0.4214865565299988, 0.07811367511749268, -1.0490113496780396, 0.31691208481788635, 0.07401615381240845, 0.8974982500076294, -0.013656772673130035, -0.8036755919456482, 0.24169018864631653, -0.07019191235303879, -0.16549839079380035, -0.552931547164917, -0.11660552769899368, -0.0, -0.0], [0.0, -14.130410194396973, -10.449058532714844, -11.11241626739502, -10.269449234008789, -10.118085861206055, -8.809568405151367, -8.61287784576416, -8.601286888122559, -8.036210060119629, -7.502712726593018, -7.599008560180664, -6.236347198486328, -6.209465980529785, -5.942694664001465, -5.752419948577881, -5.063432216644287, -5.302021503448486, -4.3171844482421875, -4.5327253341674805, -4.232933521270752, -4.016234397888184, -2.9790000915527344, -3.6617610454559326, -2.0806374549865723, -3.2746376991271973, -2.692142963409424, -1.2616286277770996, -1.7077072858810425, -2.576144218444824, -2.102027416229248, -1.6138250827789307, -2.3792738914489746, -1.1450512409210205, -0.9324005246162415, -0.38172197341918945, -0.8495330810546875, -1.8066117763519287, 0.002294232603162527, -0.4241078197956085, 1.3404228687286377, -0.48641782999038696, -0.5695984959602356, -0.6515576839447021, -0.720049262046814, -0.8974394202232361, -1.6125571727752686, 0.21468009054660797, 1.485910177230835, -0.5100015997886658, -1.0346730947494507, 0.207571342587471, -0.2740508019924164, 0.25089314579963684, -0.019587812945246696, -0.8406291604042053, 0.6969423890113831, -0.12546253204345703, -0.440634548664093, 0.2581648826599121, 0.03548532351851463, -0.1622588038444519, 0.49830469489097595, -0.9970138072967529, -0.8791642189025879, -0.7135169506072998, -0.5336185693740845, -0.2956470847129822, 0.36981791257858276, -0.1268918663263321, -0.6481653451919556, -0.3351759910583496, -0.389339804649353, -0.566973090171814, -0.39134207367897034, -0.9770292043685913, 0.0, 0.0, -0.0, -14.130410194396973, -10.449058532714844, -11.11241626739502, -10.269449234008789, -10.118085861206055, -8.809568405151367, -8.61287784576416, -8.601286888122559, -8.036210060119629, -7.502712726593018, -7.599008560180664, -6.236347198486328, -6.209465980529785, -5.942694664001465, -5.752419948577881, -5.063432216644287, -5.302021503448486, -4.3171844482421875, -4.5327253341674805, -4.232933521270752, -4.016234397888184, -2.9790000915527344, -3.6617610454559326, -2.0806374549865723, -3.2746376991271973, -2.692142963409424, -1.2616286277770996, -1.7077072858810425, -2.576144218444824, -2.102027416229248, -1.6138250827789307, -2.3792738914489746, -1.1450512409210205, -0.9324005246162415, -0.38172197341918945, -0.8495330810546875, -1.8066117763519287, 0.002294232603162527, -0.4241078197956085, 1.3404228687286377, -0.48641782999038696, -0.5695984959602356, -0.6515576839447021, -0.720049262046814, -0.8974394202232361, -1.6125571727752686, 0.21468009054660797, 1.485910177230835, -0.5100015997886658, -1.0346730947494507, 0.207571342587471, -0.2740508019924164, 0.25089314579963684, -0.019587812945246696, -0.8406291604042053, 0.6969423890113831, -0.12546253204345703, -0.440634548664093, 0.2581648826599121, 0.03548532351851463, -0.1622588038444519, 0.49830469489097595, -0.9970138072967529, -0.8791642189025879, -0.7135169506072998, -0.5336185693740845, -0.2956470847129822, 0.36981791257858276, -0.1268918663263321, -0.6481653451919556, -0.3351759910583496, -0.389339804649353, -0.566973090171814, -0.39134207367897034, -0.9770292043685913, -0.0, -0.0], [0.0, -15.140681266784668, -10.368951797485352, -11.024906158447266, -10.72653579711914, -10.404182434082031, -10.386018753051758, -7.996252059936523, -8.460570335388184, -7.720663070678711, -7.749538898468018, -6.516448020935059, -8.082952499389648, -6.740497589111328, -6.080244064331055, -6.920297145843506, -5.608626842498779, -5.410996913909912, -5.230648994445801, -4.598829746246338, -4.047086715698242, -2.6336569786071777, -3.74647855758667, -3.0528855323791504, -1.9612892866134644, -2.0092806816101074, -1.3251347541809082, -2.5793662071228027, -1.9088693857192993, -0.863513171672821, -1.5196893215179443, -2.329235076904297, -2.3239593505859375, -1.0059075355529785, -1.3814113140106201, -1.0013821125030518, -1.4132074117660522, -1.2719268798828125, -1.627999186515808, -0.06176556646823883, -1.8543285131454468, -0.8295478224754333, -1.3664624691009521, -0.11164695769548416, -0.0021699978969991207, -0.6946841478347778, -0.7596722841262817, 0.3394424617290497, -0.4610790014266968, -0.8858201503753662, 0.21043060719966888, 0.5371168851852417, 0.3312864303588867, 0.6129317283630371, -0.5234916806221008, -0.7576165199279785, -0.8843540549278259, 0.020155420526862144, 0.9305348992347717, 0.4330717921257019, 0.3166113793849945, -0.07164762169122696, 0.579672634601593, -1.3321284055709839, -1.244187355041504, -0.22581489384174347, -1.0290498733520508, -0.3254324197769165, -0.8853212594985962, -1.3999626636505127, -0.04824869707226753, -0.8023917078971863, -0.31676608324050903, -0.37280458211898804, -0.7297875881195068, -0.8681722283363342, 0.0, 0.0, -0.0, -15.140681266784668, -10.368951797485352, -11.024906158447266, -10.72653579711914, -10.404182434082031, -10.386018753051758, -7.996252059936523, -8.460570335388184, -7.720663070678711, -7.749538898468018, -6.516448020935059, -8.082952499389648, -6.740497589111328, -6.080244064331055, -6.920297145843506, -5.608626842498779, -5.410996913909912, -5.230648994445801, -4.598829746246338, -4.047086715698242, -2.6336569786071777, -3.74647855758667, -3.0528855323791504, -1.9612892866134644, -2.0092806816101074, -1.3251347541809082, -2.5793662071228027, -1.9088693857192993, -0.863513171672821, -1.5196893215179443, -2.329235076904297, -2.3239593505859375, -1.0059075355529785, -1.3814113140106201, -1.0013821125030518, -1.4132074117660522, -1.2719268798828125, -1.627999186515808, -0.06176556646823883, -1.8543285131454468, -0.8295478224754333, -1.3664624691009521, -0.11164695769548416, -0.0021699978969991207, -0.6946841478347778, -0.7596722841262817, 0.3394424617290497, -0.4610790014266968, -0.8858201503753662, 0.21043060719966888, 0.5371168851852417, 0.3312864303588867, 0.6129317283630371, -0.5234916806221008, -0.7576165199279785, -0.8843540549278259, 0.020155420526862144, 0.9305348992347717, 0.4330717921257019, 0.3166113793849945, -0.07164762169122696, 0.579672634601593, -1.3321284055709839, -1.244187355041504, -0.22581489384174347, -1.0290498733520508, -0.3254324197769165, -0.8853212594985962, -1.3999626636505127, -0.04824869707226753, -0.8023917078971863, -0.31676608324050903, -0.37280458211898804, -0.7297875881195068, -0.8681722283363342, -0.0, -0.0], [0.0, -12.598389625549316, -11.416818618774414, -11.866425514221191, -11.123103141784668, -10.29881763458252, -9.953362464904785, -9.421568870544434, -8.89908218383789, -8.627092361450195, -8.42205810546875, -8.109639167785645, -7.073545932769775, -7.105975151062012, -6.867244720458984, -5.941623210906982, -5.3715620040893555, -5.580792427062988, -5.454092502593994, -4.447152614593506, -4.658754825592041, -4.012060165405273, -4.0232768058776855, -3.739949941635132, -2.027202844619751, -2.1439428329467773, -3.0125105381011963, -1.364973545074463, -3.418116569519043, -2.3356521129608154, -2.6558480262756348, -1.9548970460891724, -2.6883926391601562, -1.3538302183151245, -0.6224730610847473, -2.969865322113037, -1.2079626321792603, -3.130467176437378, -1.061833143234253, -0.9037905931472778, 0.0, -1.1385955810546875, -1.3044719696044922, -0.7997267842292786, -0.6058384776115417, -2.5508506298065186, -1.0814393758773804, 2.174208641052246, -0.926227331161499, -0.5265153646469116, 0.21256352961063385, -0.491504430770874, -0.36958053708076477, 0.9123499989509583, -0.8803424835205078, -0.6243031024932861, -0.49577566981315613, -0.1903165876865387, -0.10825183987617493, -0.05201369524002075, -0.19784246385097504, -0.13053204119205475, 0.21478699147701263, 0.6649370193481445, -0.39024919271469116, -0.5628445148468018, -0.19940508902072906, 0.9145981669425964, -0.3210143446922302, -0.5253422856330872, -0.4525972008705139, -0.5630044341087341, -0.12599778175354004, -0.09543139487504959, -1.4540024995803833, -1.2525506019592285, 0.0, 0.0, -0.0, -12.598389625549316, -11.416818618774414, -11.866425514221191, -11.123103141784668, -10.29881763458252, -9.953362464904785, -9.421568870544434, -8.89908218383789, -8.627092361450195, -8.42205810546875, -8.109639167785645, -7.073545932769775, -7.105975151062012, -6.867244720458984, -5.941623210906982, -5.3715620040893555, -5.580792427062988, -5.454092502593994, -4.447152614593506, -4.658754825592041, -4.012060165405273, -4.0232768058776855, -3.739949941635132, -2.027202844619751, -2.1439428329467773, -3.0125105381011963, -1.364973545074463, -3.418116569519043, -2.3356521129608154, -2.6558480262756348, -1.9548970460891724, -2.6883926391601562, -1.3538302183151245, -0.6224730610847473, -2.969865322113037, -1.2079626321792603, -3.130467176437378, -1.061833143234253, -0.9037905931472778, -0.0, -1.1385955810546875, -1.3044719696044922, -0.7997267842292786, -0.6058384776115417, -2.5508506298065186, -1.0814393758773804, 2.174208641052246, -0.926227331161499, -0.5265153646469116, 0.21256352961063385, -0.491504430770874, -0.36958053708076477, 0.9123499989509583, -0.8803424835205078, -0.6243031024932861, -0.49577566981315613, -0.1903165876865387, -0.10825183987617493, -0.05201369524002075, -0.19784246385097504, -0.13053204119205475, 0.21478699147701263, 0.6649370193481445, -0.39024919271469116, -0.5628445148468018, -0.19940508902072906, 0.9145981669425964, -0.3210143446922302, -0.5253422856330872, -0.4525972008705139, -0.5630044341087341, -0.12599778175354004, -0.09543139487504959, -1.4540024995803833, -1.2525506019592285, -0.0, -0.0], [0.0, -8.9398193359375, -12.047744750976562, -12.412795066833496, -11.039918899536133, -11.004308700561523, -9.784934997558594, -9.662871360778809, -8.819622039794922, -9.147669792175293, -9.917142868041992, -7.814609527587891, -6.666302680969238, -7.020193099975586, -7.77079963684082, -5.730403423309326, -5.811222553253174, -5.3229265213012695, -5.071026802062988, -4.103346347808838, -4.105874538421631, -3.77131724357605, -4.724734306335449, -4.037724494934082, -3.575479030609131, -3.1406502723693848, -2.946286916732788, -2.6255664825439453, -2.194483757019043, -2.665494203567505, -2.2595953941345215, -0.4814731478691101, -2.8603596687316895, -2.741608142852783, -2.154595375061035, -1.8344215154647827, -0.41409093141555786, -2.9993045330047607, -1.0288817882537842, -1.2046246528625488, 0.0, -1.910725474357605, -0.9875954985618591, -0.6673016548156738, -1.3712619543075562, -2.2377004623413086, -0.9732329845428467, -2.0683417320251465, -1.1680256128311157, -2.7656073570251465, -1.2550671100616455, 0.08110730350017548, -0.8230642676353455, -1.8409236669540405, -1.2358736991882324, -0.12475740909576416, -2.451063632965088, -0.3629477024078369, -0.22904448211193085, 0.4513130784034729, -0.5188525915145874, -0.5100139379501343, -0.203225240111351, -0.14016221463680267, -0.721531867980957, -1.4748295545578003, -0.4832601547241211, -0.9336513876914978, -0.7893211245536804, -0.43316030502319336, -1.3888925313949585, -0.6755480170249939, -0.11978756636381149, 0.5346837043762207, -3.41788387298584, -1.4327796697616577, 0.0, 0.0, -0.0, -8.9398193359375, -12.047744750976562, -12.412795066833496, -11.039918899536133, -11.004308700561523, -9.784934997558594, -9.662871360778809, -8.819622039794922, -9.147669792175293, -9.917142868041992, -7.814609527587891, -6.666302680969238, -7.020193099975586, -7.77079963684082, -5.730403423309326, -5.811222553253174, -5.3229265213012695, -5.071026802062988, -4.103346347808838, -4.105874538421631, -3.77131724357605, -4.724734306335449, -4.037724494934082, -3.575479030609131, -3.1406502723693848, -2.946286916732788, -2.6255664825439453, -2.194483757019043, -2.665494203567505, -2.2595953941345215, -0.4814731478691101, -2.8603596687316895, -2.741608142852783, -2.154595375061035, -1.8344215154647827, -0.41409093141555786, -2.9993045330047607, -1.0288817882537842, -1.2046246528625488, -0.0, -1.910725474357605, -0.9875954985618591, -0.6673016548156738, -1.3712619543075562, -2.2377004623413086, -0.9732329845428467, -2.0683417320251465, -1.1680256128311157, -2.7656073570251465, -1.2550671100616455, 0.08110730350017548, -0.8230642676353455, -1.8409236669540405, -1.2358736991882324, -0.12475740909576416, -2.451063632965088, -0.3629477024078369, -0.22904448211193085, 0.4513130784034729, -0.5188525915145874, -0.5100139379501343, -0.203225240111351, -0.14016221463680267, -0.721531867980957, -1.4748295545578003, -0.4832601547241211, -0.9336513876914978, -0.7893211245536804, -0.43316030502319336, -1.3888925313949585, -0.6755480170249939, -0.11978756636381149, 0.5346837043762207, -3.41788387298584, -1.4327796697616577, -0.0, -0.0], [0.0, -11.251648902893066, -12.256559371948242, -12.639859199523926, -12.277459144592285, -10.335086822509766, -10.534875869750977, -10.170106887817383, -9.615535736083984, -9.114316940307617, -8.748041152954102, -7.21359395980835, -7.926764965057373, -7.203889846801758, -6.93554162979126, -5.817676544189453, -5.627784729003906, -5.503873825073242, -5.654011249542236, -4.70776891708374, -4.961339950561523, -4.556424617767334, -4.898025989532471, -4.707579135894775, -5.164480686187744, -3.7515108585357666, -3.1979877948760986, -2.588325023651123, -2.3273282051086426, -2.374350070953369, -3.5344185829162598, -2.616879463195801, -3.0487301349639893, -2.9873006343841553, -1.8243335485458374, -1.7782649993896484, -3.6277806758880615, -3.111931562423706, -2.0370445251464844, -1.4248000383377075, 0.0, 0.0, -1.8400516510009766, -1.5984599590301514, -3.034614324569702, -1.8457207679748535, -0.5052571296691895, -1.5431634187698364, -1.4315966367721558, -2.900171995162964, -0.34541037678718567, -1.5308754444122314, -2.041499137878418, -1.1646440029144287, -0.45960670709609985, -2.26729416847229, -1.7634788751602173, -2.5642566680908203, -0.03313715383410454, 0.4263993501663208, 0.125219464302063, -0.9394428133964539, -0.09686991572380066, -0.4109228849411011, -1.2640469074249268, -0.8971644043922424, -0.5567993521690369, 0.4910963773727417, -1.155530571937561, -0.9565222263336182, -0.6740217804908752, -0.29803019762039185, -0.04588870331645012, 0.837971031665802, 0.0, -0.07729580253362656, 0.0, 0.0, -0.0, -11.251648902893066, -12.256559371948242, -12.639859199523926, -12.277459144592285, -10.335086822509766, -10.534875869750977, -10.170106887817383, -9.615535736083984, -9.114316940307617, -8.748041152954102, -7.21359395980835, -7.926764965057373, -7.203889846801758, -6.93554162979126, -5.817676544189453, -5.627784729003906, -5.503873825073242, -5.654011249542236, -4.70776891708374, -4.961339950561523, -4.556424617767334, -4.898025989532471, -4.707579135894775, -5.164480686187744, -3.7515108585357666, -3.1979877948760986, -2.588325023651123, -2.3273282051086426, -2.374350070953369, -3.5344185829162598, -2.616879463195801, -3.0487301349639893, -2.9873006343841553, -1.8243335485458374, -1.7782649993896484, -3.6277806758880615, -3.111931562423706, -2.0370445251464844, -1.4248000383377075, -0.0, -0.0, -1.8400516510009766, -1.5984599590301514, -3.034614324569702, -1.8457207679748535, -0.5052571296691895, -1.5431634187698364, -1.4315966367721558, -2.900171995162964, -0.34541037678718567, -1.5308754444122314, -2.041499137878418, -1.1646440029144287, -0.45960670709609985, -2.26729416847229, -1.7634788751602173, -2.5642566680908203, -0.03313715383410454, 0.4263993501663208, 0.125219464302063, -0.9394428133964539, -0.09686991572380066, -0.4109228849411011, -1.2640469074249268, -0.8971644043922424, -0.5567993521690369, 0.4910963773727417, -1.155530571937561, -0.9565222263336182, -0.6740217804908752, -0.29803019762039185, -0.04588870331645012, 0.837971031665802, -0.0, -0.07729580253362656, -0.0, -0.0], [0.0, 0.0, -13.042850494384766, -12.147722244262695, -12.00516414642334, -11.024584770202637, -11.513012886047363, -10.360040664672852, -10.202033042907715, -10.850052833557129, -8.004953384399414, -7.052018642425537, -7.293605804443359, -7.232344150543213, -6.0768046379089355, -6.033720970153809, -6.676175594329834, -5.350045204162598, -5.886900901794434, -4.864748001098633, -4.7589616775512695, -3.125919818878174, -3.1259312629699707, -4.433923721313477, -1.7628597021102905, -5.870021820068359, -3.7420499324798584, -2.9562125205993652, -3.4986541271209717, -3.092852830886841, -1.677858591079712, -3.1834938526153564, -2.9689183235168457, -3.137017011642456, -3.2692322731018066, -4.735815048217773, -2.997075080871582, -1.7108259201049805, -3.064098834991455, -1.9298559427261353, -2.57199764251709, -1.6347671747207642, -1.306876301765442, -2.2099928855895996, -1.1341066360473633, -2.42386531829834, -1.3478999137878418, -2.772292375564575, -2.173299789428711, -1.2677876949310303, -1.897156000137329, -1.3353314399719238, -0.6259035468101501, -2.1937904357910156, -0.84473717212677, -1.4984151124954224, -1.6995947360992432, -0.5581080317497253, -1.344602108001709, -0.7966178059577942, -0.5970282554626465, -0.19038496911525726, -0.5608597993850708, -0.006062404252588749, -0.734976589679718, -0.5089439749717712, -1.267029047012329, -0.2700800895690918, -0.9966868758201599, -0.5057153105735779, -0.6254505515098572, -0.613561749458313, 0.4300647974014282, 1.3086965084075928, 0.42583122849464417, 0.2941302955150604, 0.0, 0.0, -0.0, -0.0, -13.042850494384766, -12.147722244262695, -12.00516414642334, -11.024584770202637, -11.513012886047363, -10.360040664672852, -10.202033042907715, -10.850052833557129, -8.004953384399414, -7.052018642425537, -7.293605804443359, -7.232344150543213, -6.0768046379089355, -6.033720970153809, -6.676175594329834, -5.350045204162598, -5.886900901794434, -4.864748001098633, -4.7589616775512695, -3.125919818878174, -3.1259312629699707, -4.433923721313477, -1.7628597021102905, -5.870021820068359, -3.7420499324798584, -2.9562125205993652, -3.4986541271209717, -3.092852830886841, -1.677858591079712, -3.1834938526153564, -2.9689183235168457, -3.137017011642456, -3.2692322731018066, -4.735815048217773, -2.997075080871582, -1.7108259201049805, -3.064098834991455, -1.9298559427261353, -2.57199764251709, -1.6347671747207642, -1.306876301765442, -2.2099928855895996, -1.1341066360473633, -2.42386531829834, -1.3478999137878418, -2.772292375564575, -2.173299789428711, -1.2677876949310303, -1.897156000137329, -1.3353314399719238, -0.6259035468101501, -2.1937904357910156, -0.84473717212677, -1.4984151124954224, -1.6995947360992432, -0.5581080317497253, -1.344602108001709, -0.7966178059577942, -0.5970282554626465, -0.19038496911525726, -0.5608597993850708, -0.006062404252588749, -0.734976589679718, -0.5089439749717712, -1.267029047012329, -0.2700800895690918, -0.9966868758201599, -0.5057153105735779, -0.6254505515098572, -0.613561749458313, 0.4300647974014282, 1.3086965084075928, 0.42583122849464417, 0.2941302955150604, 0.0, 0.0], [0.0, 0.0, -13.714041709899902, -12.965871810913086, -12.707958221435547, -11.12628173828125, -10.850197792053223, -9.940293312072754, -9.73388385772705, -9.04538345336914, -6.054287910461426, -7.873854160308838, -7.524814128875732, -6.875124454498291, -6.798292636871338, -6.501001358032227, -6.220495700836182, -5.534815788269043, -5.618946075439453, -4.728585720062256, -5.3238959312438965, -4.815260887145996, -4.617101192474365, -4.590211868286133, -2.8922345638275146, -3.7035396099090576, -1.4937241077423096, -0.7846354246139526, -1.2962199449539185, -4.660780906677246, -3.394697666168213, -3.389878988265991, -6.050777435302734, -3.1956729888916016, -3.691737413406372, -3.8838038444519043, -3.794294595718384, -3.5483365058898926, -2.834709405899048, -2.9532852172851562, -3.476139783859253, 0.0, 0.0, -2.503798007965088, -2.7936043739318848, -2.6779625415802, -3.0242860317230225, -2.9494433403015137, 0.21326999366283417, -3.012946367263794, -2.1922149658203125, -1.2238472700119019, -1.281978964805603, -1.2437406778335571, -1.097365140914917, -0.6715993881225586, -0.49918749928474426, -1.62534761428833, -0.8121284246444702, -0.17130005359649658, -1.5530182123184204, -1.1788498163223267, -0.6360679268836975, -0.08384447544813156, -0.9055985808372498, -0.22806794941425323, -1.1272273063659668, -1.0430678129196167, -0.9129405617713928, -1.0030863285064697, -0.7292541265487671, -0.757358968257904, -0.03799223154783249, 0.5725746154785156, 0.39296576380729675, -0.2873266637325287, 0.0, 0.0, -0.0, -0.0, -13.714041709899902, -12.965871810913086, -12.707958221435547, -11.12628173828125, -10.850197792053223, -9.940293312072754, -9.73388385772705, -9.04538345336914, -6.054287910461426, -7.873854160308838, -7.524814128875732, -6.875124454498291, -6.798292636871338, -6.501001358032227, -6.220495700836182, -5.534815788269043, -5.618946075439453, -4.728585720062256, -5.3238959312438965, -4.815260887145996, -4.617101192474365, -4.590211868286133, -2.8922345638275146, -3.7035396099090576, -1.4937241077423096, -0.7846354246139526, -1.2962199449539185, -4.660780906677246, -3.394697666168213, -3.389878988265991, -6.050777435302734, -3.1956729888916016, -3.691737413406372, -3.8838038444519043, -3.794294595718384, -3.5483365058898926, -2.834709405899048, -2.9532852172851562, -3.476139783859253, -0.0, -0.0, -2.503798007965088, -2.7936043739318848, -2.6779625415802, -3.0242860317230225, -2.9494433403015137, 0.21326999366283417, -3.012946367263794, -2.1922149658203125, -1.2238472700119019, -1.281978964805603, -1.2437406778335571, -1.097365140914917, -0.6715993881225586, -0.49918749928474426, -1.62534761428833, -0.8121284246444702, -0.17130005359649658, -1.5530182123184204, -1.1788498163223267, -0.6360679268836975, -0.08384447544813156, -0.9055985808372498, -0.22806794941425323, -1.1272273063659668, -1.0430678129196167, -0.9129405617713928, -1.0030863285064697, -0.7292541265487671, -0.757358968257904, -0.03799223154783249, 0.5725746154785156, 0.39296576380729675, -0.2873266637325287, -0.0, -0.0], [0.0, 0.0, -13.394172668457031, -13.476530075073242, -12.599637985229492, -11.687713623046875, -10.874783515930176, -10.927512168884277, -10.188529968261719, -9.673567771911621, -7.197648525238037, -7.961380958557129, -7.475461006164551, -7.538002967834473, -6.7618865966796875, -6.045261383056641, -6.31893253326416, -5.8143229484558105, -5.719019889831543, -3.9646923542022705, -5.00224494934082, -3.96272349357605, -5.651181221008301, -4.413084030151367, -5.840664863586426, -3.9956860542297363, -1.865337610244751, -4.298415184020996, -5.263598442077637, -3.4464070796966553, -4.609226703643799, -3.586956739425659, -3.111355781555176, -6.664534568786621, -4.552933692932129, -3.851303815841675, -4.250574111938477, -5.973701477050781, -3.572204351425171, -3.5468239784240723, -3.1397109031677246, -3.655120372772217, -3.372300624847412, -4.348644733428955, -2.7751147747039795, -4.071786880493164, -3.1636288166046143, -3.314622163772583, -0.31353959441185, -2.6937923431396484, -2.9147796630859375, -2.924042224884033, -1.0755901336669922, -1.0252296924591064, -2.719203233718872, -2.4688048362731934, 0.34582439064979553, -4.012213706970215, -1.0914645195007324, -0.32833725214004517, -0.009606828913092613, -1.1017311811447144, -1.1384408473968506, -1.3880707025527954, -0.5386366844177246, -0.9129047393798828, -1.0028798580169678, -1.0201029777526855, -0.6134352087974548, -1.0357965230941772, -0.9910927414894104, -0.5356255173683167, -0.3423135280609131, -0.519336462020874, -1.9164766073226929, -0.9020662903785706, 0.0, 0.0, -0.0, -0.0, -13.394172668457031, -13.476530075073242, -12.599637985229492, -11.687713623046875, -10.874783515930176, -10.927512168884277, -10.188529968261719, -9.673567771911621, -7.197648525238037, -7.961380958557129, -7.475461006164551, -7.538002967834473, -6.7618865966796875, -6.045261383056641, -6.31893253326416, -5.8143229484558105, -5.719019889831543, -3.9646923542022705, -5.00224494934082, -3.96272349357605, -5.651181221008301, -4.413084030151367, -5.840664863586426, -3.9956860542297363, -1.865337610244751, -4.298415184020996, -5.263598442077637, -3.4464070796966553, -4.609226703643799, -3.586956739425659, -3.111355781555176, -6.664534568786621, -4.552933692932129, -3.851303815841675, -4.250574111938477, -5.973701477050781, -3.572204351425171, -3.5468239784240723, -3.1397109031677246, -3.655120372772217, -3.372300624847412, -4.348644733428955, -2.7751147747039795, -4.071786880493164, -3.1636288166046143, -3.314622163772583, -0.31353959441185, -2.6937923431396484, -2.9147796630859375, -2.924042224884033, -1.0755901336669922, -1.0252296924591064, -2.719203233718872, -2.4688048362731934, 0.34582439064979553, -4.012213706970215, -1.0914645195007324, -0.32833725214004517, -0.009606828913092613, -1.1017311811447144, -1.1384408473968506, -1.3880707025527954, -0.5386366844177246, -0.9129047393798828, -1.0028798580169678, -1.0201029777526855, -0.6134352087974548, -1.0357965230941772, -0.9910927414894104, -0.5356255173683167, -0.3423135280609131, -0.519336462020874, -1.9164766073226929, -0.9020662903785706, -0.0, -0.0], [0.0, 0.0, -14.302806854248047, -13.642606735229492, -13.547659873962402, -11.794110298156738, -11.367049217224121, -10.503741264343262, -9.743524551391602, -9.550177574157715, -9.656973838806152, -8.857959747314453, -8.258054733276367, -7.123290538787842, -6.746326446533203, -6.46140193939209, -6.556313514709473, -7.852573871612549, -5.3958330154418945, -5.234250068664551, -5.589056015014648, -4.933712005615234, -5.898013591766357, -5.731769561767578, -4.431773662567139, -4.183378219604492, -4.6167707443237305, -3.9827938079833984, -5.229669570922852, -6.320244789123535, -2.552283525466919, -3.6845576763153076, -3.918334722518921, -2.48388409614563, -4.636966705322266, -4.114926815032959, -5.342500686645508, -4.111894130706787, -3.448066473007202, -4.048351287841797, -5.048829555511475, -3.926807165145874, -4.201526165008545, -5.568485736846924, -2.070589542388916, -3.2933132648468018, -1.8409124612808228, -2.9797301292419434, -3.6730740070343018, -4.5400543212890625, -3.495368242263794, -3.336890697479248, -2.308173656463623, -2.1784207820892334, -2.566441059112549, -2.5433340072631836, -0.7869657874107361, -3.2469303607940674, -1.3742175102233887, -1.1843955516815186, -0.7368910312652588, -0.5343233942985535, 0.20985569059848785, -1.1148450374603271, -0.37492385506629944, -1.0237171649932861, -0.9773228168487549, -0.7587048411369324, -0.9500368237495422, -0.7007942199707031, -0.5423575043678284, -0.5185526609420776, -0.9871901273727417, -0.3969220817089081, 0.46050751209259033, -0.39117422699928284, 0.0, 0.0, -0.0, -0.0, -14.302806854248047, -13.642606735229492, -13.547659873962402, -11.794110298156738, -11.367049217224121, -10.503741264343262, -9.743524551391602, -9.550177574157715, -9.656973838806152, -8.857959747314453, -8.258054733276367, -7.123290538787842, -6.746326446533203, -6.46140193939209, -6.556313514709473, -7.852573871612549, -5.3958330154418945, -5.234250068664551, -5.589056015014648, -4.933712005615234, -5.898013591766357, -5.731769561767578, -4.431773662567139, -4.183378219604492, -4.6167707443237305, -3.9827938079833984, -5.229669570922852, -6.320244789123535, -2.552283525466919, -3.6845576763153076, -3.918334722518921, -2.48388409614563, -4.636966705322266, -4.114926815032959, -5.342500686645508, -4.111894130706787, -3.448066473007202, -4.048351287841797, -5.048829555511475, -3.926807165145874, -4.201526165008545, -5.568485736846924, -2.070589542388916, -3.2933132648468018, -1.8409124612808228, -2.9797301292419434, -3.6730740070343018, -4.5400543212890625, -3.495368242263794, -3.336890697479248, -2.308173656463623, -2.1784207820892334, -2.566441059112549, -2.5433340072631836, -0.7869657874107361, -3.2469303607940674, -1.3742175102233887, -1.1843955516815186, -0.7368910312652588, -0.5343233942985535, 0.20985569059848785, -1.1148450374603271, -0.37492385506629944, -1.0237171649932861, -0.9773228168487549, -0.7587048411369324, -0.9500368237495422, -0.7007942199707031, -0.5423575043678284, -0.5185526609420776, -0.9871901273727417, -0.3969220817089081, 0.46050751209259033, -0.39117422699928284, -0.0, -0.0], [0.0, 0.0, -13.954118728637695, -12.657065391540527, -13.317465782165527, -10.789705276489258, -11.007591247558594, -10.544013023376465, -9.469040870666504, -9.055070877075195, -8.960309028625488, -8.499509811401367, -8.105731964111328, -7.412252902984619, -6.968210220336914, -6.348154544830322, -6.7024054527282715, -6.967939853668213, -5.5040178298950195, -5.000186920166016, -6.808048725128174, -4.639411449432373, -4.624360084533691, -5.082197189331055, -6.2896342277526855, -5.441814422607422, -4.437143802642822, -4.1452107429504395, -5.5366644859313965, -4.373706340789795, -5.008878707885742, -3.733412981033325, -4.658249378204346, -4.138172149658203, -4.86195707321167, -5.1335625648498535, -5.937455177307129, -4.626945495605469, -4.661711692810059, -5.896949768066406, -4.794813632965088, -4.709841251373291, -4.421896934509277, -3.4216527938842773, -4.998254299163818, -4.78422737121582, -3.7269275188446045, -3.3323256969451904, -2.9425368309020996, -2.8719935417175293, -3.48799204826355, -3.0609302520751953, -3.830615520477295, -2.081912040710449, -2.4886186122894287, -2.6486268043518066, -1.9018634557724, -1.3486077785491943, -1.2926785945892334, -1.0953290462493896, -1.800705075263977, -1.572790503501892, -0.6083235740661621, -1.0012903213500977, -2.1157870292663574, -1.9792327880859375, -0.7042268514633179, -2.050170421600342, -0.7859951853752136, -1.0648698806762695, -0.9156859517097473, -1.8060131072998047, -1.577483892440796, -1.3753341436386108, -2.2931454181671143, 0.0, 0.0, 0.0, -0.0, -0.0, -13.954118728637695, -12.657065391540527, -13.317465782165527, -10.789705276489258, -11.007591247558594, -10.544013023376465, -9.469040870666504, -9.055070877075195, -8.960309028625488, -8.499509811401367, -8.105731964111328, -7.412252902984619, -6.968210220336914, -6.348154544830322, -6.7024054527282715, -6.967939853668213, -5.5040178298950195, -5.000186920166016, -6.808048725128174, -4.639411449432373, -4.624360084533691, -5.082197189331055, -6.2896342277526855, -5.441814422607422, -4.437143802642822, -4.1452107429504395, -5.5366644859313965, -4.373706340789795, -5.008878707885742, -3.733412981033325, -4.658249378204346, -4.138172149658203, -4.86195707321167, -5.1335625648498535, -5.937455177307129, -4.626945495605469, -4.661711692810059, -5.896949768066406, -4.794813632965088, -4.709841251373291, -4.421896934509277, -3.4216527938842773, -4.998254299163818, -4.78422737121582, -3.7269275188446045, -3.3323256969451904, -2.9425368309020996, -2.8719935417175293, -3.48799204826355, -3.0609302520751953, -3.830615520477295, -2.081912040710449, -2.4886186122894287, -2.6486268043518066, -1.9018634557724, -1.3486077785491943, -1.2926785945892334, -1.0953290462493896, -1.800705075263977, -1.572790503501892, -0.6083235740661621, -1.0012903213500977, -2.1157870292663574, -1.9792327880859375, -0.7042268514633179, -2.050170421600342, -0.7859951853752136, -1.0648698806762695, -0.9156859517097473, -1.8060131072998047, -1.577483892440796, -1.3753341436386108, -2.2931454181671143, -0.0, -0.0, -0.0], [0.0, 0.0, -14.713438034057617, -13.686440467834473, -13.882195472717285, -12.794455528259277, -11.368586540222168, -11.755276679992676, -10.263813972473145, -9.99954891204834, -9.318934440612793, -9.102354049682617, -8.441695213317871, -7.455484867095947, -7.520643711090088, -6.879916667938232, -6.149752616882324, -6.810929775238037, -6.172147750854492, -5.56571102142334, -6.213330268859863, -5.259556770324707, -4.299798965454102, -5.688595771789551, -6.383394718170166, -3.9059226512908936, -5.2025837898254395, -6.81944465637207, -5.0399298667907715, -6.077943801879883, -5.198575496673584, -4.295452117919922, -7.7371416091918945, -5.999669551849365, -5.497933864593506, -5.842741012573242, -5.906390190124512, -5.64544153213501, -6.105705261230469, -5.007819652557373, -5.940491676330566, -5.648820877075195, -4.836556911468506, -4.857892990112305, -6.50768518447876, -4.5983500480651855, -5.334420680999756, -4.445209980010986, -5.018730163574219, -4.2377214431762695, -3.6151933670043945, -2.9547083377838135, -4.686635971069336, -2.9692909717559814, -3.5706746578216553, -2.2628774642944336, -3.5640339851379395, -1.8534363508224487, -1.2306677103042603, -1.286329984664917, -1.0588451623916626, -1.3228676319122314, -0.9418741464614868, -0.7450423240661621, -0.0910409688949585, -1.3057124614715576, -1.7975388765335083, -1.3904051780700684, -1.2567702531814575, -0.6573511362075806, -0.904207170009613, -1.3719913959503174, -2.572838068008423, -3.608717679977417, -2.4534099102020264, 0.0, 0.0, 0.0, -0.0, -0.0, -14.713438034057617, -13.686440467834473, -13.882195472717285, -12.794455528259277, -11.368586540222168, -11.755276679992676, -10.263813972473145, -9.99954891204834, -9.318934440612793, -9.102354049682617, -8.441695213317871, -7.455484867095947, -7.520643711090088, -6.879916667938232, -6.149752616882324, -6.810929775238037, -6.172147750854492, -5.56571102142334, -6.213330268859863, -5.259556770324707, -4.299798965454102, -5.688595771789551, -6.383394718170166, -3.9059226512908936, -5.2025837898254395, -6.81944465637207, -5.0399298667907715, -6.077943801879883, -5.198575496673584, -4.295452117919922, -7.7371416091918945, -5.999669551849365, -5.497933864593506, -5.842741012573242, -5.906390190124512, -5.64544153213501, -6.105705261230469, -5.007819652557373, -5.940491676330566, -5.648820877075195, -4.836556911468506, -4.857892990112305, -6.50768518447876, -4.5983500480651855, -5.334420680999756, -4.445209980010986, -5.018730163574219, -4.2377214431762695, -3.6151933670043945, -2.9547083377838135, -4.686635971069336, -2.9692909717559814, -3.5706746578216553, -2.2628774642944336, -3.5640339851379395, -1.8534363508224487, -1.2306677103042603, -1.286329984664917, -1.0588451623916626, -1.3228676319122314, -0.9418741464614868, -0.7450423240661621, -0.0910409688949585, -1.3057124614715576, -1.7975388765335083, -1.3904051780700684, -1.2567702531814575, -0.6573511362075806, -0.904207170009613, -1.3719913959503174, -2.572838068008423, -3.608717679977417, -2.4534099102020264, -0.0, -0.0, -0.0], [0.0, 0.0, -13.494702339172363, -13.76951789855957, -13.642515182495117, -13.005411148071289, -11.777189254760742, -11.377854347229004, -10.153165817260742, -10.886669158935547, -9.538625717163086, -8.727177619934082, -8.105446815490723, -7.750149726867676, -5.965240955352783, -6.927305221557617, -5.918813228607178, -6.120970249176025, -6.505548477172852, -3.465818166732788, -5.401595115661621, -5.8700032234191895, -6.293790340423584, -6.01369571685791, -6.472458839416504, -5.453179359436035, -5.863193035125732, -5.729342937469482, -5.48158073425293, -3.0994765758514404, -5.176291465759277, -6.32027530670166, -6.3792405128479, -8.77707576751709, -6.719541072845459, -5.982940673828125, -6.225375652313232, -8.732169151306152, -6.145047187805176, -6.556221961975098, -6.424868583679199, -6.486737251281738, -5.9703474044799805, -5.4200520515441895, -5.151177883148193, -5.73972225189209, -4.164613246917725, -5.947690010070801, -5.485114574432373, -4.973888397216797, -4.914127826690674, -3.2246978282928467, -2.89274525642395, -2.7099075317382812, -3.510190486907959, -2.6013989448547363, -2.3312647342681885, -2.1321752071380615, -3.2839064598083496, -1.2772777080535889, -1.531301498413086, -1.9331767559051514, -1.2929936647415161, -1.30360746383667, -0.6685502529144287, -1.1221586465835571, -1.4197617769241333, -1.5365031957626343, -0.18422167003154755, -1.0051902532577515, -1.2686009407043457, -1.8243253231048584, -2.983187675476074, -2.78196120262146, -2.5274064540863037, 0.0, 0.0, 7.842835903167725, -0.0, -0.0, -13.494702339172363, -13.76951789855957, -13.642515182495117, -13.005411148071289, -11.777189254760742, -11.377854347229004, -10.153165817260742, -10.886669158935547, -9.538625717163086, -8.727177619934082, -8.105446815490723, -7.750149726867676, -5.965240955352783, -6.927305221557617, -5.918813228607178, -6.120970249176025, -6.505548477172852, -3.465818166732788, -5.401595115661621, -5.8700032234191895, -6.293790340423584, -6.01369571685791, -6.472458839416504, -5.453179359436035, -5.863193035125732, -5.729342937469482, -5.48158073425293, -3.0994765758514404, -5.176291465759277, -6.32027530670166, -6.3792405128479, -8.77707576751709, -6.719541072845459, -5.982940673828125, -6.225375652313232, -8.732169151306152, -6.145047187805176, -6.556221961975098, -6.424868583679199, -6.486737251281738, -5.9703474044799805, -5.4200520515441895, -5.151177883148193, -5.73972225189209, -4.164613246917725, -5.947690010070801, -5.485114574432373, -4.973888397216797, -4.914127826690674, -3.2246978282928467, -2.89274525642395, -2.7099075317382812, -3.510190486907959, -2.6013989448547363, -2.3312647342681885, -2.1321752071380615, -3.2839064598083496, -1.2772777080535889, -1.531301498413086, -1.9331767559051514, -1.2929936647415161, -1.30360746383667, -0.6685502529144287, -1.1221586465835571, -1.4197617769241333, -1.5365031957626343, -0.18422167003154755, -1.0051902532577515, -1.2686009407043457, -1.8243253231048584, -2.983187675476074, -2.78196120262146, -2.5274064540863037, -0.0, -0.0, 7.842835903167725], [0.0, 0.0, -14.42409610748291, -14.659432411193848, -14.23347282409668, -13.029875755310059, -12.032783508300781, -11.128995895385742, -10.872688293457031, -10.719987869262695, -8.902351379394531, -8.48603343963623, -8.176628112792969, -7.437328815460205, -7.160834312438965, -6.8206915855407715, -6.352959632873535, -6.6010541915893555, -6.510411262512207, -6.306771755218506, -5.561257362365723, -5.596126079559326, -6.758999347686768, -7.274908542633057, -6.474330902099609, -5.3006720542907715, -5.840155601501465, -5.073215484619141, -5.761379718780518, -6.543715476989746, -6.013433456420898, -6.2900519371032715, -6.697035312652588, -6.715206623077393, -4.1273064613342285, -7.514492034912109, -7.553977012634277, -7.615384578704834, -7.20574426651001, -6.883498668670654, -6.784306526184082, -7.622478485107422, -6.265036582946777, -6.599229335784912, -5.317709445953369, -5.479878902435303, -6.551516056060791, -6.540571689605713, -6.556529521942139, -7.001403331756592, -5.899349689483643, -1.6026827096939087, -3.296820878982544, -3.218724489212036, -2.8785858154296875, -3.1529288291931152, -3.400996446609497, -2.7744863033294678, -2.758136510848999, -2.6245079040527344, -1.694902777671814, -2.1537117958068848, -1.1741983890533447, -1.5266218185424805, -1.7546237707138062, -1.748049259185791, -1.0920602083206177, -2.2614150047302246, -1.1110798120498657, -0.04065925255417824, -0.34252774715423584, -1.8774616718292236, -2.680088758468628, -2.6856296062469482, -2.3202450275421143, 0.0, 0.0, 9.047469139099121, -0.0, -0.0, -14.42409610748291, -14.659432411193848, -14.23347282409668, -13.029875755310059, -12.032783508300781, -11.128995895385742, -10.872688293457031, -10.719987869262695, -8.902351379394531, -8.48603343963623, -8.176628112792969, -7.437328815460205, -7.160834312438965, -6.8206915855407715, -6.352959632873535, -6.6010541915893555, -6.510411262512207, -6.306771755218506, -5.561257362365723, -5.596126079559326, -6.758999347686768, -7.274908542633057, -6.474330902099609, -5.3006720542907715, -5.840155601501465, -5.073215484619141, -5.761379718780518, -6.543715476989746, -6.013433456420898, -6.2900519371032715, -6.697035312652588, -6.715206623077393, -4.1273064613342285, -7.514492034912109, -7.553977012634277, -7.615384578704834, -7.20574426651001, -6.883498668670654, -6.784306526184082, -7.622478485107422, -6.265036582946777, -6.599229335784912, -5.317709445953369, -5.479878902435303, -6.551516056060791, -6.540571689605713, -6.556529521942139, -7.001403331756592, -5.899349689483643, -1.6026827096939087, -3.296820878982544, -3.218724489212036, -2.8785858154296875, -3.1529288291931152, -3.400996446609497, -2.7744863033294678, -2.758136510848999, -2.6245079040527344, -1.694902777671814, -2.1537117958068848, -1.1741983890533447, -1.5266218185424805, -1.7546237707138062, -1.748049259185791, -1.0920602083206177, -2.2614150047302246, -1.1110798120498657, -0.04065925255417824, -0.34252774715423584, -1.8774616718292236, -2.680088758468628, -2.6856296062469482, -2.3202450275421143, -0.0, -0.0, 9.047469139099121], [0.0, 0.0, 0.0, -13.901350975036621, -13.915467262268066, -13.453173637390137, -12.501043319702148, -11.388421058654785, -12.067602157592773, -10.566485404968262, -9.762117385864258, -8.792486190795898, -8.504420280456543, -7.744967937469482, -7.258747100830078, -7.68349027633667, -7.10152530670166, -7.274953842163086, -6.392849445343018, -6.7725510597229, -6.141082763671875, -5.6002631187438965, -5.932525634765625, -7.099100589752197, -6.072102069854736, -5.867232322692871, -6.36822509765625, -6.3274407386779785, -5.464991569519043, -8.964418411254883, -7.203613758087158, -8.669522285461426, -7.625156879425049, -8.241520881652832, -8.085434913635254, -8.548440933227539, -7.832458019256592, -8.093928337097168, -8.034906387329102, -9.069942474365234, -7.938224792480469, -7.610891342163086, -6.840875625610352, -7.933984279632568, -6.083122253417969, -6.07435417175293, -6.429480075836182, -3.8009161949157715, -6.309254169464111, -7.446889877319336, -5.062941074371338, -4.635527610778809, -4.430529594421387, -3.5047073364257812, -2.896559953689575, -5.322052001953125, -3.5790441036224365, -2.865027904510498, -2.057199001312256, -2.8324928283691406, -2.2692418098449707, -1.3013441562652588, -1.8600332736968994, -1.2249250411987305, -1.9782021045684814, -0.7430902123451233, -1.1713848114013672, -1.3894553184509277, -0.9746609926223755, -1.1700783967971802, -0.7939646244049072, -2.4084019660949707, -2.6333441734313965, -2.6702466011047363, -3.2650153636932373, 0.0, 0.0, 4.112213611602783, -0.0, -0.0, -0.0, -13.901350975036621, -13.915467262268066, -13.453173637390137, -12.501043319702148, -11.388421058654785, -12.067602157592773, -10.566485404968262, -9.762117385864258, -8.792486190795898, -8.504420280456543, -7.744967937469482, -7.258747100830078, -7.68349027633667, -7.10152530670166, -7.274953842163086, -6.392849445343018, -6.7725510597229, -6.141082763671875, -5.6002631187438965, -5.932525634765625, -7.099100589752197, -6.072102069854736, -5.867232322692871, -6.36822509765625, -6.3274407386779785, -5.464991569519043, -8.964418411254883, -7.203613758087158, -8.669522285461426, -7.625156879425049, -8.241520881652832, -8.085434913635254, -8.548440933227539, -7.832458019256592, -8.093928337097168, -8.034906387329102, -9.069942474365234, -7.938224792480469, -7.610891342163086, -6.840875625610352, -7.933984279632568, -6.083122253417969, -6.07435417175293, -6.429480075836182, -3.8009161949157715, -6.309254169464111, -7.446889877319336, -5.062941074371338, -4.635527610778809, -4.430529594421387, -3.5047073364257812, -2.896559953689575, -5.322052001953125, -3.5790441036224365, -2.865027904510498, -2.057199001312256, -2.8324928283691406, -2.2692418098449707, -1.3013441562652588, -1.8600332736968994, -1.2249250411987305, -1.9782021045684814, -0.7430902123451233, -1.1713848114013672, -1.3894553184509277, -0.9746609926223755, -1.1700783967971802, -0.7939646244049072, -2.4084019660949707, -2.6333441734313965, -2.6702466011047363, -3.2650153636932373, -0.0, -0.0, 4.112213611602783], [0.0, 0.0, 0.0, -13.873940467834473, -13.977176666259766, -12.986983299255371, -12.396382331848145, -11.972196578979492, -10.910309791564941, -9.722296714782715, -9.338821411132812, -9.01681900024414, -7.993241786956787, -8.060717582702637, -7.656754493713379, -7.4223408699035645, -8.153698921203613, -7.467297554016113, -7.154842853546143, -7.007997035980225, -6.617490291595459, -6.534810543060303, -6.651098728179932, -6.3028788566589355, -5.002593040466309, -6.259021759033203, -6.457099914550781, -6.9689178466796875, -7.08107328414917, -7.852108001708984, -7.098829746246338, -7.216105937957764, -10.592613220214844, -8.26471996307373, -8.54333782196045, -9.307827949523926, -9.132529258728027, -8.977802276611328, -9.271702766418457, -9.312859535217285, -8.849305152893066, -7.911168098449707, -7.5368733406066895, -8.321051597595215, -6.587465763092041, -6.871007442474365, -8.75459098815918, -8.470901489257812, -6.209478855133057, -6.676902770996094, -6.426756858825684, -4.899903774261475, -4.973741054534912, -3.657219409942627, -3.8938441276550293, -3.538024663925171, -2.0714235305786133, -3.4473249912261963, -3.198869466781616, -3.585084915161133, -2.925464153289795, -1.5086390972137451, -1.8358365297317505, -1.4024815559387207, -1.6656304597854614, -1.447839617729187, -1.8470323085784912, -1.350568413734436, -1.1814451217651367, -0.5421566963195801, 0.3439411222934723, -1.771384596824646, -1.5917083024978638, -2.363715648651123, -1.7657365798950195, 0.0, 0.0, 5.513758182525635, -0.0, -0.0, -0.0, -13.873940467834473, -13.977176666259766, -12.986983299255371, -12.396382331848145, -11.972196578979492, -10.910309791564941, -9.722296714782715, -9.338821411132812, -9.01681900024414, -7.993241786956787, -8.060717582702637, -7.656754493713379, -7.4223408699035645, -8.153698921203613, -7.467297554016113, -7.154842853546143, -7.007997035980225, -6.617490291595459, -6.534810543060303, -6.651098728179932, -6.3028788566589355, -5.002593040466309, -6.259021759033203, -6.457099914550781, -6.9689178466796875, -7.08107328414917, -7.852108001708984, -7.098829746246338, -7.216105937957764, -10.592613220214844, -8.26471996307373, -8.54333782196045, -9.307827949523926, -9.132529258728027, -8.977802276611328, -9.271702766418457, -9.312859535217285, -8.849305152893066, -7.911168098449707, -7.5368733406066895, -8.321051597595215, -6.587465763092041, -6.871007442474365, -8.75459098815918, -8.470901489257812, -6.209478855133057, -6.676902770996094, -6.426756858825684, -4.899903774261475, -4.973741054534912, -3.657219409942627, -3.8938441276550293, -3.538024663925171, -2.0714235305786133, -3.4473249912261963, -3.198869466781616, -3.585084915161133, -2.925464153289795, -1.5086390972137451, -1.8358365297317505, -1.4024815559387207, -1.6656304597854614, -1.447839617729187, -1.8470323085784912, -1.350568413734436, -1.1814451217651367, -0.5421566963195801, 0.3439411222934723, -1.771384596824646, -1.5917083024978638, -2.363715648651123, -1.7657365798950195, -0.0, -0.0, 5.513758182525635], [-20.834758758544922, 0.0, 0.0, -13.630118370056152, -14.581775665283203, -13.514798164367676, -13.04251480102539, -11.646797180175781, -10.878806114196777, -11.016419410705566, -9.821245193481445, -8.62225341796875, -8.031984329223633, -8.060951232910156, -8.111867904663086, -7.019913196563721, -7.171921730041504, -7.696488857269287, -6.950314044952393, -6.584095001220703, -6.743763446807861, -6.589921951293945, -5.764858245849609, -6.290728569030762, -7.085243225097656, -6.675422191619873, -7.027969837188721, -7.879950523376465, -7.357569694519043, -9.743582725524902, -7.880187034606934, -9.44912052154541, -6.189570426940918, -8.188533782958984, -9.6065034866333, -8.869124412536621, -9.768797874450684, -8.675341606140137, -9.865415573120117, -9.207805633544922, -9.229073524475098, -8.45655345916748, -7.451157569885254, -8.34891414642334, -9.577098846435547, -8.842363357543945, -8.446045875549316, -7.175088882446289, -6.155631065368652, -3.69390606880188, -7.115039825439453, -4.245141506195068, -7.362027168273926, -4.753052234649658, -4.148929119110107, -3.9790241718292236, -3.1413612365722656, -3.058279514312744, -3.158637046813965, -2.5449037551879883, -3.043797254562378, -2.577711820602417, -1.8986432552337646, -1.5608547925949097, -1.9159284830093384, -2.4124135971069336, -1.5208206176757812, -1.0641223192214966, -1.685828447341919, -0.5295946598052979, -1.9572499990463257, -1.2026833295822144, -1.8616576194763184, -1.974108338356018, -2.6862404346466064, 0.0, 0.0, 5.4249043464660645, -20.834758758544922, -0.0, -0.0, -13.630118370056152, -14.581775665283203, -13.514798164367676, -13.04251480102539, -11.646797180175781, -10.878806114196777, -11.016419410705566, -9.821245193481445, -8.62225341796875, -8.031984329223633, -8.060951232910156, -8.111867904663086, -7.019913196563721, -7.171921730041504, -7.696488857269287, -6.950314044952393, -6.584095001220703, -6.743763446807861, -6.589921951293945, -5.764858245849609, -6.290728569030762, -7.085243225097656, -6.675422191619873, -7.027969837188721, -7.879950523376465, -7.357569694519043, -9.743582725524902, -7.880187034606934, -9.44912052154541, -6.189570426940918, -8.188533782958984, -9.6065034866333, -8.869124412536621, -9.768797874450684, -8.675341606140137, -9.865415573120117, -9.207805633544922, -9.229073524475098, -8.45655345916748, -7.451157569885254, -8.34891414642334, -9.577098846435547, -8.842363357543945, -8.446045875549316, -7.175088882446289, -6.155631065368652, -3.69390606880188, -7.115039825439453, -4.245141506195068, -7.362027168273926, -4.753052234649658, -4.148929119110107, -3.9790241718292236, -3.1413612365722656, -3.058279514312744, -3.158637046813965, -2.5449037551879883, -3.043797254562378, -2.577711820602417, -1.8986432552337646, -1.5608547925949097, -1.9159284830093384, -2.4124135971069336, -1.5208206176757812, -1.0641223192214966, -1.685828447341919, -0.5295946598052979, -1.9572499990463257, -1.2026833295822144, -1.8616576194763184, -1.974108338356018, -2.6862404346466064, -0.0, 0.0, 5.4249043464660645], [-20.804649353027344, 0.0, 0.0, -15.893548965454102, -14.938284873962402, -13.957513809204102, -13.31217098236084, -12.156009674072266, -11.740070343017578, -10.489337921142578, -9.673250198364258, -9.262201309204102, -8.693103790283203, -8.243955612182617, -7.283290863037109, -8.359126091003418, -8.966537475585938, -7.416914939880371, -7.727806091308594, -8.283522605895996, -8.012868881225586, -8.13974380493164, -6.373948574066162, -7.382667541503906, -8.111763000488281, -5.770009994506836, -4.6904191970825195, -7.127857208251953, -8.567914962768555, -8.265388488769531, -9.223663330078125, -9.503029823303223, -10.749027252197266, -11.175682067871094, -10.896641731262207, -10.320759773254395, -10.25999927520752, -10.117084503173828, -10.674322128295898, -9.903868675231934, -10.517822265625, -10.539186477661133, -10.840347290039062, -10.36216926574707, -8.669462203979492, -8.391671180725098, -9.445311546325684, -9.202712059020996, -7.18960428237915, -8.065827369689941, -7.260493278503418, -6.819551944732666, -4.599581241607666, -5.365952014923096, -5.747353553771973, -5.539548397064209, -4.585211753845215, -3.3043019771575928, -3.6428916454315186, -3.4301440715789795, -3.6747753620147705, -2.993593454360962, -2.602012872695923, -3.3328921794891357, -2.85072922706604, -1.80077064037323, -1.654772162437439, -1.1562583446502686, -0.9288878440856934, -0.24837805330753326, 0.20239639282226562, -0.5797906517982483, -1.4315217733383179, -0.605923056602478, 0.0, 0.0, 5.046341896057129, 4.008628845214844, -20.804649353027344, -0.0, -0.0, -15.893548965454102, -14.938284873962402, -13.957513809204102, -13.31217098236084, -12.156009674072266, -11.740070343017578, -10.489337921142578, -9.673250198364258, -9.262201309204102, -8.693103790283203, -8.243955612182617, -7.283290863037109, -8.359126091003418, -8.966537475585938, -7.416914939880371, -7.727806091308594, -8.283522605895996, -8.012868881225586, -8.13974380493164, -6.373948574066162, -7.382667541503906, -8.111763000488281, -5.770009994506836, -4.6904191970825195, -7.127857208251953, -8.567914962768555, -8.265388488769531, -9.223663330078125, -9.503029823303223, -10.749027252197266, -11.175682067871094, -10.896641731262207, -10.320759773254395, -10.25999927520752, -10.117084503173828, -10.674322128295898, -9.903868675231934, -10.517822265625, -10.539186477661133, -10.840347290039062, -10.36216926574707, -8.669462203979492, -8.391671180725098, -9.445311546325684, -9.202712059020996, -7.18960428237915, -8.065827369689941, -7.260493278503418, -6.819551944732666, -4.599581241607666, -5.365952014923096, -5.747353553771973, -5.539548397064209, -4.585211753845215, -3.3043019771575928, -3.6428916454315186, -3.4301440715789795, -3.6747753620147705, -2.993593454360962, -2.602012872695923, -3.3328921794891357, -2.85072922706604, -1.80077064037323, -1.654772162437439, -1.1562583446502686, -0.9288878440856934, -0.24837805330753326, 0.20239639282226562, -0.5797906517982483, -1.4315217733383179, -0.605923056602478, -0.0, 0.0, 5.046341896057129, 4.008628845214844], [-19.845504760742188, 0.0, 0.0, 0.0, -14.880864143371582, -13.643176078796387, -13.723628044128418, -12.245616912841797, -11.27100944519043, -10.556503295898438, -9.401216506958008, -9.628815650939941, -8.676947593688965, -8.457107543945312, -7.308979511260986, -7.741448879241943, -7.869778633117676, -7.838258743286133, -7.643657207489014, -7.252959728240967, -7.284460544586182, -7.333984375, -7.830112457275391, -7.048778533935547, -8.495798110961914, -8.212065696716309, -4.318643093109131, -7.87290096282959, -10.748491287231445, -9.462359428405762, -10.472419738769531, -9.287979125976562, -9.328173637390137, -11.808599472045898, -12.184280395507812, -8.80201244354248, -10.996246337890625, -11.32299518585205, -10.082464218139648, -11.90189266204834, -12.2423095703125, -10.911531448364258, -11.221022605895996, -10.232132911682129, -10.286518096923828, -11.568730354309082, -8.2000732421875, -9.565901756286621, -9.481549263000488, -9.524599075317383, -8.980015754699707, -7.477795600891113, -8.74223804473877, -6.463090896606445, -5.089460372924805, -6.310153484344482, -3.7270419597625732, -4.5546040534973145, -6.563600540161133, -5.345404148101807, -3.5202903747558594, -3.614579439163208, -2.1438751220703125, -2.9655332565307617, -1.994473934173584, -2.309368133544922, -2.112819194793701, -1.8463917970657349, -1.4916020631790161, -1.4319227933883667, -2.667384147644043, -1.2597166299819946, -1.1640329360961914, 0.0, 0.0, 0.0, 2.6453583240509033, 6.7888078689575195, -19.845504760742188, -0.0, -0.0, -0.0, -14.880864143371582, -13.643176078796387, -13.723628044128418, -12.245616912841797, -11.27100944519043, -10.556503295898438, -9.401216506958008, -9.628815650939941, -8.676947593688965, -8.457107543945312, -7.308979511260986, -7.741448879241943, -7.869778633117676, -7.838258743286133, -7.643657207489014, -7.252959728240967, -7.284460544586182, -7.333984375, -7.830112457275391, -7.048778533935547, -8.495798110961914, -8.212065696716309, -4.318643093109131, -7.87290096282959, -10.748491287231445, -9.462359428405762, -10.472419738769531, -9.287979125976562, -9.328173637390137, -11.808599472045898, -12.184280395507812, -8.80201244354248, -10.996246337890625, -11.32299518585205, -10.082464218139648, -11.90189266204834, -12.2423095703125, -10.911531448364258, -11.221022605895996, -10.232132911682129, -10.286518096923828, -11.568730354309082, -8.2000732421875, -9.565901756286621, -9.481549263000488, -9.524599075317383, -8.980015754699707, -7.477795600891113, -8.74223804473877, -6.463090896606445, -5.089460372924805, -6.310153484344482, -3.7270419597625732, -4.5546040534973145, -6.563600540161133, -5.345404148101807, -3.5202903747558594, -3.614579439163208, -2.1438751220703125, -2.9655332565307617, -1.994473934173584, -2.309368133544922, -2.112819194793701, -1.8463917970657349, -1.4916020631790161, -1.4319227933883667, -2.667384147644043, -1.2597166299819946, -1.1640329360961914, -0.0, -0.0, 0.0, 2.6453583240509033, 6.7888078689575195], [-20.395851135253906, 0.0, 0.0, 0.0, -15.061933517456055, -14.783036231994629, -13.283702850341797, -11.567028045654297, -11.307955741882324, -10.736612319946289, -9.987874984741211, -9.374574661254883, -9.238231658935547, -8.801856994628906, -8.547739028930664, -7.880639553070068, -8.010917663574219, -8.141142845153809, -7.421689033508301, -8.575427055358887, -8.173011779785156, -8.352648735046387, -7.480500221252441, -8.787670135498047, -9.024621963500977, -9.175064086914062, -8.66826057434082, -8.649261474609375, -7.875072002410889, -9.00126838684082, -10.26127815246582, -8.249537467956543, -10.369009017944336, -11.932214736938477, -10.828757286071777, -11.918741226196289, -12.872931480407715, -12.995061874389648, -11.772697448730469, -13.18860912322998, -12.768879890441895, -12.719380378723145, -15.166033744812012, -12.071220397949219, -11.659765243530273, -13.711661338806152, -11.183862686157227, -9.460641860961914, -9.427992820739746, -9.458428382873535, -7.074788570404053, -8.4562349319458, -8.124123573303223, -5.064174652099609, -5.995391845703125, -6.403885364532471, -4.788479328155518, -4.55250883102417, -2.6975317001342773, -3.634383201599121, -5.827193260192871, -3.2949235439300537, -3.1335337162017822, -2.654266834259033, -1.817020058631897, -2.778724193572998, -2.5485637187957764, -2.848656177520752, -1.9001942873001099, -3.168581962585449, -2.4658679962158203, -1.821980357170105, -1.4492475986480713, 0.0, 0.0, 0.0, 5.275155067443848, 5.1830034255981445, -20.395851135253906, -0.0, -0.0, -0.0, -15.061933517456055, -14.783036231994629, -13.283702850341797, -11.567028045654297, -11.307955741882324, -10.736612319946289, -9.987874984741211, -9.374574661254883, -9.238231658935547, -8.801856994628906, -8.547739028930664, -7.880639553070068, -8.010917663574219, -8.141142845153809, -7.421689033508301, -8.575427055358887, -8.173011779785156, -8.352648735046387, -7.480500221252441, -8.787670135498047, -9.024621963500977, -9.175064086914062, -8.66826057434082, -8.649261474609375, -7.875072002410889, -9.00126838684082, -10.26127815246582, -8.249537467956543, -10.369009017944336, -11.932214736938477, -10.828757286071777, -11.918741226196289, -12.872931480407715, -12.995061874389648, -11.772697448730469, -13.18860912322998, -12.768879890441895, -12.719380378723145, -15.166033744812012, -12.071220397949219, -11.659765243530273, -13.711661338806152, -11.183862686157227, -9.460641860961914, -9.427992820739746, -9.458428382873535, -7.074788570404053, -8.4562349319458, -8.124123573303223, -5.064174652099609, -5.995391845703125, -6.403885364532471, -4.788479328155518, -4.55250883102417, -2.6975317001342773, -3.634383201599121, -5.827193260192871, -3.2949235439300537, -3.1335337162017822, -2.654266834259033, -1.817020058631897, -2.778724193572998, -2.5485637187957764, -2.848656177520752, -1.9001942873001099, -3.168581962585449, -2.4658679962158203, -1.821980357170105, -1.4492475986480713, -0.0, 0.0, 0.0, 5.275155067443848, 5.1830034255981445], [-20.166101455688477, 0.0, 0.0, 0.0, -15.175492286682129, -15.095091819763184, -13.186234474182129, -12.674734115600586, -11.018683433532715, -11.0678071975708, -10.033872604370117, -9.389755249023438, -8.715156555175781, -8.8018798828125, -8.699033737182617, -7.950292110443115, -8.8329496383667, -8.84019660949707, -8.030240058898926, -8.113303184509277, -8.600226402282715, -9.607621192932129, -7.905218124389648, -7.576524257659912, -9.03442668914795, -8.29763412475586, -11.5824556350708, -10.526118278503418, -8.879526138305664, -11.170160293579102, -10.146946907043457, -9.34069538116455, -12.374021530151367, -13.338085174560547, -11.628860473632812, -13.341158866882324, -13.792542457580566, -13.220486640930176, -14.838499069213867, -12.493646621704102, -13.472762107849121, -13.822041511535645, -13.821090698242188, -14.399117469787598, -12.78170108795166, -13.530570030212402, -11.88036060333252, -10.197237014770508, -11.034072875976562, -10.078929901123047, -9.617997169494629, -8.724356651306152, -8.679176330566406, -6.807601451873779, -6.137418270111084, -6.050617694854736, -5.061770439147949, -5.354049205780029, -5.179320812225342, -4.216126441955566, -3.9185245037078857, -3.2486584186553955, -4.0298752784729, -2.8565900325775146, -2.5734713077545166, -2.052119255065918, -1.7923961877822876, -1.9528290033340454, -2.5503270626068115, -3.349670171737671, -2.8976516723632812, -1.8111399412155151, -2.018115997314453, 0.0, 0.0, 0.0, 6.351909637451172, 3.307786464691162, -20.166101455688477, -0.0, -0.0, -0.0, -15.175492286682129, -15.095091819763184, -13.186234474182129, -12.674734115600586, -11.018683433532715, -11.0678071975708, -10.033872604370117, -9.389755249023438, -8.715156555175781, -8.8018798828125, -8.699033737182617, -7.950292110443115, -8.8329496383667, -8.84019660949707, -8.030240058898926, -8.113303184509277, -8.600226402282715, -9.607621192932129, -7.905218124389648, -7.576524257659912, -9.03442668914795, -8.29763412475586, -11.5824556350708, -10.526118278503418, -8.879526138305664, -11.170160293579102, -10.146946907043457, -9.34069538116455, -12.374021530151367, -13.338085174560547, -11.628860473632812, -13.341158866882324, -13.792542457580566, -13.220486640930176, -14.838499069213867, -12.493646621704102, -13.472762107849121, -13.822041511535645, -13.821090698242188, -14.399117469787598, -12.78170108795166, -13.530570030212402, -11.88036060333252, -10.197237014770508, -11.034072875976562, -10.078929901123047, -9.617997169494629, -8.724356651306152, -8.679176330566406, -6.807601451873779, -6.137418270111084, -6.050617694854736, -5.061770439147949, -5.354049205780029, -5.179320812225342, -4.216126441955566, -3.9185245037078857, -3.2486584186553955, -4.0298752784729, -2.8565900325775146, -2.5734713077545166, -2.052119255065918, -1.7923961877822876, -1.9528290033340454, -2.5503270626068115, -3.349670171737671, -2.8976516723632812, -1.8111399412155151, -2.018115997314453, -0.0, 0.0, 0.0, 6.351909637451172, 3.307786464691162], [-18.09317398071289, -19.615737915039062, 0.0, 0.0, 0.0, -16.345775604248047, -13.39858341217041, -11.722681999206543, -11.439712524414062, -10.604793548583984, -9.830833435058594, -8.581338882446289, -8.716554641723633, -9.194378852844238, -8.249088287353516, -8.415108680725098, -8.914739608764648, -9.169585227966309, -8.649027824401855, -8.695075035095215, -8.66238784790039, -8.707661628723145, -8.936152458190918, -9.217899322509766, -8.740870475769043, -10.48422908782959, -8.97697925567627, -10.250176429748535, -11.678211212158203, -10.308391571044922, -12.30120849609375, -11.66072940826416, -13.217891693115234, -14.595300674438477, -12.839449882507324, -14.173269271850586, -13.962512969970703, -16.82190704345703, -14.514389038085938, -15.65129280090332, -14.912934303283691, -16.462480545043945, -14.872363090515137, -14.338653564453125, -14.247016906738281, -14.326360702514648, -12.750304222106934, -11.447062492370605, -12.810416221618652, -10.432714462280273, -10.335495948791504, -10.485586166381836, -9.412596702575684, -9.42305850982666, -5.148007392883301, -7.80726432800293, -5.828222274780273, -5.906173229217529, -5.418068885803223, -4.151702404022217, -4.262513160705566, -3.4060933589935303, -3.322169542312622, -3.2605841159820557, -3.477480173110962, -2.270146369934082, -3.245582103729248, -2.329261302947998, -2.698040723800659, -3.3879222869873047, -2.9813547134399414, -2.0627853870391846, -1.4178462028503418, 0.0, 0.0, 0.0, 6.981841087341309, 5.3339948654174805, -18.09317398071289, -19.615737915039062, -0.0, -0.0, -0.0, -16.345775604248047, -13.39858341217041, -11.722681999206543, -11.439712524414062, -10.604793548583984, -9.830833435058594, -8.581338882446289, -8.716554641723633, -9.194378852844238, -8.249088287353516, -8.415108680725098, -8.914739608764648, -9.169585227966309, -8.649027824401855, -8.695075035095215, -8.66238784790039, -8.707661628723145, -8.936152458190918, -9.217899322509766, -8.740870475769043, -10.48422908782959, -8.97697925567627, -10.250176429748535, -11.678211212158203, -10.308391571044922, -12.30120849609375, -11.66072940826416, -13.217891693115234, -14.595300674438477, -12.839449882507324, -14.173269271850586, -13.962512969970703, -16.82190704345703, -14.514389038085938, -15.65129280090332, -14.912934303283691, -16.462480545043945, -14.872363090515137, -14.338653564453125, -14.247016906738281, -14.326360702514648, -12.750304222106934, -11.447062492370605, -12.810416221618652, -10.432714462280273, -10.335495948791504, -10.485586166381836, -9.412596702575684, -9.42305850982666, -5.148007392883301, -7.80726432800293, -5.828222274780273, -5.906173229217529, -5.418068885803223, -4.151702404022217, -4.262513160705566, -3.4060933589935303, -3.322169542312622, -3.2605841159820557, -3.477480173110962, -2.270146369934082, -3.245582103729248, -2.329261302947998, -2.698040723800659, -3.3879222869873047, -2.9813547134399414, -2.0627853870391846, -1.4178462028503418, -0.0, 0.0, 0.0, 6.981841087341309, 5.3339948654174805], [-20.622724533081055, -19.443971633911133, 0.0, 0.0, 0.0, -16.132339477539062, -13.772305488586426, -12.65595531463623, -11.583951950073242, -10.555992126464844, -9.940447807312012, -10.094465255737305, -9.667128562927246, -9.923216819763184, -9.108896255493164, -8.718977928161621, -8.917033195495605, -9.279102325439453, -8.95630931854248, -8.819048881530762, -9.373456001281738, -9.474584579467773, -9.304065704345703, -8.610955238342285, -9.646925926208496, -10.95954418182373, -9.370992660522461, -11.53223991394043, -10.628679275512695, -12.481795310974121, -13.17044448852539, -13.377246856689453, -13.558856010437012, -13.40000057220459, -13.99194622039795, -15.797943115234375, -14.938093185424805, -15.921124458312988, -15.058160781860352, -17.41615867614746, -16.107711791992188, -13.861176490783691, -15.925248146057129, -16.075010299682617, -14.954607009887695, -14.8101224899292, -14.170196533203125, -13.216428756713867, -11.112153053283691, -12.525409698486328, -10.931163787841797, -12.952666282653809, -9.036136627197266, -6.76800537109375, -6.878011226654053, -7.4621968269348145, -6.946766376495361, -5.839781761169434, -5.808034896850586, -5.400731086730957, -4.0659499168396, -3.3539512157440186, -3.9855449199676514, -3.5174710750579834, -3.75016450881958, -3.452601909637451, -3.4856619834899902, -3.3131844997406006, -3.1290457248687744, -3.7099740505218506, -2.3641912937164307, -1.2612910270690918, 0.0, 0.0, 0.0, 4.626785755157471, 4.373625755310059, 5.266486644744873, -20.622724533081055, -19.443971633911133, -0.0, -0.0, -0.0, -16.132339477539062, -13.772305488586426, -12.65595531463623, -11.583951950073242, -10.555992126464844, -9.940447807312012, -10.094465255737305, -9.667128562927246, -9.923216819763184, -9.108896255493164, -8.718977928161621, -8.917033195495605, -9.279102325439453, -8.95630931854248, -8.819048881530762, -9.373456001281738, -9.474584579467773, -9.304065704345703, -8.610955238342285, -9.646925926208496, -10.95954418182373, -9.370992660522461, -11.53223991394043, -10.628679275512695, -12.481795310974121, -13.17044448852539, -13.377246856689453, -13.558856010437012, -13.40000057220459, -13.99194622039795, -15.797943115234375, -14.938093185424805, -15.921124458312988, -15.058160781860352, -17.41615867614746, -16.107711791992188, -13.861176490783691, -15.925248146057129, -16.075010299682617, -14.954607009887695, -14.8101224899292, -14.170196533203125, -13.216428756713867, -11.112153053283691, -12.525409698486328, -10.931163787841797, -12.952666282653809, -9.036136627197266, -6.76800537109375, -6.878011226654053, -7.4621968269348145, -6.946766376495361, -5.839781761169434, -5.808034896850586, -5.400731086730957, -4.0659499168396, -3.3539512157440186, -3.9855449199676514, -3.5174710750579834, -3.75016450881958, -3.452601909637451, -3.4856619834899902, -3.3131844997406006, -3.1290457248687744, -3.7099740505218506, -2.3641912937164307, -1.2612910270690918, -0.0, -0.0, 0.0, 4.626785755157471, 4.373625755310059, 5.266486644744873], [-20.32451629638672, -19.71207618713379, -19.246984481811523, 0.0, 0.0, -16.375898361206055, -14.01830005645752, -13.555974006652832, -11.859986305236816, -10.696434020996094, -10.117950439453125, -9.807783126831055, -9.17116928100586, -9.44216537475586, -9.777366638183594, -8.928034782409668, -8.90758228302002, -9.613764762878418, -8.897011756896973, -8.815878868103027, -9.596296310424805, -9.332122802734375, -8.6455717086792, -9.417232513427734, -9.767435073852539, -11.549939155578613, -11.545780181884766, -10.461955070495605, -11.688419342041016, -13.24924373626709, -13.234231948852539, -14.280889511108398, -15.178686141967773, -14.871999740600586, -15.45608139038086, -16.55373191833496, -15.282474517822266, -17.164108276367188, -18.4952392578125, -16.38552474975586, -17.319272994995117, -17.037574768066406, -17.39512062072754, -16.05280876159668, -16.159374237060547, -15.618749618530273, -14.173099517822266, -14.237469673156738, -14.016130447387695, -11.898165702819824, -13.110589981079102, -11.538923263549805, -10.738451957702637, -9.397493362426758, -8.919963836669922, -7.820169925689697, -6.783720970153809, -6.183890342712402, -6.584774971008301, -5.810789108276367, -4.323470115661621, -4.995070934295654, -5.504363059997559, -3.9926135540008545, -3.6172358989715576, -3.0830979347229004, -3.803417921066284, -3.339390993118286, -2.9610507488250732, -3.021073341369629, -1.9789063930511475, 0.3306839168071747, 0.0, 0.0, 0.0, 2.391305923461914, 3.5731430053710938, 3.7788634300231934, -20.32451629638672, -19.71207618713379, -19.246984481811523, -0.0, -0.0, -16.375898361206055, -14.01830005645752, -13.555974006652832, -11.859986305236816, -10.696434020996094, -10.117950439453125, -9.807783126831055, -9.17116928100586, -9.44216537475586, -9.777366638183594, -8.928034782409668, -8.90758228302002, -9.613764762878418, -8.897011756896973, -8.815878868103027, -9.596296310424805, -9.332122802734375, -8.6455717086792, -9.417232513427734, -9.767435073852539, -11.549939155578613, -11.545780181884766, -10.461955070495605, -11.688419342041016, -13.24924373626709, -13.234231948852539, -14.280889511108398, -15.178686141967773, -14.871999740600586, -15.45608139038086, -16.55373191833496, -15.282474517822266, -17.164108276367188, -18.4952392578125, -16.38552474975586, -17.319272994995117, -17.037574768066406, -17.39512062072754, -16.05280876159668, -16.159374237060547, -15.618749618530273, -14.173099517822266, -14.237469673156738, -14.016130447387695, -11.898165702819824, -13.110589981079102, -11.538923263549805, -10.738451957702637, -9.397493362426758, -8.919963836669922, -7.820169925689697, -6.783720970153809, -6.183890342712402, -6.584774971008301, -5.810789108276367, -4.323470115661621, -4.995070934295654, -5.504363059997559, -3.9926135540008545, -3.6172358989715576, -3.0830979347229004, -3.803417921066284, -3.339390993118286, -2.9610507488250732, -3.021073341369629, -1.9789063930511475, 0.3306839168071747, 0.0, 0.0, 0.0, 2.391305923461914, 3.5731430053710938, 3.7788634300231934], [-20.083053588867188, -19.1313533782959, -17.68968963623047, 0.0, 0.0, 0.0, 0.0, -15.040660858154297, -11.365097045898438, -10.444016456604004, -10.404354095458984, -10.202178955078125, -9.966075897216797, -10.129012107849121, -9.933053016662598, -9.292930603027344, -8.816631317138672, -9.162664413452148, -9.529268264770508, -9.954035758972168, -10.283308029174805, -10.085456848144531, -9.51633358001709, -9.841879844665527, -12.325798988342285, -10.922327995300293, -11.62869930267334, -11.479549407958984, -13.104588508605957, -12.985064506530762, -13.174047470092773, -14.893109321594238, -15.079547882080078, -16.055034637451172, -16.97429847717285, -18.186092376708984, -17.790124893188477, -18.571849822998047, -18.892122268676758, -17.59627342224121, -17.84086799621582, -18.33075714111328, -18.013843536376953, -20.362272262573242, -16.7515869140625, -16.181201934814453, -15.908598899841309, -14.446179389953613, -14.46575927734375, -14.542891502380371, -13.018132209777832, -11.308698654174805, -11.17457389831543, -7.829868316650391, -9.311941146850586, -7.781530380249023, -7.478572368621826, -7.5239057540893555, -7.015408992767334, -6.740143299102783, -5.84886360168457, -5.224820137023926, -4.6451029777526855, -4.112891674041748, -3.627065896987915, -3.558847188949585, -2.906925916671753, -2.6934642791748047, -2.8030261993408203, -2.1927900314331055, -1.9930121898651123, -1.5494524240493774, 0.0, 0.0, 0.0, 3.652250289916992, 4.693239688873291, 3.549318790435791, -20.083053588867188, -19.1313533782959, -17.68968963623047, -0.0, -0.0, -0.0, -0.0, -15.040660858154297, -11.365097045898438, -10.444016456604004, -10.404354095458984, -10.202178955078125, -9.966075897216797, -10.129012107849121, -9.933053016662598, -9.292930603027344, -8.816631317138672, -9.162664413452148, -9.529268264770508, -9.954035758972168, -10.283308029174805, -10.085456848144531, -9.51633358001709, -9.841879844665527, -12.325798988342285, -10.922327995300293, -11.62869930267334, -11.479549407958984, -13.104588508605957, -12.985064506530762, -13.174047470092773, -14.893109321594238, -15.079547882080078, -16.055034637451172, -16.97429847717285, -18.186092376708984, -17.790124893188477, -18.571849822998047, -18.892122268676758, -17.59627342224121, -17.84086799621582, -18.33075714111328, -18.013843536376953, -20.362272262573242, -16.7515869140625, -16.181201934814453, -15.908598899841309, -14.446179389953613, -14.46575927734375, -14.542891502380371, -13.018132209777832, -11.308698654174805, -11.17457389831543, -7.829868316650391, -9.311941146850586, -7.781530380249023, -7.478572368621826, -7.5239057540893555, -7.015408992767334, -6.740143299102783, -5.84886360168457, -5.224820137023926, -4.6451029777526855, -4.112891674041748, -3.627065896987915, -3.558847188949585, -2.906925916671753, -2.6934642791748047, -2.8030261993408203, -2.1927900314331055, -1.9930121898651123, -1.5494524240493774, -0.0, 0.0, 0.0, 3.652250289916992, 4.693239688873291, 3.549318790435791], [-19.676862716674805, -18.944141387939453, -18.640625, -18.180418014526367, 0.0, 0.0, -15.395478248596191, -13.225242614746094, -11.554128646850586, -10.52068042755127, -10.755546569824219, -10.162440299987793, -9.979506492614746, -10.521029472351074, -9.39885139465332, -9.332010269165039, -10.208026885986328, -9.904637336730957, -9.456184387207031, -9.566981315612793, -10.235363006591797, -10.493796348571777, -10.175299644470215, -11.1146879196167, -11.623098373413086, -11.628076553344727, -12.49212646484375, -14.1226806640625, -14.442744255065918, -14.314581871032715, -14.925896644592285, -15.982933044433594, -15.922465324401855, -17.765235900878906, -18.247657775878906, -18.08783531188965, -18.932619094848633, -18.961257934570312, -19.885953903198242, -20.691078186035156, -19.73430061340332, -17.048547744750977, -19.515155792236328, -20.06838035583496, -18.649860382080078, -17.975971221923828, -16.40802574157715, -16.407346725463867, -15.15927505493164, -15.598222732543945, -13.840770721435547, -13.160026550292969, -12.112850189208984, -10.265536308288574, -10.658551216125488, -8.989579200744629, -7.795908451080322, -7.557968616485596, -6.821214199066162, -7.396075248718262, -5.4133453369140625, -5.882142543792725, -5.2393999099731445, -4.045820713043213, -4.932751178741455, -2.682753324508667, -2.8699893951416016, -2.697495460510254, -2.492175579071045, -2.2739248275756836, -0.22389915585517883, -0.2145037204027176, 0.0, 0.0, 2.681678533554077, 3.243664503097534, 3.9596993923187256, 3.5045502185821533, -19.676862716674805, -18.944141387939453, -18.640625, -18.180418014526367, -0.0, -0.0, -15.395478248596191, -13.225242614746094, -11.554128646850586, -10.52068042755127, -10.755546569824219, -10.162440299987793, -9.979506492614746, -10.521029472351074, -9.39885139465332, -9.332010269165039, -10.208026885986328, -9.904637336730957, -9.456184387207031, -9.566981315612793, -10.235363006591797, -10.493796348571777, -10.175299644470215, -11.1146879196167, -11.623098373413086, -11.628076553344727, -12.49212646484375, -14.1226806640625, -14.442744255065918, -14.314581871032715, -14.925896644592285, -15.982933044433594, -15.922465324401855, -17.765235900878906, -18.247657775878906, -18.08783531188965, -18.932619094848633, -18.961257934570312, -19.885953903198242, -20.691078186035156, -19.73430061340332, -17.048547744750977, -19.515155792236328, -20.06838035583496, -18.649860382080078, -17.975971221923828, -16.40802574157715, -16.407346725463867, -15.15927505493164, -15.598222732543945, -13.840770721435547, -13.160026550292969, -12.112850189208984, -10.265536308288574, -10.658551216125488, -8.989579200744629, -7.795908451080322, -7.557968616485596, -6.821214199066162, -7.396075248718262, -5.4133453369140625, -5.882142543792725, -5.2393999099731445, -4.045820713043213, -4.932751178741455, -2.682753324508667, -2.8699893951416016, -2.697495460510254, -2.492175579071045, -2.2739248275756836, -0.22389915585517883, -0.2145037204027176, -0.0, 0.0, 2.681678533554077, 3.243664503097534, 3.9596993923187256, 3.5045502185821533], [-19.924396514892578, -19.218130111694336, -18.81846809387207, -17.405254364013672, 0.0, 0.0, -13.724647521972656, 0.0, -12.84589672088623, -12.41498851776123, -11.77155590057373, -10.985129356384277, -10.138677597045898, -10.235265731811523, -9.76662826538086, -9.978716850280762, -11.0529203414917, -10.446783065795898, -10.172419548034668, -9.94176197052002, -10.05234146118164, -10.559906005859375, -11.587662696838379, -10.58283519744873, -12.11686897277832, -12.127774238586426, -13.256570816040039, -13.125332832336426, -14.053699493408203, -13.148283958435059, -15.75030517578125, -16.189453125, -17.109661102294922, -17.180633544921875, -18.43536949157715, -20.99216079711914, -20.297704696655273, -21.801902770996094, -19.988391876220703, 0.0, -20.294273376464844, -21.0468692779541, -19.98785972595215, -20.5072021484375, -17.87786293029785, -18.853656768798828, -18.08366584777832, -17.0572452545166, -15.954328536987305, -14.640833854675293, -14.436036109924316, -14.212300300598145, -11.996835708618164, -11.495152473449707, -8.042779922485352, -9.526803970336914, -7.866849422454834, -8.119742393493652, -6.881917953491211, -6.888097763061523, -6.880516529083252, -5.972257137298584, -4.954865455627441, -4.870791435241699, -3.980083465576172, -3.782264471054077, -2.90006160736084, -4.2003374099731445, -2.3715004920959473, -2.592236280441284, -1.0445427894592285, -0.38230276107788086, 0.0, 0.0, 3.593407392501831, 3.3482301235198975, 3.039748191833496, 2.1217942237854004, -19.924396514892578, -19.218130111694336, -18.81846809387207, -17.405254364013672, -0.0, -0.0, -13.724647521972656, -0.0, -12.84589672088623, -12.41498851776123, -11.77155590057373, -10.985129356384277, -10.138677597045898, -10.235265731811523, -9.76662826538086, -9.978716850280762, -11.0529203414917, -10.446783065795898, -10.172419548034668, -9.94176197052002, -10.05234146118164, -10.559906005859375, -11.587662696838379, -10.58283519744873, -12.11686897277832, -12.127774238586426, -13.256570816040039, -13.125332832336426, -14.053699493408203, -13.148283958435059, -15.75030517578125, -16.189453125, -17.109661102294922, -17.180633544921875, -18.43536949157715, -20.99216079711914, -20.297704696655273, -21.801902770996094, -19.988391876220703, -0.0, -20.294273376464844, -21.0468692779541, -19.98785972595215, -20.5072021484375, -17.87786293029785, -18.853656768798828, -18.08366584777832, -17.0572452545166, -15.954328536987305, -14.640833854675293, -14.436036109924316, -14.212300300598145, -11.996835708618164, -11.495152473449707, -8.042779922485352, -9.526803970336914, -7.866849422454834, -8.119742393493652, -6.881917953491211, -6.888097763061523, -6.880516529083252, -5.972257137298584, -4.954865455627441, -4.870791435241699, -3.980083465576172, -3.782264471054077, -2.90006160736084, -4.2003374099731445, -2.3715004920959473, -2.592236280441284, -1.0445427894592285, -0.38230276107788086, -0.0, 0.0, 3.593407392501831, 3.3482301235198975, 3.039748191833496, 2.1217942237854004], [-20.331392288208008, -19.105228424072266, -17.96392250061035, -17.30013084411621, 0.0, 0.0, 0.0, 0.0, -15.281230926513672, -10.830693244934082, -12.99923038482666, -12.160578727722168, -11.839567184448242, -11.558892250061035, -11.05867862701416, -10.566640853881836, -10.13638973236084, -11.750460624694824, -10.808460235595703, -10.587752342224121, -11.120962142944336, -11.746801376342773, -12.163463592529297, -12.700484275817871, -11.972352981567383, -12.029669761657715, -13.790185928344727, -12.839509963989258, -14.408387184143066, -16.141801834106445, -15.749030113220215, -17.8178768157959, -20.358665466308594, -18.1372127532959, -19.53348159790039, -18.87485694885254, -22.0977783203125, -22.644906997680664, -22.590923309326172, -21.5252628326416, -20.733875274658203, -22.04741096496582, -21.283510208129883, -21.484350204467773, -20.401844024658203, -20.413137435913086, -18.422748565673828, -18.808713912963867, -17.516733169555664, -15.64770793914795, -16.165922164916992, -14.435768127441406, -14.720401763916016, -12.831945419311523, -11.599373817443848, -10.418889999389648, -9.499391555786133, -9.236761093139648, -9.098474502563477, -7.053439140319824, -6.958908557891846, -6.168003082275391, -5.123323917388916, -3.909968137741089, -4.144504547119141, -3.7233169078826904, -3.8964998722076416, -2.218031406402588, -2.3872029781341553, -2.0349555015563965, -0.9482641220092773, -1.7450611591339111, 0.0, 0.0, 4.536397457122803, 4.634853363037109, 3.4762625694274902, 3.823741912841797, -20.331392288208008, -19.105228424072266, -17.96392250061035, -17.30013084411621, -0.0, -0.0, -0.0, -0.0, -15.281230926513672, -10.830693244934082, -12.99923038482666, -12.160578727722168, -11.839567184448242, -11.558892250061035, -11.05867862701416, -10.566640853881836, -10.13638973236084, -11.750460624694824, -10.808460235595703, -10.587752342224121, -11.120962142944336, -11.746801376342773, -12.163463592529297, -12.700484275817871, -11.972352981567383, -12.029669761657715, -13.790185928344727, -12.839509963989258, -14.408387184143066, -16.141801834106445, -15.749030113220215, -17.8178768157959, -20.358665466308594, -18.1372127532959, -19.53348159790039, -18.87485694885254, -22.0977783203125, -22.644906997680664, -22.590923309326172, -21.5252628326416, -20.733875274658203, -22.04741096496582, -21.283510208129883, -21.484350204467773, -20.401844024658203, -20.413137435913086, -18.422748565673828, -18.808713912963867, -17.516733169555664, -15.64770793914795, -16.165922164916992, -14.435768127441406, -14.720401763916016, -12.831945419311523, -11.599373817443848, -10.418889999389648, -9.499391555786133, -9.236761093139648, -9.098474502563477, -7.053439140319824, -6.958908557891846, -6.168003082275391, -5.123323917388916, -3.909968137741089, -4.144504547119141, -3.7233169078826904, -3.8964998722076416, -2.218031406402588, -2.3872029781341553, -2.0349555015563965, -0.9482641220092773, -1.7450611591339111, -0.0, 0.0, 4.536397457122803, 4.634853363037109, 3.4762625694274902, 3.823741912841797], [-20.861068725585938, -19.1977596282959, -16.437997817993164, -17.16485023498535, -17.01749610900879, 0.0, 0.0, 0.0, -16.615787506103516, -16.454435348510742, -14.59811782836914, -13.035895347595215, -12.215422630310059, -12.020310401916504, -11.14546012878418, -11.394015312194824, -10.987624168395996, -10.903831481933594, -10.640798568725586, -10.685425758361816, -11.339883804321289, -11.164813995361328, -12.441635131835938, -12.19785213470459, -13.171457290649414, -13.801332473754883, -14.330230712890625, -15.047932624816895, -16.219823837280273, -16.130725860595703, -17.898422241210938, -17.68528175354004, -19.842241287231445, -20.332460403442383, -18.353689193725586, -22.330020904541016, -22.633319854736328, -22.376136779785156, -22.940114974975586, -22.770763397216797, -23.375272750854492, -22.80799102783203, -22.51111602783203, -23.961946487426758, -20.81936264038086, -20.240921020507812, -19.871946334838867, -20.013574600219727, -18.562118530273438, -19.862337112426758, -15.58654499053955, -15.263341903686523, -14.564180374145508, -13.486820220947266, -11.648137092590332, -10.913044929504395, -9.292854309082031, -8.803257942199707, -7.2017598152160645, -7.397525310516357, -6.3948893547058105, -7.219433307647705, -5.110896587371826, -7.738142013549805, -3.8078677654266357, -3.9125092029571533, -3.629225015640259, -2.7087562084198, -2.456089496612549, -2.279514789581299, -1.8164472579956055, -0.5293848514556885, 0.0, 6.763725280761719, 3.889939069747925, 3.951901435852051, 3.460947275161743, 4.01029109954834, -20.861068725585938, -19.1977596282959, -16.437997817993164, -17.16485023498535, -17.01749610900879, -0.0, -0.0, -0.0, -16.615787506103516, -16.454435348510742, -14.59811782836914, -13.035895347595215, -12.215422630310059, -12.020310401916504, -11.14546012878418, -11.394015312194824, -10.987624168395996, -10.903831481933594, -10.640798568725586, -10.685425758361816, -11.339883804321289, -11.164813995361328, -12.441635131835938, -12.19785213470459, -13.171457290649414, -13.801332473754883, -14.330230712890625, -15.047932624816895, -16.219823837280273, -16.130725860595703, -17.898422241210938, -17.68528175354004, -19.842241287231445, -20.332460403442383, -18.353689193725586, -22.330020904541016, -22.633319854736328, -22.376136779785156, -22.940114974975586, -22.770763397216797, -23.375272750854492, -22.80799102783203, -22.51111602783203, -23.961946487426758, -20.81936264038086, -20.240921020507812, -19.871946334838867, -20.013574600219727, -18.562118530273438, -19.862337112426758, -15.58654499053955, -15.263341903686523, -14.564180374145508, -13.486820220947266, -11.648137092590332, -10.913044929504395, -9.292854309082031, -8.803257942199707, -7.2017598152160645, -7.397525310516357, -6.3948893547058105, -7.219433307647705, -5.110896587371826, -7.738142013549805, -3.8078677654266357, -3.9125092029571533, -3.629225015640259, -2.7087562084198, -2.456089496612549, -2.279514789581299, -1.8164472579956055, -0.5293848514556885, 0.0, 6.763725280761719, 3.889939069747925, 3.951901435852051, 3.460947275161743, 4.01029109954834], [-19.366735458374023, -18.29741859436035, -18.238950729370117, -16.1523494720459, -16.747575759887695, -15.402913093566895, 0.0, 0.0, -16.174461364746094, 0.0, -11.13308334350586, -14.324596405029297, -13.639001846313477, -13.32889461517334, -11.70918083190918, -11.972887992858887, -11.838644981384277, -11.673766136169434, -11.84323501586914, -10.47482681274414, -12.486190795898438, -12.038603782653809, -13.3463773727417, -12.245604515075684, -12.877482414245605, -15.3720121383667, -14.288312911987305, -15.29433536529541, -15.628138542175293, -16.532695770263672, -18.124380111694336, -19.260234832763672, -20.687646865844727, -22.015331268310547, -22.267301559448242, -22.65525245666504, -23.604509353637695, -23.78833770751953, -24.087976455688477, -24.441783905029297, -24.78375244140625, -24.727832794189453, -24.7620906829834, -23.614511489868164, -22.39691925048828, -22.54865074157715, -20.659120559692383, -19.665128707885742, -18.63819122314453, -18.58301544189453, -16.95417594909668, -15.333916664123535, -16.009872436523438, -14.18517017364502, -12.224849700927734, -11.717862129211426, -8.784502983093262, -8.39148235321045, -8.639272689819336, -7.382397174835205, -7.000764846801758, -6.3484649658203125, -5.839018821716309, -5.3066725730896, -5.334957599639893, -4.204091548919678, -3.797811985015869, -3.4951367378234863, -2.7374749183654785, -2.6286187171936035, -2.0052921772003174, 0.0, 0.0, 4.894347190856934, 4.1099162101745605, 4.312796592712402, 3.508226156234741, 0.0, -19.366735458374023, -18.29741859436035, -18.238950729370117, -16.1523494720459, -16.747575759887695, -15.402913093566895, -0.0, -0.0, -16.174461364746094, -0.0, -11.13308334350586, -14.324596405029297, -13.639001846313477, -13.32889461517334, -11.70918083190918, -11.972887992858887, -11.838644981384277, -11.673766136169434, -11.84323501586914, -10.47482681274414, -12.486190795898438, -12.038603782653809, -13.3463773727417, -12.245604515075684, -12.877482414245605, -15.3720121383667, -14.288312911987305, -15.29433536529541, -15.628138542175293, -16.532695770263672, -18.124380111694336, -19.260234832763672, -20.687646865844727, -22.015331268310547, -22.267301559448242, -22.65525245666504, -23.604509353637695, -23.78833770751953, -24.087976455688477, -24.441783905029297, -24.78375244140625, -24.727832794189453, -24.7620906829834, -23.614511489868164, -22.39691925048828, -22.54865074157715, -20.659120559692383, -19.665128707885742, -18.63819122314453, -18.58301544189453, -16.95417594909668, -15.333916664123535, -16.009872436523438, -14.18517017364502, -12.224849700927734, -11.717862129211426, -8.784502983093262, -8.39148235321045, -8.639272689819336, -7.382397174835205, -7.000764846801758, -6.3484649658203125, -5.839018821716309, -5.3066725730896, -5.334957599639893, -4.204091548919678, -3.797811985015869, -3.4951367378234863, -2.7374749183654785, -2.6286187171936035, -2.0052921772003174, -0.0, 0.0, 4.894347190856934, 4.1099162101745605, 4.312796592712402, 3.508226156234741, 0.0], [-16.19051742553711, -18.524063110351562, -17.401527404785156, -16.939836502075195, -16.151805877685547, -15.6185941696167, -14.457409858703613, 0.0, 0.0, 0.0, 0.0, -15.758909225463867, -15.824786186218262, -13.473917007446289, -12.346810340881348, -12.174023628234863, -11.062012672424316, -12.307238578796387, -13.102821350097656, -14.863856315612793, -11.50973892211914, -12.957015037536621, -12.234230995178223, -14.229841232299805, -17.212697982788086, -14.431257247924805, -15.321183204650879, -14.95848560333252, -17.60708999633789, -17.300880432128906, -19.12569236755371, -20.1275634765625, -20.684865951538086, -20.98418617248535, -22.504283905029297, -24.444190979003906, -24.24679183959961, -24.9632511138916, -26.130298614501953, -25.357349395751953, -25.107465744018555, -26.00356674194336, -25.590564727783203, -24.33841323852539, -23.458797454833984, -23.862293243408203, -21.401899337768555, -21.32431983947754, -19.602684020996094, -21.83485221862793, -16.92124366760254, -13.627318382263184, -14.808627128601074, -14.86559009552002, -12.452303886413574, -11.957131385803223, -10.360628128051758, -9.834663391113281, -8.364522933959961, -7.010941505432129, -7.092716693878174, -7.488507270812988, -6.0168304443359375, -5.206664562225342, -5.144011497497559, -3.909907341003418, -3.9443233013153076, -4.043802738189697, -3.5561206340789795, -2.1400303840637207, -1.5410524606704712, 0.0, 6.414637088775635, 4.763968467712402, 4.220221519470215, 2.9321389198303223, 4.13740348815918, 3.662008047103882, -16.19051742553711, -18.524063110351562, -17.401527404785156, -16.939836502075195, -16.151805877685547, -15.6185941696167, -14.457409858703613, -0.0, -0.0, -0.0, -0.0, -15.758909225463867, -15.824786186218262, -13.473917007446289, -12.346810340881348, -12.174023628234863, -11.062012672424316, -12.307238578796387, -13.102821350097656, -14.863856315612793, -11.50973892211914, -12.957015037536621, -12.234230995178223, -14.229841232299805, -17.212697982788086, -14.431257247924805, -15.321183204650879, -14.95848560333252, -17.60708999633789, -17.300880432128906, -19.12569236755371, -20.1275634765625, -20.684865951538086, -20.98418617248535, -22.504283905029297, -24.444190979003906, -24.24679183959961, -24.9632511138916, -26.130298614501953, -25.357349395751953, -25.107465744018555, -26.00356674194336, -25.590564727783203, -24.33841323852539, -23.458797454833984, -23.862293243408203, -21.401899337768555, -21.32431983947754, -19.602684020996094, -21.83485221862793, -16.92124366760254, -13.627318382263184, -14.808627128601074, -14.86559009552002, -12.452303886413574, -11.957131385803223, -10.360628128051758, -9.834663391113281, -8.364522933959961, -7.010941505432129, -7.092716693878174, -7.488507270812988, -6.0168304443359375, -5.206664562225342, -5.144011497497559, -3.909907341003418, -3.9443233013153076, -4.043802738189697, -3.5561206340789795, -2.1400303840637207, -1.5410524606704712, 0.0, 6.414637088775635, 4.763968467712402, 4.220221519470215, 2.9321389198303223, 4.13740348815918, 3.662008047103882], [0.0, -18.55939483642578, -17.270570755004883, -16.80084800720215, -15.671746253967285, -15.149297714233398, -13.848353385925293, -12.058701515197754, 0.0, 0.0, -11.5834321975708, 0.0, -10.586933135986328, -10.251945495605469, -11.77492904663086, -11.945592880249023, -11.619762420654297, -11.91860294342041, -13.683442115783691, -12.339279174804688, -12.29503345489502, -13.974566459655762, -12.27072525024414, -12.371891975402832, -15.261619567871094, -14.686318397521973, -15.327645301818848, -17.042587280273438, -18.454017639160156, -19.149810791015625, -18.817790985107422, -20.856882095336914, -20.076499938964844, -23.461641311645508, -23.97325897216797, -24.374940872192383, -25.09294319152832, -25.715837478637695, -26.23965072631836, -26.475053787231445, -25.526926040649414, -25.031288146972656, -26.399444580078125, -25.72606658935547, -25.932832717895508, -24.05708885192871, -21.77019500732422, -22.79070472717285, -19.657989501953125, -19.489768981933594, -18.494237899780273, -16.915311813354492, -14.964966773986816, -14.305617332458496, -13.734599113464355, -12.657157897949219, -10.318243980407715, -9.886128425598145, -9.878417015075684, -8.042210578918457, -7.774493217468262, -7.296628475189209, -6.446403980255127, -6.200563430786133, -5.145999431610107, -5.088726043701172, -4.8743767738342285, -4.639257907867432, -5.611947059631348, -2.865772008895874, -2.679999589920044, 0.0, 3.5459020137786865, 4.635636329650879, 3.8679251670837402, 4.6626458168029785, 0.0, 0.21694394946098328, -0.0, -18.55939483642578, -17.270570755004883, -16.80084800720215, -15.671746253967285, -15.149297714233398, -13.848353385925293, -12.058701515197754, -0.0, -0.0, -11.5834321975708, -0.0, -10.586933135986328, -10.251945495605469, -11.77492904663086, -11.945592880249023, -11.619762420654297, -11.91860294342041, -13.683442115783691, -12.339279174804688, -12.29503345489502, -13.974566459655762, -12.27072525024414, -12.371891975402832, -15.261619567871094, -14.686318397521973, -15.327645301818848, -17.042587280273438, -18.454017639160156, -19.149810791015625, -18.817790985107422, -20.856882095336914, -20.076499938964844, -23.461641311645508, -23.97325897216797, -24.374940872192383, -25.09294319152832, -25.715837478637695, -26.23965072631836, -26.475053787231445, -25.526926040649414, -25.031288146972656, -26.399444580078125, -25.72606658935547, -25.932832717895508, -24.05708885192871, -21.77019500732422, -22.79070472717285, -19.657989501953125, -19.489768981933594, -18.494237899780273, -16.915311813354492, -14.964966773986816, -14.305617332458496, -13.734599113464355, -12.657157897949219, -10.318243980407715, -9.886128425598145, -9.878417015075684, -8.042210578918457, -7.774493217468262, -7.296628475189209, -6.446403980255127, -6.200563430786133, -5.145999431610107, -5.088726043701172, -4.8743767738342285, -4.639257907867432, -5.611947059631348, -2.865772008895874, -2.679999589920044, 0.0, 3.5459020137786865, 4.635636329650879, 3.8679251670837402, 4.6626458168029785, 0.0, 0.21694394946098328], [-20.006311416625977, 0.0, -18.095300674438477, -16.710983276367188, -14.77990436553955, -14.687837600708008, -13.239901542663574, -11.86423110961914, -11.28846263885498, 0.0, -11.086384773254395, 0.0, -11.471824645996094, -10.461091041564941, -9.98299503326416, -9.836217880249023, -11.972277641296387, -11.187491416931152, -11.857288360595703, -12.922049522399902, -12.813797950744629, -13.376636505126953, -12.730195045471191, -14.93480110168457, -14.99672794342041, -15.349507331848145, -17.323610305786133, -18.16119956970215, -18.34326934814453, -19.499040603637695, -20.243356704711914, -20.29413414001465, -21.684263229370117, -22.123777389526367, -23.415056228637695, -25.152402877807617, -25.855350494384766, -26.47032928466797, -26.587465286254883, -26.773366928100586, -27.389209747314453, -26.402936935424805, -26.494565963745117, -25.631967544555664, -25.388093948364258, -25.288084030151367, -21.53117561340332, -24.127578735351562, -22.239242553710938, -20.530174255371094, -18.88735580444336, -19.4386043548584, -17.122642517089844, -15.428943634033203, -13.436606407165527, -13.421516418457031, -11.74304485321045, -10.255184173583984, -8.323507308959961, -7.801982879638672, -7.133086681365967, -6.9776740074157715, -6.218623161315918, -6.271812915802002, -6.046889781951904, -5.675467014312744, -5.008995532989502, -4.165709018707275, -3.0805513858795166, -4.268179416656494, 0.0, 0.0, 2.0732884407043457, 2.92814040184021, 2.332737922668457, 1.0411485433578491, 0.0, 1.8690168857574463, -20.006311416625977, -0.0, -18.095300674438477, -16.710983276367188, -14.77990436553955, -14.687837600708008, -13.239901542663574, -11.86423110961914, -11.28846263885498, -0.0, -11.086384773254395, -0.0, -11.471824645996094, -10.461091041564941, -9.98299503326416, -9.836217880249023, -11.972277641296387, -11.187491416931152, -11.857288360595703, -12.922049522399902, -12.813797950744629, -13.376636505126953, -12.730195045471191, -14.93480110168457, -14.99672794342041, -15.349507331848145, -17.323610305786133, -18.16119956970215, -18.34326934814453, -19.499040603637695, -20.243356704711914, -20.29413414001465, -21.684263229370117, -22.123777389526367, -23.415056228637695, -25.152402877807617, -25.855350494384766, -26.47032928466797, -26.587465286254883, -26.773366928100586, -27.389209747314453, -26.402936935424805, -26.494565963745117, -25.631967544555664, -25.388093948364258, -25.288084030151367, -21.53117561340332, -24.127578735351562, -22.239242553710938, -20.530174255371094, -18.88735580444336, -19.4386043548584, -17.122642517089844, -15.428943634033203, -13.436606407165527, -13.421516418457031, -11.74304485321045, -10.255184173583984, -8.323507308959961, -7.801982879638672, -7.133086681365967, -6.9776740074157715, -6.218623161315918, -6.271812915802002, -6.046889781951904, -5.675467014312744, -5.008995532989502, -4.165709018707275, -3.0805513858795166, -4.268179416656494, -0.0, 0.0, 2.0732884407043457, 2.92814040184021, 2.332737922668457, 1.0411485433578491, 0.0, 1.8690168857574463], [0.0, 0.0, -18.47662353515625, -16.979061126708984, -15.801385879516602, -15.333390235900879, -12.367515563964844, -12.446968078613281, -12.245750427246094, 0.0, 0.0, 0.0, -13.46731185913086, -8.23443603515625, -11.755636215209961, -9.646951675415039, -10.106223106384277, -11.48490047454834, -11.35014820098877, -12.0910005569458, -13.217949867248535, -14.726058006286621, -14.704935073852539, -14.277569770812988, -15.816590309143066, -16.212902069091797, -17.876291275024414, -17.650264739990234, -17.387235641479492, -19.90867805480957, -21.039505004882812, -22.628694534301758, -23.020395278930664, -24.712196350097656, -25.754587173461914, -25.601600646972656, -26.2806453704834, -27.562776565551758, -27.613018035888672, -27.354368209838867, -28.0654354095459, -27.68154525756836, -26.27018165588379, -25.921316146850586, -26.038490295410156, -25.2137393951416, -24.9320068359375, -23.731151580810547, -22.934791564941406, -23.739042282104492, -19.73296546936035, -20.491695404052734, -16.796493530273438, -15.08056354522705, -15.225876808166504, -13.167980194091797, -10.292088508605957, -9.830361366271973, -9.066876411437988, -6.839114189147949, -5.985365867614746, -6.141136169433594, -6.27080774307251, -6.0165815353393555, -6.0232672691345215, -6.097208023071289, -4.828484058380127, -3.988945960998535, -3.5914390087127686, -3.7121994495391846, 0.0, 3.440268039703369, 2.8791730403900146, 4.185532093048096, 2.8266735076904297, 0.0, 3.9510011672973633, 1.9188166856765747, -0.0, -0.0, -18.47662353515625, -16.979061126708984, -15.801385879516602, -15.333390235900879, -12.367515563964844, -12.446968078613281, -12.245750427246094, -0.0, -0.0, -0.0, -13.46731185913086, -8.23443603515625, -11.755636215209961, -9.646951675415039, -10.106223106384277, -11.48490047454834, -11.35014820098877, -12.0910005569458, -13.217949867248535, -14.726058006286621, -14.704935073852539, -14.277569770812988, -15.816590309143066, -16.212902069091797, -17.876291275024414, -17.650264739990234, -17.387235641479492, -19.90867805480957, -21.039505004882812, -22.628694534301758, -23.020395278930664, -24.712196350097656, -25.754587173461914, -25.601600646972656, -26.2806453704834, -27.562776565551758, -27.613018035888672, -27.354368209838867, -28.0654354095459, -27.68154525756836, -26.27018165588379, -25.921316146850586, -26.038490295410156, -25.2137393951416, -24.9320068359375, -23.731151580810547, -22.934791564941406, -23.739042282104492, -19.73296546936035, -20.491695404052734, -16.796493530273438, -15.08056354522705, -15.225876808166504, -13.167980194091797, -10.292088508605957, -9.830361366271973, -9.066876411437988, -6.839114189147949, -5.985365867614746, -6.141136169433594, -6.27080774307251, -6.0165815353393555, -6.0232672691345215, -6.097208023071289, -4.828484058380127, -3.988945960998535, -3.5914390087127686, -3.7121994495391846, 0.0, 3.440268039703369, 2.8791730403900146, 4.185532093048096, 2.8266735076904297, 0.0, 3.9510011672973633, 1.9188166856765747], [0.0, -19.984525680541992, -20.534181594848633, -18.132230758666992, -16.083757400512695, -15.445924758911133, -13.341355323791504, -13.211206436157227, -12.477862358093262, -10.845318794250488, 0.0, 0.0, -11.994039535522461, -10.52423095703125, -11.121127128601074, -11.537749290466309, -10.915157318115234, -11.168008804321289, -10.946640014648438, -10.916839599609375, -11.8425874710083, -12.382402420043945, -13.773819923400879, -14.923090934753418, -15.489129066467285, -15.912840843200684, -16.93935203552246, -18.43849754333496, -18.49129867553711, -18.934307098388672, -21.090003967285156, -22.416353225708008, -24.517005920410156, -24.343582153320312, -25.521718978881836, -27.73538589477539, -27.256017684936523, -27.897933959960938, -27.530237197875977, -29.714263916015625, -28.84366798400879, -28.296794891357422, -27.933691024780273, -28.1790714263916, -25.931276321411133, -25.570016860961914, -24.92538833618164, -24.395851135253906, -22.737560272216797, -22.950483322143555, -20.988948822021484, -20.077482223510742, -18.55103874206543, -16.829912185668945, -14.835663795471191, -12.870889663696289, -11.428041458129883, -11.411563873291016, -11.364553451538086, -7.5348920822143555, -6.054424285888672, -3.9432334899902344, -5.4670891761779785, -5.0753350257873535, -5.0608954429626465, -4.82689094543457, -4.363144397735596, -3.345386028289795, -1.951948881149292, 0.0, 0.0, 3.322953701019287, 2.0686514377593994, 2.009918689727783, -0.09197758138179779, -2.2195792198181152, 0.0, -0.558529257774353, -0.0, -19.984525680541992, -20.534181594848633, -18.132230758666992, -16.083757400512695, -15.445924758911133, -13.341355323791504, -13.211206436157227, -12.477862358093262, -10.845318794250488, -0.0, -0.0, -11.994039535522461, -10.52423095703125, -11.121127128601074, -11.537749290466309, -10.915157318115234, -11.168008804321289, -10.946640014648438, -10.916839599609375, -11.8425874710083, -12.382402420043945, -13.773819923400879, -14.923090934753418, -15.489129066467285, -15.912840843200684, -16.93935203552246, -18.43849754333496, -18.49129867553711, -18.934307098388672, -21.090003967285156, -22.416353225708008, -24.517005920410156, -24.343582153320312, -25.521718978881836, -27.73538589477539, -27.256017684936523, -27.897933959960938, -27.530237197875977, -29.714263916015625, -28.84366798400879, -28.296794891357422, -27.933691024780273, -28.1790714263916, -25.931276321411133, -25.570016860961914, -24.92538833618164, -24.395851135253906, -22.737560272216797, -22.950483322143555, -20.988948822021484, -20.077482223510742, -18.55103874206543, -16.829912185668945, -14.835663795471191, -12.870889663696289, -11.428041458129883, -11.411563873291016, -11.364553451538086, -7.5348920822143555, -6.054424285888672, -3.9432334899902344, -5.4670891761779785, -5.0753350257873535, -5.0608954429626465, -4.82689094543457, -4.363144397735596, -3.345386028289795, -1.951948881149292, -0.0, 0.0, 3.322953701019287, 2.0686514377593994, 2.009918689727783, -0.09197758138179779, -2.2195792198181152, 0.0, -0.558529257774353], [0.0, 0.0, -18.786348342895508, -18.884803771972656, -15.131179809570312, -15.05694580078125, -16.252180099487305, -14.3597993850708, -16.20691680908203, -12.108114242553711, -10.747163772583008, -11.377645492553711, -12.86242961883545, -12.178821563720703, -13.728261947631836, -13.945976257324219, -15.15743350982666, -12.090032577514648, -12.391674041748047, -12.121532440185547, -11.808082580566406, -10.597342491149902, -12.740121841430664, -14.36005973815918, -15.646113395690918, -17.126968383789062, -18.089872360229492, -19.021947860717773, -19.04485511779785, -20.195146560668945, -21.10610580444336, -23.16861915588379, -23.715749740600586, -26.57111167907715, -26.645103454589844, -27.575145721435547, -27.806507110595703, -29.126285552978516, -29.12084197998047, -29.090925216674805, -28.569232940673828, -28.853296279907227, -28.41498374938965, -27.731517791748047, -27.419240951538086, -26.720216751098633, -25.750741958618164, -25.22826385498047, -25.109228134155273, -23.10759925842285, -21.17475700378418, -17.948345184326172, -17.7753963470459, -17.41382598876953, -15.786835670471191, -14.625746726989746, -13.81423282623291, -10.6210298538208, -9.633688926696777, -8.215292930603027, -6.099647521972656, -5.152240753173828, -4.896625995635986, -4.918473720550537, -5.6709794998168945, -5.409537315368652, -4.617197513580322, -4.121279716491699, 0.0, 0.0, 0.0, 2.76505708694458, 1.799561858177185, 1.6469058990478516, 0.0, -4.714759826660156, 0.0, 0.8705722093582153, -0.0, -0.0, -18.786348342895508, -18.884803771972656, -15.131179809570312, -15.05694580078125, -16.252180099487305, -14.3597993850708, -16.20691680908203, -12.108114242553711, -10.747163772583008, -11.377645492553711, -12.86242961883545, -12.178821563720703, -13.728261947631836, -13.945976257324219, -15.15743350982666, -12.090032577514648, -12.391674041748047, -12.121532440185547, -11.808082580566406, -10.597342491149902, -12.740121841430664, -14.36005973815918, -15.646113395690918, -17.126968383789062, -18.089872360229492, -19.021947860717773, -19.04485511779785, -20.195146560668945, -21.10610580444336, -23.16861915588379, -23.715749740600586, -26.57111167907715, -26.645103454589844, -27.575145721435547, -27.806507110595703, -29.126285552978516, -29.12084197998047, -29.090925216674805, -28.569232940673828, -28.853296279907227, -28.41498374938965, -27.731517791748047, -27.419240951538086, -26.720216751098633, -25.750741958618164, -25.22826385498047, -25.109228134155273, -23.10759925842285, -21.17475700378418, -17.948345184326172, -17.7753963470459, -17.41382598876953, -15.786835670471191, -14.625746726989746, -13.81423282623291, -10.6210298538208, -9.633688926696777, -8.215292930603027, -6.099647521972656, -5.152240753173828, -4.896625995635986, -4.918473720550537, -5.6709794998168945, -5.409537315368652, -4.617197513580322, -4.121279716491699, -0.0, -0.0, 0.0, 2.76505708694458, 1.799561858177185, 1.6469058990478516, -0.0, -4.714759826660156, -0.0, 0.8705722093582153], [0.0, 0.0, -20.918621063232422, -19.81719970703125, 0.0, -16.337848663330078, -15.136673927307129, -14.044173240661621, -13.54190731048584, -13.163504600524902, -12.207929611206055, 0.0, -14.497953414916992, -13.133790016174316, -14.786290168762207, -12.762582778930664, -12.220529556274414, -12.56434440612793, -13.336730003356934, -14.311450958251953, -12.082771301269531, -10.372995376586914, -14.072336196899414, -14.747291564941406, -15.970502853393555, -17.315948486328125, -17.54715347290039, -18.967477798461914, -19.710737228393555, -21.093643188476562, -22.225492477416992, -23.61195182800293, -24.716703414916992, -25.191875457763672, -26.82309913635254, -28.09450340270996, -28.4368839263916, -30.701522827148438, -29.0570125579834, -28.072439193725586, -28.464237213134766, -30.192813873291016, -28.735780715942383, -28.065940856933594, -27.96990203857422, -27.052330017089844, -27.103757858276367, -26.070171356201172, -24.233768463134766, -22.487653732299805, -21.153884887695312, -21.332197189331055, -19.42629623413086, -17.798551559448242, -15.68475341796875, -15.11948013305664, -13.266706466674805, -11.64868450164795, -10.47084903717041, -9.137432098388672, -8.220159530639648, -6.620742321014404, -6.365414142608643, -9.208527565002441, -6.5579962730407715, -5.194361686706543, -2.7894299030303955, 0.0, 0.0, 0.0, 1.6251702308654785, 1.512668251991272, 1.9450916051864624, 0.0, 0.0, -4.049607276916504, -3.7050726413726807, 0.0, -0.0, -0.0, -20.918621063232422, -19.81719970703125, -0.0, -16.337848663330078, -15.136673927307129, -14.044173240661621, -13.54190731048584, -13.163504600524902, -12.207929611206055, -0.0, -14.497953414916992, -13.133790016174316, -14.786290168762207, -12.762582778930664, -12.220529556274414, -12.56434440612793, -13.336730003356934, -14.311450958251953, -12.082771301269531, -10.372995376586914, -14.072336196899414, -14.747291564941406, -15.970502853393555, -17.315948486328125, -17.54715347290039, -18.967477798461914, -19.710737228393555, -21.093643188476562, -22.225492477416992, -23.61195182800293, -24.716703414916992, -25.191875457763672, -26.82309913635254, -28.09450340270996, -28.4368839263916, -30.701522827148438, -29.0570125579834, -28.072439193725586, -28.464237213134766, -30.192813873291016, -28.735780715942383, -28.065940856933594, -27.96990203857422, -27.052330017089844, -27.103757858276367, -26.070171356201172, -24.233768463134766, -22.487653732299805, -21.153884887695312, -21.332197189331055, -19.42629623413086, -17.798551559448242, -15.68475341796875, -15.11948013305664, -13.266706466674805, -11.64868450164795, -10.47084903717041, -9.137432098388672, -8.220159530639648, -6.620742321014404, -6.365414142608643, -9.208527565002441, -6.5579962730407715, -5.194361686706543, -2.7894299030303955, -0.0, -0.0, 0.0, 1.6251702308654785, 1.512668251991272, 1.9450916051864624, 0.0, -0.0, -4.049607276916504, -3.7050726413726807, -0.0], [0.0, -18.592023849487305, -19.537002563476562, -19.162935256958008, 0.0, -18.351289749145508, -15.592789649963379, -14.43173599243164, -13.776510238647461, -13.84909439086914, -13.200193405151367, 0.0, 0.0, -10.660116195678711, -14.072616577148438, -13.048803329467773, -14.076062202453613, -14.525280952453613, -14.037358283996582, -12.009696960449219, -11.409345626831055, -12.709208488464355, -14.99020767211914, -16.390085220336914, -17.487781524658203, -18.041019439697266, -17.907197952270508, -19.866308212280273, -19.820560455322266, -21.551485061645508, -22.612764358520508, -21.403676986694336, -25.110721588134766, -26.83985137939453, -27.15216827392578, -28.528486251831055, -28.17852783203125, -29.621015548706055, -28.36520004272461, -29.148509979248047, -29.16884422302246, -29.922334671020508, -27.961132049560547, -28.805217742919922, -28.372879028320312, -27.0225830078125, -27.294153213500977, -26.047151565551758, -26.451616287231445, -23.67255401611328, -22.395503997802734, -21.443737030029297, -19.888174057006836, -15.211913108825684, -17.260353088378906, -14.992621421813965, -13.876379013061523, -12.136224746704102, -11.627169609069824, -10.615591049194336, -12.313948631286621, -8.92665958404541, -7.6595635414123535, -5.921248435974121, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.4689564108848572, 1.174316644668579, -0.4265553057193756, 0.0, 0.0, -0.6864431500434875, 0.0, 0.0, -0.0, -18.592023849487305, -19.537002563476562, -19.162935256958008, -0.0, -18.351289749145508, -15.592789649963379, -14.43173599243164, -13.776510238647461, -13.84909439086914, -13.200193405151367, -0.0, -0.0, -10.660116195678711, -14.072616577148438, -13.048803329467773, -14.076062202453613, -14.525280952453613, -14.037358283996582, -12.009696960449219, -11.409345626831055, -12.709208488464355, -14.99020767211914, -16.390085220336914, -17.487781524658203, -18.041019439697266, -17.907197952270508, -19.866308212280273, -19.820560455322266, -21.551485061645508, -22.612764358520508, -21.403676986694336, -25.110721588134766, -26.83985137939453, -27.15216827392578, -28.528486251831055, -28.17852783203125, -29.621015548706055, -28.36520004272461, -29.148509979248047, -29.16884422302246, -29.922334671020508, -27.961132049560547, -28.805217742919922, -28.372879028320312, -27.0225830078125, -27.294153213500977, -26.047151565551758, -26.451616287231445, -23.67255401611328, -22.395503997802734, -21.443737030029297, -19.888174057006836, -15.211913108825684, -17.260353088378906, -14.992621421813965, -13.876379013061523, -12.136224746704102, -11.627169609069824, -10.615591049194336, -12.313948631286621, -8.92665958404541, -7.6595635414123535, -5.921248435974121, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.4689564108848572, 1.174316644668579, -0.4265553057193756, -0.0, -0.0, -0.6864431500434875, -0.0, -0.0], [0.0, -19.092439651489258, -21.207704544067383, 0.0, 0.0, 0.0, -15.883464813232422, -15.91991901397705, -15.003114700317383, -14.027970314025879, -13.597271919250488, -13.421910285949707, -13.152857780456543, -14.290846824645996, -15.05962085723877, 0.0, -12.757952690124512, 0.0, 0.0, 0.0, -16.73040771484375, -16.693933486938477, -17.35112953186035, -17.372663497924805, -18.910898208618164, -19.266765594482422, -20.145044326782227, -20.582815170288086, -20.9298038482666, -22.08226203918457, -22.632356643676758, -23.937379837036133, -25.3637638092041, -26.496135711669922, -27.734224319458008, -28.400230407714844, -28.833833694458008, -29.33445930480957, -29.131454467773438, -29.756568908691406, -28.79828453063965, -28.60200309753418, -28.94156837463379, -29.164623260498047, -28.95254898071289, -28.389963150024414, -27.616151809692383, -26.962478637695312, -25.98556137084961, -22.045045852661133, -22.590333938598633, -21.575246810913086, -19.67616081237793, -18.531524658203125, -16.599138259887695, -14.777071952819824, -15.125727653503418, -15.249992370605469, -11.235823631286621, -12.706196784973145, -10.88518238067627, -11.306894302368164, -6.502903461456299, -4.583476543426514, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0810718536376953, 0.48476070165634155, -0.15794403851032257, 0.0, -0.8070847392082214, -0.14596806466579437, 0.0, 0.0, -0.0, -19.092439651489258, -21.207704544067383, -0.0, -0.0, -0.0, -15.883464813232422, -15.91991901397705, -15.003114700317383, -14.027970314025879, -13.597271919250488, -13.421910285949707, -13.152857780456543, -14.290846824645996, -15.05962085723877, -0.0, -12.757952690124512, -0.0, -0.0, -0.0, -16.73040771484375, -16.693933486938477, -17.35112953186035, -17.372663497924805, -18.910898208618164, -19.266765594482422, -20.145044326782227, -20.582815170288086, -20.9298038482666, -22.08226203918457, -22.632356643676758, -23.937379837036133, -25.3637638092041, -26.496135711669922, -27.734224319458008, -28.400230407714844, -28.833833694458008, -29.33445930480957, -29.131454467773438, -29.756568908691406, -28.79828453063965, -28.60200309753418, -28.94156837463379, -29.164623260498047, -28.95254898071289, -28.389963150024414, -27.616151809692383, -26.962478637695312, -25.98556137084961, -22.045045852661133, -22.590333938598633, -21.575246810913086, -19.67616081237793, -18.531524658203125, -16.599138259887695, -14.777071952819824, -15.125727653503418, -15.249992370605469, -11.235823631286621, -12.706196784973145, -10.88518238067627, -11.306894302368164, -6.502903461456299, -4.583476543426514, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0810718536376953, 0.48476070165634155, -0.15794403851032257, -0.0, -0.8070847392082214, -0.14596806466579437, -0.0, -0.0], [0.0, 0.0, -20.06696128845215, -22.03227424621582, -18.970352172851562, 0.0, 0.0, -15.997879981994629, -16.180925369262695, -14.37417221069336, -13.762812614440918, -13.035321235656738, 0.0, 0.0, -14.309770584106445, 0.0, 0.0, -11.790602684020996, 0.0, 0.0, -17.781890869140625, -18.031896591186523, -19.322254180908203, -19.254066467285156, -19.873050689697266, -20.014606475830078, -20.43815040588379, -21.758785247802734, -21.909414291381836, -22.83812713623047, -23.434316635131836, -25.449241638183594, -26.087980270385742, -26.782398223876953, -26.848224639892578, -28.518301010131836, -29.548681259155273, -30.0870304107666, -28.925546646118164, -29.330249786376953, -28.572961807250977, -28.77837562561035, -28.53155517578125, -29.74176597595215, -29.438756942749023, -28.761024475097656, -27.615707397460938, -28.176408767700195, -26.703205108642578, -25.63972282409668, -23.179201126098633, -21.926136016845703, -20.700592041015625, -19.27290916442871, -19.54834747314453, -17.298973083496094, -18.52454948425293, -15.987227439880371, -13.620098114013672, -15.328730583190918, -12.401721000671387, -10.677794456481934, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0860453844070435, -0.4475906491279602, -2.103361129760742, 0.0, -1.5187177658081055, -1.4783366918563843, 0.0, 0.0, -0.0, -0.0, -20.06696128845215, -22.03227424621582, -18.970352172851562, -0.0, -0.0, -15.997879981994629, -16.180925369262695, -14.37417221069336, -13.762812614440918, -13.035321235656738, -0.0, -0.0, -14.309770584106445, -0.0, -0.0, -11.790602684020996, -0.0, -0.0, -17.781890869140625, -18.031896591186523, -19.322254180908203, -19.254066467285156, -19.873050689697266, -20.014606475830078, -20.43815040588379, -21.758785247802734, -21.909414291381836, -22.83812713623047, -23.434316635131836, -25.449241638183594, -26.087980270385742, -26.782398223876953, -26.848224639892578, -28.518301010131836, -29.548681259155273, -30.0870304107666, -28.925546646118164, -29.330249786376953, -28.572961807250977, -28.77837562561035, -28.53155517578125, -29.74176597595215, -29.438756942749023, -28.761024475097656, -27.615707397460938, -28.176408767700195, -26.703205108642578, -25.63972282409668, -23.179201126098633, -21.926136016845703, -20.700592041015625, -19.27290916442871, -19.54834747314453, -17.298973083496094, -18.52454948425293, -15.987227439880371, -13.620098114013672, -15.328730583190918, -12.401721000671387, -10.677794456481934, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -1.0860453844070435, -0.4475906491279602, -2.103361129760742, -0.0, -1.5187177658081055, -1.4783366918563843, -0.0, -0.0], [0.0, 0.0, -23.593063354492188, -22.358531951904297, 0.0, 0.0, 0.0, -13.149489402770996, -14.945904731750488, -16.577390670776367, -15.516788482666016, -14.488869667053223, -15.90572738647461, 0.0, 0.0, 0.0, -12.187637329101562, 0.0, 0.0, 0.0, -18.731966018676758, -15.400321006774902, -18.019262313842773, -21.17413330078125, -20.40018653869629, -21.223669052124023, -21.88808250427246, -21.898941040039062, -23.14512825012207, -22.472091674804688, -23.957229614257812, -26.1728515625, -25.685874938964844, -27.689966201782227, -27.64665412902832, -29.174297332763672, -29.730104446411133, -29.24576759338379, -28.938474655151367, -29.58428382873535, -28.787471771240234, -28.76331901550293, -29.164979934692383, -29.02826690673828, -29.309968948364258, -29.434621810913086, -28.31161117553711, -29.945079803466797, -25.240867614746094, -25.810335159301758, -24.054441452026367, -22.65555191040039, -20.699100494384766, -18.12164306640625, -17.053295135498047, -17.81280517578125, -17.073036193847656, 0.0, -14.261317253112793, -15.451175689697266, -14.966102600097656, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.7153899669647217, -2.7254533767700195, -1.7290922403335571, -3.256910562515259, -2.181549549102783, -1.903812289237976, 0.0, 0.0, 0.0, -0.0, -0.0, -23.593063354492188, -22.358531951904297, -0.0, -0.0, -0.0, -13.149489402770996, -14.945904731750488, -16.577390670776367, -15.516788482666016, -14.488869667053223, -15.90572738647461, -0.0, -0.0, -0.0, -12.187637329101562, -0.0, -0.0, -0.0, -18.731966018676758, -15.400321006774902, -18.019262313842773, -21.17413330078125, -20.40018653869629, -21.223669052124023, -21.88808250427246, -21.898941040039062, -23.14512825012207, -22.472091674804688, -24.245250701904297, -25.792255401611328, -25.974767684936523, -27.61872100830078, -27.886859893798828, -29.08399200439453, -29.557575225830078, -29.322763442993164, -29.083803176879883, -29.415353775024414, -28.839757919311523, -28.82101058959961, -29.083539962768555, -29.03005599975586, -29.243423461914062, -29.269229888916016, -28.331005096435547, -29.102445602416992, -25.58856201171875, -25.486764907836914, -23.70826530456543, -22.182632446289062, -20.23435401916504, -18.029552459716797, -16.698884963989258, -17.81280517578125, -17.073036193847656, -0.0, -14.261317253112793, -15.451175689697266, -14.966102600097656, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -2.7153899669647217, -2.7254533767700195, -1.7290922403335571, -3.256910562515259, -2.181549549102783, -1.903812289237976, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -19.739986419677734, -19.42387580871582, 0.0, 0.0, -17.0457820892334, -17.016891479492188, -15.900238990783691, -16.05467987060547, -14.518879890441895, 0.0, 0.0, 0.0, -8.743230819702148, 0.0, 0.0, 0.0, -19.1949520111084, -18.802330017089844, -19.242137908935547, -17.790382385253906, -19.419254302978516, -17.458086013793945, -17.923376083374023, -19.328943252563477, -24.897489547729492, -24.924869537353516, -26.109054565429688, -25.660966873168945, -25.568941116333008, -27.521825790405273, -29.04059410095215, -28.706897735595703, -29.515113830566406, -30.990015029907227, -28.797351837158203, -28.38930892944336, -28.28425407409668, -27.99978256225586, -27.96700096130371, -28.738807678222656, -28.249393463134766, -30.27450180053711, -28.920289993286133, -27.83595848083496, -27.407705307006836, -26.442989349365234, -24.0353946685791, -22.473142623901367, -19.40041732788086, -17.851116180419922, 0.0, -17.47688102722168, -16.48948097229004, 0.0, 0.0, 0.0, -17.204010009765625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.6239278316497803, -1.7108815908432007, 0.0, -1.566474437713623, -2.89693284034729, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -19.739986419677734, -19.42387580871582, -0.0, -0.0, -17.0457820892334, -17.016891479492188, -15.900238990783691, -16.05467987060547, -14.518879890441895, -0.0, -0.0, -0.0, -8.743230819702148, -0.0, -0.0, -0.0, -19.1949520111084, -18.802330017089844, -19.242137908935547, -17.790382385253906, -19.419254302978516, -17.458086013793945, -17.923376083374023, -19.328943252563477, -24.897489547729492, -24.924869537353516, -25.753705978393555, -26.210779190063477, -26.774606704711914, -27.698410034179688, -28.415578842163086, -29.06568145751953, -29.352643966674805, -29.257518768310547, -29.01653480529785, -28.821630477905273, -28.52598762512207, -28.427976608276367, -28.499605178833008, -28.609403610229492, -28.800329208374023, -28.813243865966797, -28.383604049682617, -27.80076789855957, -26.282987594604492, -25.0467586517334, -23.463972091674805, -21.63047218322754, -19.583953857421875, -17.701244354248047, -0.0, -17.47688102722168, -16.48948097229004, -0.0, -0.0, -0.0, -17.204010009765625, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -3.6239278316497803, -1.7108815908432007, -0.0, -1.566474437713623, -2.89693284034729, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -22.623043060302734, -18.899003982543945, -18.9602108001709, 0.0, -20.10679817199707, -18.003597259521484, -16.710861206054688, -16.78544807434082, -16.12983512878418, 0.0, 0.0, 0.0, -10.158565521240234, 0.0, 0.0, -15.81444263458252, -17.985212326049805, 0.0, -19.276714324951172, -19.034320831298828, -18.435041427612305, -19.00527572631836, -18.390907287597656, 0.0, 0.0, -26.03797721862793, -26.111724853515625, -29.631345748901367, 0.0, -28.129859924316406, -30.0996150970459, -29.835840225219727, -30.03551483154297, -30.835474014282227, -28.953304290771484, -27.807485580444336, -27.442975997924805, -27.082242965698242, -27.259056091308594, -27.562658309936523, -28.475427627563477, -27.870790481567383, -29.46761703491211, -29.657751083374023, -28.008892059326172, -25.879793167114258, -24.464630126953125, -22.887203216552734, 0.0, 0.0, 0.0, -13.228940963745117, 0.0, 0.0, 0.0, 0.0, -20.91645622253418, -18.00775146484375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.200425148010254, -4.405309677124023, 0.0, 0.0, -1.2221823930740356, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -22.623043060302734, -18.899003982543945, -18.9602108001709, -0.0, -20.10679817199707, -18.003597259521484, -16.710861206054688, -16.78544807434082, -16.12983512878418, -0.0, -0.0, -0.0, -10.158565521240234, -0.0, -0.0, -15.81444263458252, -17.985212326049805, -0.0, -19.276714324951172, -19.034320831298828, -18.435041427612305, -19.00527572631836, -18.390907287597656, -0.0, -0.0, -26.03797721862793, -25.920448303222656, -26.541187286376953, -0.0, -27.879030227661133, -28.557954788208008, -28.98956298828125, -29.122739791870117, -28.990079879760742, -28.670021057128906, -28.280521392822266, -27.973560333251953, -27.821521759033203, -27.820430755615234, -27.94875144958496, -28.10875129699707, -28.14253807067871, -27.811176300048828, -27.03624725341797, -26.029817581176758, -24.723915100097656, -23.139097213745117, -21.09137725830078, -0.0, -0.0, -0.0, -13.228940963745117, -0.0, -0.0, -0.0, -0.0, -20.91645622253418, -18.00775146484375, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.200425148010254, -4.405309677124023, -0.0, -0.0, -1.2221823930740356, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, -18.457975387573242, -18.57118034362793, -19.622222900390625, 0.0, 0.0, -18.30336570739746, -18.33859634399414, -17.60647964477539, -15.988662719726562, 0.0, 0.0, -13.85071086883545, 0.0, 0.0, 0.0, -17.041488647460938, -19.236591339111328, -18.863115310668945, -19.442907333374023, -19.825159072875977, -18.47471809387207, -19.9399356842041, 0.0, 0.0, 0.0, -27.988327026367188, 0.0, -30.159257888793945, -30.466297149658203, -31.554651260375977, -28.649141311645508, -28.738693237304688, -30.61456871032715, -28.758258819580078, -27.96990203857422, -27.550729751586914, -25.562397003173828, -25.767627716064453, -25.536449432373047, -27.567007064819336, -28.33335304260254, -28.574954986572266, -28.263959884643555, -29.78397560119629, -28.510080337524414, -26.629528045654297, -25.55436134338379, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.612342834472656, -20.97076988220215, -20.847135543823242, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.271380424499512, 0.0, -6.373321533203125, -6.033282279968262, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -18.457975387573242, -18.57118034362793, -19.622222900390625, -0.0, -0.0, -18.30336570739746, -18.33859634399414, -17.60647964477539, -15.988662719726562, -0.0, -0.0, -13.85071086883545, -0.0, -0.0, -0.0, -17.041488647460938, -19.236591339111328, -18.863115310668945, -19.442907333374023, -19.825159072875977, -18.47471809387207, -19.9399356842041, -0.0, -0.0, -0.0, -27.988327026367188, -0.0, -26.86334991455078, -27.27126121520996, -27.85379409790039, -28.381702423095703, -28.692028045654297, -28.71758270263672, -28.514238357543945, -28.150726318359375, -27.68914794921875, -27.287036895751953, -27.06515121459961, -27.026622772216797, -27.127593994140625, -27.26909065246582, -27.283924102783203, -26.91533088684082, -26.254247665405273, -25.445152282714844, -24.316478729248047, -22.818899154663086, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.612342834472656, -20.97076988220215, -20.847135543823242, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.271380424499512, -0.0, -6.373321533203125, -6.033282279968262, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -22.986587524414062, -21.81620979309082, 0.0, 0.0, -18.747251510620117, -20.29442024230957, -18.278657913208008, -19.474842071533203, 0.0, 0.0, -16.459951400756836, 0.0, -18.37604331970215, -17.024141311645508, -16.008554458618164, -17.215261459350586, -19.726154327392578, -19.37302589416504, -20.577438354492188, -20.33570098876953, -21.44529914855957, -21.99205207824707, 0.0, 0.0, -26.770950317382812, 0.0, 0.0, 0.0, -30.82619857788086, -27.83867835998535, 0.0, -27.657943725585938, -29.38204574584961, -26.930721282958984, -26.633216857910156, -24.81025505065918, -24.42925453186035, -24.243833541870117, -26.155832290649414, -28.80023956298828, -28.102420806884766, -26.625015258789062, -29.16722869873047, -26.948942184448242, -27.492462158203125, -27.28993034362793, 0.0, 0.0, 0.0, 0.0, 0.0, -21.556467056274414, 0.0, 0.0, 0.0, -18.06419563293457, -17.920665740966797, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.980840682983398, 0.0, -8.425764083862305, -5.9201202392578125, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.986587524414062, -21.81620979309082, -0.0, -0.0, -18.747251510620117, -20.29442024230957, -18.278657913208008, -19.474842071533203, -0.0, -0.0, -16.459951400756836, -0.0, -18.37604331970215, -17.024141311645508, -16.008554458618164, -17.215261459350586, -19.726154327392578, -19.37302589416504, -20.577438354492188, -20.33570098876953, -21.44529914855957, -21.99205207824707, -0.0, -0.0, -26.770950317382812, -0.0, -0.0, -0.0, -27.530498504638672, -27.946868896484375, -0.0, -28.08631134033203, -27.849760055541992, -27.500146865844727, -27.037036895751953, -26.570228576660156, -26.267314910888672, -26.176231384277344, -26.235504150390625, -26.347105026245117, -26.37318992614746, -25.945737838745117, -25.279521942138672, -24.59294319152832, -23.73175811767578, -22.495059967041016, -0.0, -0.0, -0.0, -0.0, -0.0, -21.556467056274414, -0.0, -0.0, -0.0, -18.06419563293457, -17.920665740966797, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.980840682983398, -0.0, -8.425764083862305, -5.9201202392578125, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -23.161531448364258, -22.272052764892578, -21.731321334838867, 0.0, 0.0, -20.036027908325195, -19.764434814453125, 0.0, 0.0, 0.0, 0.0, 0.0, -17.636919021606445, -18.941076278686523, -14.644618034362793, -17.60599708557129, -18.33531379699707, -17.756423950195312, -17.24234390258789, -21.028596878051758, -20.90587043762207, -20.202484130859375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.7580509185791, -27.04387855529785, -26.789962768554688, -28.75672721862793, -28.478086471557617, -26.90660858154297, -24.584524154663086, -27.839698791503906, -24.056467056274414, -22.674659729003906, -22.675914764404297, 0.0, -26.68161964416504, -25.511533737182617, -25.520856857299805, -24.472942352294922, -24.288692474365234, -24.133319854736328, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.871002197265625, -21.91744041442871, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.089168071746826, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.161531448364258, -22.272052764892578, -21.731321334838867, -0.0, -0.0, -20.036027908325195, -19.764434814453125, -0.0, -0.0, -0.0, -0.0, -0.0, -17.636919021606445, -18.941076278686523, -14.644618034362793, -17.60599708557129, -18.33531379699707, -17.756423950195312, -17.24234390258789, -21.028596878051758, -20.90587043762207, -20.202484130859375, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.13633155822754, -27.338178634643555, -27.439468383789062, -27.31540298461914, -27.04379653930664, -26.79068946838379, -26.39328384399414, -25.90127944946289, -25.527626037597656, -25.355371475219727, -25.359500885009766, -0.0, -25.395557403564453, -25.00625228881836, -24.475719451904297, -23.929351806640625, -23.200973510742188, -22.205394744873047, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.871002197265625, -21.91744041442871, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.089168071746826, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.56932258605957, -23.487686157226562, 0.0, 0.0, -21.92702293395996, 0.0, 0.0, 0.0, -20.81954574584961, 0.0, -19.28748321533203, -19.217391967773438, -19.947011947631836, 0.0, -21.17436408996582, -19.596708297729492, -20.12133026123047, 0.0, -22.40924072265625, -22.715763092041016, -24.375762939453125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -30.483816146850586, -27.970565795898438, -26.99432945251465, -27.249103546142578, -25.728113174438477, -27.26788330078125, -25.975509643554688, -26.96773338317871, 0.0, -23.558387756347656, -25.683639526367188, -28.701154708862305, -25.32990837097168, 0.0, 0.0, -26.733821868896484, -26.18330955505371, -25.696876525878906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.163652420043945, -21.13020133972168, -22.40852928161621, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.173044204711914, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.56932258605957, -23.487686157226562, -0.0, -0.0, -21.92702293395996, -0.0, -0.0, -0.0, -20.81954574584961, -0.0, -19.28748321533203, -19.217391967773438, -19.947011947631836, -0.0, -21.17436408996582, -19.596708297729492, -20.12133026123047, -0.0, -22.40924072265625, -22.715763092041016, -24.375762939453125, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.600069046020508, -26.741016387939453, -26.754783630371094, -26.574289321899414, -26.16714096069336, -26.10039710998535, -25.87356948852539, -25.41715431213379, -0.0, -24.70250701904297, -24.53557586669922, -24.593595504760742, -24.533008575439453, -0.0, -0.0, -23.430627822875977, -22.922943115234375, -22.26775360107422, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.163652420043945, -21.13020133972168, -22.40852928161621, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.173044204711914, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.705324172973633, -22.76224708557129, -21.23250961303711, 0.0, -20.036544799804688, 0.0, 0.0, -17.949745178222656, -21.630876541137695, 0.0, 0.0, -19.390193939208984, -20.577451705932617, -19.119794845581055, -19.56858253479004, -21.604494094848633, -21.985342025756836, -21.499422073364258, -23.148094177246094, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.435354232788086, -26.525707244873047, -25.934955596923828, -26.752241134643555, -25.910118103027344, 0.0, 0.0, -28.71671485900879, -29.28649139404297, -27.486600875854492, -27.180988311767578, -28.438379287719727, -23.9970703125, -21.846752166748047, -26.818561553955078, -27.13726043701172, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.31638526916504, -24.060670852661133, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.254335880279541, -4.88988733291626, -6.959444046020508, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.705324172973633, -22.76224708557129, -21.23250961303711, -0.0, -20.036544799804688, -0.0, -0.0, -17.949745178222656, -21.630876541137695, -0.0, -0.0, -19.390193939208984, -20.577451705932617, -19.119794845581055, -19.56858253479004, -21.604494094848633, -21.985342025756836, -21.499422073364258, -23.148094177246094, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.25099754333496, -26.226499557495117, -26.167987823486328, -25.92732810974121, -25.53557586669922, -0.0, -0.0, -25.27289390563965, -24.85906219482422, -24.419382095336914, -23.992334365844727, -23.832763671875, -23.811298370361328, -23.896310806274414, -23.693614959716797, -23.12272834777832, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.31638526916504, -24.060670852661133, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.254335880279541, -4.88988733291626, -6.959444046020508, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.527223587036133, -25.67762565612793, -24.53095054626465, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.88719367980957, -20.665695190429688, -20.392261505126953, -20.704301834106445, -20.741052627563477, -22.98834800720215, -24.01630973815918, -24.751144409179688, -24.913911819458008, 0.0, 0.0, -20.414749145507812, 0.0, 0.0, 0.0, 0.0, -27.687725067138672, -27.68291473388672, -27.415781021118164, 0.0, -25.910221099853516, 0.0, 0.0, -25.72754669189453, -26.301851272583008, 0.0, 0.0, -26.61393165588379, -24.84903335571289, -23.606409072875977, -24.267515182495117, -25.767786026000977, -28.678531646728516, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.966197967529297, 0.0, 0.0, -13.250090599060059, 0.0, 0.0, 0.0, 0.0, -5.583322525024414, -7.62538480758667, -7.718479156494141, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.527223587036133, -25.67762565612793, -24.53095054626465, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.88719367980957, -20.665695190429688, -20.392261505126953, -20.704301834106445, -20.741052627563477, -22.98834800720215, -24.01630973815918, -24.751144409179688, -24.913911819458008, -0.0, -0.0, -20.414749145507812, -0.0, -0.0, -0.0, -0.0, -26.1025447845459, -25.966217041015625, -25.795068740844727, -0.0, -25.213666915893555, -0.0, -0.0, -25.926408767700195, -25.60959243774414, -0.0, -0.0, -23.419940948486328, -23.246023178100586, -23.872982025146484, -23.904441833496094, -23.12990951538086, -22.405601501464844, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.966197967529297, -0.0, -0.0, -13.250090599060059, -0.0, -0.0, -0.0, -0.0, -5.583322525024414, -7.62538480758667, -7.718479156494141, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.446016311645508, -26.46486473083496, 0.0, 0.0, 0.0, 0.0, 0.0, -9.900408744812012, 0.0, -17.788013458251953, -17.989288330078125, -19.74747657775879, -20.793020248413086, -22.021474838256836, -24.18161964416504, -22.753292083740234, -24.974777221679688, -25.957487106323242, -27.859140396118164, -27.611955642700195, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.169584274291992, -28.209741592407227, -29.10093116760254, 0.0, 0.0, 0.0, 0.0, 0.0, -26.66482925415039, -25.80434799194336, -27.413728713989258, 0.0, -26.074026107788086, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.547395706176758, -24.1531982421875, -25.283100128173828, -29.23583221435547, -24.497892379760742, -23.74735450744629, -23.207969665527344, -22.58829689025879, -20.055519104003906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.559599876403809, -8.412920951843262, -9.90931510925293, -11.1570405960083, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.446016311645508, -26.46486473083496, -0.0, -0.0, -0.0, -0.0, -0.0, -9.900408744812012, -0.0, -17.788013458251953, -17.989288330078125, -19.74747657775879, -20.793020248413086, -22.021474838256836, -24.18161964416504, -22.753292083740234, -24.974777221679688, -25.957487106323242, -27.859140396118164, -27.611955642700195, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.4565486907959, -25.141372680664062, -24.97072982788086, -0.0, -0.0, -0.0, -0.0, -0.0, -23.547718048095703, -22.960901260375977, -23.415565490722656, -0.0, -23.142276763916016, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.547395706176758, -24.1531982421875, -25.283100128173828, -29.23583221435547, -24.497892379760742, -23.74735450744629, -23.207969665527344, -22.58829689025879, -20.055519104003906, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.559599876403809, -8.412920951843262, -9.90931510925293, -11.1570405960083, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.164501190185547, -23.050065994262695, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.40593910217285, 0.0, -17.226511001586914, -18.858495712280273, -22.768693923950195, -22.34039878845215, -23.786285400390625, -25.21379280090332, -26.781919479370117, -27.712175369262695, -27.923925399780273, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.10610580444336, 0.0, 0.0, -31.836078643798828, 0.0, 0.0, -24.84491539001465, -24.55714225769043, -22.550947189331055, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.929210662841797, -26.287817001342773, -24.83909034729004, -28.475147247314453, -29.6588077545166, -26.603981018066406, 0.0, -24.17828941345215, -24.38161849975586, -19.9443416595459, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.150846481323242, -11.189861297607422, -12.772758483886719, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.164501190185547, -23.050065994262695, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.40593910217285, -0.0, -17.226511001586914, -18.858495712280273, -22.768693923950195, -22.34039878845215, -23.786285400390625, -25.21379280090332, -26.781919479370117, -27.712175369262695, -27.923925399780273, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.240068435668945, -0.0, -0.0, -26.66253662109375, -0.0, -0.0, -25.30911636352539, -24.19464683532715, -23.52037811279297, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.929210662841797, -26.287817001342773, -24.83909034729004, -28.475147247314453, -29.6588077545166, -26.603981018066406, -0.0, -24.17828941345215, -24.38161849975586, -19.9443416595459, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.150846481323242, -11.189861297607422, -12.772758483886719, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.217464447021484, -25.07977294921875, -24.01325798034668, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.663511276245117, -19.64284896850586, -17.250507354736328, -17.686298370361328, -18.555530548095703, -21.11855125427246, -23.7918758392334, -26.46014404296875, -27.294837951660156, -28.859636306762695, -30.504249572753906, -29.940092086791992, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.627582550048828, -26.875938415527344, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.492923736572266, 0.0, 0.0, 0.0, -18.870431900024414, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.242165565490723, -13.778787612915039, -12.98318099975586, -14.922050476074219, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.217464447021484, -25.07977294921875, -24.01325798034668, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.663511276245117, -19.64284896850586, -17.250507354736328, -17.686298370361328, -18.555530548095703, -21.11855125427246, -23.7918758392334, -26.46014404296875, -27.294837951660156, -28.859636306762695, -30.504249572753906, -29.940092086791992, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.763601303100586, -25.503122329711914, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.492923736572266, -0.0, -0.0, -0.0, -18.870431900024414, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.242165565490723, -13.778787612915039, -12.98318099975586, -14.922050476074219, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.966651916503906, -27.578773498535156, -22.989259719848633, -24.838712692260742, 0.0, 0.0, 0.0, 0.0, 0.0, -17.54541778564453, -20.867008209228516, -18.5076904296875, -17.399782180786133, -18.63038444519043, -20.10918617248535, 0.0, -25.34602928161621, -27.33867835998535, -30.24514389038086, -29.75476837158203, -30.888425827026367, -25.217309951782227, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.115917205810547, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.54955291748047, -20.789443969726562, -18.688146591186523, -17.46943473815918, -15.72056770324707, -19.092649459838867, 0.0, 0.0, 0.0, 0.0, 0.0, -11.8143892288208, -10.605034828186035, -10.974297523498535, -10.25405216217041, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.966651916503906, -27.578773498535156, -22.989259719848633, -24.838712692260742, -0.0, -0.0, -0.0, -0.0, -0.0, -17.54541778564453, -20.867008209228516, -18.5076904296875, -17.399782180786133, -18.63038444519043, -20.10918617248535, -0.0, -25.34602928161621, -27.33867835998535, -30.24514389038086, -29.75476837158203, -30.888425827026367, -25.217309951782227, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.3636474609375, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.54955291748047, -20.789443969726562, -18.688146591186523, -17.46943473815918, -15.72056770324707, -19.092649459838867, -0.0, -0.0, -0.0, -0.0, -0.0, -11.8143892288208, -10.605034828186035, -10.974297523498535, -10.25405216217041, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.626123428344727, -27.695240020751953, -26.339191436767578, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.38095474243164, -18.752140045166016, 0.0, 0.0, -29.94403648376465, -29.88222312927246, 0.0, 0.0, -25.05616569519043, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.814477920532227, -27.864315032958984, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.86450481414795, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.195980072021484, -8.110544204711914, 0.0, -8.200881004333496, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.626123428344727, -27.695240020751953, -26.339191436767578, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.38095474243164, -18.752140045166016, -0.0, -0.0, -29.94403648376465, -29.88222312927246, -0.0, -0.0, -25.05616569519043, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.16617774963379, -23.834728240966797, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.86450481414795, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -8.195980072021484, -8.110544204711914, -0.0, -8.200881004333496, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.181432723999023, -27.2159423828125, -26.453880310058594, -25.91175079345703, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.355789184570312, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.3084716796875, -18.62198829650879, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.181432723999023, -27.2159423828125, -26.453880310058594, -25.91175079345703, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.249683380126953, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.3084716796875, -18.62198829650879, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.63627052307129, -29.287076950073242, -25.16072654724121, -22.939298629760742, -21.401636123657227, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.595367431640625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.876521110534668, 0.0, -7.6141839027404785, 0.0, 0.0, 0.0, -18.20751953125, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.63627052307129, -29.287076950073242, -25.16072654724121, -22.939298629760742, -21.401636123657227, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.932729721069336, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -8.876521110534668, -0.0, -7.6141839027404785, -0.0, -0.0, -0.0, -18.20751953125, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.341951370239258, -25.998870849609375, -25.81047821044922, -22.975805282592773, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.58345603942871, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.464501857757568, -6.588515281677246, 0.0, 0.0, 0.0, 0.0, -17.240726470947266, -19.074390411376953, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -29.341951370239258, -25.998870849609375, -25.81047821044922, -22.975805282592773, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.372827529907227, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -8.051597595214844, -6.588515281677246, -0.0, -0.0, -0.0, -0.0, -17.240726470947266, -19.074390411376953, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.690555572509766, -24.234209060668945, -26.169160842895508, -28.407827377319336, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.484923362731934, -9.675549507141113, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.690555572509766, -24.234209060668945, -26.169160842895508, -28.407827377319336, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -8.484923362731934, -9.675549507141113, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.216514587402344, -9.636313438415527, -7.530318737030029, -5.751405239105225, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -8.216514587402344, -9.636313438415527, -7.530318737030029, -5.751405239105225, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.447091102600098, -11.052539825439453, -10.116827011108398, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.447091102600098, -11.052539825439453, -10.116827011108398, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.628887176513672, -14.141021728515625, -10.560822486877441, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.628887176513672, -14.141021728515625, -10.560822486877441, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.497513771057129, -10.681844711303711, -13.215472221374512, -15.216416358947754, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.497513771057129, -10.681844711303711, -13.215472221374512, -15.216416358947754, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -13.024188995361328, -13.385632514953613, -14.631383895874023, -13.047917366027832, -13.350380897521973, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -13.024188995361328, -13.385632514953613, -14.631383895874023, -13.047917366027832, -13.350380897521973, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.653059005737305, -15.177166938781738, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.653059005737305, -15.177166938781738, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.11376667022705, -17.033723831176758, -18.149433135986328, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.11376667022705, -17.033723831176758, -18.149433135986328, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.59051513671875, -20.224681854248047, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.59051513671875, -20.224681854248047, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0]]}, {\"colorbar\": {\"title\": {\"text\": \"B<sub>0</sub> (Hz)\"}}, \"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.3333333333333333, \"rgb(230,0,0)\"], [0.6666666666666666, \"rgb(255,210,0)\"], [1.0, \"rgb(255,255,255)\"]], \"name\": \"comparison heatmap\", \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.482254981994629, 10.720178604125977, 8.64598274230957, 9.56879711151123, 11.86092758178711, 12.19910717010498, 0.0, 18.06865119934082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.482254981994629, 10.720178604125977, 8.64598274230957, 9.56879711151123, 11.86092758178711, 12.19910717010498, 0.0, 18.06865119934082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 11.823168754577637, 0.0, 0.0, 9.104900360107422, 9.566153526306152, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 11.823168754577637, 0.0, 0.0, 9.104900360107422, 9.566153526306152, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 9.139104843139648, 10.940336227416992, 10.374631881713867, 8.557120323181152, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 9.139104843139648, 10.940336227416992, 10.374631881713867, 8.557120323181152, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 12.829489707946777, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 12.829489707946777, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 17.355690002441406, 18.18445587158203, 17.712087631225586, 14.806838989257812, 12.724477767944336, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 17.355690002441406, 18.18445587158203, 17.712087631225586, 14.806838989257812, 12.724477767944336, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.80807113647461, 13.701199531555176, 16.38389778137207, 14.407476425170898, 15.196538925170898, 13.771385192871094, 12.345194816589355, 12.652359008789062, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.80807113647461, 13.701199531555176, 16.38389778137207, 14.407476425170898, 15.196538925170898, 13.771385192871094, 12.345194816589355, 12.652359008789062, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 16.712358474731445, 16.24265480041504, 0.0, 0.0, 0.0, 0.0, 10.9118013381958, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 16.712358474731445, 16.24265480041504, 0.0, 0.0, 0.0, 0.0, 10.9118013381958, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.019582271575928, 0.0, 7.5832839012146, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.019582271575928, 0.0, 7.5832839012146, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.6545636653900146, 5.13594913482666, 8.149569511413574, 5.91478157043457, 0.0, 8.263936996459961, 0.0, 5.2990922927856445, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.6545636653900146, 5.13594913482666, 8.149569511413574, 5.91478157043457, 0.0, 8.263936996459961, 0.0, 5.2990922927856445, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 9.071881294250488, 9.393362998962402, 8.045559883117676, 7.008281230926514, 7.192357063293457, 7.62793493270874, 8.647873878479004, 6.109538555145264, 4.03924560546875, 6.1517744064331055, 6.431262016296387, 6.650238037109375, 6.951193332672119, 6.254461765289307, 9.618903160095215, 7.745124340057373, 8.133657455444336, 8.204794883728027, 4.798900604248047, 3.5068747997283936, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 9.071881294250488, 9.393362998962402, 8.045559883117676, 7.008281230926514, 7.192357063293457, 7.62793493270874, 8.647873878479004, 6.109538555145264, 4.03924560546875, 6.1517744064331055, 6.431262016296387, 6.650238037109375, 6.951193332672119, 6.254461765289307, 9.618903160095215, 7.745124340057373, 8.133657455444336, 8.204794883728027, 4.798900604248047, 3.5068747997283936, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.916154861450195, 3.853719472885132, 5.481447696685791, 6.649596214294434, 6.284081935882568, 6.084208965301514, 6.806357383728027, 5.849802017211914, 4.799739360809326, 5.313260555267334, 5.537892818450928, 3.5840418338775635, 5.092653751373291, 4.741657257080078, 4.766592502593994, 4.374217510223389, 4.881612300872803, 5.828818321228027, 4.87324857711792, 5.581781387329102, 5.495373725891113, 5.110301971435547, 5.719772815704346, 5.614063739776611, 6.783890724182129, 6.353141784667969, 7.576323986053467, 9.10863208770752, 7.78785514831543, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.916154861450195, 3.853719472885132, 5.481447696685791, 6.649596214294434, 6.284081935882568, 6.084208965301514, 6.806357383728027, 5.849802017211914, 4.799739360809326, 5.313260555267334, 5.537892818450928, 3.5840418338775635, 5.092653751373291, 4.741657257080078, 4.766592502593994, 4.374217510223389, 4.881612300872803, 5.828818321228027, 4.87324857711792, 5.581781387329102, 5.495373725891113, 5.110301971435547, 5.719772815704346, 5.614063739776611, 6.783890724182129, 6.353141784667969, 7.576323986053467, 9.10863208770752, 7.78785514831543, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.8365278244018555, 5.188507080078125, 6.349634647369385, 5.708256721496582, 4.216126441955566, 4.915124893188477, 5.780331611633301, 3.4734106063842773, 3.173170328140259, 3.603139877319336, 4.098721027374268, 0.0, 8.516594886779785, 7.01160192489624, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.251689910888672, 0.0, 7.40477991104126, 0.0, 3.720961332321167, 5.361122131347656, 5.739506244659424, 5.305844783782959, 7.039665222167969, 7.322968482971191, 6.825679779052734, 7.285155773162842, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.8365278244018555, 5.188507080078125, 6.349634647369385, 5.708256721496582, 4.216126441955566, 4.915124893188477, 5.780331611633301, 3.4734106063842773, 3.173170328140259, 3.603139877319336, 4.098721027374268, 0.0, 8.516594886779785, 7.01160192489624, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 8.251689910888672, 0.0, 7.40477991104126, 0.0, 3.720961332321167, 5.361122131347656, 5.739506244659424, 5.305844783782959, 7.039665222167969, 7.322968482971191, 6.825679779052734, 7.285155773162842, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.071778297424316, 5.1490068435668945, 5.048962116241455, 3.4956417083740234, 4.928104400634766, 0.0, 0.0, 0.0, 0.0, 0.7906116247177124, 5.248328685760498, 4.514959812164307, 4.633188724517822, 6.674098491668701, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.639773368835449, 7.021555423736572, 5.093355655670166, 6.986053943634033, 3.6927289962768555, 0.0, 0.0, 0.0, 4.9075164794921875, 5.7856903076171875, 6.385712623596191, 7.763695240020752, 8.670865058898926, 8.917677879333496, 7.600839614868164, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.071778297424316, 5.1490068435668945, 5.048962116241455, 3.4956417083740234, 4.928104400634766, 0.0, 0.0, 0.0, 0.0, 0.7906116247177124, 5.248328685760498, 4.514959812164307, 4.633188724517822, 6.674098491668701, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.639773368835449, 7.021555423736572, 5.093355655670166, 6.986053943634033, 3.6927289962768555, 0.0, 0.0, 0.0, 4.9075164794921875, 5.7856903076171875, 6.385712623596191, 7.763695240020752, 8.670865058898926, 8.917677879333496, 7.600839614868164, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.653098106384277, 5.748956680297852, 5.092437744140625, 4.084634304046631, 4.193944931030273, 3.2948267459869385, 0.0, 0.0, 0.0, 0.0, -0.14358097314834595, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.096263885498047, 7.215293884277344, 0.0, 0.0, 0.0, 6.455075263977051, 8.183472633361816, 7.006716728210449, 6.0284199714660645, 9.178313255310059, 8.347267150878906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 4.653098106384277, 5.748956680297852, 5.092437744140625, 4.084634304046631, 4.193944931030273, 3.2948267459869385, 0.0, 0.0, 0.0, 0.0, -0.14358097314834595, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 10.096263885498047, 7.215293884277344, 0.0, 0.0, 0.0, 6.455075263977051, 8.183472633361816, 7.006716728210449, 6.0284199714660645, 9.178313255310059, 8.347267150878906, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.534712314605713, 4.438542366027832, 4.3948655128479, 3.701608657836914, 4.234633922576904, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.6254583597183228, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.589016437530518, 7.679548740386963, 0.0, 4.844855785369873, 4.856319904327393, 8.331079483032227, 7.3354878425598145, 8.645035743713379, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.534712314605713, 4.438542366027832, 4.3948655128479, 3.701608657836914, 4.234633922576904, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -1.6254583597183228, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 6.589016437530518, 7.679548740386963, 0.0, 4.844855785369873, 4.856319904327393, 8.331079483032227, 7.3354878425598145, 8.645035743713379, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.441162586212158, 2.8376646041870117, 1.5326073169708252, 2.7909865379333496, 1.5685677528381348, -0.09058374166488647, 0.0, 3.715973377227783, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.9696896076202393, 2.2105867862701416, 2.1307151317596436, 0.0, 0.0, 2.867683172225952, 0.0, 0.00454630795866251, 0.28245967626571655, 2.103687286376953, 0.18842488527297974, 0.8488161563873291, 1.2608057260513306, 2.750192642211914, 2.153022527694702, 3.0566186904907227, 4.925914287567139, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.955038070678711, 6.648962497711182, 8.3991060256958, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.441162586212158, 2.8376646041870117, 1.5326073169708252, 2.7909865379333496, 1.5685677528381348, -0.09058374166488647, 0.0, 3.715973377227783, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 1.9696896076202393, 2.2105867862701416, 2.1307151317596436, 0.0, 0.0, 2.867683172225952, 0.0, 0.00454630795866251, 0.28245967626571655, 2.103687286376953, 0.18842488527297974, 0.8488161563873291, 1.2608057260513306, 2.750192642211914, 2.153022527694702, 3.0566186904907227, 4.925914287567139, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.955038070678711, 6.648962497711182, 8.3991060256958, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.226854085922241, 3.5382792949676514, 2.554236888885498, 1.9403220415115356, 0.0, -1.249981164932251, 0.4351484775543213, -2.0805740356445312, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.56032395362854, 0.0, -2.3182854652404785, -0.35972514748573303, -2.6274170875549316, -2.151000499725342, 0.5619989633560181, 0.8639385104179382, 0.9090483784675598, 0.7415906190872192, 0.9364968538284302, 0.8648592829704285, 0.7626150250434875, 1.3946126699447632, 1.0874069929122925, 0.9654628038406372, 1.0903818607330322, 0.40291833877563477, 0.8918110728263855, 1.1139450073242188, 1.5900241136550903, 1.4344698190689087, 2.966602325439453, 0.6037665605545044, 0.0, 0.0, 0.0, 0.0, 0.0, 4.642113208770752, 3.9245264530181885, 0.0, 7.530307769775391, 5.373858451843262, 5.682816982269287, 9.908818244934082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 3.226854085922241, 3.5382792949676514, 2.554236888885498, 1.9403220415115356, 0.0, -1.249981164932251, 0.4351484775543213, -2.0805740356445312, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 1.56032395362854, -0.0, -2.3182854652404785, -0.35972514748573303, -2.6274170875549316, -2.151000499725342, 0.5619989633560181, 0.8639385104179382, 0.9090483784675598, 0.7415906190872192, 0.9364968538284302, 0.8648592829704285, 0.7626150250434875, 1.3946126699447632, 1.0874069929122925, 0.9654628038406372, 1.0903818607330322, 0.40291833877563477, 0.8918110728263855, 1.1139450073242188, 1.5900241136550903, 1.4344698190689087, 2.966602325439453, 0.6037665605545044, 0.0, -0.0, -0.0, 0.0, 0.0, 4.642113208770752, 3.9245264530181885, 0.0, 7.530307769775391, 5.373858451843262, 5.682816982269287, 9.908818244934082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.3985276222229004, 2.6588432788848877, 1.4008841514587402, 2.2304582595825195, 1.3259165287017822, -0.28354087471961975, -1.459333896636963, 0.6947689652442932, 0.0, 0.0, 0.0, -3.5961854457855225, -0.8315570950508118, -1.0204232931137085, -3.818431854248047, -2.234238386154175, 0.6916479468345642, 0.1107674390077591, -0.08517497777938843, -0.45425844192504883, 1.5806607007980347, -2.1312572956085205, -1.7352302074432373, -1.1374483108520508, -0.48546937108039856, 2.4477508068084717, 1.5773918628692627, 1.0224370956420898, 1.3057883977890015, 1.2886323928833008, 1.2348862886428833, 0.9013135433197021, 1.485857605934143, 1.2091963291168213, 1.1382490396499634, 1.252509593963623, 0.9121138453483582, 0.8567862510681152, 0.28571686148643494, 1.0717591047286987, 1.2219319343566895, 2.143357992172241, -0.15093429386615753, 0.0, 0.0, 0.0, 0.0, 3.943943500518799, 4.6267595291137695, 0.0, 7.2015838623046875, 3.653831720352173, 5.883376121520996, 6.432251453399658, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.3985276222229004, 2.6588432788848877, 1.4008841514587402, 2.2304582595825195, 1.3259165287017822, -0.28354087471961975, -1.459333896636963, 0.6947689652442932, 0.0, -0.0, -0.0, -3.5961854457855225, -0.8315570950508118, -1.0204232931137085, -3.818431854248047, -2.234238386154175, 0.6916479468345642, 0.1107674390077591, -0.08517497777938843, -0.45425844192504883, 1.5806607007980347, -2.1312572956085205, -1.7352302074432373, -1.1374483108520508, -0.48546937108039856, 2.4477508068084717, 1.5773918628692627, 1.0224370956420898, 1.3057883977890015, 1.2886323928833008, 1.2348862886428833, 0.9013135433197021, 1.485857605934143, 1.2091963291168213, 1.1382490396499634, 1.252509593963623, 0.9121138453483582, 0.8567862510681152, 0.28571686148643494, 1.0717591047286987, 1.2219319343566895, 2.143357992172241, -0.15093429386615753, -0.0, 0.0, 0.0, 0.0, 3.943943500518799, 4.6267595291137695, 0.0, 7.2015838623046875, 3.653831720352173, 5.883376121520996, 6.432251453399658, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.840921401977539, 1.0513818264007568, 3.7474186420440674, 1.177050232887268, -1.649308681488037, -3.454639434814453, -2.8273773193359375, 0.0, 0.0, 0.0, 0.0, 0.2769346833229065, -1.869113802909851, -0.4242340624332428, -0.5159928798675537, -4.013478755950928, -0.7628746628761292, -0.8424467444419861, -1.025225281715393, -0.38155362010002136, 0.2821810245513916, -1.8383337259292603, -1.5146026611328125, -0.10166317224502563, -1.3786574602127075, -1.9540302753448486, 1.4546490907669067, 4.048929214477539, 1.1579782962799072, 1.4688472747802734, 1.2515549659729004, 1.3954006433486938, 1.1498839855194092, 0.6672635674476624, 1.357514500617981, 1.0122747421264648, 1.4559227228164673, 1.3198010921478271, 1.263362169265747, 1.220381498336792, 1.2232662439346313, 1.8478177785873413, 1.6556833982467651, 1.4371044635772705, 1.1611822843551636, 0.0, 0.0, 0.0, 0.0, 0.0, 4.479120254516602, 4.091357231140137, 6.943482875823975, 4.471831798553467, 7.017519950866699, 4.363913059234619, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.840921401977539, 1.0513818264007568, 3.7474186420440674, 1.177050232887268, -1.649308681488037, -3.454639434814453, -2.8273773193359375, -0.0, 0.0, -0.0, 0.0, 0.2769346833229065, -1.869113802909851, -0.4242340624332428, -0.5159928798675537, -4.013478755950928, -0.7628746628761292, -0.8424467444419861, -1.025225281715393, -0.38155362010002136, 0.2821810245513916, -1.8383337259292603, -1.5146026611328125, -0.10166317224502563, -1.3786574602127075, -1.9540302753448486, 1.4546490907669067, 4.048929214477539, 1.1579782962799072, 1.4688472747802734, 1.2515549659729004, 1.3954006433486938, 1.1498839855194092, 0.6672635674476624, 1.357514500617981, 1.0122747421264648, 1.4559227228164673, 1.3198010921478271, 1.263362169265747, 1.220381498336792, 1.2232662439346313, 1.8478177785873413, 1.6556833982467651, 1.4371044635772705, 1.1611822843551636, 0.0, -0.0, 0.0, 0.0, 0.0, 4.479120254516602, 4.091357231140137, 6.943482875823975, 4.471831798553467, 7.017519950866699, 4.363913059234619, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.831370234489441, 1.66743803024292, 2.105691432952881, 2.5175936222076416, -0.21447192132472992, -1.646070122718811, -0.04934209957718849, 0.0, 0.0, 0.0, 1.300969123840332, -0.49936771392822266, -0.6675986647605896, -0.8570017218589783, -0.7368500232696533, -0.5605199933052063, -0.7202264070510864, 0.14695551991462708, -0.33869683742523193, 0.10947427898645401, 0.5763972997665405, -0.058113597333431244, 0.4093017280101776, 2.3707239627838135, 0.0, -0.6179364919662476, -1.2451229095458984, 1.389200210571289, 0.7226887345314026, 1.4976874589920044, 1.443472146987915, 1.30130934715271, 1.0374963283538818, 0.6301659345626831, 0.41897720098495483, 1.9249900579452515, 0.9565982222557068, 1.263087272644043, 0.4947502315044403, 0.8819258809089661, 1.5323832035064697, 0.9487621188163757, 1.3105436563491821, 1.891230821609497, 1.6125582456588745, 1.4655911922454834, 1.1685293912887573, 0.7273183465003967, -1.1256691217422485, 0.0, 0.0, 0.0, 0.0, 5.731160640716553, 0.0, 0.0, 2.9343528747558594, 3.904352903366089, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, 1.831370234489441, 1.66743803024292, 2.105691432952881, 2.5175936222076416, -0.21447192132472992, -1.646070122718811, -0.04934209957718849, -0.0, -0.0, 0.0, 1.300969123840332, -0.49936771392822266, -0.6675986647605896, -0.8570017218589783, -0.7368500232696533, -0.5605199933052063, -0.7202264070510864, 0.14695551991462708, -0.33869683742523193, 0.10947427898645401, 0.5763972997665405, -0.058113597333431244, 0.4093017280101776, 2.3707239627838135, -0.0, -0.6179364919662476, -1.2451229095458984, 1.389200210571289, 0.7226887345314026, 1.4976874589920044, 1.443472146987915, 1.30130934715271, 1.0374963283538818, 0.6301659345626831, 0.41897720098495483, 1.9249900579452515, 0.9565982222557068, 1.263087272644043, 0.4947502315044403, 0.8819258809089661, 1.5323832035064697, 0.9487621188163757, 1.3105436563491821, 1.891230821609497, 1.6125582456588745, 1.4655911922454834, 1.1685293912887573, 0.7273183465003967, -1.1256691217422485, -0.0, -0.0, -0.0, 0.0, 5.731160640716553, 0.0, 0.0, 2.9343528747558594, 3.904352903366089, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.979658603668213, 1.1873568296432495, 4.033677577972412, 0.0, -2.8837010860443115, -1.0192697048187256, 0.0, -1.699271559715271, -0.40862441062927246, -2.777024269104004, -0.8944202065467834, -1.1160240173339844, -1.094015121459961, -0.9553385972976685, -0.5523242950439453, -1.072899341583252, -0.37338462471961975, -1.002930760383606, -0.4081212282180786, -0.31155505776405334, 0.12452498078346252, 0.017221279442310333, -0.34855917096138, 0.9104078412055969, 1.1109174489974976, 2.8402533531188965, 1.754338264465332, 0.664877712726593, 0.7114795446395874, 0.6736363172531128, 1.2124853134155273, 1.0278559923171997, 0.950523316860199, 0.38358792662620544, -0.485530823469162, 0.4941278100013733, 0.42679423093795776, 1.2132798433303833, 1.7280346155166626, 1.5060756206512451, 0.9062100648880005, 0.7457932233810425, 1.2284663915634155, 1.0983940362930298, 1.066786766052246, 1.2861549854278564, 1.0629143714904785, 0.3060372769832611, -0.46678346395492554, 1.4918164014816284, -0.210176482796669, -1.7831122875213623, 0.0, 0.0, 0.0, 0.0, 3.130720853805542, 3.2906148433685303, 2.5231375694274902, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 1.979658603668213, 1.1873568296432495, 4.033677577972412, 0.0, -2.8837010860443115, -1.0192697048187256, -0.0, -1.699271559715271, -0.40862441062927246, -2.777024269104004, -0.8944202065467834, -1.1160240173339844, -1.094015121459961, -0.9553385972976685, -0.5523242950439453, -1.072899341583252, -0.37338462471961975, -1.002930760383606, -0.4081212282180786, -0.31155505776405334, 0.12452498078346252, 0.017221279442310333, -0.34855917096138, 0.9104078412055969, 1.1109174489974976, 2.8402533531188965, 1.754338264465332, 0.664877712726593, 0.7114795446395874, 0.6736363172531128, 1.2124853134155273, 1.0278559923171997, 0.950523316860199, 0.38358792662620544, -0.485530823469162, 0.4941278100013733, 0.42679423093795776, 1.2132798433303833, 1.7280346155166626, 1.5060756206512451, 0.9062100648880005, 0.7457932233810425, 1.2284663915634155, 1.0983940362930298, 1.066786766052246, 1.2861549854278564, 1.0629143714904785, 0.3060372769832611, -0.46678346395492554, 1.4918164014816284, -0.210176482796669, -1.7831122875213623, -0.0, 0.0, 0.0, 0.0, 3.130720853805542, 3.2906148433685303, 2.5231375694274902, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.13897709548473358, 0.3120313584804535, -1.7565724849700928, 0.0, 2.299309730529785, -0.594257116317749, 0.0, 0.0, 1.21513831615448, -1.314374327659607, -1.0343016386032104, -1.6561208963394165, -1.1162692308425903, -0.379849374294281, -1.1862506866455078, -0.9984257817268372, -1.0999239683151245, 0.14248855412006378, -0.9247747659683228, -0.08161145448684692, -0.273603230714798, 0.2821473181247711, -0.21871910989284515, 0.060566842555999756, 0.11314408481121063, -0.11800342798233032, 0.09677772223949432, 0.6075836420059204, 0.6066912412643433, 1.2077581882476807, 0.009281438775360584, 1.1030619144439697, 1.4251970052719116, 1.1037092208862305, 1.3156582117080688, 1.331999659538269, 0.8956145644187927, 1.0277314186096191, 0.7324399352073669, 0.9534406065940857, 0.7979711890220642, 0.9130769968032837, 0.8834973573684692, 1.0196030139923096, 0.9625835418701172, 0.8559263348579407, 1.280358910560608, 0.5668949484825134, 0.305009663105011, 0.7883999347686768, 1.5713821649551392, 0.5835846066474915, 1.1567296981811523, 1.2144887447357178, 3.1829841136932373, 0.0, 0.0, 1.7535170316696167, 1.7767224311828613, 4.14809513092041, 3.338179588317871, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, 0.0, 0.13897709548473358, 0.3120313584804535, -1.7565724849700928, 0.0, 2.299309730529785, -0.594257116317749, -0.0, 0.0, 1.21513831615448, -1.314374327659607, -1.0343016386032104, -1.6561208963394165, -1.1162692308425903, -0.379849374294281, -1.1862506866455078, -0.9984257817268372, -1.0999239683151245, 0.14248855412006378, -0.9247747659683228, -0.08161145448684692, -0.273603230714798, 0.2821473181247711, -0.21871910989284515, 0.060566842555999756, 0.11314408481121063, -0.11800342798233032, 0.09677772223949432, 0.6075836420059204, 0.6066912412643433, 1.2077581882476807, 0.009281438775360584, 1.1030619144439697, 1.4251970052719116, 1.1037092208862305, 1.3156582117080688, 1.331999659538269, 0.8956145644187927, 1.0277314186096191, 0.7324399352073669, 0.9534406065940857, 0.7979711890220642, 0.9130769968032837, 0.8834973573684692, 1.0196030139923096, 0.9625835418701172, 0.8559263348579407, 1.280358910560608, 0.5668949484825134, 0.305009663105011, 0.7883999347686768, 1.5713821649551392, 0.5835846066474915, 1.1567296981811523, 1.2144887447357178, 3.1829841136932373, 0.0, 0.0, 1.7535170316696167, 1.7767224311828613, 4.14809513092041, 3.338179588317871, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.03131765127182007, -2.077277898788452, -0.2535516917705536, 0.0, 0.0, 4.3846635818481445, 0.0, 0.0, -1.06240713596344, -1.3001574277877808, -3.304532766342163, -1.3724400997161865, -1.4203745126724243, -1.5595214366912842, -1.5431976318359375, -0.9414201974868774, -1.0468233823776245, -1.404893398284912, -0.608005166053772, -0.7781339883804321, -1.8200198411941528, -0.9475368857383728, 0.11791703850030899, -0.38976678252220154, -0.07165040820837021, 0.11712096631526947, 0.1373443901538849, 0.1853056699037552, 0.48933619260787964, 0.7768024802207947, 0.43961405754089355, 0.7151665687561035, 1.2860991954803467, 1.2188081741333008, 1.297497034072876, 1.2608191967010498, 0.6199561357498169, 0.821242094039917, 1.1537343263626099, 0.8822834491729736, -0.18128715455532074, 1.0378971099853516, 0.5487487316131592, 1.2839329242706299, 1.5324517488479614, 1.0772690773010254, 0.5157577395439148, 1.2530226707458496, 1.2643707990646362, 0.7781747579574585, 0.15159288048744202, 0.6178412437438965, 0.7203177809715271, 0.7080891132354736, 1.0329488515853882, 3.713348388671875, 0.0, 0.0, -0.5548906326293945, 0.2075396031141281, 0.0, 0.0, 2.961829900741577, 4.3251118659973145, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.03131765127182007, -2.077277898788452, -0.2535516917705536, -0.0, 0.0, 4.3846635818481445, -0.0, -0.0, -1.06240713596344, -1.3001574277877808, -3.304532766342163, -1.3724400997161865, -1.4203745126724243, -1.5595214366912842, -1.5431976318359375, -0.9414201974868774, -1.0468233823776245, -1.404893398284912, -0.608005166053772, -0.7781339883804321, -1.8200198411941528, -0.9475368857383728, 0.11791703850030899, -0.38976678252220154, -0.07165040820837021, 0.11712096631526947, 0.1373443901538849, 0.1853056699037552, 0.48933619260787964, 0.7768024802207947, 0.43961405754089355, 0.7151665687561035, 1.2860991954803467, 1.2188081741333008, 1.297497034072876, 1.2608191967010498, 0.6199561357498169, 0.821242094039917, 1.1537343263626099, 0.8822834491729736, -0.18128715455532074, 1.0378971099853516, 0.5487487316131592, 1.2839329242706299, 1.5324517488479614, 1.0772690773010254, 0.5157577395439148, 1.2530226707458496, 1.2643707990646362, 0.7781747579574585, 0.15159288048744202, 0.6178412437438965, 0.7203177809715271, 0.7080891132354736, 1.0329488515853882, 3.713348388671875, 0.0, -0.0, -0.5548906326293945, 0.2075396031141281, 0.0, 0.0, 2.961829900741577, 4.3251118659973145, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.31665971875190735, 0.20187367498874664, 0.0, 1.929460883140564, -0.17818590998649597, 0.0, 0.0, 0.0, -3.3030505180358887, -2.5066161155700684, -3.247739791870117, -2.326801300048828, -2.0427427291870117, -1.6781649589538574, -1.33700430393219, -1.4072686433792114, -1.433465600013733, -1.632702112197876, -0.9303216934204102, -0.4822908043861389, -0.5994775891304016, -0.3929503560066223, 0.6194504499435425, -0.09966229647397995, -0.2618483603000641, 0.48122352361679077, 0.3563886880874634, -0.04602556303143501, 0.4774443507194519, -0.3019395172595978, 0.7662297487258911, 1.387308120727539, 0.904267430305481, 0.7106389999389648, 1.1223713159561157, 0.5308669805526733, 1.1682084798812866, 0.4545847475528717, 1.1741645336151123, 1.1803804636001587, 0.6584400534629822, 0.5463799834251404, 0.46439048647880554, 0.561838686466217, 1.240564227104187, 1.1687569618225098, 0.5822190046310425, 0.6271541714668274, 1.0301567316055298, 0.9908127784729004, 1.6922690868377686, 0.8489608764648438, 0.9810172319412231, 0.8049091696739197, 0.3377760648727417, 0.8805955648422241, -0.9675381183624268, 0.0, 0.0, 0.0, 0.0, 0.0, 0.8653430342674255, 3.624150037765503, 3.7876827716827393, 3.754385232925415, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.31665971875190735, 0.20187367498874664, -0.0, 1.929460883140564, -0.17818590998649597, -0.0, 0.0, -0.0, -3.3030505180358887, -2.5066161155700684, -3.247739791870117, -2.326801300048828, -2.0427427291870117, -1.6781649589538574, -1.33700430393219, -1.4072686433792114, -1.433465600013733, -1.632702112197876, -0.9303216934204102, -0.4822908043861389, -0.5994775891304016, -0.3929503560066223, 0.6194504499435425, -0.09966229647397995, -0.2618483603000641, 0.48122352361679077, 0.3563886880874634, -0.04602556303143501, 0.4774443507194519, -0.3019395172595978, 0.7662297487258911, 1.387308120727539, 0.904267430305481, 0.7106389999389648, 1.1223713159561157, 0.5308669805526733, 1.1682084798812866, 0.4545847475528717, 1.1741645336151123, 1.1803804636001587, 0.6584400534629822, 0.5463799834251404, 0.46439048647880554, 0.561838686466217, 1.240564227104187, 1.1687569618225098, 0.5822190046310425, 0.6271541714668274, 1.0301567316055298, 0.9908127784729004, 1.6922690868377686, 0.8489608764648438, 0.9810172319412231, 0.8049091696739197, 0.3377760648727417, 0.8805955648422241, -0.9675381183624268, -0.0, -0.0, -0.0, 0.0, 0.0, 0.8653430342674255, 3.624150037765503, 3.7876827716827393, 3.754385232925415, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.7784475088119507, 0.28760018944740295, -0.296858012676239, 0.0, -0.7483680844306946, 0.0, 0.0, 0.0, -2.2614712715148926, -2.5389816761016846, -2.4946579933166504, -1.4744399785995483, -2.6288416385650635, -1.8373769521713257, -1.3403657674789429, -1.3022024631500244, -1.180770993232727, -0.9271230697631836, -0.48067736625671387, 0.02745801955461502, -0.45698297023773193, -0.08567920327186584, 0.01944948546588421, 0.2835952937602997, 0.22104977071285248, -0.41481679677963257, 1.1494684219360352, 0.14611800014972687, 0.37705355882644653, 0.7885677218437195, 0.10394632816314697, 0.7074229121208191, 0.8327161073684692, 0.8705897331237793, 0.8343908190727234, 1.5144490003585815, 1.2518913745880127, 1.178475260734558, 1.1557639837265015, 0.14174669981002808, 0.6809908151626587, 0.506398618221283, 0.9465376734733582, 1.1212773323059082, 1.2881011962890625, 1.24147629737854, 1.5060745477676392, 0.6121663451194763, 0.7795937061309814, 0.7474988102912903, 0.2840692102909088, 0.8965941071510315, 1.4297716617584229, 0.5533156394958496, 0.6473076343536377, 0.7862914800643921, 0.2823235094547272, 0.22984790802001953, 0.20580755174160004, 0.0, 0.0, 0.0, 0.9121926426887512, 1.1970494985580444, 0.0, 1.7259433269500732, 2.145993709564209, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -1.7784475088119507, 0.28760018944740295, -0.296858012676239, -0.0, -0.7483680844306946, -0.0, -0.0, -0.0, -2.2614712715148926, -2.5389816761016846, -2.4946579933166504, -1.4744399785995483, -2.6288416385650635, -1.8373769521713257, -1.3403657674789429, -1.3022024631500244, -1.180770993232727, -0.9271230697631836, -0.48067736625671387, 0.02745801955461502, -0.45698297023773193, -0.08567920327186584, 0.01944948546588421, 0.2835952937602997, 0.22104977071285248, -0.41481679677963257, 1.1494684219360352, 0.14611800014972687, 0.37705355882644653, 0.7885677218437195, 0.10394632816314697, 0.7074229121208191, 0.8327161073684692, 0.8705897331237793, 0.8343908190727234, 1.5144490003585815, 1.2518913745880127, 1.178475260734558, 1.1557639837265015, 0.14174669981002808, 0.6809908151626587, 0.506398618221283, 0.9465376734733582, 1.1212773323059082, 1.2881011962890625, 1.24147629737854, 1.5060745477676392, 0.6121663451194763, 0.7795937061309814, 0.7474988102912903, 0.2840692102909088, 0.8965941071510315, 1.4297716617584229, 0.5533156394958496, 0.6473076343536377, 0.7862914800643921, 0.2823235094547272, 0.22984790802001953, 0.20580755174160004, 0.0, 0.0, 0.0, 0.9121926426887512, 1.1970494985580444, 0.0, 1.7259433269500732, 2.145993709564209, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.6831333041191101, -0.06935863196849823, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -3.4559378623962402, -3.013603687286377, -2.8317160606384277, -2.9591500759124756, -2.3718178272247314, -2.5581841468811035, -2.406480312347412, -1.8139750957489014, -1.5595515966415405, -1.2015002965927124, -1.6994974613189697, -1.4995744228363037, -0.5961545705795288, -0.5261787176132202, -0.7486652135848999, -1.168199896812439, -0.4105692207813263, 0.18781934678554535, 0.13361690938472748, -0.18973785638809204, 0.2318999171257019, 0.7739737033843994, 0.7734514474868774, 0.42371806502342224, -0.1758730560541153, 0.8108311891555786, 0.14298969507217407, 1.0095114707946777, 1.2311131954193115, 0.961222231388092, 0.8479458689689636, 0.7569063901901245, 1.427186369895935, 0.7513095736503601, 1.310410499572754, 1.2727608680725098, 0.1486728936433792, 1.0016720294952393, 1.0386358499526978, 0.9103673696517944, 1.172232747077942, 0.9475302696228027, 1.8186613321304321, 0.935331404209137, 0.7662354111671448, 1.5622260570526123, 1.7164216041564941, 1.0394010543823242, 0.714712381362915, 0.6441947817802429, 0.4177625775337219, 0.5671365261077881, 1.493471384048462, 0.0, 0.0, 0.0, 0.0, 0.0, 0.8979331254959106, 3.0193800926208496, 3.150851011276245, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.6831333041191101, -0.06935863196849823, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -3.4559378623962402, -3.013603687286377, -2.8317160606384277, -2.9591500759124756, -2.3718178272247314, -2.5581841468811035, -2.406480312347412, -1.8139750957489014, -1.5595515966415405, -1.2015002965927124, -1.6994974613189697, -1.4995744228363037, -0.5961545705795288, -0.5261787176132202, -0.7486652135848999, -1.168199896812439, -0.4105692207813263, 0.18781934678554535, 0.13361690938472748, -0.18973785638809204, 0.2318999171257019, 0.7739737033843994, 0.7734514474868774, 0.42371806502342224, -0.1758730560541153, 0.8108311891555786, 0.14298969507217407, 1.0095114707946777, 1.2311131954193115, 0.961222231388092, 0.8479458689689636, 0.7569063901901245, 1.427186369895935, 0.7513095736503601, 1.310410499572754, 1.2727608680725098, 0.1486728936433792, 1.0016720294952393, 1.0386358499526978, 0.9103673696517944, 1.172232747077942, 0.9475302696228027, 1.8186613321304321, 0.935331404209137, 0.7662354111671448, 1.5622260570526123, 1.7164216041564941, 1.0394010543823242, 0.714712381362915, 0.6441947817802429, 0.4177625775337219, 0.5671365261077881, 1.493471384048462, 0.0, 0.0, 0.0, 0.0, 0.0, 0.8979331254959106, 3.0193800926208496, 3.150851011276245, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, 0.891390323638916, -0.5710275769233704, 0.10849128663539886, 0.0, -0.5000417232513428, 0.0, 0.0, 0.0, -2.625082492828369, -3.0152432918548584, -2.9588305950164795, -3.182863712310791, -2.8059399127960205, -2.246976375579834, -1.9266527891159058, -1.8844910860061646, -2.0366291999816895, -1.3259189128875732, -1.2941410541534424, -1.7036012411117554, -1.5686928033828735, -1.53338623046875, -0.4979681670665741, -0.14935274422168732, -0.6298138499259949, 0.4870944023132324, -0.28291550278663635, -0.10743776708841324, 0.20389549434185028, 0.6457309126853943, 0.09350186586380005, 0.6225829124450684, 0.94209885597229, 0.6736270189285278, 0.8037027716636658, 0.2982686758041382, 0.9717884659767151, 0.988158106803894, 0.9478685855865479, 0.9364721775054932, 0.9723134636878967, 1.0916024446487427, 1.6999796628952026, 1.4131981134414673, 0.38876697421073914, 1.0925122499465942, 1.2373459339141846, 1.2314796447753906, 1.001262903213501, 0.824577808380127, 1.164297342300415, 1.7570507526397705, 1.371285080909729, 1.1469882726669312, 0.9412131905555725, 1.1486635208129883, 0.9751881957054138, 0.8673670291900635, 0.6660382747650146, 0.7657639384269714, -0.015584982000291348, 0.3172225058078766, 1.602185606956482, 0.0, 0.0, 0.0, 2.8442208766937256, 3.915736436843872, 4.635813236236572, 5.00950813293457, 5.251308917999268, 0.0, 0.0, 0.0, -0.0, -0.0, 0.0, 0.0, 0.891390323638916, -0.5710275769233704, 0.10849128663539886, -0.0, -0.5000417232513428, -0.0, -0.0, -0.0, -2.625082492828369, -3.0152432918548584, -2.9588305950164795, -3.182863712310791, -2.8059399127960205, -2.246976375579834, -1.9266527891159058, -1.8844910860061646, -2.0366291999816895, -1.3259189128875732, -1.2941410541534424, -1.7036012411117554, -1.5686928033828735, -1.53338623046875, -0.4979681670665741, -0.14935274422168732, -0.6298138499259949, 0.4870944023132324, -0.28291550278663635, -0.10743776708841324, 0.20389549434185028, 0.6457309126853943, 0.09350186586380005, 0.6225829124450684, 0.94209885597229, 0.6736270189285278, 0.8037027716636658, 0.2982686758041382, 0.9717884659767151, 0.988158106803894, 0.9478685855865479, 0.9364721775054932, 0.9723134636878967, 1.0916024446487427, 1.6999796628952026, 1.4131981134414673, 0.38876697421073914, 1.0925122499465942, 1.2373459339141846, 1.2314796447753906, 1.001262903213501, 0.824577808380127, 1.164297342300415, 1.7570507526397705, 1.371285080909729, 1.1469882726669312, 0.9412131905555725, 1.1486635208129883, 0.9751881957054138, 0.8673670291900635, 0.6660382747650146, 0.7657639384269714, -0.015584982000291348, 0.3172225058078766, 1.602185606956482, 0.0, 0.0, 0.0, 2.8442208766937256, 3.915736436843872, 4.635813236236572, 5.00950813293457, 5.251308917999268, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, 0.0, -2.158355236053467, -2.491860866546631, 0.0, -5.019843101501465, -2.1934003829956055, 0.0, 0.0, -3.7211079597473145, -2.5973753929138184, -2.38649582862854, -2.996623992919922, -2.635946750640869, -3.1284759044647217, -2.6771247386932373, -2.237313985824585, -1.7396008968353271, -2.5075793266296387, -1.1273859739303589, -1.1115944385528564, -1.483677625656128, 0.07303797453641891, -0.7478782534599304, -0.6417897939682007, -0.7295858860015869, -0.19008247554302216, 0.12183976173400879, -0.3137339651584625, 0.7049070596694946, 0.6308978796005249, 0.37698715925216675, 0.20327238738536835, 0.4568561315536499, 0.04501771181821823, 0.2717548906803131, 1.2210215330123901, 1.3447301387786865, 0.1611623615026474, 1.0686572790145874, 1.2376974821090698, 1.1045327186584473, 0.9832984805107117, 1.0668725967407227, 1.981751799583435, 2.0091891288757324, 0.5506511330604553, 0.8560579419136047, 1.691003680229187, 1.3602232933044434, 0.8831126093864441, 1.6320403814315796, 1.6909281015396118, 0.6388793587684631, 0.6335660219192505, 0.45325958728790283, 1.770576000213623, 0.8790489435195923, 0.7088825106620789, 0.691163957118988, 0.17983181774616241, 1.0123540163040161, -0.04181506484746933, 0.5433489084243774, 1.7599031925201416, 1.2589585781097412, 0.4201171398162842, 0.0, 0.0, 3.0087685585021973, 0.0, 4.249544620513916, 4.148549556732178, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -2.158355236053467, -2.491860866546631, 0.0, -5.019843101501465, -2.1934003829956055, -0.0, -0.0, -3.7211079597473145, -2.5973753929138184, -2.38649582862854, -2.996623992919922, -2.635946750640869, -3.1284759044647217, -2.6771247386932373, -2.237313985824585, -1.7396008968353271, -2.5075793266296387, -1.1273859739303589, -1.1115944385528564, -1.483677625656128, 0.07303797453641891, -0.7478782534599304, -0.6417897939682007, -0.7295858860015869, -0.19008247554302216, 0.12183976173400879, -0.3137339651584625, 0.7049070596694946, 0.6308978796005249, 0.37698715925216675, 0.20327238738536835, 0.4568561315536499, 0.04501771181821823, 0.2717548906803131, 1.2210215330123901, 1.3447301387786865, 0.1611623615026474, 1.0686572790145874, 1.2376974821090698, 1.1045327186584473, 0.9832984805107117, 1.0668725967407227, 1.981751799583435, 2.0091891288757324, 0.5506511330604553, 0.8560579419136047, 1.691003680229187, 1.3602232933044434, 0.8831126093864441, 1.6320403814315796, 1.6909281015396118, 0.6388793587684631, 0.6335660219192505, 0.45325958728790283, 1.770576000213623, 0.8790489435195923, 0.7088825106620789, 0.691163957118988, 0.17983181774616241, 1.0123540163040161, -0.04181506484746933, 0.5433489084243774, 1.7599031925201416, 1.2589585781097412, 0.4201171398162842, 0.0, 0.0, 3.0087685585021973, 0.0, 4.249544620513916, 4.148549556732178, 0.0, 0.0, 0.0], [0.0, 0.0, 0.0, -1.8554072380065918, -2.4230117797851562, -4.831282615661621, -2.3843393325805664, -2.1252150535583496, 0.0, 0.0, -2.7868714332580566, -3.1183202266693115, -3.3859431743621826, -4.136152267456055, -2.888484239578247, -2.6950924396514893, -2.378689765930176, -1.4591225385665894, -1.8334234952926636, -1.737039566040039, -2.0853970050811768, -1.2155429124832153, -1.6501235961914062, -3.7047810554504395, -0.8602938652038574, -0.9409635066986084, -0.8268613815307617, -0.49713996052742004, -0.541976273059845, -0.40515562891960144, -0.07516147941350937, 0.4825986325740814, 0.4913807213306427, 0.2116367667913437, 0.7037457227706909, 0.38843315839767456, 0.6417635679244995, 0.1063648983836174, 1.2208220958709717, 1.0780755281448364, 0.8294336199760437, 1.2165714502334595, 1.1294195652008057, 1.5393425226211548, 1.0263144969940186, 0.8756475448608398, 1.1897268295288086, 1.5530184507369995, 1.9018415212631226, 1.533473253250122, 0.9401301145553589, 0.5617417693138123, 0.946902871131897, 2.379457712173462, 2.272538661956787, 1.4912782907485962, 1.8314374685287476, 0.3526868224143982, 1.226850986480713, 0.6559746861457825, 1.211169958114624, 0.8928067684173584, 0.9964951276779175, 1.4227261543273926, 0.5237489342689514, 0.9448235034942627, 0.8800276517868042, 1.1681455373764038, 0.8773946762084961, -0.9979652166366577, 0.0, 0.0, 1.8832893371582031, 2.4970898628234863, 5.90407657623291, 6.7300543785095215, 0.0, 0.0, 0.0, 0.0, -0.0, -1.8554072380065918, -2.4230117797851562, -4.831282615661621, -2.3843393325805664, -2.1252150535583496, -0.0, -0.0, -2.7868714332580566, -3.1183202266693115, -3.3859431743621826, -4.136152267456055, -2.888484239578247, -2.6950924396514893, -2.378689765930176, -1.4591225385665894, -1.8334234952926636, -1.737039566040039, -2.0853970050811768, -1.2155429124832153, -1.6501235961914062, -3.7047810554504395, -0.8602938652038574, -0.9409635066986084, -0.8268613815307617, -0.49713996052742004, -0.541976273059845, -0.40515562891960144, -0.07516147941350937, 0.4825986325740814, 0.4913807213306427, 0.2116367667913437, 0.7037457227706909, 0.38843315839767456, 0.6417635679244995, 0.1063648983836174, 1.2208220958709717, 1.0780755281448364, 0.8294336199760437, 1.2165714502334595, 1.1294195652008057, 1.5393425226211548, 1.0263144969940186, 0.8756475448608398, 1.1897268295288086, 1.5530184507369995, 1.9018415212631226, 1.533473253250122, 0.9401301145553589, 0.5617417693138123, 0.946902871131897, 2.379457712173462, 2.272538661956787, 1.4912782907485962, 1.8314374685287476, 0.3526868224143982, 1.226850986480713, 0.6559746861457825, 1.211169958114624, 0.8928067684173584, 0.9964951276779175, 1.4227261543273926, 0.5237489342689514, 0.9448235034942627, 0.8800276517868042, 1.1681455373764038, 0.8773946762084961, -0.9979652166366577, -0.0, 0.0, 1.8832893371582031, 2.4970898628234863, 5.90407657623291, 6.7300543785095215, 0.0, 0.0], [0.0, 0.0, 0.4746008813381195, -1.6515005826950073, -3.304356575012207, 0.0, -0.8235371112823486, 0.0, 0.0, 0.0, -3.330573320388794, -3.3191041946411133, -3.593440055847168, -3.477858066558838, -3.8059487342834473, -3.0654549598693848, -2.0864715576171875, -2.467822790145874, -1.7633988857269287, -2.293977737426758, -1.296352744102478, -2.2491443157196045, -1.401961326599121, -0.9416108131408691, -3.903444528579712, -0.6627151966094971, -0.5260283946990967, 0.23035115003585815, -0.7325911521911621, -0.5129393935203552, 0.40994924306869507, 0.1796606332063675, 0.08482522517442703, 0.36285942792892456, 1.3053269386291504, 0.7587653398513794, 0.4943406879901886, 1.7856448888778687, 0.4111490845680237, 1.683958888053894, 1.1610345840454102, 1.162137746810913, 1.0255159139633179, 0.8807235956192017, 2.1415345668792725, 1.5332719087600708, 0.7303655743598938, 0.5398383736610413, 2.4942805767059326, 1.4762954711914062, 1.8010777235031128, 1.4069384336471558, 1.061012864112854, 0.8581735491752625, 0.7430365681648254, 0.9097747802734375, 3.5771985054016113, 1.2860043048858643, 1.7084184885025024, 0.744965136051178, 0.8627190589904785, 1.6452326774597168, 0.619552493095398, 0.7265349626541138, 0.9428583979606628, -0.20323535799980164, 0.8403323292732239, 0.8983425498008728, 1.353515863418579, 1.8565773963928223, 0.0, 0.0, -0.8638201951980591, -0.130411297082901, 4.061652660369873, 5.65029764175415, 6.869464874267578, 0.0, 0.0, 0.0, 0.4746008813381195, -1.6515005826950073, -3.304356575012207, -0.0, -0.8235371112823486, -0.0, -0.0, -0.0, -3.330573320388794, -3.3191041946411133, -3.593440055847168, -3.477858066558838, -3.8059487342834473, -3.0654549598693848, -2.0864715576171875, -2.467822790145874, -1.7633988857269287, -2.293977737426758, -1.296352744102478, -2.2491443157196045, -1.401961326599121, -0.9416108131408691, -3.903444528579712, -0.6627151966094971, -0.5260283946990967, 0.23035115003585815, -0.7325911521911621, -0.5129393935203552, 0.40994924306869507, 0.1796606332063675, 0.08482522517442703, 0.36285942792892456, 1.3053269386291504, 0.7587653398513794, 0.4943406879901886, 1.7856448888778687, 0.4111490845680237, 1.683958888053894, 1.1610345840454102, 1.162137746810913, 1.0255159139633179, 0.8807235956192017, 2.1415345668792725, 1.5332719087600708, 0.7303655743598938, 0.5398383736610413, 2.4942805767059326, 1.4762954711914062, 1.8010777235031128, 1.4069384336471558, 1.061012864112854, 0.8581735491752625, 0.7430365681648254, 0.9097747802734375, 3.5771985054016113, 1.2860043048858643, 1.7084184885025024, 0.744965136051178, 0.8627190589904785, 1.6452326774597168, 0.619552493095398, 0.7265349626541138, 0.9428583979606628, -0.20323535799980164, 0.8403323292732239, 0.8983425498008728, 1.353515863418579, 1.8565773963928223, 0.0, -0.0, -0.8638201951980591, -0.130411297082901, 4.061652660369873, 5.65029764175415, 6.869464874267578, 0.0], [0.0, 0.0, -4.290987491607666, -0.8869003057479858, -4.7510085105896, -7.269857883453369, 0.0, 0.0, 0.0, -3.6470625400543213, -3.913306713104248, -3.4302759170532227, -3.4374501705169678, -5.131506443023682, -3.605109930038452, -2.9901530742645264, -2.617306709289551, -2.5302624702453613, -2.387913942337036, -1.9964123964309692, -2.0740582942962646, -1.58222496509552, -0.9560309648513794, -1.6502952575683594, -1.2665989398956299, -0.9934799671173096, -0.10817193984985352, 0.05340981483459473, -0.5596045851707458, -0.27338847517967224, 0.629462480545044, 0.3159152865409851, 0.6445251703262329, 1.1855357885360718, -0.2764061689376831, 0.4754539430141449, -0.02015627548098564, 0.18729138374328613, 0.7203311324119568, 1.1585241556167603, 1.568393349647522, 0.909407377243042, 1.0144368410110474, 0.5204375982284546, 1.2982646226882935, 1.0143252611160278, 0.4636923372745514, 1.4834367036819458, 1.8057944774627686, 1.1430718898773193, 1.0110112428665161, 1.120054006576538, 1.2366728782653809, 1.0983805656433105, 0.8080388903617859, 1.7474740743637085, 1.2214365005493164, 0.5617204904556274, 2.4504168033599854, 0.8198095560073853, 1.2290706634521484, 1.1283330917358398, 1.3633298873901367, 0.7794745564460754, 0.5333600044250488, 1.0230941772460938, 0.8192123770713806, 1.0284903049468994, 0.9931951761245728, 1.4250210523605347, 3.9195432662963867, 0.0, 0.0, 0.0, 0.0, 4.666625499725342, 6.280948638916016, 0.0, -0.0, -0.0, -4.290987491607666, -0.8869003057479858, -4.7510085105896, -7.269857883453369, -0.0, -0.0, -0.0, -3.6470625400543213, -3.913306713104248, -3.4302759170532227, -3.4374501705169678, -5.131506443023682, -3.605109930038452, -2.9901530742645264, -2.617306709289551, -2.5302624702453613, -2.387913942337036, -1.9964123964309692, -2.0740582942962646, -1.58222496509552, -0.9560309648513794, -1.6502952575683594, -1.2665989398956299, -0.9934799671173096, -0.10817193984985352, 0.05340981483459473, -0.5596045851707458, -0.27338847517967224, 0.629462480545044, 0.3159152865409851, 0.6445251703262329, 1.1855357885360718, -0.2764061689376831, 0.4754539430141449, -0.02015627548098564, 0.18729138374328613, 0.7203311324119568, 1.1585241556167603, 1.568393349647522, 0.909407377243042, 1.0144368410110474, 0.5204375982284546, 1.2982646226882935, 1.0143252611160278, 0.4636923372745514, 1.4834367036819458, 1.8057944774627686, 1.1430718898773193, 1.0110112428665161, 1.120054006576538, 1.2366728782653809, 1.0983805656433105, 0.8080388903617859, 1.7474740743637085, 1.2214365005493164, 0.5617204904556274, 2.4504168033599854, 0.8198095560073853, 1.2290706634521484, 1.1283330917358398, 1.3633298873901367, 0.7794745564460754, 0.5333600044250488, 1.0230941772460938, 0.8192123770713806, 1.0284903049468994, 0.9931951761245728, 1.4250210523605347, 3.9195432662963867, 0.0, -0.0, -0.0, 0.0, 4.666625499725342, 6.280948638916016, 0.0], [0.0, -1.7966257333755493, -3.242201328277588, 0.0, -6.723295211791992, -6.930031776428223, 0.0, 0.0, 0.0, -5.445068836212158, -4.936439514160156, -4.147866725921631, -3.8889293670654297, -3.2809643745422363, -2.9291584491729736, -3.546527624130249, -2.356837272644043, -1.8447402715682983, -3.7709901332855225, -1.0637218952178955, -2.3610763549804688, -1.5099037885665894, -1.244086742401123, -0.6827413439750671, -1.1004256010055542, -0.9957186579704285, -1.0151106119155884, -1.1568092107772827, 0.0407683365046978, -0.13552424311637878, -0.12437476962804794, 0.2659721076488495, 0.422275573015213, 2.1512396335601807, 0.3632808327674866, 0.6557135581970215, 0.04663544520735741, 1.0662373304367065, 0.6058562397956848, 1.4162139892578125, 0.772236168384552, 0.36388295888900757, 1.4530152082443237, 1.6484187841415405, 1.6903090476989746, 1.382299780845642, 1.3218655586242676, 1.6231745481491089, 0.9283609986305237, 1.5252519845962524, 1.4823509454727173, 0.9960678219795227, 1.240026593208313, 0.9309872984886169, 1.5915392637252808, 1.835866928100586, 0.8810520768165588, 1.1708118915557861, 0.2809140384197235, 0.31588542461395264, 0.9828393459320068, 1.2642838954925537, 0.8730961084365845, 0.2875370383262634, 0.8381294012069702, 1.7987275123596191, 1.5253300666809082, -1.0545729398727417, 0.5986010432243347, 1.179747223854065, 1.73322331905365, 0.0, 0.0, 0.0, 0.9928036332130432, 0.0, 4.006091117858887, 5.543036460876465, -0.0, -1.7966257333755493, -3.242201328277588, -0.0, -6.723295211791992, -6.930031776428223, -0.0, -0.0, -0.0, -5.445068836212158, -4.936439514160156, -4.147866725921631, -3.8889293670654297, -3.2809643745422363, -2.9291584491729736, -3.546527624130249, -2.356837272644043, -1.8447402715682983, -3.7709901332855225, -1.0637218952178955, -2.3610763549804688, -1.5099037885665894, -1.244086742401123, -0.6827413439750671, -1.1004256010055542, -0.9957186579704285, -1.0151106119155884, -1.1568092107772827, 0.0407683365046978, -0.13552424311637878, -0.12437476962804794, 0.2659721076488495, 0.422275573015213, 2.1512396335601807, 0.3632808327674866, 0.6557135581970215, 0.04663544520735741, 1.0662373304367065, 0.6058562397956848, 1.4162139892578125, 0.772236168384552, 0.36388295888900757, 1.4530152082443237, 1.6484187841415405, 1.6903090476989746, 1.382299780845642, 1.3218655586242676, 1.6231745481491089, 0.9283609986305237, 1.5252519845962524, 1.4823509454727173, 0.9960678219795227, 1.240026593208313, 0.9309872984886169, 1.5915392637252808, 1.835866928100586, 0.8810520768165588, 1.1708118915557861, 0.2809140384197235, 0.31588542461395264, 0.9828393459320068, 1.2642838954925537, 0.8730961084365845, 0.2875370383262634, 0.8381294012069702, 1.7987275123596191, 1.5253300666809082, -1.0545729398727417, 0.5986010432243347, 1.179747223854065, 1.73322331905365, 0.0, 0.0, 0.0, 0.9928036332130432, 0.0, 4.006091117858887, 5.543036460876465], [-1.5787742137908936, -1.0842020511627197, -5.30670166015625, 0.0, -7.155555725097656, 0.0, 0.0, 0.0, -5.838186740875244, -5.58305025100708, -4.8905229568481445, -4.271909236907959, -4.434023857116699, -3.805649757385254, -3.1814475059509277, -2.3939261436462402, -3.107264757156372, -2.250974655151367, -3.2723793983459473, -1.8611425161361694, -0.9634402990341187, -1.3533602952957153, -1.5057132244110107, -0.23484785854816437, -0.3988112211227417, -0.6913604140281677, -0.6384575366973877, -0.7301878929138184, -0.6033150553703308, -0.20144973695278168, -0.10985095798969269, 0.5191327929496765, 0.09101948887109756, 0.43014901876449585, 0.13303303718566895, -0.4683598577976227, 1.0467818975448608, 0.892458438873291, 1.4337563514709473, 0.6493173837661743, 0.515819251537323, 0.9957808256149292, 1.28721284866333, 2.0679285526275635, 1.2334152460098267, 0.5480401515960693, 2.2376084327697754, 1.286882996559143, 1.568702220916748, 1.3785336017608643, 0.9697360992431641, 0.30651119351387024, 1.1490707397460938, 2.470238447189331, 1.0325393676757812, 0.562574028968811, 1.634303331375122, 1.7270022630691528, 1.2063026428222656, 0.8088700175285339, 1.3808939456939697, 1.715126395225525, 1.3216009140014648, 1.4208098649978638, 1.3422493934631348, 0.5317339301109314, 0.9893589615821838, 0.8876633048057556, 1.2189091444015503, 1.4782181978225708, 1.2722036838531494, 2.175140857696533, 0.0, 0.0, 0.2127634733915329, 0.0, 4.32963228225708, 6.595488548278809, -1.5787742137908936, -1.0842020511627197, -5.30670166015625, -0.0, -7.155555725097656, -0.0, -0.0, -0.0, -5.838186740875244, -5.58305025100708, -4.8905229568481445, -4.271909236907959, -4.434023857116699, -3.805649757385254, -3.1814475059509277, -2.3939261436462402, -3.107264757156372, -2.250974655151367, -3.2723793983459473, -1.8611425161361694, -0.9634402990341187, -1.3533602952957153, -1.5057132244110107, -0.23484785854816437, -0.3988112211227417, -0.6913604140281677, -0.6384575366973877, -0.7301878929138184, -0.6033150553703308, -0.20144973695278168, -0.10985095798969269, 0.5191327929496765, 0.09101948887109756, 0.43014901876449585, 0.13303303718566895, -0.4683598577976227, 1.0467818975448608, 0.892458438873291, 1.4337563514709473, 0.6493173837661743, 0.515819251537323, 0.9957808256149292, 1.28721284866333, 2.0679285526275635, 1.2334152460098267, 0.5480401515960693, 2.2376084327697754, 1.286882996559143, 1.568702220916748, 1.3785336017608643, 0.9697360992431641, 0.30651119351387024, 1.1490707397460938, 2.470238447189331, 1.0325393676757812, 0.562574028968811, 1.634303331375122, 1.7270022630691528, 1.2063026428222656, 0.8088700175285339, 1.3808939456939697, 1.715126395225525, 1.3216009140014648, 1.4208098649978638, 1.3422493934631348, 0.5317339301109314, 0.9893589615821838, 0.8876633048057556, 1.2189091444015503, 1.4782181978225708, 1.2722036838531494, 2.175140857696533, 0.0, 0.0, 0.2127634733915329, 0.0, 4.32963228225708, 6.595488548278809], [-2.0771501064300537, -1.339023470878601, -4.2038164138793945, 0.0, -9.43350601196289, 0.0, 0.0, -5.910905361175537, -5.526287078857422, -5.14870023727417, -4.521742343902588, -4.655202865600586, -3.8403913974761963, -2.769165515899658, -2.9710183143615723, -2.8907408714294434, -2.107459783554077, -2.4218690395355225, -2.361112594604492, -2.5302164554595947, -1.654957890510559, -1.4931484460830688, 0.23778879642486572, -0.7383654117584229, -0.5822891592979431, 0.07055108994245529, -0.9587765336036682, -1.5375417470932007, -0.5105026364326477, 0.23035185039043427, 0.09754931181669235, 0.01516159251332283, 0.2932847738265991, 0.421874076128006, 0.0880010724067688, 0.1997913271188736, 0.4085468053817749, 0.5349932312965393, 0.9316682815551758, 1.6777743101119995, 0.7459301352500916, 2.535397529602051, 1.9256724119186401, 1.5326892137527466, 1.7263373136520386, 1.198447823524475, 0.981330931186676, 1.6832973957061768, 1.48062264919281, 1.3827980756759644, 2.259509563446045, 2.188445568084717, 1.1885054111480713, 1.1361702680587769, 2.650175094604492, 1.7889113426208496, 2.2800803184509277, 0.8826870322227478, 1.5862562656402588, 0.9719694256782532, 0.8022134304046631, 0.8706744313240051, 1.589160680770874, 1.6044366359710693, 0.8314931988716125, 1.300162672996521, 1.8260302543640137, 0.7885562777519226, 1.321851134300232, 1.1234111785888672, 1.4086191654205322, 1.9274723529815674, 0.0, 0.0, 0.0, 0.0, 0.0, 8.26900577545166, -2.0771501064300537, -1.339023470878601, -4.2038164138793945, -0.0, -9.43350601196289, -0.0, -0.0, -5.910905361175537, -5.526287078857422, -5.14870023727417, -4.521742343902588, -4.655202865600586, -3.8403913974761963, -2.769165515899658, -2.9710183143615723, -2.8907408714294434, -2.107459783554077, -2.4218690395355225, -2.361112594604492, -2.5302164554595947, -1.654957890510559, -1.4931484460830688, 0.23778879642486572, -0.7383654117584229, -0.5822891592979431, 0.07055108994245529, -0.9587765336036682, -1.5375417470932007, -0.5105026364326477, 0.23035185039043427, 0.09754931181669235, 0.01516159251332283, 0.2932847738265991, 0.421874076128006, 0.0880010724067688, 0.1997913271188736, 0.4085468053817749, 0.5349932312965393, 0.9316682815551758, 1.6777743101119995, 0.7459301352500916, 2.535397529602051, 1.9256724119186401, 1.5326892137527466, 1.7263373136520386, 1.198447823524475, 0.981330931186676, 1.6832973957061768, 1.48062264919281, 1.3827980756759644, 2.259509563446045, 2.188445568084717, 1.1885054111480713, 1.1361702680587769, 2.650175094604492, 1.7889113426208496, 2.2800803184509277, 0.8826870322227478, 1.5862562656402588, 0.9719694256782532, 0.8022134304046631, 0.8706744313240051, 1.589160680770874, 1.6044366359710693, 0.8314931988716125, 1.300162672996521, 1.8260302543640137, 0.7885562777519226, 1.321851134300232, 1.1234111785888672, 1.4086191654205322, 1.9274723529815674, 0.0, 0.0, 0.0, 0.0, 0.0, 8.26900577545166], [-1.2551395893096924, 0.0, 0.0, 0.0, 0.0, 0.0, -5.530953884124756, -5.364499568939209, -4.599081516265869, -4.590511322021484, -4.589367866516113, -3.2992591857910156, -4.9722676277160645, -4.1737961769104, -3.5093724727630615, -2.9264585971832275, -2.0851428508758545, -2.7794597148895264, -2.264662027359009, -1.8982371091842651, -1.5928007364273071, -0.6255652904510498, -0.3833869695663452, -0.8928344249725342, -0.7536735534667969, -0.3844488859176636, -0.6126847267150879, -1.2662980556488037, -0.07996363937854767, 0.24967338144779205, 0.3937244415283203, 0.28476208448410034, -0.6227888464927673, 0.4808911085128784, 0.14185400307178497, 0.08668585866689682, 0.371671587228775, 1.5185086727142334, 1.626985788345337, 0.40997859835624695, 0.6285750269889832, 1.1259503364562988, 0.5669443011283875, 0.7968780994415283, 1.110852599143982, 1.3289471864700317, 1.2121765613555908, 3.118082284927368, 1.3656017780303955, 1.5849037170410156, 2.0012285709381104, 1.7152661085128784, 1.3753864765167236, 1.77810800075531, 0.8417423963546753, 1.1967685222625732, 0.9047791361808777, 0.9561734199523926, 1.317640781402588, 1.329757571220398, 1.1924340724945068, 1.5181368589401245, 1.611673355102539, 1.8675028085708618, 2.898986577987671, 1.0595579147338867, 1.4559098482131958, 1.7670819759368896, 1.4235233068466187, 1.9038094282150269, 1.0651861429214478, 1.71710205078125, 1.7818623781204224, 0.0, 0.0, 0.0, 0.0, 7.200682163238525, -1.2551395893096924, -0.0, -0.0, -0.0, -0.0, -0.0, -5.530953884124756, -5.364499568939209, -4.599081516265869, -4.590511322021484, -4.589367866516113, -3.2992591857910156, -4.9722676277160645, -4.1737961769104, -3.5093724727630615, -2.9264585971832275, -2.0851428508758545, -2.7794597148895264, -2.264662027359009, -1.8982371091842651, -1.5928007364273071, -0.6255652904510498, -0.3833869695663452, -0.8928344249725342, -0.7536735534667969, -0.3844488859176636, -0.6126847267150879, -1.2662980556488037, -0.07996363937854767, 0.24967338144779205, 0.3937244415283203, 0.28476208448410034, -0.6227888464927673, 0.4808911085128784, 0.14185400307178497, 0.08668585866689682, 0.371671587228775, 1.5185086727142334, 1.626985788345337, 0.40997859835624695, 0.6285750269889832, 1.1259503364562988, 0.5669443011283875, 0.7968780994415283, 1.110852599143982, 1.3289471864700317, 1.2121765613555908, 3.118082284927368, 1.3656017780303955, 1.5849037170410156, 2.0012285709381104, 1.7152661085128784, 1.3753864765167236, 1.77810800075531, 0.8417423963546753, 1.1967685222625732, 0.9047791361808777, 0.9561734199523926, 1.317640781402588, 1.329757571220398, 1.1924340724945068, 1.5181368589401245, 1.611673355102539, 1.8675028085708618, 2.898986577987671, 1.0595579147338867, 1.4559098482131958, 1.7670819759368896, 1.4235233068466187, 1.9038094282150269, 1.0651861429214478, 1.71710205078125, 1.7818623781204224, 0.0, 0.0, 0.0, 0.0, 7.200682163238525], [-3.5093581676483154, 0.0, 0.0, 0.0, 0.0, 0.0, -6.141363620758057, -5.7709760665893555, -5.8111162185668945, -5.577615737915039, -5.490537166595459, -4.148882865905762, -3.7580678462982178, -3.925163507461548, -3.412235736846924, -2.881181478500366, -3.4329686164855957, -2.9472572803497314, -1.944655418395996, -1.936447024345398, -2.2653932571411133, -0.9268689155578613, -1.0744520425796509, -0.6826500296592712, -2.391040086746216, -1.3853100538253784, 0.07237882912158966, -0.11088360846042633, 0.43701910972595215, 0.18211451172828674, 0.5791237950325012, 0.7652784585952759, 1.7185077667236328, -0.12712331116199493, 0.9442362189292908, 0.025633634999394417, 0.6595780253410339, 1.4651850461959839, 1.7414565086364746, 1.2814061641693115, 0.6152123212814331, 2.902401924133301, 2.34399151802063, 0.5812251567840576, 1.7198512554168701, 1.3338156938552856, 1.54837965965271, 0.6732848286628723, 1.3052566051483154, 1.5841532945632935, 1.4538908004760742, 2.1494975090026855, 1.1274104118347168, 1.4158543348312378, 1.3651131391525269, 3.427476406097412, 1.0264348983764648, 1.66007399559021, 0.9293960928916931, 1.6469621658325195, 1.2229009866714478, 1.7743154764175415, 1.872064232826233, 2.004563808441162, 1.7577624320983887, 1.6368882656097412, 1.515971302986145, 1.4374775886535645, 2.155268430709839, 1.2516707181930542, 2.0276284217834473, 1.9247571229934692, 2.1004068851470947, 0.0, 0.0, 0.0, 0.0, 7.891686916351318, -3.5093581676483154, -0.0, -0.0, -0.0, -0.0, -0.0, -6.141363620758057, -5.7709760665893555, -5.8111162185668945, -5.577615737915039, -5.490537166595459, -4.148882865905762, -3.7580678462982178, -3.925163507461548, -3.412235736846924, -2.881181478500366, -3.4329686164855957, -2.9472572803497314, -1.944655418395996, -1.936447024345398, -2.2653932571411133, -0.9268689155578613, -1.0744520425796509, -0.6826500296592712, -2.391040086746216, -1.3853100538253784, 0.07237882912158966, -0.11088360846042633, 0.43701910972595215, 0.18211451172828674, 0.5791237950325012, 0.7652784585952759, 1.7185077667236328, -0.12712331116199493, 0.9442362189292908, 0.025633634999394417, 0.6595780253410339, 1.4651850461959839, 1.7414565086364746, 1.2814061641693115, 0.6152123212814331, 2.902401924133301, 2.34399151802063, 0.5812251567840576, 1.7198512554168701, 1.3338156938552856, 1.54837965965271, 0.6732848286628723, 1.3052566051483154, 1.5841532945632935, 1.4538908004760742, 2.1494975090026855, 1.1274104118347168, 1.4158543348312378, 1.3651131391525269, 3.427476406097412, 1.0264348983764648, 1.66007399559021, 0.9293960928916931, 1.6469621658325195, 1.2229009866714478, 1.7743154764175415, 1.872064232826233, 2.004563808441162, 1.7577624320983887, 1.6368882656097412, 1.515971302986145, 1.4374775886535645, 2.155268430709839, 1.2516707181930542, 2.0276284217834473, 1.9247571229934692, 2.1004068851470947, 0.0, 0.0, 0.0, 0.0, 7.891686916351318], [-6.118391036987305, 0.0, 0.0, 0.0, 0.0, -5.740739822387695, -5.376936435699463, -5.498082637786865, -5.011989116668701, -5.460554599761963, -5.274220943450928, -4.665687561035156, -3.632354259490967, -3.7914628982543945, -3.6190459728240967, -2.0781822204589844, -3.6429202556610107, -3.057905912399292, -2.80389142036438, -2.1456167697906494, -1.7137151956558228, -1.3154734373092651, -0.8439759612083435, -0.8610806465148926, -0.6521421074867249, -0.64573073387146, -0.863434374332428, -0.033077728003263474, -0.29884254932403564, -0.33982053399086, -0.27900755405426025, 0.11140041053295135, 3.0619874000549316, 0.10971691459417343, 0.8735707998275757, 0.2529129981994629, 1.3892773389816284, 0.985196590423584, 4.313968658447266, 0.9490045309066772, 0.19494526088237762, 2.4399020671844482, 0.7805284261703491, 2.7914769649505615, 1.1481101512908936, 1.1461529731750488, 1.321256399154663, 1.6338427066802979, 1.8575111627578735, 1.4010100364685059, 2.1617448329925537, 1.5866562128067017, 2.1454391479492188, 1.93877375125885, 1.9505559206008911, 1.1429927349090576, 0.7306398153305054, 0.9920560717582703, 1.6113513708114624, 0.9416900277137756, 0.6664835214614868, 1.6061131954193115, 1.9170955419540405, 1.2001121044158936, 2.1185574531555176, 1.1497193574905396, 1.469587802886963, 1.4293785095214844, 1.1764336824417114, 1.537624716758728, 0.6071068048477173, 1.5917084217071533, 2.1632871627807617, 2.300987958908081, 0.0, 0.0, 0.0, 0.0, -6.118391036987305, -0.0, -0.0, -0.0, -0.0, -5.740739822387695, -5.376936435699463, -5.498082637786865, -5.011989116668701, -5.460554599761963, -5.274220943450928, -4.665687561035156, -3.632354259490967, -3.7914628982543945, -3.6190459728240967, -2.0781822204589844, -3.6429202556610107, -3.057905912399292, -2.80389142036438, -2.1456167697906494, -1.7137151956558228, -1.3154734373092651, -0.8439759612083435, -0.8610806465148926, -0.6521421074867249, -0.64573073387146, -0.863434374332428, -0.033077728003263474, -0.29884254932403564, -0.33982053399086, -0.27900755405426025, 0.11140041053295135, 3.0619874000549316, 0.10971691459417343, 0.8735707998275757, 0.2529129981994629, 1.3892773389816284, 0.985196590423584, 4.313968658447266, 0.9490045309066772, 0.19494526088237762, 2.4399020671844482, 0.7805284261703491, 2.7914769649505615, 1.1481101512908936, 1.1461529731750488, 1.321256399154663, 1.6338427066802979, 1.8575111627578735, 1.4010100364685059, 2.1617448329925537, 1.5866562128067017, 2.1454391479492188, 1.93877375125885, 1.9505559206008911, 1.1429927349090576, 0.7306398153305054, 0.9920560717582703, 1.6113513708114624, 0.9416900277137756, 0.6664835214614868, 1.6061131954193115, 1.9170955419540405, 1.2001121044158936, 2.1185574531555176, 1.1497193574905396, 1.469587802886963, 1.4293785095214844, 1.1764336824417114, 1.537624716758728, 0.6071068048477173, 1.5917084217071533, 2.1632871627807617, 2.300987958908081, 0.0, 0.0, 0.0, 0.0], [-4.863194942474365, 0.0, 0.0, 0.0, 0.0, -5.893496036529541, -4.995842456817627, -5.333341121673584, -5.666049480438232, -5.002092361450195, -4.853250026702881, -5.034110069274902, -4.112328052520752, -3.9493367671966553, -3.6919713020324707, -2.877208709716797, -3.1740646362304688, -2.7063636779785156, -2.499760389328003, -2.395681142807007, -0.6600756645202637, -1.2252882719039917, -0.5324446558952332, -0.9228333830833435, -0.7110595107078552, -0.3459581732749939, -0.6453980803489685, -0.9417846202850342, 0.11735149472951889, -0.04245130345225334, 0.2510395050048828, 0.2651166021823883, 0.332960844039917, 1.2491252422332764, 0.5121146440505981, 0.6783219575881958, 0.20831717550754547, 1.9500831365585327, 1.6971964836120605, 1.4225983619689941, 1.135389804840088, 0.6793777346611023, 0.7803186178207397, 1.2676506042480469, 1.7826814651489258, 1.402498722076416, 1.7306755781173706, 1.7754381895065308, 1.7019083499908447, 1.3844233751296997, 3.285087823867798, 1.113981008529663, 1.3108340501785278, 1.5128531455993652, 1.8156154155731201, 0.9727182984352112, 2.5810234546661377, 1.7285287380218506, 2.4598982334136963, 1.1992182731628418, 1.8159043788909912, 2.043227195739746, 1.330125331878662, 1.153801441192627, 0.9701058268547058, 1.2640483379364014, 2.050577163696289, 1.9386134147644043, 1.6275285482406616, 1.3483909368515015, 1.0941162109375, 0.8959717750549316, 1.8544912338256836, 2.4716291427612305, 0.0, 0.0, 0.0, 0.0, -4.863194942474365, -0.0, -0.0, -0.0, -0.0, -5.893496036529541, -4.995842456817627, -5.333341121673584, -5.666049480438232, -5.002092361450195, -4.853250026702881, -5.034110069274902, -4.112328052520752, -3.9493367671966553, -3.6919713020324707, -2.877208709716797, -3.1740646362304688, -2.7063636779785156, -2.499760389328003, -2.395681142807007, -0.6600756645202637, -1.2252882719039917, -0.5324446558952332, -0.9228333830833435, -0.7110595107078552, -0.3459581732749939, -0.6453980803489685, -0.9417846202850342, 0.11735149472951889, -0.04245130345225334, 0.2510395050048828, 0.2651166021823883, 0.332960844039917, 1.2491252422332764, 0.5121146440505981, 0.6783219575881958, 0.20831717550754547, 1.9500831365585327, 1.6971964836120605, 1.4225983619689941, 1.135389804840088, 0.6793777346611023, 0.7803186178207397, 1.2676506042480469, 1.7826814651489258, 1.402498722076416, 1.7306755781173706, 1.7754381895065308, 1.7019083499908447, 1.3844233751296997, 3.285087823867798, 1.113981008529663, 1.3108340501785278, 1.5128531455993652, 1.8156154155731201, 0.9727182984352112, 2.5810234546661377, 1.7285287380218506, 2.4598982334136963, 1.1992182731628418, 1.8159043788909912, 2.043227195739746, 1.330125331878662, 1.153801441192627, 0.9701058268547058, 1.2640483379364014, 2.050577163696289, 1.9386134147644043, 1.6275285482406616, 1.3483909368515015, 1.0941162109375, 0.8959717750549316, 1.8544912338256836, 2.4716291427612305, 0.0, 0.0, 0.0, 0.0], [-3.7051925659179688, 0.0, 0.0, 0.0, -5.558844089508057, -5.834915637969971, -6.391825199127197, -5.283206462860107, -4.950830936431885, -5.212950229644775, -4.847777366638184, -4.8167877197265625, -4.994106769561768, -4.1154375076293945, -4.477376461029053, -3.2014219760894775, -4.3686418533325195, -1.811646819114685, -2.2142298221588135, -2.3122060298919678, -2.286569356918335, -0.86501145362854, -0.431215763092041, -0.6830600500106812, -1.7002131938934326, -0.5689623355865479, -0.23670348525047302, 0.23261350393295288, -0.1017395406961441, -0.3790128231048584, -0.16448889672756195, 0.31529486179351807, 1.9594366550445557, 0.8720241189002991, 0.29023948311805725, -0.17560121417045593, 0.5754697918891907, 0.9942699074745178, 1.5864598751068115, 0.7620776891708374, 1.1747862100601196, 0.5695991516113281, 0.8286474943161011, 0.7075996994972229, 1.392829179763794, 3.1263248920440674, 2.5453946590423584, 1.8643945455551147, 1.5535091161727905, 1.5387784242630005, 1.773552656173706, 1.349990725517273, 1.416346549987793, 1.885269284248352, 1.8993217945098877, 1.374510645866394, 0.3531399369239807, 2.279928684234619, 1.911296010017395, 2.0157108306884766, 1.676045298576355, 1.8996864557266235, 0.9796591997146606, 1.1210321187973022, 1.9126166105270386, 1.7838820219039917, 2.4967126846313477, 2.1640772819519043, 1.8015687465667725, 1.6772135496139526, 1.5104858875274658, 1.6789860725402832, 1.633175015449524, 1.982887625694275, 0.0, 0.0, 0.0, 0.0, -3.7051925659179688, -0.0, -0.0, -0.0, -5.558844089508057, -5.834915637969971, -6.391825199127197, -5.283206462860107, -4.950830936431885, -5.212950229644775, -4.847777366638184, -4.8167877197265625, -4.994106769561768, -4.1154375076293945, -4.477376461029053, -3.2014219760894775, -4.3686418533325195, -1.811646819114685, -2.2142298221588135, -2.3122060298919678, -2.286569356918335, -0.86501145362854, -0.431215763092041, -0.6830600500106812, -1.7002131938934326, -0.5689623355865479, -0.23670348525047302, 0.23261350393295288, -0.1017395406961441, -0.3790128231048584, -0.16448889672756195, 0.31529486179351807, 1.9594366550445557, 0.8720241189002991, 0.29023948311805725, -0.17560121417045593, 0.5754697918891907, 0.9942699074745178, 1.5864598751068115, 0.7620776891708374, 1.1747862100601196, 0.5695991516113281, 0.8286474943161011, 0.7075996994972229, 1.392829179763794, 3.1263248920440674, 2.5453946590423584, 1.8643945455551147, 1.5535091161727905, 1.5387784242630005, 1.773552656173706, 1.349990725517273, 1.416346549987793, 1.885269284248352, 1.8993217945098877, 1.374510645866394, 0.3531399369239807, 2.279928684234619, 1.911296010017395, 2.0157108306884766, 1.676045298576355, 1.8996864557266235, 0.9796591997146606, 1.1210321187973022, 1.9126166105270386, 1.7838820219039917, 2.4967126846313477, 2.1640772819519043, 1.8015687465667725, 1.6772135496139526, 1.5104858875274658, 1.6789860725402832, 1.633175015449524, 1.982887625694275, 0.0, 0.0, 0.0, 0.0], [-6.460433006286621, 0.0, 0.0, 0.0, -6.150173664093018, -6.409689426422119, -5.504426956176758, -5.135342597961426, -4.906545162200928, -4.592947483062744, -4.36266565322876, -4.1507110595703125, -4.3186750411987305, -3.3057191371917725, -3.0257763862609863, -3.5591819286346436, -3.5171995162963867, -2.0918705463409424, -2.842212200164795, -1.9455946683883667, -2.652888298034668, -1.445172667503357, -1.1460626125335693, -1.1991063356399536, -0.2751333713531494, 0.3418634831905365, -0.8417580723762512, 0.2104302942752838, 0.37888309359550476, -0.6542881727218628, 0.04174085333943367, -0.14357878267765045, 0.3221210241317749, 0.45163366198539734, 0.4225156307220459, 0.7174855470657349, 1.1161781549453735, -0.6931601762771606, 0.45395225286483765, 1.4914159774780273, 0.42576780915260315, 1.1603572368621826, 1.4074835777282715, -1.0903030633926392, 2.232221841812134, 1.7942276000976562, 0.6209474802017212, 1.64990234375, 1.0172483921051025, 1.72769296169281, 1.7333999872207642, 1.0399062633514404, 2.4532082080841064, 1.9354950189590454, 1.3440747261047363, 0.9439324140548706, 1.4172176122665405, 2.361433267593384, 2.2579119205474854, 1.6833040714263916, 2.2467715740203857, 1.1095495223999023, 1.1717021465301514, 1.100223422050476, 1.4518465995788574, 1.4804060459136963, 1.3590997457504272, 1.9127799272537231, 2.096707344055176, 1.4935684204101562, 2.005833387374878, 2.5790538787841797, 1.4932669401168823, 1.807470440864563, 3.2729709148406982, 0.0, 0.0, 4.100203514099121, -6.460433006286621, -0.0, -0.0, -0.0, -6.150173664093018, -6.409689426422119, -5.504426956176758, -5.135342597961426, -4.906545162200928, -4.592947483062744, -4.36266565322876, -4.1507110595703125, -4.3186750411987305, -3.3057191371917725, -3.0257763862609863, -3.5591819286346436, -3.5171995162963867, -2.0918705463409424, -2.842212200164795, -1.9455946683883667, -2.652888298034668, -1.445172667503357, -1.1460626125335693, -1.1991063356399536, -0.2751333713531494, 0.3418634831905365, -0.8417580723762512, 0.2104302942752838, 0.37888309359550476, -0.6542881727218628, 0.04174085333943367, -0.14357878267765045, 0.3221210241317749, 0.45163366198539734, 0.4225156307220459, 0.7174855470657349, 1.1161781549453735, -0.6931601762771606, 0.45395225286483765, 1.4914159774780273, 0.42576780915260315, 1.1603572368621826, 1.4074835777282715, -1.0903030633926392, 2.232221841812134, 1.7942276000976562, 0.6209474802017212, 1.64990234375, 1.0172483921051025, 1.72769296169281, 1.7333999872207642, 1.0399062633514404, 2.4532082080841064, 1.9354950189590454, 1.3440747261047363, 0.9439324140548706, 1.4172176122665405, 2.361433267593384, 2.2579119205474854, 1.6833040714263916, 2.2467715740203857, 1.1095495223999023, 1.1717021465301514, 1.100223422050476, 1.4518465995788574, 1.4804060459136963, 1.3590997457504272, 1.9127799272537231, 2.096707344055176, 1.4935684204101562, 2.005833387374878, 2.5790538787841797, 1.4932669401168823, 1.807470440864563, 3.2729709148406982, 0.0, 0.0, 4.100203514099121], [0.0, 0.0, 0.0, 0.0, -6.695716381072998, -6.528463363647461, -5.937558174133301, -6.145736217498779, -5.005019664764404, -4.437479019165039, -4.146542549133301, -3.9661123752593994, -3.6382107734680176, -2.909529685974121, -3.8443636894226074, -3.3377230167388916, -3.0216071605682373, -2.218613386154175, -2.1922638416290283, -1.2092256546020508, -1.9019113779067993, -1.126391887664795, -0.8577389121055603, -1.0942257642745972, -0.45986175537109375, -0.9552717208862305, -0.22254900634288788, -0.8019392490386963, 0.19294065237045288, -0.2055058777332306, 0.6963633298873901, -0.22906501591205597, 0.2821981608867645, 0.2486673891544342, 0.14591094851493835, 0.8729565143585205, 1.5254120826721191, 0.771933376789093, 0.873802125453949, 1.747187614440918, 1.158880591392517, 0.9954792261123657, 1.1213760375976562, 1.024623155593872, 1.14065682888031, 1.1799302101135254, 1.780003309249878, 1.8033305406570435, 1.446539044380188, 2.2627651691436768, 1.1278142929077148, 1.7861766815185547, 2.1179986000061035, 0.8827393651008606, 0.7680701613426208, 2.498751163482666, 0.43572497367858887, 1.5445654392242432, 1.6388691663742065, 0.5750542879104614, 1.583473801612854, 1.4540303945541382, 1.22258460521698, 0.4406365156173706, 1.1308603286743164, 1.4935365915298462, 1.7643362283706665, 1.9552390575408936, 1.8584550619125366, 1.8889039754867554, 2.0205390453338623, 1.6641316413879395, 2.116544723510742, 2.1813840866088867, 1.5786293745040894, 0.0, 0.0, 5.141416549682617, -0.0, -0.0, -0.0, -0.0, -6.695716381072998, -6.528463363647461, -5.937558174133301, -6.145736217498779, -5.005019664764404, -4.437479019165039, -4.146542549133301, -3.9661123752593994, -3.6382107734680176, -2.909529685974121, -3.8443636894226074, -3.3377230167388916, -3.0216071605682373, -2.218613386154175, -2.1922638416290283, -1.2092256546020508, -1.9019113779067993, -1.126391887664795, -0.8577389121055603, -1.0942257642745972, -0.45986175537109375, -0.9552717208862305, -0.22254900634288788, -0.8019392490386963, 0.19294065237045288, -0.2055058777332306, 0.6963633298873901, -0.22906501591205597, 0.2821981608867645, 0.2486673891544342, 0.14591094851493835, 0.8729565143585205, 1.5254120826721191, 0.771933376789093, 0.873802125453949, 1.747187614440918, 1.158880591392517, 0.9954792261123657, 1.1213760375976562, 1.024623155593872, 1.14065682888031, 1.1799302101135254, 1.780003309249878, 1.8033305406570435, 1.446539044380188, 2.2627651691436768, 1.1278142929077148, 1.7861766815185547, 2.1179986000061035, 0.8827393651008606, 0.7680701613426208, 2.498751163482666, 0.43572497367858887, 1.5445654392242432, 1.6388691663742065, 0.5750542879104614, 1.583473801612854, 1.4540303945541382, 1.22258460521698, 0.4406365156173706, 1.1308603286743164, 1.4935365915298462, 1.7643362283706665, 1.9552390575408936, 1.8584550619125366, 1.8889039754867554, 2.0205390453338623, 1.6641316413879395, 2.116544723510742, 2.1813840866088867, 1.5786293745040894, 0.0, 0.0, 5.141416549682617], [-3.969336748123169, 0.0, 0.0, -6.078351020812988, -6.433086395263672, -6.645144462585449, -6.596859455108643, -5.898255825042725, -4.972323417663574, -4.525406837463379, -4.649631977081299, -4.820466041564941, -3.9418230056762695, -4.010653018951416, -3.6400673389434814, -3.4066526889801025, -3.0205307006835938, -3.117995262145996, -2.5912845134735107, -1.9900850057601929, -2.6484267711639404, -2.116527557373047, -1.2957576513290405, -1.3585039377212524, -0.7248136401176453, -0.6794643998146057, 0.08046204596757889, -0.13782182335853577, -0.28048187494277954, 0.9206315279006958, 0.8464841246604919, -0.3462502956390381, 0.035962872207164764, 1.3821278810501099, 0.3534301221370697, 0.5499550700187683, 0.8503599762916565, 0.6718860864639282, 1.630980134010315, -0.6204116344451904, 1.4710243940353394, -0.3998428285121918, 1.7140613794326782, 1.3540222644805908, 2.996281623840332, 1.4145140647888184, 1.6233035326004028, 1.9167768955230713, 1.8346083164215088, 1.2680635452270508, 1.8202263116836548, 1.0887963771820068, 1.8044264316558838, 2.218295097351074, 2.4533042907714844, 0.4964756369590759, 1.5357820987701416, 1.693941593170166, 1.9101101160049438, 1.7768290042877197, 1.6073404550552368, 1.5706700086593628, 1.3778717517852783, 1.7740192413330078, 1.3517613410949707, 1.864645004272461, 1.6561906337738037, 1.4433358907699585, 1.8949602842330933, 1.955726981163025, 1.9435312747955322, 2.2008473873138428, 2.200705051422119, 3.299086093902588, 3.665210008621216, 0.0, 0.0, 4.624265193939209, -3.969336748123169, -0.0, -0.0, -6.078351020812988, -6.433086395263672, -6.645144462585449, -6.596859455108643, -5.898255825042725, -4.972323417663574, -4.525406837463379, -4.649631977081299, -4.820466041564941, -3.9418230056762695, -4.010653018951416, -3.6400673389434814, -3.4066526889801025, -3.0205307006835938, -3.117995262145996, -2.5912845134735107, -1.9900850057601929, -2.6484267711639404, -2.116527557373047, -1.2957576513290405, -1.3585039377212524, -0.7248136401176453, -0.6794643998146057, 0.08046204596757889, -0.13782182335853577, -0.28048187494277954, 0.9206315279006958, 0.8464841246604919, -0.3462502956390381, 0.035962872207164764, 1.3821278810501099, 0.3534301221370697, 0.5499550700187683, 0.8503599762916565, 0.6718860864639282, 1.630980134010315, -0.6204116344451904, 1.4710243940353394, -0.3998428285121918, 1.7140613794326782, 1.3540222644805908, 2.996281623840332, 1.4145140647888184, 1.6233035326004028, 1.9167768955230713, 1.8346083164215088, 1.2680635452270508, 1.8202263116836548, 1.0887963771820068, 1.8044264316558838, 2.218295097351074, 2.4533042907714844, 0.4964756369590759, 1.5357820987701416, 1.693941593170166, 1.9101101160049438, 1.7768290042877197, 1.6073404550552368, 1.5706700086593628, 1.3778717517852783, 1.7740192413330078, 1.3517613410949707, 1.864645004272461, 1.6561906337738037, 1.4433358907699585, 1.8949602842330933, 1.955726981163025, 1.9435312747955322, 2.2008473873138428, 2.200705051422119, 3.299086093902588, 3.665210008621216, 0.0, 0.0, 4.624265193939209], [0.0, 0.0, 0.0, -6.529037952423096, -6.34736967086792, -6.461814880371094, -7.259430408477783, -5.832311153411865, -5.38596773147583, -4.933379650115967, -4.778231143951416, -4.349971294403076, -4.102592468261719, -3.5770957469940186, -3.734164237976074, -3.060326337814331, -2.7341554164886475, -3.068958044052124, -3.769207239151001, -1.7828364372253418, -2.1221261024475098, -1.5600303411483765, -3.0644242763519287, -1.336651086807251, -0.8045008778572083, -0.5273149609565735, -0.5268856883049011, 0.018891889601945877, 1.4817310571670532, 0.7936078310012817, 0.5975247621536255, 0.3726957440376282, 0.2780396342277527, -0.02091212011873722, 0.4787338376045227, -0.8277025818824768, 0.7195003032684326, -0.7251920700073242, 1.9910634756088257, 2.6927475929260254, 0.9320768117904663, 1.8353601694107056, 1.4553269147872925, 2.2575578689575195, 2.404162645339966, 1.2179410457611084, 1.715309977531433, 1.5120322704315186, 2.267622470855713, 1.4985779523849487, 1.51994788646698, 1.7657510042190552, 1.4695930480957031, 1.1815006732940674, 1.3127551078796387, 1.3216650485992432, 2.6016271114349365, 2.0878584384918213, 2.2813024520874023, 1.9999395608901978, 1.6870663166046143, 1.4990026950836182, 1.406328558921814, 1.5107958316802979, 1.7270982265472412, 1.9439656734466553, 1.8536322116851807, 1.53875732421875, 1.484834909439087, 1.760471224784851, 2.406895399093628, 1.967631459236145, 2.307936191558838, 3.941342830657959, 2.8877735137939453, 0.0, 0.0, 3.203962802886963, -0.0, -0.0, -0.0, -6.529037952423096, -6.34736967086792, -6.461814880371094, -7.259430408477783, -5.832311153411865, -5.38596773147583, -4.933379650115967, -4.778231143951416, -4.349971294403076, -4.102592468261719, -3.5770957469940186, -3.734164237976074, -3.060326337814331, -2.7341554164886475, -3.068958044052124, -3.769207239151001, -1.7828364372253418, -2.1221261024475098, -1.5600303411483765, -3.0644242763519287, -1.336651086807251, -0.8045008778572083, -0.5273149609565735, -0.5268856883049011, 0.018891889601945877, 1.4817310571670532, 0.7936078310012817, 0.5975247621536255, 0.3726957440376282, 0.2780396342277527, -0.02091212011873722, 0.4787338376045227, -0.8277025818824768, 0.7195003032684326, -0.7251920700073242, 1.9910634756088257, 2.6927475929260254, 0.9320768117904663, 1.8353601694107056, 1.4553269147872925, 2.2575578689575195, 2.404162645339966, 1.2179410457611084, 1.715309977531433, 1.5120322704315186, 2.267622470855713, 1.4985779523849487, 1.51994788646698, 1.7657510042190552, 1.4695930480957031, 1.1815006732940674, 1.3127551078796387, 1.3216650485992432, 2.6016271114349365, 2.0878584384918213, 2.2813024520874023, 1.9999395608901978, 1.6870663166046143, 1.4990026950836182, 1.406328558921814, 1.5107958316802979, 1.7270982265472412, 1.9439656734466553, 1.8536322116851807, 1.53875732421875, 1.484834909439087, 1.760471224784851, 2.406895399093628, 1.967631459236145, 2.307936191558838, 3.941342830657959, 2.8877735137939453, 0.0, 0.0, 3.203962802886963], [-6.105823040008545, 0.0, 0.0, -6.731180191040039, -6.395312786102295, -6.273972988128662, -6.411584377288818, -5.6307597160339355, -5.6758294105529785, -5.7609734535217285, -5.17397403717041, -4.156133651733398, -4.390692234039307, -3.417985439300537, -4.399473190307617, -3.5235447883605957, -3.796919107437134, -3.5414578914642334, -2.4973151683807373, -1.6505931615829468, -3.4140779972076416, -2.0533089637756348, -1.4206342697143555, -1.1171940565109253, -0.8112477660179138, -0.7626465559005737, -0.21929462254047394, 0.20870861411094666, -0.2190238982439041, -0.43016278743743896, 0.8009549975395203, 0.7730119228363037, 1.3219352960586548, 0.39595523476600647, 0.4453986585140228, 0.8676003813743591, 1.313624382019043, 0.3466382622718811, 1.19569993019104, 0.44756823778152466, 1.067126750946045, 1.8544307947158813, 2.451137065887451, -0.6853219270706177, 1.4772191047668457, 1.6467403173446655, 1.531232476234436, 1.5621085166931152, 2.2644565105438232, 1.6840170621871948, 1.59523344039917, 1.2682883739471436, 1.85358464717865, 1.6556930541992188, 1.6102529764175415, 1.6074384450912476, 1.7747284173965454, 1.8645998239517212, 1.9157310724258423, -0.0026504367124289274, 1.5880829095840454, 1.6320914030075073, 2.3268768787384033, 1.0676053762435913, 1.3110716342926025, 1.539681077003479, 1.591754674911499, 1.5609304904937744, 2.0369873046875, 2.082056760787964, 1.4927231073379517, 2.120114803314209, 1.7484875917434692, 3.0525596141815186, 2.7655651569366455, 0.0, 0.0, 4.0834808349609375, -6.105823040008545, -0.0, -0.0, -6.731180191040039, -6.395312786102295, -6.273972988128662, -6.411584377288818, -5.6307597160339355, -5.6758294105529785, -5.7609734535217285, -5.17397403717041, -4.156133651733398, -4.390692234039307, -3.417985439300537, -4.399473190307617, -3.5235447883605957, -3.796919107437134, -3.5414578914642334, -2.4973151683807373, -1.6505931615829468, -3.4140779972076416, -2.0533089637756348, -1.4206342697143555, -1.1171940565109253, -0.8112477660179138, -0.7626465559005737, -0.21929462254047394, 0.20870861411094666, -0.2190238982439041, -0.43016278743743896, 0.8009549975395203, 0.7730119228363037, 1.3219352960586548, 0.39595523476600647, 0.4453986585140228, 0.8676003813743591, 1.313624382019043, 0.3466382622718811, 1.19569993019104, 0.44756823778152466, 1.067126750946045, 1.8544307947158813, 2.451137065887451, -0.6853219270706177, 1.4772191047668457, 1.6467403173446655, 1.531232476234436, 1.5621085166931152, 2.2644565105438232, 1.6840170621871948, 1.59523344039917, 1.2682883739471436, 1.85358464717865, 1.6556930541992188, 1.6102529764175415, 1.6074384450912476, 1.7747284173965454, 1.8645998239517212, 1.9157310724258423, -0.0026504367124289274, 1.5880829095840454, 1.6320914030075073, 2.3268768787384033, 1.0676053762435913, 1.3110716342926025, 1.539681077003479, 1.591754674911499, 1.5609304904937744, 2.0369873046875, 2.082056760787964, 1.4927231073379517, 2.120114803314209, 1.7484875917434692, 3.0525596141815186, 2.7655651569366455, 0.0, 0.0, 4.0834808349609375], [-7.092510223388672, 0.0, 0.0, -7.27903938293457, -6.822894096374512, -6.086004257202148, -6.531296253204346, -5.579793930053711, -5.633299827575684, -4.031412601470947, -4.9371337890625, -5.976431846618652, -4.209218502044678, -4.5332136154174805, -3.9961204528808594, -3.308976173400879, -2.8534839153289795, -3.115077495574951, -2.1131374835968018, -2.6236228942871094, -1.9892135858535767, -0.8863635063171387, -1.5330228805541992, -0.7690140604972839, -0.7418879866600037, -0.8641464710235596, -0.1598127782344818, -0.4463934004306793, -0.07371832430362701, -0.18999473750591278, 0.6136552095413208, 0.4454939067363739, 0.9279323816299438, 0.8170260787010193, 0.502264678478241, 1.8023518323898315, 1.8895292282104492, 1.0889453887939453, 1.4953289031982422, 0.6683356165885925, 0.07815400511026382, 0.8959366679191589, 1.0032751560211182, 1.8159154653549194, 1.4166432619094849, 1.5195389986038208, 1.4226937294006348, 1.3346601724624634, 1.6745582818984985, 2.1559274196624756, 1.619826316833496, 1.3071410655975342, 1.3866046667099, 1.7451813220977783, 2.3993117809295654, 1.266301155090332, 2.1821041107177734, 2.182081699371338, 0.9602951407432556, 1.5697044134140015, 2.2333173751831055, 1.607359528541565, 1.3738139867782593, 1.9382163286209106, 1.6817436218261719, 2.3447818756103516, 2.304670810699463, 1.6281602382659912, 1.9911482334136963, 1.6825908422470093, 1.5312776565551758, 2.8108127117156982, 1.5893670320510864, 2.4845519065856934, 2.5161850452423096, 0.0, 0.0, 0.0, -7.092510223388672, -0.0, -0.0, -7.27903938293457, -6.822894096374512, -6.086004257202148, -6.531296253204346, -5.579793930053711, -5.633299827575684, -4.031412601470947, -4.9371337890625, -5.976431846618652, -4.209218502044678, -4.5332136154174805, -3.9961204528808594, -3.308976173400879, -2.8534839153289795, -3.115077495574951, -2.1131374835968018, -2.6236228942871094, -1.9892135858535767, -0.8863635063171387, -1.5330228805541992, -0.7690140604972839, -0.7418879866600037, -0.8641464710235596, -0.1598127782344818, -0.4463934004306793, -0.07371832430362701, -0.18999473750591278, 0.6136552095413208, 0.4454939067363739, 0.9279323816299438, 0.8170260787010193, 0.502264678478241, 1.8023518323898315, 1.8895292282104492, 1.0889453887939453, 1.4953289031982422, 0.6683356165885925, 0.07815400511026382, 0.8959366679191589, 1.0032751560211182, 1.8159154653549194, 1.4166432619094849, 1.5195389986038208, 1.4226937294006348, 1.3346601724624634, 1.6745582818984985, 2.1559274196624756, 1.619826316833496, 1.3071410655975342, 1.3866046667099, 1.7451813220977783, 2.3993117809295654, 1.266301155090332, 2.1821041107177734, 2.182081699371338, 0.9602951407432556, 1.5697044134140015, 2.2333173751831055, 1.607359528541565, 1.3738139867782593, 1.9382163286209106, 1.6817436218261719, 2.3447818756103516, 2.304670810699463, 1.6281602382659912, 1.9911482334136963, 1.6825908422470093, 1.5312776565551758, 2.8108127117156982, 1.5893670320510864, 2.4845519065856934, 2.5161850452423096, 0.0, 0.0, 0.0], [-8.265329360961914, 0.0, 0.0, -6.236841678619385, -6.70734167098999, -7.666074275970459, -6.215223789215088, -6.253057479858398, -5.810783863067627, -5.241846084594727, -5.48465633392334, -4.605623245239258, -4.58494758605957, -4.1487908363342285, -4.0736403465271, -4.108270168304443, -3.122466802597046, -2.829838752746582, -2.5090813636779785, -1.765491008758545, -2.2970826625823975, -3.0463175773620605, -1.5874748229980469, -1.1394015550613403, -1.4657024145126343, -0.7311902046203613, -0.1831503063440323, -0.4719408452510834, -0.3941260576248169, -0.16145071387290955, 0.0014261627802625299, 0.46311601996421814, 0.39537957310676575, -0.2833520770072937, 0.224387526512146, 1.0496588945388794, 1.4421931505203247, 2.4448156356811523, 0.37072882056236267, 1.136244297027588, -0.24450574815273285, 0.6981865763664246, 1.4809397459030151, 2.08296275138855, 1.0835648775100708, 1.277406930923462, 1.43165123462677, 1.7340840101242065, 1.6585572957992554, 1.4953339099884033, 1.740895390510559, 1.5190860033035278, 1.7056804895401, 1.2107925415039062, 1.002005696296692, 1.4717003107070923, 1.5405148267745972, 1.8609354496002197, 1.7212923765182495, 1.0638580322265625, 2.1935861110687256, 0.5138657689094543, 1.3761025667190552, 0.9723731875419617, 1.182959794998169, 1.4431782960891724, 1.4873239994049072, 0.32476404309272766, 2.501136541366577, 2.159877300262451, 2.085662603378296, 1.744637131690979, 2.2723584175109863, 2.3984451293945312, 2.7239716053009033, 0.0, 0.0, 0.0, -8.265329360961914, -0.0, -0.0, -6.236841678619385, -6.70734167098999, -7.666074275970459, -6.215223789215088, -6.253057479858398, -5.810783863067627, -5.241846084594727, -5.48465633392334, -4.605623245239258, -4.58494758605957, -4.1487908363342285, -4.0736403465271, -4.108270168304443, -3.122466802597046, -2.829838752746582, -2.5090813636779785, -1.765491008758545, -2.2970826625823975, -3.0463175773620605, -1.5874748229980469, -1.1394015550613403, -1.4657024145126343, -0.7311902046203613, -0.1831503063440323, -0.4719408452510834, -0.3941260576248169, -0.16145071387290955, 0.0014261627802625299, 0.46311601996421814, 0.39537957310676575, -0.2833520770072937, 0.224387526512146, 1.0496588945388794, 1.4421931505203247, 2.4448156356811523, 0.37072882056236267, 1.136244297027588, -0.24450574815273285, 0.6981865763664246, 1.4809397459030151, 2.08296275138855, 1.0835648775100708, 1.277406930923462, 1.43165123462677, 1.7340840101242065, 1.6585572957992554, 1.4953339099884033, 1.740895390510559, 1.5190860033035278, 1.7056804895401, 1.2107925415039062, 1.002005696296692, 1.4717003107070923, 1.5405148267745972, 1.8609354496002197, 1.7212923765182495, 1.0638580322265625, 2.1935861110687256, 0.5138657689094543, 1.3761025667190552, 0.9723731875419617, 1.182959794998169, 1.4431782960891724, 1.4873239994049072, 0.32476404309272766, 2.501136541366577, 2.159877300262451, 2.085662603378296, 1.744637131690979, 2.2723584175109863, 2.3984451293945312, 2.7239716053009033, 0.0, 0.0, 0.0], [-6.503652095794678, 0.0, 0.0, -7.4911789894104, -6.961017608642578, -6.738053321838379, -6.865712642669678, -6.2455925941467285, -5.347357749938965, -5.220365047454834, -4.935374736785889, -5.003605842590332, -3.691443681716919, -3.9931514263153076, -3.981735944747925, -3.9105262756347656, -4.747464656829834, -1.6184537410736084, -2.701542615890503, -2.181504011154175, -0.8037474751472473, -1.8626960515975952, -0.9648354649543762, -1.6215014457702637, -0.3030443489551544, -1.179579734802246, -0.07877955585718155, -0.1274513453245163, -0.23894964158535004, 0.42789748311042786, -0.18211612105369568, 0.2633921802043915, -0.31586626172065735, 1.452275276184082, -0.7136552333831787, 1.0032926797866821, 0.31777626276016235, 1.0762797594070435, 1.9326274394989014, 0.6091806292533875, 1.7432039976119995, 1.2002134323120117, 1.949313759803772, 1.2919671535491943, 1.2655694484710693, 1.5459281206130981, 1.6850738525390625, 2.3426461219787598, 1.262372374534607, 0.9434511065483093, 1.102699875831604, 1.19638991355896, 1.3011633157730103, 1.7263332605361938, 1.0688782930374146, 1.4476203918457031, 1.5461442470550537, 1.3476600646972656, 1.4815274477005005, 1.4494179487228394, 2.100208282470703, 1.1227138042449951, 0.959685206413269, 1.0472990274429321, 0.9970948100090027, 1.1542408466339111, 1.5339272022247314, 1.8430016040802002, 1.3956429958343506, 2.1686413288116455, 1.8505243062973022, 1.2525019645690918, 1.5756456851959229, 2.3184733390808105, 2.629859209060669, 0.0, 0.0, 0.0, -6.503652095794678, -0.0, -0.0, -7.4911789894104, -6.961017608642578, -6.738053321838379, -6.865712642669678, -6.2455925941467285, -5.347357749938965, -5.220365047454834, -4.935374736785889, -5.003605842590332, -3.691443681716919, -3.9931514263153076, -3.981735944747925, -3.9105262756347656, -4.747464656829834, -1.6184537410736084, -2.701542615890503, -2.181504011154175, -0.8037474751472473, -1.8626960515975952, -0.9648354649543762, -1.6215014457702637, -0.3030443489551544, -1.179579734802246, -0.07877955585718155, -0.1274513453245163, -0.23894964158535004, 0.42789748311042786, -0.18211612105369568, 0.2633921802043915, -0.31586626172065735, 1.452275276184082, -0.7136552333831787, 1.0032926797866821, 0.31777626276016235, 1.0762797594070435, 1.9326274394989014, 0.6091806292533875, 1.7432039976119995, 1.2002134323120117, 1.949313759803772, 1.2919671535491943, 1.2655694484710693, 1.5459281206130981, 1.6850738525390625, 2.3426461219787598, 1.262372374534607, 0.9434511065483093, 1.102699875831604, 1.19638991355896, 1.3011633157730103, 1.7263332605361938, 1.0688782930374146, 1.4476203918457031, 1.5461442470550537, 1.3476600646972656, 1.4815274477005005, 1.4494179487228394, 2.100208282470703, 1.1227138042449951, 0.959685206413269, 1.0472990274429321, 0.9970948100090027, 1.1542408466339111, 1.5339272022247314, 1.8430016040802002, 1.3956429958343506, 2.1686413288116455, 1.8505243062973022, 1.2525019645690918, 1.5756456851959229, 2.3184733390808105, 2.629859209060669, 0.0, 0.0, 0.0], [-3.978292226791382, 0.0, 0.0, -7.541728496551514, -7.0325140953063965, -7.370841979980469, -6.363910675048828, -6.26411247253418, -5.9096293449401855, -5.853832721710205, -5.120334148406982, -5.164944648742676, -5.539432525634766, -4.927543640136719, -4.188299655914307, -3.4009852409362793, -3.1601383686065674, -2.464466094970703, -2.9285953044891357, -2.81557297706604, -1.9840432405471802, -1.8820558786392212, -1.6845457553863525, -0.987036406993866, -1.0335865020751953, -0.9982669353485107, -0.3193646967411041, -0.5589096546173096, -0.11870452761650085, -0.22004938125610352, 0.14588677883148193, 0.12907952070236206, 0.34242624044418335, 0.5373207926750183, 0.958069384098053, 1.1296215057373047, 1.408107876777649, 1.322508454322815, 0.7570999264717102, -1.0347886085510254, 1.359189510345459, 0.7481387853622437, 1.8231226205825806, 1.0687636137008667, 1.59163236618042, 1.206573724746704, 1.609174132347107, 1.3978900909423828, 1.0193252563476562, 1.7794342041015625, 1.3449057340621948, 1.3535950183868408, 1.1874830722808838, 1.5070406198501587, 1.6441919803619385, 0.1986621618270874, 2.4419596195220947, 1.670535683631897, 1.8162370920181274, 1.1459790468215942, 0.9993657469749451, 2.073951244354248, 1.7222418785095215, 0.8871129751205444, 1.3364582061767578, 1.2811895608901978, 1.2379528284072876, 1.4832983016967773, 1.8359253406524658, 2.020796060562134, 1.5076779127120972, 1.6635125875473022, 1.7866507768630981, 2.266268253326416, 2.2011921405792236, 2.3150634765625, 0.0, 0.0, -3.978292226791382, -0.0, -0.0, -7.541728496551514, -7.0325140953063965, -7.370841979980469, -6.363910675048828, -6.26411247253418, -5.9096293449401855, -5.853832721710205, -5.120334148406982, -5.164944648742676, -5.539432525634766, -4.927543640136719, -4.188299655914307, -3.4009852409362793, -3.1601383686065674, -2.464466094970703, -2.9285953044891357, -2.81557297706604, -1.9840432405471802, -1.8820558786392212, -1.6845457553863525, -0.987036406993866, -1.0335865020751953, -0.9982669353485107, -0.3193646967411041, -0.5589096546173096, -0.11870452761650085, -0.22004938125610352, 0.14588677883148193, 0.12907952070236206, 0.34242624044418335, 0.5373207926750183, 0.958069384098053, 1.1296215057373047, 1.408107876777649, 1.322508454322815, 0.7570999264717102, -1.0347886085510254, 1.359189510345459, 0.7481387853622437, 1.8231226205825806, 1.0687636137008667, 1.59163236618042, 1.206573724746704, 1.609174132347107, 1.3978900909423828, 1.0193252563476562, 1.7794342041015625, 1.3449057340621948, 1.3535950183868408, 1.1874830722808838, 1.5070406198501587, 1.6441919803619385, 0.1986621618270874, 2.4419596195220947, 1.670535683631897, 1.8162370920181274, 1.1459790468215942, 0.9993657469749451, 2.073951244354248, 1.7222418785095215, 0.8871129751205444, 1.3364582061767578, 1.2811895608901978, 1.2379528284072876, 1.4832983016967773, 1.8359253406524658, 2.020796060562134, 1.5076779127120972, 1.6635125875473022, 1.7866507768630981, 2.266268253326416, 2.2011921405792236, 2.3150634765625, 0.0, 0.0], [-1.9548920392990112, 0.0, -8.624749183654785, -8.133798599243164, -7.810446739196777, -6.984238147735596, -7.614658832550049, -7.0430474281311035, -5.837729454040527, -5.901915073394775, -5.118024826049805, -4.869248390197754, -4.903947353363037, -4.44423246383667, -3.4350569248199463, -4.058985710144043, -3.243117332458496, -3.2353038787841797, -3.9242825508117676, -1.814685583114624, -2.2703940868377686, -0.5801688432693481, -1.2939410209655762, -1.085632562637329, -1.0367923974990845, -1.4060369729995728, -0.5407599806785583, -0.7631263732910156, -0.4352166950702667, -0.5579748153686523, -0.10065971314907074, -0.1549813151359558, 0.28169700503349304, 0.2491598278284073, 0.795983076095581, 0.8745098114013672, 0.471164733171463, 0.4796701669692993, 0.8839342594146729, 0.8190942406654358, 0.849929928779602, 1.350517988204956, 1.5701122283935547, 1.459434986114502, 1.2926222085952759, 1.3118999004364014, 1.0693161487579346, 1.1565885543823242, 1.2965902090072632, 1.2763279676437378, 1.1447293758392334, 1.7630869150161743, 1.1542298793792725, 0.6015887260437012, 1.2031867504119873, 0.8267613053321838, 1.238849401473999, 1.2352375984191895, 1.456453561782837, 1.230762004852295, 1.2118175029754639, 1.3710051774978638, 0.7074235677719116, 1.5284591913223267, 1.1310489177703857, 1.2746405601501465, 1.1991063356399536, 1.349845051765442, 1.274963140487671, 2.3476061820983887, 1.3088500499725342, 1.5656830072402954, 1.610207438468933, 1.7622120380401611, 1.9902039766311646, 0.09931369870901108, 0.0, 0.0, -1.9548920392990112, -0.0, -8.624749183654785, -8.133798599243164, -7.810446739196777, -6.984238147735596, -7.614658832550049, -7.0430474281311035, -5.837729454040527, -5.901915073394775, -5.118024826049805, -4.869248390197754, -4.903947353363037, -4.44423246383667, -3.4350569248199463, -4.058985710144043, -3.243117332458496, -3.2353038787841797, -3.9242825508117676, -1.814685583114624, -2.2703940868377686, -0.5801688432693481, -1.2939410209655762, -1.085632562637329, -1.0367923974990845, -1.4060369729995728, -0.5407599806785583, -0.7631263732910156, -0.4352166950702667, -0.5579748153686523, -0.10065971314907074, -0.1549813151359558, 0.28169700503349304, 0.2491598278284073, 0.795983076095581, 0.8745098114013672, 0.471164733171463, 0.4796701669692993, 0.8839342594146729, 0.8190942406654358, 0.849929928779602, 1.350517988204956, 1.5701122283935547, 1.459434986114502, 1.2926222085952759, 1.3118999004364014, 1.0693161487579346, 1.1565885543823242, 1.2965902090072632, 1.2763279676437378, 1.1447293758392334, 1.7630869150161743, 1.1542298793792725, 0.6015887260437012, 1.2031867504119873, 0.8267613053321838, 1.238849401473999, 1.2352375984191895, 1.456453561782837, 1.230762004852295, 1.2118175029754639, 1.3710051774978638, 0.7074235677719116, 1.5284591913223267, 1.1310489177703857, 1.2746405601501465, 1.1991063356399536, 1.349845051765442, 1.274963140487671, 2.3476061820983887, 1.3088500499725342, 1.5656830072402954, 1.610207438468933, 1.7622120380401611, 1.9902039766311646, 0.09931369870901108, 0.0, 0.0], [0.0, 0.0, -8.317864418029785, -8.922104835510254, -7.833641529083252, -6.7583818435668945, -6.908620357513428, -6.896566867828369, -6.452031135559082, -5.700697898864746, -6.165657043457031, -5.280712604522705, -7.468419075012207, -5.291853427886963, -3.7277796268463135, -3.644814968109131, -3.647564172744751, -3.341202974319458, -3.294774293899536, -2.8698415756225586, -1.6186063289642334, -1.269766926765442, -2.3897414207458496, -1.4966121912002563, -1.4449059963226318, -0.9261907935142517, -0.5997322201728821, -0.8262160420417786, -0.0920565277338028, -0.572401762008667, -0.4234262704849243, -0.2062140703201294, 0.44810837507247925, 0.8445743322372437, 0.6969006061553955, 1.3603565692901611, 0.09358545392751694, 0.6316689252853394, 0.8724839091300964, 1.2217024564743042, 0.6390234231948853, 0.9049992561340332, 1.504401445388794, 1.8765724897384644, 0.7645778656005859, 0.10647137463092804, 0.957472562789917, 1.012259840965271, 1.4996145963668823, 0.863554835319519, 1.5310827493667603, 1.076755166053772, -1.3496817350387573, 1.4341621398925781, 1.5309221744537354, 1.200401782989502, 1.3245940208435059, 1.0820889472961426, 1.628312110900879, 1.4656100273132324, 0.7399660348892212, 0.5192306041717529, 1.0486398935317993, 0.7814551591873169, 1.5546458959579468, 1.0719009637832642, 0.6759751439094543, 0.7436344027519226, 1.3053089380264282, 1.5942689180374146, 1.3354003429412842, 1.4693421125411987, 1.657678484916687, 1.815665364265442, 1.8989185094833374, 1.1545225381851196, 0.0, 0.0, -0.0, -0.0, -8.317864418029785, -8.922104835510254, -7.833641529083252, -6.7583818435668945, -6.908620357513428, -6.896566867828369, -6.452031135559082, -5.700697898864746, -6.165657043457031, -5.280712604522705, -7.468419075012207, -5.291853427886963, -3.7277796268463135, -3.644814968109131, -3.647564172744751, -3.341202974319458, -3.294774293899536, -2.8698415756225586, -1.6186063289642334, -1.269766926765442, -2.3897414207458496, -1.4966121912002563, -1.4449059963226318, -0.9261907935142517, -0.5997322201728821, -0.8262160420417786, -0.0920565277338028, -0.572401762008667, -0.4234262704849243, -0.2062140703201294, 0.44810837507247925, 0.8445743322372437, 0.6969006061553955, 1.3603565692901611, 0.09358545392751694, 0.6316689252853394, 0.8724839091300964, 1.2217024564743042, 0.6390234231948853, 0.9049992561340332, 1.504401445388794, 1.8765724897384644, 0.7645778656005859, 0.10647137463092804, 0.957472562789917, 1.012259840965271, 1.4996145963668823, 0.863554835319519, 1.5310827493667603, 1.076755166053772, -1.3496817350387573, 1.4341621398925781, 1.5309221744537354, 1.200401782989502, 1.3245940208435059, 1.0820889472961426, 1.628312110900879, 1.4656100273132324, 0.7399660348892212, 0.5192306041717529, 1.0486398935317993, 0.7814551591873169, 1.5546458959579468, 1.0719009637832642, 0.6759751439094543, 0.7436344027519226, 1.3053089380264282, 1.5942689180374146, 1.3354003429412842, 1.4693421125411987, 1.657678484916687, 1.815665364265442, 1.8989185094833374, 1.1545225381851196, 0.0, 0.0], [0.0, 0.0, -9.701807022094727, -9.041651725769043, -7.5414628982543945, -7.574416637420654, -6.875150680541992, -6.9197001457214355, -5.87543249130249, -6.046632289886475, -5.271041393280029, -5.350934028625488, -5.0159993171691895, -5.215044021606445, -4.566492080688477, -3.905327558517456, -3.1531624794006348, -3.330181121826172, -2.530759334564209, -3.068032741546631, -2.1577553749084473, -3.19931960105896, -1.5958327054977417, -1.318393349647522, -0.8810674548149109, -0.5327627658843994, -0.4434344470500946, -0.6527561545372009, -0.3431565761566162, -0.044557005167007446, -0.33716583251953125, -0.07227309048175812, -0.45086878538131714, 0.2684016525745392, 0.053716324269771576, 0.4694208800792694, 0.29299303889274597, 0.6807907223701477, 0.9288551807403564, 1.7185348272323608, 1.1995017528533936, 0.8688251972198486, 0.6205388903617859, 0.6853005290031433, 0.766316831111908, 1.160404086112976, 0.9437131285667419, 0.8725447058677673, 1.0413557291030884, 1.0162535905838013, 1.225745439529419, -0.21304386854171753, 1.7641738653182983, 1.7047866582870483, 1.0857105255126953, 1.4461822509765625, 0.9943551421165466, 1.4618217945098877, 1.7010483741760254, 1.0834981203079224, 0.442010760307312, 0.8922585248947144, 0.373051255941391, 0.7931622266769409, 0.8443450331687927, 1.7623671293258667, 1.4002842903137207, 0.9979202151298523, 1.2646392583847046, 1.433462142944336, 1.5790380239486694, 1.0636924505233765, 1.5191895961761475, 1.3913238048553467, 1.3372838497161865, 0.07417717576026917, 0.0, 0.0, -0.0, -0.0, -9.701807022094727, -9.041651725769043, -7.5414628982543945, -7.574416637420654, -6.875150680541992, -6.9197001457214355, -5.87543249130249, -6.046632289886475, -5.271041393280029, -5.350934028625488, -5.0159993171691895, -5.215044021606445, -4.566492080688477, -3.905327558517456, -3.1531624794006348, -3.330181121826172, -2.530759334564209, -3.068032741546631, -2.1577553749084473, -3.19931960105896, -1.5958327054977417, -1.318393349647522, -0.8810674548149109, -0.5327627658843994, -0.4434344470500946, -0.6527561545372009, -0.3431565761566162, -0.044557005167007446, -0.33716583251953125, -0.07227309048175812, -0.45086878538131714, 0.2684016525745392, 0.053716324269771576, 0.4694208800792694, 0.29299303889274597, 0.6807907223701477, 0.9288551807403564, 1.7185348272323608, 1.1995017528533936, 0.8688251972198486, 0.6205388903617859, 0.6853005290031433, 0.766316831111908, 1.160404086112976, 0.9437131285667419, 0.8725447058677673, 1.0413557291030884, 1.0162535905838013, 1.225745439529419, -0.21304386854171753, 1.7641738653182983, 1.7047866582870483, 1.0857105255126953, 1.4461822509765625, 0.9943551421165466, 1.4618217945098877, 1.7010483741760254, 1.0834981203079224, 0.442010760307312, 0.8922585248947144, 0.373051255941391, 0.7931622266769409, 0.8443450331687927, 1.7623671293258667, 1.4002842903137207, 0.9979202151298523, 1.2646392583847046, 1.433462142944336, 1.5790380239486694, 1.0636924505233765, 1.5191895961761475, 1.3913238048553467, 1.3372838497161865, 0.07417717576026917, 0.0, 0.0], [0.0, 0.0, -9.9406156539917, -8.756000518798828, -8.178692817687988, -8.239517211914062, -7.331636905670166, -6.538455009460449, -6.657952785491943, -6.554854869842529, -5.18086051940918, -6.1075358390808105, -5.831901550292969, -5.082549571990967, -4.221632957458496, -4.110746383666992, -4.118348121643066, -2.787783145904541, -2.7792747020721436, -2.977257013320923, -2.349691867828369, -2.941121816635132, -2.903679132461548, -2.706726551055908, -2.105947256088257, -1.338481068611145, -0.8245169520378113, -1.118496298789978, -0.445512056350708, -0.05054323002696037, -0.44762828946113586, -0.5132484436035156, -0.2975704073905945, 0.4363395869731903, 1.6843091249465942, 0.17591504752635956, 1.1598355770111084, 0.7429592609405518, 1.055626392364502, 0.6605209708213806, 1.3481301069259644, 1.0677465200424194, 1.0489723682403564, 0.9586294293403625, 1.5488427877426147, 0.8150967955589294, 0.7324343323707581, 1.1564065217971802, 0.7635789513587952, 0.8560305237770081, 0.2969605028629303, 1.037217378616333, 0.47635698318481445, 1.078263521194458, 1.6618067026138306, 1.2600808143615723, -1.6109446287155151, 0.7849938273429871, 2.202049732208252, 0.8564651608467102, 0.9491077661514282, 0.6058635711669922, 0.9566127061843872, 0.789175808429718, 1.1547002792358398, 1.373210072517395, 0.8299464583396912, 0.4084394574165344, 0.6421892046928406, 0.8636837601661682, 0.6798185706138611, 0.8932863473892212, 1.1758615970611572, 0.8386990427970886, 1.7223345041275024, 1.378650426864624, 0.0, 0.0, -0.0, -0.0, -9.9406156539917, -8.756000518798828, -8.178692817687988, -8.239517211914062, -7.331636905670166, -6.538455009460449, -6.657952785491943, -6.554854869842529, -5.18086051940918, -6.1075358390808105, -5.831901550292969, -5.082549571990967, -4.221632957458496, -4.110746383666992, -4.118348121643066, -2.787783145904541, -2.7792747020721436, -2.977257013320923, -2.349691867828369, -2.941121816635132, -2.903679132461548, -2.706726551055908, -2.105947256088257, -1.338481068611145, -0.8245169520378113, -1.118496298789978, -0.445512056350708, -0.05054323002696037, -0.44762828946113586, -0.5132484436035156, -0.2975704073905945, 0.4363395869731903, 1.6843091249465942, 0.17591504752635956, 1.1598355770111084, 0.7429592609405518, 1.055626392364502, 0.6605209708213806, 1.3481301069259644, 1.0677465200424194, 1.0489723682403564, 0.9586294293403625, 1.5488427877426147, 0.8150967955589294, 0.7324343323707581, 1.1564065217971802, 0.7635789513587952, 0.8560305237770081, 0.2969605028629303, 1.037217378616333, 0.47635698318481445, 1.078263521194458, 1.6618067026138306, 1.2600808143615723, -1.6109446287155151, 0.7849938273429871, 2.202049732208252, 0.8564651608467102, 0.9491077661514282, 0.6058635711669922, 0.9566127061843872, 0.789175808429718, 1.1547002792358398, 1.373210072517395, 0.8299464583396912, 0.4084394574165344, 0.6421892046928406, 0.8636837601661682, 0.6798185706138611, 0.8932863473892212, 1.1758615970611572, 0.8386990427970886, 1.7223345041275024, 1.378650426864624, 0.0, 0.0], [0.0, 0.0, -10.380131721496582, -8.635866165161133, -8.571100234985352, -7.982335567474365, -7.498856067657471, -7.058990955352783, -6.822696685791016, -4.65946626663208, -6.322656154632568, -5.398003101348877, -5.475124835968018, -5.0743560791015625, -3.960273027420044, -3.943906307220459, -3.9376559257507324, -3.1828978061676025, -2.6485962867736816, -2.919813394546509, -2.6730213165283203, -2.91872501373291, -2.5124292373657227, -1.5949627161026, -2.573500633239746, -2.296660900115967, -1.0253310203552246, -1.2475647926330566, -0.6486476063728333, -1.0936325788497925, -0.9103102087974548, -0.3835832178592682, -0.5577160120010376, 0.253329336643219, 0.4527495503425598, 0.0948411300778389, -0.34896254539489746, 0.44200634956359863, 1.2145601511001587, 0.9673014879226685, 1.1624090671539307, 0.5206122398376465, 0.4555497467517853, 0.8034493327140808, 0.7165713310241699, 0.9436713457107544, 0.8482043743133545, 0.9858337044715881, 0.9523069262504578, 1.0784326791763306, 1.2754981517791748, 0.46800175309181213, 1.265903353691101, 1.343851923942566, 1.584216594696045, 0.4380923807621002, 1.1677393913269043, 0.5677796006202698, 0.7861252427101135, 1.0892280340194702, 1.1714340448379517, 0.5786776542663574, 1.3575071096420288, 0.659365177154541, 0.5426918268203735, 1.1710705757141113, 0.6503571271896362, -0.3078615367412567, 0.8906096816062927, 0.9363288283348083, 0.889449954032898, 1.917712926864624, 1.3247385025024414, 1.1909289360046387, 0.6968814730644226, 1.3989295959472656, 0.0, 0.0, -0.0, -0.0, -10.380131721496582, -8.635866165161133, -8.571100234985352, -7.982335567474365, -7.498856067657471, -7.058990955352783, -6.822696685791016, -4.65946626663208, -6.322656154632568, -5.398003101348877, -5.475124835968018, -5.0743560791015625, -3.960273027420044, -3.943906307220459, -3.9376559257507324, -3.1828978061676025, -2.6485962867736816, -2.919813394546509, -2.6730213165283203, -2.91872501373291, -2.5124292373657227, -1.5949627161026, -2.573500633239746, -2.296660900115967, -1.0253310203552246, -1.2475647926330566, -0.6486476063728333, -1.0936325788497925, -0.9103102087974548, -0.3835832178592682, -0.5577160120010376, 0.253329336643219, 0.4527495503425598, 0.0948411300778389, -0.34896254539489746, 0.44200634956359863, 1.2145601511001587, 0.9673014879226685, 1.1624090671539307, 0.5206122398376465, 0.4555497467517853, 0.8034493327140808, 0.7165713310241699, 0.9436713457107544, 0.8482043743133545, 0.9858337044715881, 0.9523069262504578, 1.0784326791763306, 1.2754981517791748, 0.46800175309181213, 1.265903353691101, 1.343851923942566, 1.584216594696045, 0.4380923807621002, 1.1677393913269043, 0.5677796006202698, 0.7861252427101135, 1.0892280340194702, 1.1714340448379517, 0.5786776542663574, 1.3575071096420288, 0.659365177154541, 0.5426918268203735, 1.1710705757141113, 0.6503571271896362, -0.3078615367412567, 0.8906096816062927, 0.9363288283348083, 0.889449954032898, 1.917712926864624, 1.3247385025024414, 1.1909289360046387, 0.6968814730644226, 1.3989295959472656, 0.0, 0.0], [0.0, 0.0, -10.470155715942383, -8.903890609741211, -8.738512992858887, -7.719852924346924, -7.418116569519043, -7.571496486663818, -7.515203952789307, -6.520204067230225, -6.62315559387207, -5.935263633728027, -5.295166015625, -4.408286094665527, -3.7651844024658203, -4.326904296875, -4.352084636688232, -4.134875774383545, -4.068296909332275, -3.384964942932129, -1.651416301727295, -2.504868984222412, -2.2783992290496826, -1.0225062370300293, 1.3452816009521484, -1.3048418760299683, -1.3055055141448975, -0.9871781468391418, -0.5584855675697327, -0.7793036699295044, 0.03978390991687775, -0.7638531923294067, -0.9791660308837891, -0.0839364230632782, 0.19209209084510803, 0.8242833018302917, 0.33162519335746765, 0.38062024116516113, 0.7545206546783447, 0.802237331867218, 0.5899395942687988, 0.8595783114433289, 1.6896675825119019, 1.0682647228240967, 1.0816717147827148, 1.2098336219787598, 1.2565608024597168, 0.7024868130683899, -0.6246281862258911, 0.7930259704589844, 0.1597079038619995, 0.3114463984966278, 1.6146477460861206, 1.5164790153503418, 0.3306231200695038, 0.983197808265686, 1.5211101770401, 0.7308452129364014, 0.9049044847488403, 0.7461578249931335, 1.4452974796295166, 1.10736882686615, 0.3791806995868683, 0.3672267496585846, 2.1409363746643066, 1.2199708223342896, 0.9819976687431335, 0.7138853669166565, 0.832367479801178, 1.3106026649475098, 1.3599298000335693, 0.999876081943512, 0.5652482509613037, 0.0918193832039833, -0.05803715065121651, 1.747226595878601, 0.0, 0.0, -0.0, -0.0, -10.470155715942383, -8.903890609741211, -8.738512992858887, -7.719852924346924, -7.418116569519043, -7.571496486663818, -7.515203952789307, -6.520204067230225, -6.62315559387207, -5.935263633728027, -5.295166015625, -4.408286094665527, -3.7651844024658203, -4.326904296875, -4.352084636688232, -4.134875774383545, -4.068296909332275, -3.384964942932129, -1.651416301727295, -2.504868984222412, -2.2783992290496826, -1.0225062370300293, 1.3452816009521484, -1.3048418760299683, -1.3055055141448975, -0.9871781468391418, -0.5584855675697327, -0.7793036699295044, 0.03978390991687775, -0.7638531923294067, -0.9791660308837891, -0.0839364230632782, 0.19209209084510803, 0.8242833018302917, 0.33162519335746765, 0.38062024116516113, 0.7545206546783447, 0.802237331867218, 0.5899395942687988, 0.8595783114433289, 1.6896675825119019, 1.0682647228240967, 1.0816717147827148, 1.2098336219787598, 1.2565608024597168, 0.7024868130683899, -0.6246281862258911, 0.7930259704589844, 0.1597079038619995, 0.3114463984966278, 1.6146477460861206, 1.5164790153503418, 0.3306231200695038, 0.983197808265686, 1.5211101770401, 0.7308452129364014, 0.9049044847488403, 0.7461578249931335, 1.4452974796295166, 1.10736882686615, 0.3791806995868683, 0.3672267496585846, 2.1409363746643066, 1.2199708223342896, 0.9819976687431335, 0.7138853669166565, 0.832367479801178, 1.3106026649475098, 1.3599298000335693, 0.999876081943512, 0.5652482509613037, 0.0918193832039833, -0.05803715065121651, 1.747226595878601, 0.0, 0.0], [0.0, 0.0, -8.849913597106934, -9.419301986694336, -8.503929138183594, -7.868927955627441, -8.079120635986328, -7.674553871154785, -6.874107837677002, -6.855417728424072, -6.8539557456970215, -5.996148586273193, -4.905528545379639, -4.634876728057861, -4.585102558135986, -4.171238422393799, -3.737525701522827, -3.904090166091919, -3.025114059448242, -3.890474319458008, -3.7222111225128174, -2.8914289474487305, -1.2853901386260986, -2.473799467086792, -1.5869885683059692, -1.3416022062301636, -2.0860061645507812, -0.424454003572464, -1.3559882640838623, -1.454569935798645, -0.6760828495025635, -0.7026104927062988, -0.12219862639904022, -0.2993029057979584, -0.5717593431472778, 0.1885104924440384, -0.10741624981164932, -0.5177201628684998, 0.1955665498971939, 0.8656416535377502, 0.45850396156311035, 0.6953144073486328, 0.5530350804328918, 0.8624906539916992, 0.8664252161979675, 0.7730254530906677, 0.27043935656547546, -0.23179616034030914, -0.256686806678772, -0.2643827199935913, 0.897165060043335, 0.9853322505950928, 0.9692369699478149, 2.175673246383667, 0.6203523874282837, 0.7858431935310364, 0.015527741052210331, 1.0845677852630615, -0.06923378258943558, 0.9670251607894897, 0.7435401678085327, 0.8154226541519165, 0.6186872720718384, 0.9779168367385864, 0.3647919297218323, -0.2686726450920105, 1.1529802083969116, 0.5236389636993408, 0.44636818766593933, 0.859201192855835, 0.1452241688966751, 0.9799755811691284, -0.04574909806251526, 0.30408355593681335, -0.3058944642543793, -0.4921298623085022, 0.0, 0.0, -0.0, -0.0, -8.849913597106934, -9.419301986694336, -8.503929138183594, -7.868927955627441, -8.079120635986328, -7.674553871154785, -6.874107837677002, -6.855417728424072, -6.8539557456970215, -5.996148586273193, -4.905528545379639, -4.634876728057861, -4.585102558135986, -4.171238422393799, -3.737525701522827, -3.904090166091919, -3.025114059448242, -3.890474319458008, -3.7222111225128174, -2.8914289474487305, -1.2853901386260986, -2.473799467086792, -1.5869885683059692, -1.3416022062301636, -2.0860061645507812, -0.424454003572464, -1.3559882640838623, -1.454569935798645, -0.6760828495025635, -0.7026104927062988, -0.12219862639904022, -0.2993029057979584, -0.5717593431472778, 0.1885104924440384, -0.10741624981164932, -0.5177201628684998, 0.1955665498971939, 0.8656416535377502, 0.45850396156311035, 0.6953144073486328, 0.5530350804328918, 0.8624906539916992, 0.8664252161979675, 0.7730254530906677, 0.27043935656547546, -0.23179616034030914, -0.256686806678772, -0.2643827199935913, 0.897165060043335, 0.9853322505950928, 0.9692369699478149, 2.175673246383667, 0.6203523874282837, 0.7858431935310364, 0.015527741052210331, 1.0845677852630615, -0.06923378258943558, 0.9670251607894897, 0.7435401678085327, 0.8154226541519165, 0.6186872720718384, 0.9779168367385864, 0.3647919297218323, -0.2686726450920105, 1.1529802083969116, 0.5236389636993408, 0.44636818766593933, 0.859201192855835, 0.1452241688966751, 0.9799755811691284, -0.04574909806251526, 0.30408355593681335, -0.3058944642543793, -0.4921298623085022, -0.0, -0.0], [0.0, -10.153244018554688, -9.764017105102539, -9.400552749633789, -8.460070610046387, -8.682016372680664, -8.184918403625488, -7.852550029754639, -7.325333118438721, -7.012291431427002, -6.680459976196289, -5.841124057769775, -5.717208385467529, -5.330465793609619, -4.497915267944336, -3.8615715503692627, -3.6679961681365967, -3.816986322402954, -3.8547632694244385, -3.5719668865203857, -2.8209404945373535, -3.4199411869049072, -3.5657403469085693, -2.803884744644165, -2.058847427368164, -0.5294358730316162, -1.0633488893508911, -1.1573230028152466, -1.6111406087875366, -1.0027552843093872, -0.4134262204170227, -1.0152461528778076, -0.8930366039276123, -0.640885591506958, -0.3056100308895111, 0.024335827678442, 0.8468523025512695, -0.04640151932835579, -0.8249149322509766, 0.17763164639472961, 0.23449113965034485, -0.10007348656654358, 1.0694996118545532, 0.9185938239097595, 0.2221709042787552, 0.17469577491283417, -0.25891298055648804, 0.1444772332906723, 0.4513988494873047, 0.47396498918533325, 0.5871720314025879, 1.2331125736236572, 0.3813892900943756, 2.4437248706817627, 2.2652299404144287, -0.14184023439884186, 0.14006735384464264, 0.8565639853477478, 1.4977296590805054, 0.5328426957130432, -0.41873079538345337, 0.5143532156944275, 0.08618982136249542, 0.9152026176452637, -0.32053449749946594, -0.7637414932250977, 0.7104949951171875, 0.18724752962589264, 0.3221549093723297, 0.9339548945426941, -0.08515390008687973, 0.5681777000427246, 0.07517034560441971, -0.5721449851989746, 0.06788139790296555, 2.1835649013519287, 0.0, 0.0, -0.0, -10.153244018554688, -9.764017105102539, -9.400552749633789, -8.460070610046387, -8.682016372680664, -8.184918403625488, -7.852550029754639, -7.325333118438721, -7.012291431427002, -6.680459976196289, -5.841124057769775, -5.717208385467529, -5.330465793609619, -4.497915267944336, -3.8615715503692627, -3.6679961681365967, -3.816986322402954, -3.8547632694244385, -3.5719668865203857, -2.8209404945373535, -3.4199411869049072, -3.5657403469085693, -2.803884744644165, -2.058847427368164, -0.5294358730316162, -1.0633488893508911, -1.1573230028152466, -1.6111406087875366, -1.0027552843093872, -0.4134262204170227, -1.0152461528778076, -0.8930366039276123, -0.640885591506958, -0.3056100308895111, 0.024335827678442, 0.8468523025512695, -0.04640151932835579, -0.8249149322509766, 0.17763164639472961, 0.23449113965034485, -0.10007348656654358, 1.0694996118545532, 0.9185938239097595, 0.2221709042787552, 0.17469577491283417, -0.25891298055648804, 0.1444772332906723, 0.4513988494873047, 0.47396498918533325, 0.5871720314025879, 1.2331125736236572, 0.3813892900943756, 2.4437248706817627, 2.2652299404144287, -0.14184023439884186, 0.14006735384464264, 0.8565639853477478, 1.4977296590805054, 0.5328426957130432, -0.41873079538345337, 0.5143532156944275, 0.08618982136249542, 0.9152026176452637, -0.32053449749946594, -0.7637414932250977, 0.7104949951171875, 0.18724752962589264, 0.3221549093723297, 0.9339548945426941, -0.08515390008687973, 0.5681777000427246, 0.07517034560441971, -0.5721449851989746, 0.06788139790296555, 2.1835649013519287, 0.0, 0.0], [0.0, 0.0, -9.921272277832031, -9.213326454162598, -8.985651969909668, -8.305522918701172, -7.9260969161987305, -7.996841907501221, -7.424213409423828, -8.771389961242676, -5.910891532897949, -5.3654093742370605, -5.360981464385986, -5.197553634643555, -3.9775593280792236, -5.214529037475586, -4.311091423034668, -2.378711462020874, -2.999058485031128, -4.361013889312744, -3.3816895484924316, -2.920922040939331, -2.1198267936706543, -2.3222436904907227, -3.103992223739624, -2.05794620513916, -2.446883201599121, -2.0154128074645996, 0.9129575490951538, -2.4237749576568604, -0.5540453791618347, -2.1708755493164062, 0.35733261704444885, -0.7545883655548096, -1.259193778038025, -1.1156973838806152, 0.9876915216445923, -0.2666136920452118, -0.49967581033706665, -0.5725855231285095, 0.5991328358650208, 0.8590923547744751, 0.7172537446022034, 0.8366348743438721, 0.14686664938926697, 0.17232359945774078, 1.191664457321167, -0.4810536801815033, 0.5122020840644836, 0.47782832384109497, 0.4189588129520416, 0.42122337222099304, -0.13800206780433655, 0.019966421648859978, 0.16468538343906403, 0.894033670425415, 1.1431418657302856, 0.09296078979969025, 0.7456244826316833, 0.78435218334198, 0.6122416257858276, -0.794342577457428, 0.7434414625167847, 1.5066250562667847, 0.16174888610839844, 0.7018884420394897, 0.3859961926937103, 0.050476185977458954, -0.010648289695382118, 0.36263102293014526, 0.354813814163208, 1.1053158044815063, -0.603094220161438, 0.1700194776058197, -0.4843365550041199, -1.2472716569900513, 0.0, 0.0, -0.0, -0.0, -9.921272277832031, -9.213326454162598, -8.985651969909668, -8.305522918701172, -7.9260969161987305, -7.996841907501221, -7.424213409423828, -8.771389961242676, -5.910891532897949, -5.3654093742370605, -5.360981464385986, -5.197553634643555, -3.9775593280792236, -5.214529037475586, -4.311091423034668, -2.378711462020874, -2.999058485031128, -4.361013889312744, -3.3816895484924316, -2.920922040939331, -2.1198267936706543, -2.3222436904907227, -3.103992223739624, -2.05794620513916, -2.446883201599121, -2.0154128074645996, 0.9129575490951538, -2.4237749576568604, -0.5540453791618347, -2.1708755493164062, 0.35733261704444885, -0.7545883655548096, -1.259193778038025, -1.1156973838806152, 0.9876915216445923, -0.2666136920452118, -0.49967581033706665, -0.5725855231285095, 0.5991328358650208, 0.8590923547744751, 0.7172537446022034, 0.8366348743438721, 0.14686664938926697, 0.17232359945774078, 1.191664457321167, -0.4810536801815033, 0.5122020840644836, 0.47782832384109497, 0.4189588129520416, 0.42122337222099304, -0.13800206780433655, 0.019966421648859978, 0.16468538343906403, 0.894033670425415, 1.1431418657302856, 0.09296078979969025, 0.7456244826316833, 0.78435218334198, 0.6122416257858276, -0.794342577457428, 0.7434414625167847, 1.5066250562667847, 0.16174888610839844, 0.7018884420394897, 0.3859961926937103, 0.050476185977458954, -0.010648289695382118, 0.36263102293014526, 0.354813814163208, 1.1053158044815063, -0.603094220161438, 0.1700194776058197, -0.4843365550041199, -1.2472716569900513, -0.0, -0.0], [0.0, 0.0, -9.853371620178223, -9.743867874145508, -8.891595840454102, -9.06467056274414, -8.162362098693848, -7.369457721710205, -8.561285018920898, -7.208094596862793, -6.848360061645508, -6.119551658630371, -5.7034759521484375, -5.416656494140625, -4.9253411293029785, -5.176859378814697, -4.468781471252441, -3.900724172592163, -3.734117269515991, -2.986684799194336, -1.2656513452529907, -2.891530990600586, -2.4548213481903076, -3.0687408447265625, -2.835527181625366, -2.065854549407959, -1.1073697805404663, -1.69440758228302, -3.015434741973877, -1.6858758926391602, -1.3434702157974243, -0.7760588526725769, -1.2792693376541138, -0.9644395112991333, -0.9798445701599121, -0.3434253931045532, 0.2600363492965698, 0.3086043894290924, -2.430150270462036, -0.45617353916168213, -0.06940363347530365, 0.8502734303474426, 0.26381656527519226, 0.2244632989168167, -0.8018671870231628, 0.2439228743314743, 0.8304153084754944, -0.28841766715049744, 0.896966814994812, 0.5156855583190918, 0.9210412502288818, 1.3144128322601318, 0.22854332625865936, 1.456241250038147, 0.6292830109596252, 0.6367138624191284, 0.49410125613212585, 1.1825718879699707, -0.5105533599853516, -0.07115457206964493, 0.10701370984315872, 0.9108402132987976, 0.06556934118270874, 0.6662424802780151, 0.721305787563324, -0.16435280442237854, -0.21695508062839508, 0.0019682033453136683, 0.8396748900413513, 0.07012210786342621, -0.14890730381011963, 0.13785767555236816, 0.10209442675113678, 0.3685210645198822, -0.36589908599853516, -1.246942400932312, 0.0, 0.0, -0.0, -0.0, -9.853371620178223, -9.743867874145508, -8.891595840454102, -9.06467056274414, -8.162362098693848, -7.369457721710205, -8.561285018920898, -7.208094596862793, -6.848360061645508, -6.119551658630371, -5.7034759521484375, -5.416656494140625, -4.9253411293029785, -5.176859378814697, -4.468781471252441, -3.900724172592163, -3.734117269515991, -2.986684799194336, -1.2656513452529907, -2.891530990600586, -2.4548213481903076, -3.0687408447265625, -2.835527181625366, -2.065854549407959, -1.1073697805404663, -1.69440758228302, -3.015434741973877, -1.6858758926391602, -1.3434702157974243, -0.7760588526725769, -1.2792693376541138, -0.9644395112991333, -0.9798445701599121, -0.3434253931045532, 0.2600363492965698, 0.3086043894290924, -2.430150270462036, -0.45617353916168213, -0.06940363347530365, 0.8502734303474426, 0.26381656527519226, 0.2244632989168167, -0.8018671870231628, 0.2439228743314743, 0.8304153084754944, -0.28841766715049744, 0.896966814994812, 0.5156855583190918, 0.9210412502288818, 1.3144128322601318, 0.22854332625865936, 1.456241250038147, 0.6292830109596252, 0.6367138624191284, 0.49410125613212585, 1.1825718879699707, -0.5105533599853516, -0.07115457206964493, 0.10701370984315872, 0.9108402132987976, 0.06556934118270874, 0.6662424802780151, 0.721305787563324, -0.16435280442237854, -0.21695508062839508, 0.0019682033453136683, 0.8396748900413513, 0.07012210786342621, -0.14890730381011963, 0.13785767555236816, 0.10209442675113678, 0.3685210645198822, -0.36589908599853516, -1.246942400932312, -0.0, -0.0], [0.0, 0.0, -9.832378387451172, -9.50256061553955, -9.641772270202637, -9.124499320983887, -9.04213809967041, -8.179858207702637, -8.239177703857422, -7.581353187561035, -6.5861639976501465, -6.009185791015625, -6.445651531219482, -5.508809566497803, -5.366485118865967, -5.209512233734131, -4.94500732421875, -4.357400894165039, -3.827537775039673, -3.1038427352905273, -4.411840915679932, -3.3522164821624756, -1.4935815334320068, -2.332972526550293, -2.1686673164367676, -1.2319209575653076, -0.927560031414032, -1.9885785579681396, -1.3496657609939575, -1.5569363832473755, -1.097599744796753, -1.2611429691314697, -1.43131422996521, -0.4796430468559265, -1.513907790184021, -0.9321532845497131, 0.2580150067806244, 1.163776159286499, 0.2642349600791931, -0.7228401303291321, -0.5622278451919556, -0.07710462808609009, -0.43934181332588196, -0.4435551166534424, 0.04271913319826126, 0.5474498867988586, -0.5751446485519409, -0.2772728502750397, 0.3594873249530792, -0.15746262669563293, 0.1957065463066101, 0.7139248251914978, 0.19923970103263855, 1.0394870042800903, 0.31143689155578613, -0.36808687448501587, 0.6175854206085205, -0.19408345222473145, -0.18563513457775116, 0.6644923686981201, 0.20253480970859528, -0.6497578620910645, 0.6431024670600891, -0.1031898707151413, -0.5166359543800354, -0.6330993175506592, -0.4887780249118805, -0.9635999202728271, -0.09427214413881302, 0.38250720500946045, 0.08912068605422974, -0.010150975547730923, -0.6435819268226624, -1.5773334503173828, -0.31745457649230957, -0.8627445101737976, 0.0, 0.0, -0.0, -0.0, -9.832378387451172, -9.50256061553955, -9.641772270202637, -9.124499320983887, -9.04213809967041, -8.179858207702637, -8.239177703857422, -7.581353187561035, -6.5861639976501465, -6.009185791015625, -6.445651531219482, -5.508809566497803, -5.366485118865967, -5.209512233734131, -4.94500732421875, -4.357400894165039, -3.827537775039673, -3.1038427352905273, -4.411840915679932, -3.3522164821624756, -1.4935815334320068, -2.332972526550293, -2.1686673164367676, -1.2319209575653076, -0.927560031414032, -1.9885785579681396, -1.3496657609939575, -1.5569363832473755, -1.097599744796753, -1.2611429691314697, -1.43131422996521, -0.4796430468559265, -1.513907790184021, -0.9321532845497131, 0.2580150067806244, 1.163776159286499, 0.2642349600791931, -0.7228401303291321, -0.5622278451919556, -0.07710462808609009, -0.43934181332588196, -0.4435551166534424, 0.04271913319826126, 0.5474498867988586, -0.5751446485519409, -0.2772728502750397, 0.3594873249530792, -0.15746262669563293, 0.1957065463066101, 0.7139248251914978, 0.19923970103263855, 1.0394870042800903, 0.31143689155578613, -0.36808687448501587, 0.6175854206085205, -0.19408345222473145, -0.18563513457775116, 0.6644923686981201, 0.20253480970859528, -0.6497578620910645, 0.6431024670600891, -0.1031898707151413, -0.5166359543800354, -0.6330993175506592, -0.4887780249118805, -0.9635999202728271, -0.09427214413881302, 0.38250720500946045, 0.08912068605422974, -0.010150975547730923, -0.6435819268226624, -1.5773334503173828, -0.31745457649230957, -0.8627445101737976, -0.0, -0.0], [0.0, 0.0, -10.195268630981445, -10.320279121398926, -10.03391170501709, -9.402685165405273, -9.427912712097168, -8.722162246704102, -8.446344375610352, -7.996384620666504, -7.663361549377441, -6.4845757484436035, -5.548052787780762, -5.580070972442627, -5.437677383422852, -4.09183931350708, -4.785163879394531, -4.0763092041015625, -3.7311484813690186, -4.086096286773682, -3.572376251220703, -3.4099881649017334, -3.3936450481414795, -1.397801160812378, -2.9462738037109375, -1.8772679567337036, -1.6037846803665161, -1.1652936935424805, -1.727913737297058, -2.1033406257629395, -1.9273748397827148, -1.6371320486068726, -1.018152117729187, -2.1879048347473145, -1.63874089717865, -0.6662883162498474, -0.7226347327232361, 1.0981382131576538, -0.019211236387491226, -0.5473605394363403, -0.33918294310569763, -1.2691311836242676, 0.22669336199760437, -0.793953001499176, -0.5202875137329102, -0.5590108633041382, -0.37170591950416565, -1.1481837034225464, 0.3342627286911011, 0.15357503294944763, -0.31982797384262085, -0.14877180755138397, -0.39087995886802673, 0.6297578811645508, 1.0605368614196777, -0.4148770570755005, -0.15608623623847961, -0.34418800473213196, 0.06391889601945877, -0.5098845362663269, 0.14294889569282532, 0.49340951442718506, 0.13604570925235748, 0.3375991880893707, 0.2369116246700287, -0.29849353432655334, -0.5276211500167847, -0.468959778547287, -0.2885320782661438, 0.24308350682258606, 0.23262259364128113, -0.5767467617988586, 0.019497917965054512, -0.35768723487854004, -1.6459530591964722, -0.8242722153663635, 0.0, 0.0, -0.0, -0.0, -10.195268630981445, -10.320279121398926, -10.03391170501709, -9.402685165405273, -9.427912712097168, -8.722162246704102, -8.446344375610352, -7.996384620666504, -7.663361549377441, -6.4845757484436035, -5.548052787780762, -5.580070972442627, -5.437677383422852, -4.09183931350708, -4.785163879394531, -4.0763092041015625, -3.7311484813690186, -4.086096286773682, -3.572376251220703, -3.4099881649017334, -3.3936450481414795, -1.397801160812378, -2.9462738037109375, -1.8772679567337036, -1.6037846803665161, -1.1652936935424805, -1.727913737297058, -2.1033406257629395, -1.9273748397827148, -1.6371320486068726, -1.018152117729187, -2.1879048347473145, -1.63874089717865, -0.6662883162498474, -0.7226347327232361, 1.0981382131576538, -0.019211236387491226, -0.5473605394363403, -0.33918294310569763, -1.2691311836242676, 0.22669336199760437, -0.793953001499176, -0.5202875137329102, -0.5590108633041382, -0.37170591950416565, -1.1481837034225464, 0.3342627286911011, 0.15357503294944763, -0.31982797384262085, -0.14877180755138397, -0.39087995886802673, 0.6297578811645508, 1.0605368614196777, -0.4148770570755005, -0.15608623623847961, -0.34418800473213196, 0.06391889601945877, -0.5098845362663269, 0.14294889569282532, 0.49340951442718506, 0.13604570925235748, 0.3375991880893707, 0.2369116246700287, -0.29849353432655334, -0.5276211500167847, -0.468959778547287, -0.2885320782661438, 0.24308350682258606, 0.23262259364128113, -0.5767467617988586, 0.019497917965054512, -0.35768723487854004, -1.6459530591964722, -0.8242722153663635, -0.0, -0.0], [0.0, -12.653849601745605, -10.311004638671875, -10.975555419921875, -10.557766914367676, -9.49583911895752, -9.831632614135742, -8.73352336883545, -8.281050682067871, -7.742940425872803, -7.216343402862549, -6.483110427856445, -5.896709442138672, -5.561740875244141, -6.271296501159668, -5.417240619659424, -4.65101432800293, -4.726431369781494, -5.437652587890625, -3.946319580078125, -3.4387245178222656, -4.636250972747803, -3.4092307090759277, -4.390336513519287, -2.0040745735168457, -2.4315242767333984, -1.996184229850769, -2.537932872772217, -0.5788514018058777, -2.402498245239258, -2.175046682357788, -2.232004165649414, -0.7203827500343323, -1.4563039541244507, -1.4777573347091675, -2.175419807434082, -1.4339771270751953, -0.7860690355300903, -0.5520261526107788, -0.7217308282852173, 2.9750571250915527, 1.7466810941696167, -0.44788214564323425, -0.8166626691818237, -0.2620279788970947, -0.8592612147331238, -0.7118294835090637, -1.2885855436325073, -0.6527358293533325, -0.3536320626735687, -1.7947123050689697, 0.4075047969818115, -1.3335106372833252, 1.6056939363479614, -0.5655682682991028, -0.635136604309082, -0.280240535736084, 0.966556191444397, -0.5423615574836731, -0.46899649500846863, 0.2101326882839203, 0.12257016450166702, 0.014789474196732044, -0.9089106917381287, -0.9059104323387146, -0.9589632749557495, -0.31939566135406494, 0.466800719499588, 0.09208209812641144, -0.32819515466690063, -0.010148745030164719, 0.3597664535045624, -0.3213043510913849, -0.8017772436141968, -1.3564552068710327, -0.49361100792884827, 0.0, 0.0, -0.0, -12.653849601745605, -10.311004638671875, -10.975555419921875, -10.557766914367676, -9.49583911895752, -9.831632614135742, -8.73352336883545, -8.281050682067871, -7.742940425872803, -7.216343402862549, -6.483110427856445, -5.896709442138672, -5.561740875244141, -6.271296501159668, -5.417240619659424, -4.65101432800293, -4.726431369781494, -5.437652587890625, -3.946319580078125, -3.4387245178222656, -4.636250972747803, -3.4092307090759277, -4.390336513519287, -2.0040745735168457, -2.4315242767333984, -1.996184229850769, -2.537932872772217, -0.5788514018058777, -2.402498245239258, -2.175046682357788, -2.232004165649414, -0.7203827500343323, -1.4563039541244507, -1.4777573347091675, -2.175419807434082, -1.4339771270751953, -0.7860690355300903, -0.5520261526107788, -0.7217308282852173, 2.9750571250915527, 1.7466810941696167, -0.44788214564323425, -0.8166626691818237, -0.2620279788970947, -0.8592612147331238, -0.7118294835090637, -1.2885855436325073, -0.6527358293533325, -0.3536320626735687, -1.7947123050689697, 0.4075047969818115, -1.3335106372833252, 1.6056939363479614, -0.5655682682991028, -0.635136604309082, -0.280240535736084, 0.966556191444397, -0.5423615574836731, -0.46899649500846863, 0.2101326882839203, 0.12257016450166702, 0.014789474196732044, -0.9089106917381287, -0.9059104323387146, -0.9589632749557495, -0.31939566135406494, 0.466800719499588, 0.09208209812641144, -0.32819515466690063, -0.010148745030164719, 0.3597664535045624, -0.3213043510913849, -0.8017772436141968, -1.3564552068710327, -0.49361100792884827, -0.0, -0.0], [0.0, -14.443840980529785, -11.068952560424805, -11.32957935333252, -10.88896369934082, -10.776480674743652, -9.686692237854004, -9.142200469970703, -8.380387306213379, -6.981380462646484, -6.983656406402588, -7.050024509429932, -6.760003089904785, -5.022439956665039, -6.024780750274658, -5.197484970092773, -4.874015808105469, -4.628987789154053, -4.986313343048096, -4.372082233428955, -5.382018566131592, -3.200076103210449, -3.093585729598999, -3.324092149734497, -1.3511962890625, -3.41514253616333, -2.3591690063476562, -2.15678071975708, -1.7285895347595215, -2.0278220176696777, -1.736651062965393, -2.1631009578704834, -1.4747021198272705, -1.529977798461914, -2.386162519454956, -1.5565273761749268, -1.1020265817642212, -2.0218093395233154, -0.7861247658729553, -0.1606391817331314, 0.0, -0.7956491708755493, -1.3941766023635864, -1.8666021823883057, -1.623368263244629, 0.0393960177898407, -0.7802239060401917, -0.357417494058609, -1.0627293586730957, -0.015700235962867737, -0.6268885731697083, -0.7228024005889893, -0.3919657766819, -0.04370557889342308, -0.38624581694602966, -0.4278356730937958, -0.5947604179382324, 0.058845505118370056, -0.6164193749427795, 0.8138462901115417, -0.3539796471595764, -0.46491894125938416, -0.05477013438940048, -0.07024750858545303, -0.05553421005606651, -0.3119814693927765, 0.3840695023536682, 0.12403641641139984, 0.09233595430850983, -0.4872981011867523, 0.8419240713119507, -0.043854087591171265, -0.30327919125556946, -0.2774445116519928, -1.5772972106933594, -4.475458145141602, 0.0, 0.0, -0.0, -14.443840980529785, -11.068952560424805, -11.32957935333252, -10.88896369934082, -10.776480674743652, -9.686692237854004, -9.142200469970703, -8.380387306213379, -6.981380462646484, -6.983656406402588, -7.050024509429932, -6.760003089904785, -5.022439956665039, -6.024780750274658, -5.197484970092773, -4.874015808105469, -4.628987789154053, -4.986313343048096, -4.372082233428955, -5.382018566131592, -3.200076103210449, -3.093585729598999, -3.324092149734497, -1.3511962890625, -3.41514253616333, -2.3591690063476562, -2.15678071975708, -1.7285895347595215, -2.0278220176696777, -1.736651062965393, -2.1631009578704834, -1.4747021198272705, -1.529977798461914, -2.386162519454956, -1.5565273761749268, -1.1020265817642212, -2.0218093395233154, -0.7861247658729553, -0.1606391817331314, 0.0, -0.7956491708755493, -1.3941766023635864, -1.8666021823883057, -1.623368263244629, 0.0393960177898407, -0.7802239060401917, -0.357417494058609, -1.0627293586730957, -0.015700235962867737, -0.6268885731697083, -0.7228024005889893, -0.3919657766819, -0.04370557889342308, -0.38624581694602966, -0.4278356730937958, -0.5947604179382324, 0.058845505118370056, -0.6164193749427795, 0.8138462901115417, -0.3539796471595764, -0.46491894125938416, -0.05477013438940048, -0.07024750858545303, -0.05553421005606651, -0.3119814693927765, 0.3840695023536682, 0.12403641641139984, 0.09233595430850983, -0.4872981011867523, 0.8419240713119507, -0.043854087591171265, -0.30327919125556946, -0.2774445116519928, -1.5772972106933594, -4.475458145141602, -0.0, -0.0], [0.0, -11.673839569091797, -11.040260314941406, -10.621336936950684, -10.671792984008789, -11.144357681274414, -9.377105712890625, -8.968008995056152, -8.030936241149902, -7.2539520263671875, -6.678465366363525, -5.54335880279541, -7.070870876312256, -6.236178874969482, -6.522683143615723, -5.843708515167236, -5.027317523956299, -5.239197254180908, -4.942858695983887, -4.802610397338867, -4.61087703704834, -2.2930586338043213, -4.0043206214904785, -2.9069395065307617, -3.588948965072632, -3.177232265472412, -2.1792893409729004, -2.5365965366363525, -2.432243824005127, -2.1564080715179443, -2.4231038093566895, -4.307991027832031, -1.9097387790679932, -1.9787698984146118, -1.8096144199371338, -2.3546667098999023, 0.9094961881637573, -2.3060545921325684, -1.9187921285629272, -1.3118536472320557, 0.0, -1.3173309564590454, -1.2140841484069824, -1.5742465257644653, -1.2893471717834473, -3.352757453918457, -1.4652146100997925, -0.695935845375061, -1.3381562232971191, -2.7908785343170166, -0.7551233768463135, -1.4232847690582275, -1.3586206436157227, -0.7787148952484131, 0.049021825194358826, -1.2451441287994385, -0.7949123978614807, 0.3635377585887909, -0.6125015020370483, -0.36200007796287537, -0.12044677138328552, -0.3978610038757324, -0.4225084185600281, -0.669529914855957, -0.6319546103477478, -0.40039071440696716, -0.17275571823120117, -0.22810417413711548, -0.3825310468673706, 0.4227495491504669, 0.20976503193378448, -0.28980007767677307, 0.09139697998762131, -0.0943625271320343, -2.718416452407837, -2.4136242866516113, 0.0, 0.0, -0.0, -11.673839569091797, -11.040260314941406, -10.621336936950684, -10.671792984008789, -11.144357681274414, -9.377105712890625, -8.968008995056152, -8.030936241149902, -7.2539520263671875, -6.678465366363525, -5.54335880279541, -7.070870876312256, -6.236178874969482, -6.522683143615723, -5.843708515167236, -5.027317523956299, -5.239197254180908, -4.942858695983887, -4.802610397338867, -4.61087703704834, -2.2930586338043213, -4.0043206214904785, -2.9069395065307617, -3.588948965072632, -3.177232265472412, -2.1792893409729004, -2.5365965366363525, -2.432243824005127, -2.1564080715179443, -2.4231038093566895, -4.307991027832031, -1.9097387790679932, -1.9787698984146118, -1.8096144199371338, -2.3546667098999023, 0.9094961881637573, -2.3060545921325684, -1.9187921285629272, -1.3118536472320557, -0.0, -1.3173309564590454, -1.2140841484069824, -1.5742465257644653, -1.2893471717834473, -3.352757453918457, -1.4652146100997925, -0.695935845375061, -1.3381562232971191, -2.7908785343170166, -0.7551233768463135, -1.4232847690582275, -1.3586206436157227, -0.7787148952484131, 0.049021825194358826, -1.2451441287994385, -0.7949123978614807, 0.3635377585887909, -0.6125015020370483, -0.36200007796287537, -0.12044677138328552, -0.3978610038757324, -0.4225084185600281, -0.669529914855957, -0.6319546103477478, -0.40039071440696716, -0.17275571823120117, -0.22810417413711548, -0.3825310468673706, 0.4227495491504669, 0.20976503193378448, -0.28980007767677307, 0.09139697998762131, -0.0943625271320343, -2.718416452407837, -2.4136242866516113, -0.0, -0.0], [0.0, -11.363184928894043, -11.368025779724121, -11.716361999511719, -11.290507316589355, -10.895784378051758, -10.942294120788574, -9.64809513092041, -9.527017593383789, -8.12276840209961, -7.452665328979492, -7.180749416351318, -7.123684883117676, -6.619261741638184, -5.046180725097656, -6.420412063598633, -5.6672468185424805, -5.464744567871094, -5.6517229080200195, -5.248640537261963, -4.340000629425049, -3.9763574600219727, -3.5533370971679688, -4.2459716796875, -3.458512783050537, -3.1930055618286133, -2.6246447563171387, -2.6071252822875977, -3.453439712524414, -3.2529213428497314, -1.9836761951446533, -2.2080800533294678, -1.6680048704147339, -1.7238954305648804, -1.8429096937179565, -2.902582883834839, -2.8493824005126953, -3.123788356781006, -2.455826759338379, -2.737514019012451, 0.0, -1.3487855195999146, -1.967054843902588, -1.9489604234695435, -0.8539301156997681, -1.3919925689697266, -1.0958517789840698, -1.9555995464324951, -1.496489405632019, -0.29683542251586914, -0.9387351274490356, -1.3998405933380127, -1.8428484201431274, -0.34390896558761597, 0.413297563791275, -1.737073540687561, -0.4187264144420624, -0.6657941341400146, 0.04100697115063667, -0.3382118344306946, 0.48090028762817383, -0.6667943000793457, -0.8748048543930054, -0.410238653421402, -0.46045756340026855, -0.3389488458633423, -0.47841691970825195, -0.5343364477157593, -1.4538902044296265, -0.8845086097717285, -0.3833734691143036, -0.054685138165950775, -0.17417408525943756, -0.7306510210037231, -3.6227777004241943, -0.2881094515323639, 0.0, 0.0, -0.0, -11.363184928894043, -11.368025779724121, -11.716361999511719, -11.290507316589355, -10.895784378051758, -10.942294120788574, -9.64809513092041, -9.527017593383789, -8.12276840209961, -7.452665328979492, -7.180749416351318, -7.123684883117676, -6.619261741638184, -5.046180725097656, -6.420412063598633, -5.6672468185424805, -5.464744567871094, -5.6517229080200195, -5.248640537261963, -4.340000629425049, -3.9763574600219727, -3.5533370971679688, -4.2459716796875, -3.458512783050537, -3.1930055618286133, -2.6246447563171387, -2.6071252822875977, -3.453439712524414, -3.2529213428497314, -1.9836761951446533, -2.2080800533294678, -1.6680048704147339, -1.7238954305648804, -1.8429096937179565, -2.902582883834839, -2.8493824005126953, -3.123788356781006, -2.455826759338379, -2.737514019012451, -0.0, -1.3487855195999146, -1.967054843902588, -1.9489604234695435, -0.8539301156997681, -1.3919925689697266, -1.0958517789840698, -1.9555995464324951, -1.496489405632019, -0.29683542251586914, -0.9387351274490356, -1.3998405933380127, -1.8428484201431274, -0.34390896558761597, 0.413297563791275, -1.737073540687561, -0.4187264144420624, -0.6657941341400146, 0.04100697115063667, -0.3382118344306946, 0.48090028762817383, -0.6667943000793457, -0.8748048543930054, -0.410238653421402, -0.46045756340026855, -0.3389488458633423, -0.47841691970825195, -0.5343364477157593, -1.4538902044296265, -0.8845086097717285, -0.3833734691143036, -0.054685138165950775, -0.17417408525943756, -0.7306510210037231, -3.6227777004241943, -0.2881094515323639, -0.0, -0.0], [0.0, -13.286627769470215, -11.215025901794434, -12.333178520202637, -11.189411163330078, -11.24511432647705, -10.017754554748535, -9.604904174804688, -9.059374809265137, -8.122467994689941, -8.168625831604004, -8.090946197509766, -7.497729301452637, -6.564903736114502, -6.431972026824951, -5.704442977905273, -6.3992414474487305, -7.252917289733887, -4.92149019241333, -4.324578762054443, -5.1109490394592285, -4.262732028961182, -4.63926887512207, -4.867990493774414, -2.8294076919555664, -3.789715528488159, -2.9397664070129395, -2.2923874855041504, -3.213153839111328, -2.6809241771698, -3.452871561050415, -3.056886672973633, -1.946630597114563, -2.1011314392089844, -2.225939989089966, 0.028698325157165527, -0.2579387128353119, -3.1920833587646484, -3.0736076831817627, -1.3218519687652588, 0.0, -0.7237416505813599, -0.7729041576385498, -2.279881238937378, -2.590327501296997, -3.111999273300171, -1.698589563369751, -1.8688331842422485, -1.9597465991973877, -1.0719997882843018, -1.8927894830703735, -2.6202707290649414, -0.5718188285827637, -1.6318719387054443, -1.3931573629379272, -1.5783445835113525, -1.303349494934082, -0.6798517107963562, -0.5902310609817505, -0.8862003684043884, -0.8190809488296509, -0.6718165874481201, 0.17660817503929138, -0.38489603996276855, -0.09785399585962296, -0.5825323462486267, -0.8081143498420715, -0.6582839488983154, -0.20839625597000122, -0.5118606686592102, 0.03156520798802376, -0.9848185181617737, -0.48730066418647766, -0.6462385654449463, -1.8666261434555054, -1.6999071836471558, 0.0, 0.0, -0.0, -13.286627769470215, -11.215025901794434, -12.333178520202637, -11.189411163330078, -11.24511432647705, -10.017754554748535, -9.604904174804688, -9.059374809265137, -8.122467994689941, -8.168625831604004, -8.090946197509766, -7.497729301452637, -6.564903736114502, -6.431972026824951, -5.704442977905273, -6.3992414474487305, -7.252917289733887, -4.92149019241333, -4.324578762054443, -5.1109490394592285, -4.262732028961182, -4.63926887512207, -4.867990493774414, -2.8294076919555664, -3.789715528488159, -2.9397664070129395, -2.2923874855041504, -3.213153839111328, -2.6809241771698, -3.452871561050415, -3.056886672973633, -1.946630597114563, -2.1011314392089844, -2.225939989089966, 0.028698325157165527, -0.2579387128353119, -3.1920833587646484, -3.0736076831817627, -1.3218519687652588, -0.0, -0.7237416505813599, -0.7729041576385498, -2.279881238937378, -2.590327501296997, -3.111999273300171, -1.698589563369751, -1.8688331842422485, -1.9597465991973877, -1.0719997882843018, -1.8927894830703735, -2.6202707290649414, -0.5718188285827637, -1.6318719387054443, -1.3931573629379272, -1.5783445835113525, -1.303349494934082, -0.6798517107963562, -0.5902310609817505, -0.8862003684043884, -0.8190809488296509, -0.6718165874481201, 0.17660817503929138, -0.38489603996276855, -0.09785399585962296, -0.5825323462486267, -0.8081143498420715, -0.6582839488983154, -0.20839625597000122, -0.5118606686592102, 0.03156520798802376, -0.9848185181617737, -0.48730066418647766, -0.6462385654449463, -1.8666261434555054, -1.6999071836471558, -0.0, -0.0], [0.0, 0.0, -12.56938648223877, -12.283171653747559, -11.869868278503418, -11.059723854064941, -10.288122177124023, -10.328960418701172, -10.070796966552734, -8.049428939819336, -8.160957336425781, -7.817244529724121, -7.844038009643555, -7.412317752838135, -6.741056442260742, -6.01132345199585, -6.07198429107666, -6.813310623168945, -5.664580821990967, -4.6270976066589355, -4.527134895324707, -4.312082290649414, -2.579228401184082, -3.1967194080352783, 0.22442442178726196, -3.4285383224487305, -3.3041446208953857, -3.455442428588867, -2.579866886138916, -2.250363349914551, -2.8329920768737793, -3.5462141036987305, -3.010078191757202, -3.05320405960083, -2.7070741653442383, -2.6948554515838623, -3.332735538482666, -3.6458740234375, -3.3851075172424316, -2.093590259552002, 0.0, 0.0, -0.4353848993778229, -2.194462776184082, -1.9954789876937866, -1.7206364870071411, -2.054727077484131, -2.430119514465332, -1.755482792854309, 0.19154402613639832, -2.3871326446533203, -1.4817689657211304, -2.672351360321045, -1.915178656578064, -1.9971121549606323, -1.670154333114624, -1.3376190662384033, -1.4062983989715576, -0.9948511123657227, -1.110048770904541, -1.3129041194915771, -0.1517012119293213, -0.09887836873531342, -0.9428056478500366, -0.9115027189254761, -0.47354409098625183, -0.9687371253967285, -1.2456015348434448, 0.5847473740577698, -0.5328227877616882, -0.7610812187194824, -1.166849970817566, -1.0003691911697388, -1.5908663272857666, -1.9954476356506348, -1.1592429876327515, 0.0, 0.0, -0.0, -0.0, -12.56938648223877, -12.283171653747559, -11.869868278503418, -11.059723854064941, -10.288122177124023, -10.328960418701172, -10.070796966552734, -8.049428939819336, -8.160957336425781, -7.817244529724121, -7.844038009643555, -7.412317752838135, -6.741056442260742, -6.01132345199585, -6.07198429107666, -6.813310623168945, -5.664580821990967, -4.6270976066589355, -4.527134895324707, -4.312082290649414, -2.579228401184082, -3.1967194080352783, 0.22442442178726196, -3.4285383224487305, -3.3041446208953857, -3.455442428588867, -2.579866886138916, -2.250363349914551, -2.8329920768737793, -3.5462141036987305, -3.010078191757202, -3.05320405960083, -2.7070741653442383, -2.6948554515838623, -3.332735538482666, -3.6458740234375, -3.3851075172424316, -2.093590259552002, -0.0, -0.0, -0.4353848993778229, -2.194462776184082, -1.9954789876937866, -1.7206364870071411, -2.054727077484131, -2.430119514465332, -1.755482792854309, 0.19154402613639832, -2.3871326446533203, -1.4817689657211304, -2.672351360321045, -1.915178656578064, -1.9971121549606323, -1.670154333114624, -1.3376190662384033, -1.4062983989715576, -0.9948511123657227, -1.110048770904541, -1.3129041194915771, -0.1517012119293213, -0.09887836873531342, -0.9428056478500366, -0.9115027189254761, -0.47354409098625183, -0.9687371253967285, -1.2456015348434448, 0.5847473740577698, -0.5328227877616882, -0.7610812187194824, -1.166849970817566, -1.0003691911697388, -1.5908663272857666, -1.9954476356506348, -1.1592429876327515, -0.0, -0.0], [0.0, 0.0, -13.244180679321289, -12.583924293518066, -10.170352935791016, -11.698861122131348, -10.863225936889648, -10.409417152404785, -9.714138984680176, -9.543678283691406, -8.699728012084961, -8.090285301208496, -7.452484607696533, -7.205838203430176, -7.371821403503418, -6.180500030517578, -5.906817436218262, -5.171803951263428, -5.7099785804748535, -5.09714412689209, -6.600952625274658, -4.01376485824585, -3.5670151710510254, -4.495605945587158, -2.2527012825012207, -4.084193229675293, -5.636951923370361, -3.995985746383667, -4.510132789611816, -4.322968006134033, -4.455650806427002, -2.3790276050567627, -3.932570219039917, -3.127394914627075, -2.855583667755127, -2.320216417312622, -4.432310581207275, -3.553086519241333, -3.359332799911499, -3.3143229484558105, -2.4957802295684814, -3.662946939468384, -3.008584499359131, -0.5859453082084656, -0.20872896909713745, -4.1075968742370605, -2.4430794715881348, -2.7133638858795166, -2.7228102684020996, -1.9124810695648193, -1.9193181991577148, -3.0460219383239746, -2.804739236831665, -2.783057689666748, -2.999626398086548, -1.4268553256988525, -1.3011562824249268, -1.6073330640792847, 0.5498782396316528, -1.3523062467575073, -0.7376314401626587, -0.47692474722862244, -1.201453447341919, -2.115065813064575, -2.1058225631713867, -0.8420321345329285, -1.4345457553863525, -1.8112307786941528, -0.7119192481040955, -0.5801618099212646, -0.846954345703125, -0.8279127478599548, -0.4118843972682953, -0.6738988757133484, -1.9608514308929443, -2.0196967124938965, 0.0, 0.0, -0.0, -0.0, -13.244180679321289, -12.583924293518066, -10.170352935791016, -11.698861122131348, -10.863225936889648, -10.409417152404785, -9.714138984680176, -9.543678283691406, -8.699728012084961, -8.090285301208496, -7.452484607696533, -7.205838203430176, -7.371821403503418, -6.180500030517578, -5.906817436218262, -5.171803951263428, -5.7099785804748535, -5.09714412689209, -6.600952625274658, -4.01376485824585, -3.5670151710510254, -4.495605945587158, -2.2527012825012207, -4.084193229675293, -5.636951923370361, -3.995985746383667, -4.510132789611816, -4.322968006134033, -4.455650806427002, -2.3790276050567627, -3.932570219039917, -3.127394914627075, -2.855583667755127, -2.320216417312622, -4.432310581207275, -3.553086519241333, -3.359332799911499, -3.3143229484558105, -2.4957802295684814, -3.662946939468384, -3.008584499359131, -0.5859453082084656, -0.20872896909713745, -4.1075968742370605, -2.4430794715881348, -2.7133638858795166, -2.7228102684020996, -1.9124810695648193, -1.9193181991577148, -3.0460219383239746, -2.804739236831665, -2.783057689666748, -2.999626398086548, -1.4268553256988525, -1.3011562824249268, -1.6073330640792847, 0.5498782396316528, -1.3523062467575073, -0.7376314401626587, -0.47692474722862244, -1.201453447341919, -2.115065813064575, -2.1058225631713867, -0.8420321345329285, -1.4345457553863525, -1.8112307786941528, -0.7119192481040955, -0.5801618099212646, -0.846954345703125, -0.8279127478599548, -0.4118843972682953, -0.6738988757133484, -1.9608514308929443, -2.0196967124938965, -0.0, -0.0], [0.0, 0.0, -13.451789855957031, -13.222490310668945, -13.424334526062012, -12.847521781921387, -10.706656455993652, -10.066597938537598, -10.561090469360352, -9.490511894226074, -8.674630165100098, -7.9177632331848145, -7.245979309082031, -6.918770790100098, -6.711965560913086, -6.408957481384277, -6.201035022735596, -6.369296073913574, -4.718926429748535, -5.816176414489746, -4.608035087585449, -4.7494916915893555, -4.0864176750183105, -4.805654048919678, -3.8775434494018555, -4.834470272064209, -5.07301664352417, -3.6283795833587646, -3.8391001224517822, -3.4953291416168213, -3.4063241481781006, -3.9663875102996826, -3.5635411739349365, -4.937685966491699, -4.238105297088623, -1.8851408958435059, -3.8216240406036377, -3.8630259037017822, -3.3600096702575684, -3.2528653144836426, -3.0986719131469727, -3.1417338848114014, -1.431329369544983, -2.786839008331299, -2.770188331604004, -3.6354894638061523, -3.6285951137542725, -3.128981113433838, -1.2781621217727661, -0.8224205374717712, -3.6869704723358154, -4.96209716796875, -5.1181511878967285, -3.3270394802093506, -0.008114272728562355, -1.389622449874878, -2.652172565460205, -1.9566744565963745, -1.6688368320465088, -0.807563841342926, -0.8137649297714233, -1.0186336040496826, -1.2503005266189575, -0.8692150115966797, -1.718363642692566, -0.7894304394721985, -0.5703974366188049, -0.36863240599632263, -0.9674875736236572, -1.2533349990844727, -0.9933574795722961, -0.7513989210128784, -0.23953646421432495, -1.625571846961975, -2.286885976791382, 0.0, 0.0, 0.0, -0.0, -0.0, -13.451789855957031, -13.222490310668945, -13.424334526062012, -12.847521781921387, -10.706656455993652, -10.066597938537598, -10.561090469360352, -9.490511894226074, -8.674630165100098, -7.9177632331848145, -7.245979309082031, -6.918770790100098, -6.711965560913086, -6.408957481384277, -6.201035022735596, -6.369296073913574, -4.718926429748535, -5.816176414489746, -4.608035087585449, -4.7494916915893555, -4.0864176750183105, -4.805654048919678, -3.8775434494018555, -4.834470272064209, -5.07301664352417, -3.6283795833587646, -3.8391001224517822, -3.4953291416168213, -3.4063241481781006, -3.9663875102996826, -3.5635411739349365, -4.937685966491699, -4.238105297088623, -1.8851408958435059, -3.8216240406036377, -3.8630259037017822, -3.3600096702575684, -3.2528653144836426, -3.0986719131469727, -3.1417338848114014, -1.431329369544983, -2.786839008331299, -2.770188331604004, -3.6354894638061523, -3.6285951137542725, -3.128981113433838, -1.2781621217727661, -0.8224205374717712, -3.6869704723358154, -4.96209716796875, -5.1181511878967285, -3.3270394802093506, -0.008114272728562355, -1.389622449874878, -2.652172565460205, -1.9566744565963745, -1.6688368320465088, -0.807563841342926, -0.8137649297714233, -1.0186336040496826, -1.2503005266189575, -0.8692150115966797, -1.718363642692566, -0.7894304394721985, -0.5703974366188049, -0.36863240599632263, -0.9674875736236572, -1.2533349990844727, -0.9933574795722961, -0.7513989210128784, -0.23953646421432495, -1.625571846961975, -2.286885976791382, -0.0, -0.0, -0.0], [0.0, 0.0, -13.895703315734863, -13.20452880859375, -12.954523086547852, -12.59288501739502, -11.152714729309082, -9.978578567504883, -10.507963180541992, -9.720998764038086, -9.288399696350098, -8.009994506835938, -8.367810249328613, -7.998828411102295, -7.0085344314575195, -6.753767013549805, -6.444612503051758, -6.040610313415527, -5.309113502502441, -5.4381422996521, -5.139184951782227, -5.347490310668945, -7.287539482116699, -3.672583818435669, -4.449863433837891, -4.436803817749023, -4.974637508392334, -4.865077972412109, -6.134753704071045, -4.837551116943359, -3.6090071201324463, -3.0014476776123047, -5.546803951263428, -4.2859930992126465, -2.854578733444214, -4.584991455078125, -5.168273448944092, -4.748809814453125, -4.663822174072266, -4.112558364868164, -4.45438289642334, -3.5613677501678467, -2.827765464782715, -3.53086256980896, -3.049086570739746, -3.2253758907318115, -2.322768211364746, -4.748050689697266, -2.9285197257995605, -2.8627023696899414, -3.6805241107940674, -3.9330124855041504, -2.1519346237182617, -2.156425952911377, -2.4556236267089844, -1.4614837169647217, -3.13508677482605, -2.178349494934082, -1.4326403141021729, -1.0911139249801636, -1.347394585609436, -0.6972302794456482, -1.4142725467681885, -0.7886568903923035, -1.3456275463104248, -1.4886600971221924, -0.5719636678695679, -0.7802883386611938, -1.3545410633087158, -1.0694037675857544, -0.12088111788034439, -0.4270274043083191, -0.4553707242012024, -2.727888345718384, -1.5303317308425903, 0.0, 0.0, 0.0, -0.0, -0.0, -13.895703315734863, -13.20452880859375, -12.954523086547852, -12.59288501739502, -11.152714729309082, -9.978578567504883, -10.507963180541992, -9.720998764038086, -9.288399696350098, -8.009994506835938, -8.367810249328613, -7.998828411102295, -7.0085344314575195, -6.753767013549805, -6.444612503051758, -6.040610313415527, -5.309113502502441, -5.4381422996521, -5.139184951782227, -5.347490310668945, -7.287539482116699, -3.672583818435669, -4.449863433837891, -4.436803817749023, -4.974637508392334, -4.865077972412109, -6.134753704071045, -4.837551116943359, -3.6090071201324463, -3.0014476776123047, -5.546803951263428, -4.2859930992126465, -2.854578733444214, -4.584991455078125, -5.168273448944092, -4.748809814453125, -4.663822174072266, -4.112558364868164, -4.45438289642334, -3.5613677501678467, -2.827765464782715, -3.53086256980896, -3.049086570739746, -3.2253758907318115, -2.322768211364746, -4.748050689697266, -2.9285197257995605, -2.8627023696899414, -3.6805241107940674, -3.9330124855041504, -2.1519346237182617, -2.156425952911377, -2.4556236267089844, -1.4614837169647217, -3.13508677482605, -2.178349494934082, -1.4326403141021729, -1.0911139249801636, -1.347394585609436, -0.6972302794456482, -1.4142725467681885, -0.7886568903923035, -1.3456275463104248, -1.4886600971221924, -0.5719636678695679, -0.7802883386611938, -1.3545410633087158, -1.0694037675857544, -0.12088111788034439, -0.4270274043083191, -0.4553707242012024, -2.727888345718384, -1.5303317308425903, -0.0, -0.0, -0.0], [0.0, 0.0, -13.188714027404785, -13.30948543548584, -12.976409912109375, -12.475425720214844, -11.166411399841309, -11.175251007080078, -9.451238632202148, -9.705535888671875, -9.036669731140137, -8.665579795837402, -8.47336483001709, -7.245084762573242, -8.07411003112793, -6.868721961975098, -6.50359582901001, -5.960180282592773, -6.1988372802734375, -5.269023418426514, -6.002762794494629, -4.696968078613281, -5.141705513000488, -7.139126777648926, -6.243517875671387, -5.069098949432373, -4.232128620147705, -4.265646457672119, -3.2622008323669434, -5.0251545906066895, -2.599196195602417, -3.984914779663086, -4.783971786499023, -5.494867324829102, -5.076099872589111, -4.478202819824219, -5.028415203094482, -5.832625389099121, -3.651468515396118, -4.854330062866211, -4.516014575958252, -4.4310173988342285, -3.3423240184783936, -4.807992458343506, -4.375113487243652, -4.126256942749023, -3.3558459281921387, -3.302001953125, -3.399524211883545, -3.7734575271606445, -4.280675888061523, -3.612062692642212, -2.690657138824463, 0.31238487362861633, -2.669217109680176, -2.66677188873291, -1.664353609085083, -2.2166829109191895, -1.6276828050613403, -1.5589232444763184, -1.01961350440979, -1.5586491823196411, -0.5737416744232178, -1.0290230512619019, -1.1641606092453003, -0.6607741713523865, -2.137432813644409, -1.4068164825439453, -1.2706878185272217, -1.9209874868392944, -0.646896243095398, -0.4997059106826782, -0.3276216983795166, -0.7238833904266357, -0.5352667570114136, 0.0, 0.0, 0.0, -0.0, -0.0, -13.188714027404785, -13.30948543548584, -12.976409912109375, -12.475425720214844, -11.166411399841309, -11.175251007080078, -9.451238632202148, -9.705535888671875, -9.036669731140137, -8.665579795837402, -8.47336483001709, -7.245084762573242, -8.07411003112793, -6.868721961975098, -6.50359582901001, -5.960180282592773, -6.1988372802734375, -5.269023418426514, -6.002762794494629, -4.696968078613281, -5.141705513000488, -7.139126777648926, -6.243517875671387, -5.069098949432373, -4.232128620147705, -4.265646457672119, -3.2622008323669434, -5.0251545906066895, -2.599196195602417, -3.984914779663086, -4.783971786499023, -5.494867324829102, -5.076099872589111, -4.478202819824219, -5.028415203094482, -5.832625389099121, -3.651468515396118, -4.854330062866211, -4.516014575958252, -4.4310173988342285, -3.3423240184783936, -4.807992458343506, -4.375113487243652, -4.126256942749023, -3.3558459281921387, -3.302001953125, -3.399524211883545, -3.7734575271606445, -4.280675888061523, -3.612062692642212, -2.690657138824463, 0.31238487362861633, -2.669217109680176, -2.66677188873291, -1.664353609085083, -2.2166829109191895, -1.6276828050613403, -1.5589232444763184, -1.01961350440979, -1.5586491823196411, -0.5737416744232178, -1.0290230512619019, -1.1641606092453003, -0.6607741713523865, -2.137432813644409, -1.4068164825439453, -1.2706878185272217, -1.9209874868392944, -0.646896243095398, -0.4997059106826782, -0.3276216983795166, -0.7238833904266357, -0.5352667570114136, -0.0, -0.0, -0.0], [0.0, 0.0, -13.496251106262207, -13.705086708068848, -13.35924243927002, -13.192031860351562, -12.05433464050293, -10.933077812194824, -9.63337230682373, -9.47005558013916, -9.042290687561035, -8.645682334899902, -8.210139274597168, -7.6574273109436035, -7.529191970825195, -7.793508529663086, -6.149754524230957, -6.87221622467041, -6.786312103271484, -5.653590202331543, -5.125581741333008, -5.528264999389648, -5.611661434173584, -6.478282451629639, -5.410840034484863, -5.1778564453125, -5.70499849319458, -6.107217788696289, -5.359619140625, -4.851661682128906, -5.235532283782959, -5.156385898590088, -4.30848503112793, -4.828065395355225, -5.668613433837891, -6.313490867614746, -4.3138885498046875, -5.232968807220459, -5.275716781616211, -5.513476371765137, -5.729329586029053, -4.58437442779541, -4.974188327789307, -4.459995269775391, -4.75787353515625, -4.330620765686035, -4.443641662597656, -4.889049053192139, -3.480571746826172, -3.516125202178955, -5.675675392150879, -4.250150203704834, -6.133086204528809, -4.2898759841918945, -2.329658269882202, -2.3305184841156006, -2.502786636352539, -2.727764844894409, -1.1751735210418701, -1.3427748680114746, -1.1186703443527222, -1.8173943758010864, -1.4793850183486938, -1.9111415147781372, -1.6644808053970337, -1.7605226039886475, -1.6802655458450317, -0.7812702059745789, -1.3380719423294067, -0.313869833946228, 0.08824250102043152, -0.13963265717029572, 1.2526535987854004, -0.0005346432444639504, -1.8166388273239136, 0.0, 0.0, 0.0, -0.0, -0.0, -13.496251106262207, -13.705086708068848, -13.35924243927002, -13.192031860351562, -12.05433464050293, -10.933077812194824, -9.63337230682373, -9.47005558013916, -9.042290687561035, -8.645682334899902, -8.210139274597168, -7.6574273109436035, -7.529191970825195, -7.793508529663086, -6.149754524230957, -6.87221622467041, -6.786312103271484, -5.653590202331543, -5.125581741333008, -5.528264999389648, -5.611661434173584, -6.478282451629639, -5.410840034484863, -5.1778564453125, -5.70499849319458, -6.107217788696289, -5.359619140625, -4.851661682128906, -5.235532283782959, -5.156385898590088, -4.30848503112793, -4.828065395355225, -5.668613433837891, -6.313490867614746, -4.3138885498046875, -5.232968807220459, -5.275716781616211, -5.513476371765137, -5.729329586029053, -4.58437442779541, -4.974188327789307, -4.459995269775391, -4.75787353515625, -4.330620765686035, -4.443641662597656, -4.889049053192139, -3.480571746826172, -3.516125202178955, -5.675675392150879, -4.250150203704834, -6.133086204528809, -4.2898759841918945, -2.329658269882202, -2.3305184841156006, -2.502786636352539, -2.727764844894409, -1.1751735210418701, -1.3427748680114746, -1.1186703443527222, -1.8173943758010864, -1.4793850183486938, -1.9111415147781372, -1.6644808053970337, -1.7605226039886475, -1.6802655458450317, -0.7812702059745789, -1.3380719423294067, -0.313869833946228, 0.08824250102043152, -0.13963265717029572, 1.2526535987854004, -0.0005346432444639504, -1.8166388273239136, -0.0, -0.0, -0.0], [0.0, 0.0, -14.746844291687012, -13.841106414794922, -14.256632804870605, -12.835423469543457, -12.03414249420166, -11.192155838012695, -11.776420593261719, -10.324377059936523, -8.745494842529297, -8.89101505279541, -8.747175216674805, -8.016977310180664, -7.367748737335205, -7.018073558807373, -7.754165172576904, -6.491959571838379, -6.299672603607178, -3.5327277183532715, -6.171290874481201, -5.849405765533447, -5.511241912841797, -6.7986249923706055, -5.912951946258545, -6.047104358673096, -6.816351413726807, -5.619839191436768, -4.8076043128967285, -5.77921724319458, -6.064732074737549, -6.1513872146606445, -6.303189754486084, -6.801088333129883, -6.101795673370361, -5.763300895690918, -6.153326034545898, -5.922375679016113, -5.938863277435303, -5.995922088623047, -6.7109880447387695, -5.131218433380127, -5.471218109130859, -5.150822639465332, -5.1513285636901855, -4.871966361999512, -4.842163562774658, -4.353949069976807, -5.062837600708008, -4.9921159744262695, -6.601631164550781, -3.2839555740356445, -4.3580522537231445, -6.166914463043213, -3.337329387664795, -2.5390143394470215, -2.8806982040405273, -4.2057013511657715, -2.0270285606384277, -1.4642722606658936, -2.171509265899658, -1.876559853553772, -1.189121961593628, -1.6121164560317993, -1.3428544998168945, -1.4031320810317993, -1.5344685316085815, -1.2736258506774902, -1.0427145957946777, -1.187358021736145, -1.2996279001235962, -0.49084872007369995, 0.5045891404151917, -0.6820942163467407, -1.791342854499817, 0.0, 0.0, 7.365910530090332, -0.0, -0.0, -14.746844291687012, -13.841106414794922, -14.256632804870605, -12.835423469543457, -12.03414249420166, -11.192155838012695, -11.776420593261719, -10.324377059936523, -8.745494842529297, -8.89101505279541, -8.747175216674805, -8.016977310180664, -7.367748737335205, -7.018073558807373, -7.754165172576904, -6.491959571838379, -6.299672603607178, -3.5327277183532715, -6.171290874481201, -5.849405765533447, -5.511241912841797, -6.7986249923706055, -5.912951946258545, -6.047104358673096, -6.816351413726807, -5.619839191436768, -4.8076043128967285, -5.77921724319458, -6.064732074737549, -6.1513872146606445, -6.303189754486084, -6.801088333129883, -6.101795673370361, -5.763300895690918, -6.153326034545898, -5.922375679016113, -5.938863277435303, -5.995922088623047, -6.7109880447387695, -5.131218433380127, -5.471218109130859, -5.150822639465332, -5.1513285636901855, -4.871966361999512, -4.842163562774658, -4.353949069976807, -5.062837600708008, -4.9921159744262695, -6.601631164550781, -3.2839555740356445, -4.3580522537231445, -6.166914463043213, -3.337329387664795, -2.5390143394470215, -2.8806982040405273, -4.2057013511657715, -2.0270285606384277, -1.4642722606658936, -2.171509265899658, -1.876559853553772, -1.189121961593628, -1.6121164560317993, -1.3428544998168945, -1.4031320810317993, -1.5344685316085815, -1.2736258506774902, -1.0427145957946777, -1.187358021736145, -1.2996279001235962, -0.49084872007369995, 0.5045891404151917, -0.6820942163467407, -1.791342854499817, -0.0, -0.0, 7.365910530090332], [0.0, 0.0, -13.930120468139648, -14.23719310760498, -13.854440689086914, -13.16790771484375, -11.883472442626953, -10.762527465820312, -10.825116157531738, -10.163230895996094, -9.587014198303223, -8.43864631652832, -8.56955623626709, -8.178519248962402, -8.200699806213379, -6.880037784576416, -7.755395889282227, -6.872166156768799, -5.889749526977539, -5.760214328765869, -5.834192752838135, -6.09656286239624, -5.925097942352295, -6.344577789306641, -6.304182529449463, -6.815173625946045, -6.391181468963623, -5.527040481567383, -2.453411102294922, -5.652874946594238, -5.9117512702941895, -6.4880290031433105, -6.943612575531006, -6.752813339233398, -7.045222759246826, -7.276808738708496, -7.355705738067627, -7.128949165344238, -6.578213214874268, -6.8532562255859375, -4.968575477600098, -7.672173023223877, -6.2328104972839355, -6.533836841583252, -6.171026229858398, -5.152765274047852, -4.876073837280273, -5.981770992279053, -5.520051956176758, -4.668176174163818, -5.5187907218933105, -4.865137577056885, -5.07558536529541, -3.204200029373169, -3.8034567832946777, -2.5496716499328613, -3.0318188667297363, -2.256117820739746, -3.8341846466064453, -2.4612526893615723, -1.5270087718963623, -2.559692859649658, -0.41233915090560913, -1.7031453847885132, -1.0405783653259277, -1.4358819723129272, -1.7861589193344116, -0.7521643042564392, -1.3335905075073242, -2.0512619018554688, -0.7982562780380249, -0.3359392285346985, 0.1652347296476364, -1.290090799331665, -1.5694934129714966, 0.0, 0.0, 6.667798042297363, -0.0, -0.0, -13.930120468139648, -14.23719310760498, -13.854440689086914, -13.16790771484375, -11.883472442626953, -10.762527465820312, -10.825116157531738, -10.163230895996094, -9.587014198303223, -8.43864631652832, -8.56955623626709, -8.178519248962402, -8.200699806213379, -6.880037784576416, -7.755395889282227, -6.872166156768799, -5.889749526977539, -5.760214328765869, -5.834192752838135, -6.09656286239624, -5.925097942352295, -6.344577789306641, -6.304182529449463, -6.815173625946045, -6.391181468963623, -5.527040481567383, -2.453411102294922, -5.652874946594238, -5.9117512702941895, -6.4880290031433105, -6.943612575531006, -6.752813339233398, -7.045222759246826, -7.276808738708496, -7.355705738067627, -7.128949165344238, -6.578213214874268, -6.8532562255859375, -4.968575477600098, -7.672173023223877, -6.2328104972839355, -6.533836841583252, -6.171026229858398, -5.152765274047852, -4.876073837280273, -5.981770992279053, -5.520051956176758, -4.668176174163818, -5.5187907218933105, -4.865137577056885, -5.07558536529541, -3.204200029373169, -3.8034567832946777, -2.5496716499328613, -3.0318188667297363, -2.256117820739746, -3.8341846466064453, -2.4612526893615723, -1.5270087718963623, -2.559692859649658, -0.41233915090560913, -1.7031453847885132, -1.0405783653259277, -1.4358819723129272, -1.7861589193344116, -0.7521643042564392, -1.3335905075073242, -2.0512619018554688, -0.7982562780380249, -0.3359392285346985, 0.1652347296476364, -1.290090799331665, -1.5694934129714966, -0.0, -0.0, 6.667798042297363], [0.0, 0.0, 0.0, -14.129316329956055, -13.895309448242188, -12.70640754699707, -12.107501983642578, -11.326663970947266, -12.855639457702637, -10.099203109741211, -9.263138771057129, -8.533305168151855, -8.648509979248047, -8.423614501953125, -7.910951614379883, -7.4908223152160645, -7.118300437927246, -7.09019136428833, -7.310919761657715, -5.7578935623168945, -6.541419506072998, -6.287393569946289, -7.545553207397461, -5.36459493637085, -6.7368292808532715, -5.9315361976623535, -6.49627685546875, -7.488677501678467, -5.4480109214782715, -6.764037609100342, -6.894336223602295, -6.962192058563232, -7.048425197601318, -8.324789047241211, -8.149694442749023, -7.673094272613525, -7.103498458862305, -7.1377949714660645, -7.12528133392334, -7.4233832359313965, -8.119513511657715, -6.951358318328857, -7.3096923828125, -7.165712833404541, -7.162695407867432, -6.22671365737915, -4.674678325653076, -6.793069362640381, -6.494976997375488, -6.180229663848877, -5.527837753295898, -3.591140031814575, -5.373244762420654, -3.713904619216919, -3.424628973007202, -3.3991260528564453, -4.2454094886779785, -2.318070888519287, -1.6806281805038452, -1.9414401054382324, -1.5958441495895386, -1.7713011503219604, -1.99954092502594, -1.8612945079803467, -1.7819942235946655, -1.535351037979126, -1.3241039514541626, -2.033802032470703, -1.80759596824646, -1.167129635810852, -1.361862301826477, -1.3125149011611938, -0.999412477016449, -1.8074355125427246, -1.444818377494812, 0.0, 0.0, 5.991880893707275, -0.0, -0.0, -0.0, -14.129316329956055, -13.895309448242188, -12.70640754699707, -12.107501983642578, -11.326663970947266, -12.855639457702637, -10.099203109741211, -9.263138771057129, -8.533305168151855, -8.648509979248047, -8.423614501953125, -7.910951614379883, -7.4908223152160645, -7.118300437927246, -7.09019136428833, -7.310919761657715, -5.7578935623168945, -6.541419506072998, -6.287393569946289, -7.545553207397461, -5.36459493637085, -6.7368292808532715, -5.9315361976623535, -6.49627685546875, -7.488677501678467, -5.4480109214782715, -6.764037609100342, -6.894336223602295, -6.962192058563232, -7.048425197601318, -8.324789047241211, -8.149694442749023, -7.673094272613525, -7.103498458862305, -7.1377949714660645, -7.12528133392334, -7.4233832359313965, -8.119513511657715, -6.951358318328857, -7.3096923828125, -7.165712833404541, -7.162695407867432, -6.22671365737915, -4.674678325653076, -6.793069362640381, -6.494976997375488, -6.180229663848877, -5.527837753295898, -3.591140031814575, -5.373244762420654, -3.713904619216919, -3.424628973007202, -3.3991260528564453, -4.2454094886779785, -2.318070888519287, -1.6806281805038452, -1.9414401054382324, -1.5958441495895386, -1.7713011503219604, -1.99954092502594, -1.8612945079803467, -1.7819942235946655, -1.535351037979126, -1.3241039514541626, -2.033802032470703, -1.80759596824646, -1.167129635810852, -1.361862301826477, -1.3125149011611938, -0.999412477016449, -1.8074355125427246, -1.444818377494812, -0.0, -0.0, 5.991880893707275], [-17.193357467651367, 0.0, 0.0, -15.307260513305664, -14.120086669921875, -13.163174629211426, -12.5145845413208, -11.003913879394531, -11.283056259155273, -10.124627113342285, -9.953426361083984, -8.940526962280273, -8.374161720275879, -8.48549747467041, -7.447457313537598, -7.784093379974365, -9.617321014404297, -7.219674110412598, -6.829546928405762, -7.055323123931885, -6.29736328125, -5.628266334533691, -6.277536869049072, -5.927509307861328, -6.648010730743408, -7.181068420410156, -6.609958648681641, -7.787508487701416, -7.5780768394470215, -6.13779878616333, -7.052817344665527, -6.667646408081055, -8.490137100219727, -8.795912742614746, -9.155869483947754, -8.903946876525879, -8.896852493286133, -7.556515216827393, -9.126420974731445, -7.213723659515381, -9.295012474060059, -8.151379585266113, -8.375024795532227, -8.059948921203613, -7.0552592277526855, -6.89980936050415, -7.210442543029785, -9.530313491821289, -7.256934642791748, -7.963818073272705, -5.398884296417236, -6.392439365386963, -5.659815311431885, -4.8683624267578125, -4.479732513427734, -2.66337251663208, -4.00457239151001, -2.6762397289276123, -2.4007582664489746, -2.7842607498168945, -2.000803232192993, -2.584730863571167, -2.4415805339813232, -2.5878658294677734, -1.4874910116195679, -1.8057206869125366, -2.5987367630004883, -2.53436279296875, -1.8962820768356323, -1.0387970209121704, -1.7746553421020508, -1.2164859771728516, -1.010513424873352, -1.00123929977417, -1.5833832025527954, 0.0, 0.0, 7.191558837890625, -17.193357467651367, -0.0, -0.0, -15.307260513305664, -14.120086669921875, -13.163174629211426, -12.5145845413208, -11.003913879394531, -11.283056259155273, -10.124627113342285, -9.953426361083984, -8.940526962280273, -8.374161720275879, -8.48549747467041, -7.447457313537598, -7.784093379974365, -9.617321014404297, -7.219674110412598, -6.829546928405762, -7.055323123931885, -6.29736328125, -5.628266334533691, -6.277536869049072, -5.927509307861328, -6.648010730743408, -7.181068420410156, -6.609958648681641, -7.787508487701416, -7.5780768394470215, -6.13779878616333, -7.052817344665527, -6.667646408081055, -8.490137100219727, -8.795912742614746, -9.155869483947754, -8.903946876525879, -8.896852493286133, -7.556515216827393, -9.126420974731445, -7.213723659515381, -9.295012474060059, -8.151379585266113, -8.375024795532227, -8.059948921203613, -7.0552592277526855, -6.89980936050415, -7.210442543029785, -9.530313491821289, -7.256934642791748, -7.963818073272705, -5.398884296417236, -6.392439365386963, -5.659815311431885, -4.8683624267578125, -4.479732513427734, -2.66337251663208, -4.00457239151001, -2.6762397289276123, -2.4007582664489746, -2.7842607498168945, -2.000803232192993, -2.584730863571167, -2.4415805339813232, -2.5878658294677734, -1.4874910116195679, -1.8057206869125366, -2.5987367630004883, -2.53436279296875, -1.8962820768356323, -1.0387970209121704, -1.7746553421020508, -1.2164859771728516, -1.010513424873352, -1.00123929977417, -1.5833832025527954, -0.0, -0.0, 7.191558837890625], [-18.086626052856445, 0.0, 0.0, -14.333097457885742, -14.219644546508789, -13.380264282226562, -12.655521392822266, -10.859091758728027, -10.816950798034668, -10.281527519226074, -9.340167999267578, -9.541275978088379, -8.975050926208496, -8.305035591125488, -8.039453506469727, -7.461682319641113, -7.463315963745117, -8.11976146697998, -6.555931091308594, -6.926875591278076, -6.8747429847717285, -7.447328567504883, -6.617861270904541, -6.212355136871338, -6.595285415649414, -9.685234069824219, -7.5569844245910645, -6.164188385009766, -7.1975860595703125, -8.887381553649902, -7.345953464508057, -7.8355278968811035, -9.235203742980957, -7.97273063659668, -10.04466724395752, -7.796120643615723, -9.100712776184082, -9.487555503845215, -9.587891578674316, -8.713409423828125, -8.845562934875488, -8.680754661560059, -9.017440795898438, -7.997730255126953, -8.372923851013184, -8.336057662963867, -8.821661949157715, -7.206683158874512, -8.34902286529541, -6.698981285095215, -6.937446594238281, -6.578312397003174, -6.705334186553955, -4.381665229797363, -3.3384110927581787, -5.347592830657959, -3.8771698474884033, -2.8901853561401367, -3.79042911529541, -2.2510178089141846, -2.5119123458862305, -1.7474349737167358, -2.2690203189849854, -2.3786373138427734, -1.5663442611694336, -1.8273687362670898, -1.7671581506729126, -2.0926733016967773, -1.8029528856277466, -2.145556926727295, -2.7450835704803467, -1.0135564804077148, -0.9415557384490967, -0.08902981877326965, -2.590747833251953, 0.0, 0.0, 4.638403415679932, -18.086626052856445, -0.0, -0.0, -14.333097457885742, -14.219644546508789, -13.380264282226562, -12.655521392822266, -10.859091758728027, -10.816950798034668, -10.281527519226074, -9.340167999267578, -9.541275978088379, -8.975050926208496, -8.305035591125488, -8.039453506469727, -7.461682319641113, -7.463315963745117, -8.11976146697998, -6.555931091308594, -6.926875591278076, -6.8747429847717285, -7.447328567504883, -6.617861270904541, -6.212355136871338, -6.595285415649414, -9.685234069824219, -7.5569844245910645, -6.164188385009766, -7.1975860595703125, -8.887381553649902, -7.345953464508057, -7.8355278968811035, -9.235203742980957, -7.97273063659668, -10.04466724395752, -7.796120643615723, -9.100712776184082, -9.487555503845215, -9.587891578674316, -8.713409423828125, -8.845562934875488, -8.680754661560059, -9.017440795898438, -7.997730255126953, -8.372923851013184, -8.336057662963867, -8.821661949157715, -7.206683158874512, -8.34902286529541, -6.698981285095215, -6.937446594238281, -6.578312397003174, -6.705334186553955, -4.381665229797363, -3.3384110927581787, -5.347592830657959, -3.8771698474884033, -2.8901853561401367, -3.79042911529541, -2.2510178089141846, -2.5119123458862305, -1.7474349737167358, -2.2690203189849854, -2.3786373138427734, -1.5663442611694336, -1.8273687362670898, -1.7671581506729126, -2.0926733016967773, -1.8029528856277466, -2.145556926727295, -2.7450835704803467, -1.0135564804077148, -0.9415557384490967, -0.08902981877326965, -2.590747833251953, -0.0, -0.0, 4.638403415679932], [-19.907390594482422, 0.0, 0.0, -12.38496208190918, -14.21262264251709, -13.352306365966797, -12.11070442199707, -11.571473121643066, -10.587955474853516, -10.165392875671387, -9.33571720123291, -8.618481636047363, -8.097433090209961, -7.579047679901123, -8.225958824157715, -8.085200309753418, -7.304210186004639, -7.623114585876465, -7.405739784240723, -6.274168014526367, -8.101466178894043, -8.008238792419434, -7.620415210723877, -7.139235973358154, -7.807470321655273, -7.6924848556518555, -7.468297958374023, -8.35262393951416, -8.205039024353027, -8.779032707214355, -9.932891845703125, -9.914440155029297, -9.478926658630371, -9.30086898803711, -11.358803749084473, -9.69454288482666, -8.744674682617188, -10.579769134521484, -9.827564239501953, -11.499872207641602, -10.675101280212402, -8.36487102508545, -8.54393196105957, -9.155084609985352, -8.828313827514648, -8.319748878479004, -7.447680950164795, -8.983986854553223, -7.155895709991455, -8.721121788024902, -8.76710319519043, -7.197472095489502, -5.6980061531066895, -5.351063251495361, -4.819018363952637, -5.088461399078369, -4.268733024597168, -3.228261709213257, -3.032258987426758, -2.8140220642089844, -2.97243070602417, -2.835574150085449, -2.368393659591675, -2.6001648902893066, -1.4349429607391357, -2.009269952774048, -2.397021770477295, -1.544114351272583, -2.160856008529663, -2.417447328567505, -2.7128424644470215, -1.453493595123291, -0.845986008644104, -0.1468275785446167, 0.0, 0.0, 0.0, 4.649603366851807, -19.907390594482422, -0.0, -0.0, -12.38496208190918, -14.21262264251709, -13.352306365966797, -12.11070442199707, -11.571473121643066, -10.587955474853516, -10.165392875671387, -9.33571720123291, -8.618481636047363, -8.097433090209961, -7.579047679901123, -8.225958824157715, -8.085200309753418, -7.304210186004639, -7.623114585876465, -7.405739784240723, -6.274168014526367, -8.101466178894043, -8.008238792419434, -7.620415210723877, -7.139235973358154, -7.807470321655273, -7.6924848556518555, -7.468297958374023, -8.35262393951416, -8.205039024353027, -8.779032707214355, -9.932891845703125, -9.914440155029297, -9.478926658630371, -9.30086898803711, -11.358803749084473, -9.69454288482666, -8.744674682617188, -10.579769134521484, -9.827564239501953, -11.499872207641602, -10.675101280212402, -8.36487102508545, -8.54393196105957, -9.155084609985352, -8.828313827514648, -8.319748878479004, -7.447680950164795, -8.983986854553223, -7.155895709991455, -8.721121788024902, -8.76710319519043, -7.197472095489502, -5.6980061531066895, -5.351063251495361, -4.819018363952637, -5.088461399078369, -4.268733024597168, -3.228261709213257, -3.032258987426758, -2.8140220642089844, -2.97243070602417, -2.835574150085449, -2.368393659591675, -2.6001648902893066, -1.4349429607391357, -2.009269952774048, -2.397021770477295, -1.544114351272583, -2.160856008529663, -2.417447328567505, -2.7128424644470215, -1.453493595123291, -0.845986008644104, -0.1468275785446167, -0.0, -0.0, 0.0, 4.649603366851807], [-18.288724899291992, 0.0, 0.0, 0.0, -14.847428321838379, -13.645261764526367, -12.593381881713867, -11.439396858215332, -10.788573265075684, -10.438980102539062, -9.628849029541016, -9.333433151245117, -8.32670783996582, -8.214118957519531, -8.054491996765137, -8.357938766479492, -7.666080474853516, -7.7777018547058105, -7.895992755889893, -7.4178643226623535, -7.941985130310059, -7.039955139160156, -8.328696250915527, -7.180965423583984, -8.16014289855957, -7.9081902503967285, -7.6648783683776855, -7.95227575302124, -7.4315972328186035, -9.910224914550781, -11.032361030578613, -9.978120803833008, -9.981202125549316, -11.60511302947998, -9.813563346862793, -9.835901260375977, -10.385992050170898, -10.74416732788086, -11.230865478515625, -11.357905387878418, -11.715441703796387, -10.74959945678711, -11.258520126342773, -11.458327293395996, -9.863953590393066, -10.165518760681152, -10.431073188781738, -9.179787635803223, -9.141810417175293, -8.878866195678711, -7.116485118865967, -7.718835353851318, -6.347517013549805, -6.73116397857666, -5.315474510192871, -5.2631635665893555, -4.56621789932251, -5.539612293243408, -3.6600708961486816, -2.93581485748291, -3.507868528366089, -4.106800079345703, -2.292248487472534, -2.8804943561553955, -2.4059526920318604, -1.6405682563781738, -1.3889703750610352, -1.3596585988998413, -1.9855118989944458, -1.811927318572998, -1.8092881441116333, -1.6689033508300781, -1.2805407047271729, -0.8161612749099731, 0.0, 0.0, 0.0, 5.924898624420166, -18.288724899291992, -0.0, -0.0, -0.0, -14.847428321838379, -13.645261764526367, -12.593381881713867, -11.439396858215332, -10.788573265075684, -10.438980102539062, -9.628849029541016, -9.333433151245117, -8.32670783996582, -8.214118957519531, -8.054491996765137, -8.357938766479492, -7.666080474853516, -7.7777018547058105, -7.895992755889893, -7.4178643226623535, -7.941985130310059, -7.039955139160156, -8.328696250915527, -7.180965423583984, -8.16014289855957, -7.9081902503967285, -7.6648783683776855, -7.95227575302124, -7.4315972328186035, -9.910224914550781, -11.032361030578613, -9.978120803833008, -9.981202125549316, -11.60511302947998, -9.813563346862793, -9.835901260375977, -10.385992050170898, -10.74416732788086, -11.230865478515625, -11.357905387878418, -11.715441703796387, -10.74959945678711, -11.258520126342773, -11.458327293395996, -9.863953590393066, -10.165518760681152, -10.431073188781738, -9.179787635803223, -9.141810417175293, -8.878866195678711, -7.116485118865967, -7.718835353851318, -6.347517013549805, -6.73116397857666, -5.315474510192871, -5.2631635665893555, -4.56621789932251, -5.539612293243408, -3.6600708961486816, -2.93581485748291, -3.507868528366089, -4.106800079345703, -2.292248487472534, -2.8804943561553955, -2.4059526920318604, -1.6405682563781738, -1.3889703750610352, -1.3596585988998413, -1.9855118989944458, -1.811927318572998, -1.8092881441116333, -1.6689033508300781, -1.2805407047271729, -0.8161612749099731, -0.0, 0.0, 0.0, 5.924898624420166], [-20.045015335083008, 0.0, 0.0, 0.0, -16.128589630126953, -13.643270492553711, -12.70160961151123, -11.756759643554688, -11.109105110168457, -9.879485130310059, -10.236433982849121, -9.238348007202148, -9.211600303649902, -9.330305099487305, -8.897918701171875, -8.550972938537598, -8.145922660827637, -8.448530197143555, -7.675483703613281, -7.561789035797119, -7.520515441894531, -7.5313262939453125, -8.941031455993652, -7.189783573150635, -7.649109840393066, -9.122516632080078, -8.607864379882812, -9.05052661895752, -8.707979202270508, -11.875452995300293, -10.889572143554688, -10.92608642578125, -11.016193389892578, -10.860688209533691, -12.20273208618164, -10.822650909423828, -11.234434127807617, -11.779041290283203, -11.418670654296875, -11.549449920654297, -11.88731575012207, -12.120342254638672, -11.586027145385742, -11.506560325622559, -10.454779624938965, -10.287886619567871, -11.958789825439453, -9.485187530517578, -9.942723274230957, -8.43040657043457, -7.294012546539307, -10.358901977539062, -7.113668441772461, -7.2420573234558105, -5.464742183685303, -6.404447555541992, -5.047056198120117, -4.368384838104248, -4.431215286254883, -3.707122564315796, -3.33882737159729, -3.304363489151001, -3.2364773750305176, -2.715157985687256, -2.3365423679351807, -2.3002712726593018, -2.0318098068237305, -1.3933500051498413, -1.7303286790847778, -1.9138785600662231, -1.9258897304534912, -1.3961318731307983, -1.6360576152801514, 0.0, 0.0, 0.0, 5.219533920288086, 7.684976100921631, -20.045015335083008, -0.0, -0.0, -0.0, -16.128589630126953, -13.643270492553711, -12.70160961151123, -11.756759643554688, -11.109105110168457, -9.879485130310059, -10.236433982849121, -9.238348007202148, -9.211600303649902, -9.330305099487305, -8.897918701171875, -8.550972938537598, -8.145922660827637, -8.448530197143555, -7.675483703613281, -7.561789035797119, -7.520515441894531, -7.5313262939453125, -8.941031455993652, -7.189783573150635, -7.649109840393066, -9.122516632080078, -8.607864379882812, -9.05052661895752, -8.707979202270508, -11.875452995300293, -10.889572143554688, -10.92608642578125, -11.016193389892578, -10.860688209533691, -12.20273208618164, -10.822650909423828, -11.234434127807617, -11.779041290283203, -11.418670654296875, -11.549449920654297, -11.88731575012207, -12.120342254638672, -11.586027145385742, -11.506560325622559, -10.454779624938965, -10.287886619567871, -11.958789825439453, -9.485187530517578, -9.942723274230957, -8.43040657043457, -7.294012546539307, -10.358901977539062, -7.113668441772461, -7.2420573234558105, -5.464742183685303, -6.404447555541992, -5.047056198120117, -4.368384838104248, -4.431215286254883, -3.707122564315796, -3.33882737159729, -3.304363489151001, -3.2364773750305176, -2.715157985687256, -2.3365423679351807, -2.3002712726593018, -2.0318098068237305, -1.3933500051498413, -1.7303286790847778, -1.9138785600662231, -1.9258897304534912, -1.3961318731307983, -1.6360576152801514, -0.0, -0.0, 0.0, 5.219533920288086, 7.684976100921631], [-18.986318588256836, 0.0, 0.0, 0.0, -16.8173770904541, -15.195015907287598, -13.193928718566895, -11.968377113342285, -11.163578987121582, -10.418149948120117, -10.063204765319824, -9.2426118850708, -8.79073715209961, -9.155376434326172, -9.089274406433105, -8.528614044189453, -9.125425338745117, -8.175575256347656, -8.259822845458984, -8.00350570678711, -8.029212951660156, -7.496812343597412, -8.127310752868652, -7.816590785980225, -8.47605037689209, -10.69639778137207, -9.734170913696289, -10.65965461730957, -10.239412307739258, -8.789423942565918, -13.095006942749023, -10.920332908630371, -11.745327949523926, -13.17018985748291, -13.238205909729004, -12.285069465637207, -11.788225173950195, -13.45544719696045, -14.47566032409668, -13.80306339263916, -14.985017776489258, -12.327322959899902, -12.786565780639648, -12.65057373046875, -12.551969528198242, -11.520816802978516, -10.779716491699219, -11.433870315551758, -10.294384002685547, -9.96053695678711, -9.408425331115723, -9.30134391784668, -8.329553604125977, -7.739490509033203, -6.523060321807861, -5.519176006317139, -7.083745002746582, -5.550204753875732, -4.808272838592529, -3.908604383468628, -3.8156051635742188, -6.078449726104736, -2.9882490634918213, -2.811319351196289, -2.3443808555603027, -2.682014226913452, -2.055250644683838, -2.0646448135375977, -1.7969448566436768, -2.151278495788574, -2.077145576477051, -1.5642480850219727, -1.3493759632110596, 0.0, 0.0, 0.0, 6.1994805335998535, 4.912977695465088, -18.986318588256836, -0.0, -0.0, -0.0, -16.8173770904541, -15.195015907287598, -13.193928718566895, -11.968377113342285, -11.163578987121582, -10.418149948120117, -10.063204765319824, -9.2426118850708, -8.79073715209961, -9.155376434326172, -9.089274406433105, -8.528614044189453, -9.125425338745117, -8.175575256347656, -8.259822845458984, -8.00350570678711, -8.029212951660156, -7.496812343597412, -8.127310752868652, -7.816590785980225, -8.47605037689209, -10.69639778137207, -9.734170913696289, -10.65965461730957, -10.239412307739258, -8.789423942565918, -13.095006942749023, -10.920332908630371, -11.745327949523926, -13.17018985748291, -13.238205909729004, -12.285069465637207, -11.788225173950195, -13.45544719696045, -14.47566032409668, -13.80306339263916, -14.985017776489258, -12.327322959899902, -12.786565780639648, -12.65057373046875, -12.551969528198242, -11.520816802978516, -10.779716491699219, -11.433870315551758, -10.294384002685547, -9.96053695678711, -9.408425331115723, -9.30134391784668, -8.329553604125977, -7.739490509033203, -6.523060321807861, -5.519176006317139, -7.083745002746582, -5.550204753875732, -4.808272838592529, -3.908604383468628, -3.8156051635742188, -6.078449726104736, -2.9882490634918213, -2.811319351196289, -2.3443808555603027, -2.682014226913452, -2.055250644683838, -2.0646448135375977, -1.7969448566436768, -2.151278495788574, -2.077145576477051, -1.5642480850219727, -1.3493759632110596, -0.0, 0.0, 0.0, 6.1994805335998535, 4.912977695465088], [-19.453594207763672, -18.950422286987305, 0.0, 0.0, -17.236061096191406, -14.512618064880371, -13.336852073669434, -12.05622386932373, -10.566396713256836, -10.548630714416504, -10.06430435180664, -9.504632949829102, -10.046713829040527, -9.674908638000488, -9.516315460205078, -8.20334243774414, -8.791020393371582, -8.613656044006348, -7.885767459869385, -9.01172161102295, -8.537604331970215, -9.447094917297363, -8.377999305725098, -7.40788459777832, -8.989481925964355, -8.915512084960938, -9.241536140441895, -10.316189765930176, -10.319384574890137, -11.28754997253418, -11.359827041625977, -12.024335861206055, -11.807317733764648, -13.124336242675781, -12.711353302001953, -13.806208610534668, -14.463099479675293, -13.862380027770996, -14.15197467803955, -14.271702766418457, -13.930758476257324, -15.283177375793457, -12.721251487731934, -13.876309394836426, -12.479555130004883, -11.743377685546875, -11.720232009887695, -13.244485855102539, -11.799901962280273, -11.016631126403809, -10.050854682922363, -9.544201850891113, -8.632816314697266, -7.9471025466918945, -5.947120189666748, -7.239892959594727, -6.23295783996582, -7.444386005401611, -5.24094820022583, -4.3761749267578125, -4.928292751312256, -3.7383341789245605, -2.650766372680664, -3.1178698539733887, -3.213844060897827, -2.670102834701538, -3.6833560466766357, -3.423962354660034, -2.6204400062561035, -2.3064842224121094, -1.6449617147445679, -1.0667895078659058, -0.49321630597114563, 0.0, 0.0, 6.761444091796875, 5.669167518615723, 5.658738136291504, -19.453594207763672, -18.950422286987305, -0.0, -0.0, -17.236061096191406, -14.512618064880371, -13.336852073669434, -12.05622386932373, -10.566396713256836, -10.548630714416504, -10.06430435180664, -9.504632949829102, -10.046713829040527, -9.674908638000488, -9.516315460205078, -8.20334243774414, -8.791020393371582, -8.613656044006348, -7.885767459869385, -9.01172161102295, -8.537604331970215, -9.447094917297363, -8.377999305725098, -7.40788459777832, -8.989481925964355, -8.915512084960938, -9.241536140441895, -10.316189765930176, -10.319384574890137, -11.28754997253418, -11.359827041625977, -12.024335861206055, -11.807317733764648, -13.124336242675781, -12.711353302001953, -13.806208610534668, -14.463099479675293, -13.862380027770996, -14.15197467803955, -14.271702766418457, -13.930758476257324, -15.283177375793457, -12.721251487731934, -13.876309394836426, -12.479555130004883, -11.743377685546875, -11.720232009887695, -13.244485855102539, -11.799901962280273, -11.016631126403809, -10.050854682922363, -9.544201850891113, -8.632816314697266, -7.9471025466918945, -5.947120189666748, -7.239892959594727, -6.23295783996582, -7.444386005401611, -5.24094820022583, -4.3761749267578125, -4.928292751312256, -3.7383341789245605, -2.650766372680664, -3.1178698539733887, -3.213844060897827, -2.670102834701538, -3.6833560466766357, -3.423962354660034, -2.6204400062561035, -2.3064842224121094, -1.6449617147445679, -1.0667895078659058, -0.49321630597114563, -0.0, 0.0, 6.761444091796875, 5.669167518615723, 5.658738136291504], [-19.214412689208984, -18.58064079284668, 0.0, 0.0, 0.0, 0.0, -13.612664222717285, -12.553108215332031, -9.821276664733887, -10.385189056396484, -10.022613525390625, -9.989519119262695, -9.94068717956543, -10.646198272705078, -9.779484748840332, -9.433109283447266, -8.872430801391602, -9.464509963989258, -8.849254608154297, -9.464762687683105, -8.735540390014648, -9.101515769958496, -9.712407112121582, -10.043479919433594, -9.872603416442871, -8.752224922180176, -10.775884628295898, -12.263890266418457, -12.797866821289062, -12.234708786010742, -12.75450325012207, -13.058083534240723, -13.60520076751709, -12.933493614196777, -13.731868743896484, -14.339395523071289, -14.943448066711426, -14.931689262390137, -15.22603702545166, -14.990654945373535, -14.837467193603516, -15.378499031066895, -17.400344848632812, -14.264626502990723, -14.755218505859375, -13.367059707641602, -13.029632568359375, -13.71040153503418, -13.477747917175293, -9.81544303894043, -10.01518440246582, -9.676995277404785, -10.617155075073242, -8.998737335205078, -5.54124116897583, -6.973421573638916, -8.350028991699219, -6.1853766441345215, -5.098952770233154, -4.89119291305542, -4.120462894439697, -4.511911392211914, -3.8672869205474854, -3.619293212890625, -3.2504401206970215, -3.4624788761138916, -2.600529909133911, -3.352116107940674, -2.8463118076324463, -1.559278964996338, -1.4686877727508545, -0.9052320718765259, -0.6102553606033325, 0.0, 0.0, 6.642242908477783, 5.596309185028076, 5.306610584259033, -19.214412689208984, -18.58064079284668, -0.0, -0.0, -0.0, -0.0, -13.612664222717285, -12.553108215332031, -9.821276664733887, -10.385189056396484, -10.022613525390625, -9.989519119262695, -9.94068717956543, -10.646198272705078, -9.779484748840332, -9.433109283447266, -8.872430801391602, -9.464509963989258, -8.849254608154297, -9.464762687683105, -8.735540390014648, -9.101515769958496, -9.712407112121582, -10.043479919433594, -9.872603416442871, -8.752224922180176, -10.775884628295898, -12.263890266418457, -12.797866821289062, -12.234708786010742, -12.75450325012207, -13.058083534240723, -13.60520076751709, -12.933493614196777, -13.731868743896484, -14.339395523071289, -14.943448066711426, -14.931689262390137, -15.22603702545166, -14.990654945373535, -14.837467193603516, -15.378499031066895, -17.400344848632812, -14.264626502990723, -14.755218505859375, -13.367059707641602, -13.029632568359375, -13.71040153503418, -13.477747917175293, -9.81544303894043, -10.01518440246582, -9.676995277404785, -10.617155075073242, -8.998737335205078, -5.54124116897583, -6.973421573638916, -8.350028991699219, -6.1853766441345215, -5.098952770233154, -4.89119291305542, -4.120462894439697, -4.511911392211914, -3.8672869205474854, -3.619293212890625, -3.2504401206970215, -3.4624788761138916, -2.600529909133911, -3.352116107940674, -2.8463118076324463, -1.559278964996338, -1.4686877727508545, -0.9052320718765259, -0.6102553606033325, -0.0, 0.0, 6.642242908477783, 5.596309185028076, 5.306610584259033], [-18.472877502441406, -18.150264739990234, 0.0, 0.0, 0.0, 0.0, -16.292850494384766, -14.214584350585938, -9.161035537719727, -10.264924049377441, -10.510059356689453, -9.862611770629883, -9.615986824035645, -9.775761604309082, -9.150520324707031, -8.953445434570312, -9.469714164733887, -9.239384651184082, -8.87951374053955, -9.21569538116455, -9.533510208129883, -9.066245079040527, -9.884954452514648, -10.44439697265625, -9.779067039489746, -11.094884872436523, -10.34389591217041, -12.061806678771973, -11.778732299804688, -12.659858703613281, -13.13999080657959, -12.242178916931152, -15.238011360168457, -13.669129371643066, -17.02837562561035, -16.654651641845703, -15.88651180267334, -15.493032455444336, -16.50345802307129, -16.241792678833008, -16.607221603393555, -16.57435417175293, -14.476521492004395, -15.301138877868652, -14.686749458312988, -12.827495574951172, -14.276691436767578, -13.08077621459961, -12.700857162475586, -12.657516479492188, -12.210433006286621, -11.33195686340332, -9.935870170593262, -9.457515716552734, -6.803653717041016, -7.409235000610352, -6.384140491485596, -7.493334770202637, -6.081898212432861, -5.368177890777588, -5.29873514175415, -3.998349905014038, -4.109914302825928, -4.267126560211182, -4.139622688293457, -2.9996092319488525, -3.137066125869751, -3.2903032302856445, -2.8987622261047363, -2.394012212753296, -1.5735688209533691, -0.09886442869901657, 1.4750680923461914, 0.0, 0.0, 5.243010520935059, 2.9848344326019287, 3.1262338161468506, -18.472877502441406, -18.150264739990234, -0.0, -0.0, -0.0, -0.0, -16.292850494384766, -14.214584350585938, -9.161035537719727, -10.264924049377441, -10.510059356689453, -9.862611770629883, -9.615986824035645, -9.775761604309082, -9.150520324707031, -8.953445434570312, -9.469714164733887, -9.239384651184082, -8.87951374053955, -9.21569538116455, -9.533510208129883, -9.066245079040527, -9.884954452514648, -10.44439697265625, -9.779067039489746, -11.094884872436523, -10.34389591217041, -12.061806678771973, -11.778732299804688, -12.659858703613281, -13.13999080657959, -12.242178916931152, -15.238011360168457, -13.669129371643066, -17.02837562561035, -16.654651641845703, -15.88651180267334, -15.493032455444336, -16.50345802307129, -16.241792678833008, -16.607221603393555, -16.57435417175293, -14.476521492004395, -15.301138877868652, -14.686749458312988, -12.827495574951172, -14.276691436767578, -13.08077621459961, -12.700857162475586, -12.657516479492188, -12.210433006286621, -11.33195686340332, -9.935870170593262, -9.457515716552734, -6.803653717041016, -7.409235000610352, -6.384140491485596, -7.493334770202637, -6.081898212432861, -5.368177890777588, -5.29873514175415, -3.998349905014038, -4.109914302825928, -4.267126560211182, -4.139622688293457, -2.9996092319488525, -3.137066125869751, -3.2903032302856445, -2.8987622261047363, -2.394012212753296, -1.5735688209533691, -0.09886442869901657, 1.4750680923461914, 0.0, 0.0, 5.243010520935059, 2.9848344326019287, 3.1262338161468506], [-18.621797561645508, -18.41571044921875, -15.683292388916016, 0.0, 0.0, 0.0, -13.435064315795898, -13.266012191772461, -13.218771934509277, -10.910430908203125, -11.021566390991211, -10.455012321472168, -10.574761390686035, -10.644120216369629, -9.385052680969238, -11.144410133361816, -9.338871955871582, -9.598803520202637, -9.46492862701416, -9.82266616821289, -9.566960334777832, -9.956645011901855, -9.844635963439941, -9.16688060760498, -10.70938491821289, -11.026421546936035, -13.166592597961426, -12.515826225280762, -12.550960540771484, -14.682442665100098, -11.797480583190918, -15.565092086791992, -14.113214492797852, -14.682292938232422, -18.110342025756836, -16.151819229125977, -17.9429988861084, -17.22252082824707, -18.485538482666016, -17.105533599853516, -17.327503204345703, -17.751829147338867, -16.80752944946289, -18.378524780273438, -16.11546516418457, -14.768634796142578, -14.312614440917969, -13.668375968933105, -14.41848087310791, -12.310840606689453, -11.330742835998535, -11.498809814453125, -11.456007957458496, -9.234807014465332, -9.605569839477539, -8.852931022644043, -7.205948829650879, -6.4334001541137695, -6.439552307128906, -5.970693588256836, -5.129123210906982, -5.090917587280273, -4.546360969543457, -4.211798191070557, -3.76147198677063, -3.451263427734375, -3.3405163288116455, -2.551729440689087, -2.835967540740967, -2.0602734088897705, -2.0931310653686523, 0.23040920495986938, 1.5272527933120728, 0.0, 3.758709669113159, 4.443807601928711, 4.689756870269775, 4.65837287902832, -18.621797561645508, -18.41571044921875, -15.683292388916016, -0.0, -0.0, -0.0, -13.435064315795898, -13.266012191772461, -13.218771934509277, -10.910430908203125, -11.021566390991211, -10.455012321472168, -10.574761390686035, -10.644120216369629, -9.385052680969238, -11.144410133361816, -9.338871955871582, -9.598803520202637, -9.46492862701416, -9.82266616821289, -9.566960334777832, -9.956645011901855, -9.844635963439941, -9.16688060760498, -10.70938491821289, -11.026421546936035, -13.166592597961426, -12.515826225280762, -12.550960540771484, -14.682442665100098, -11.797480583190918, -15.565092086791992, -14.113214492797852, -14.682292938232422, -18.110342025756836, -16.151819229125977, -17.9429988861084, -17.22252082824707, -18.485538482666016, -17.105533599853516, -17.327503204345703, -17.751829147338867, -16.80752944946289, -18.378524780273438, -16.11546516418457, -14.768634796142578, -14.312614440917969, -13.668375968933105, -14.41848087310791, -12.310840606689453, -11.330742835998535, -11.498809814453125, -11.456007957458496, -9.234807014465332, -9.605569839477539, -8.852931022644043, -7.205948829650879, -6.4334001541137695, -6.439552307128906, -5.970693588256836, -5.129123210906982, -5.090917587280273, -4.546360969543457, -4.211798191070557, -3.76147198677063, -3.451263427734375, -3.3405163288116455, -2.551729440689087, -2.835967540740967, -2.0602734088897705, -2.0931310653686523, 0.23040920495986938, 1.5272527933120728, 0.0, 3.758709669113159, 4.443807601928711, 4.689756870269775, 4.65837287902832], [-19.00534439086914, -17.711849212646484, -16.499345779418945, -15.846064567565918, 0.0, 0.0, -11.391252517700195, -12.553293228149414, -13.336708068847656, -12.37222957611084, -10.962084770202637, -10.629254341125488, -10.383755683898926, -10.313908576965332, -10.167492866516113, -10.128725051879883, -9.854615211486816, -9.78649616241455, -9.454059600830078, -9.41611385345459, -10.03145694732666, -10.14666748046875, -12.332682609558105, -10.955340385437012, -11.756345748901367, -11.258309364318848, -12.80372428894043, -11.008867263793945, -11.641036987304688, -14.600868225097656, -14.486696243286133, -15.982991218566895, -14.49405288696289, -16.643037796020508, -17.698156356811523, -16.50680160522461, -17.401569366455078, -18.175434112548828, -17.45534896850586, -15.220134735107422, -17.33450698852539, -18.7819881439209, -19.477760314941406, -17.941089630126953, -16.739763259887695, -16.976755142211914, -15.498658180236816, -14.90047836303711, -14.609712600708008, -14.025971412658691, -12.659712791442871, -12.138504981994629, -8.167891502380371, -9.60393238067627, -9.56519603729248, -8.036227226257324, -7.503667831420898, -7.717591285705566, -7.552681922912598, -6.963212490081787, -5.978282451629639, -4.885679244995117, -5.269673824310303, -4.492502689361572, -4.120988845825195, -4.079439163208008, -3.648986577987671, -2.322096347808838, -2.826873302459717, -2.318565845489502, -2.2401647567749023, -0.19583234190940857, 2.2717316150665283, 0.0, 4.515851020812988, 5.054420471191406, 4.003873825073242, 3.963107109069824, -19.00534439086914, -17.711849212646484, -16.499345779418945, -15.846064567565918, -0.0, -0.0, -11.391252517700195, -12.553293228149414, -13.336708068847656, -12.37222957611084, -10.962084770202637, -10.629254341125488, -10.383755683898926, -10.313908576965332, -10.167492866516113, -10.128725051879883, -9.854615211486816, -9.78649616241455, -9.454059600830078, -9.41611385345459, -10.03145694732666, -10.14666748046875, -12.332682609558105, -10.955340385437012, -11.756345748901367, -11.258309364318848, -12.80372428894043, -11.008867263793945, -11.641036987304688, -14.600868225097656, -14.486696243286133, -15.982991218566895, -14.49405288696289, -16.643037796020508, -17.698156356811523, -16.50680160522461, -17.401569366455078, -18.175434112548828, -17.45534896850586, -15.220134735107422, -17.33450698852539, -18.7819881439209, -19.477760314941406, -17.941089630126953, -16.739763259887695, -16.976755142211914, -15.498658180236816, -14.90047836303711, -14.609712600708008, -14.025971412658691, -12.659712791442871, -12.138504981994629, -8.167891502380371, -9.60393238067627, -9.56519603729248, -8.036227226257324, -7.503667831420898, -7.717591285705566, -7.552681922912598, -6.963212490081787, -5.978282451629639, -4.885679244995117, -5.269673824310303, -4.492502689361572, -4.120988845825195, -4.079439163208008, -3.648986577987671, -2.322096347808838, -2.826873302459717, -2.318565845489502, -2.2401647567749023, -0.19583234190940857, 2.2717316150665283, 0.0, 4.515851020812988, 5.054420471191406, 4.003873825073242, 3.963107109069824], [-18.42954444885254, -18.638954162597656, -17.0374698638916, -15.717802047729492, 0.0, 0.0, 0.0, -13.717473983764648, -14.474112510681152, -12.722814559936523, -11.847622871398926, -11.449689865112305, -11.253194808959961, -10.702241897583008, -11.315225601196289, -10.4569730758667, -10.017416954040527, -10.43416690826416, -10.2477445602417, -11.04117202758789, -9.941940307617188, -10.443841934204102, -10.778473854064941, -12.491837501525879, -11.751379013061523, -11.978076934814453, -12.937244415283203, -12.40787124633789, -14.716331481933594, -13.42428970336914, -15.735204696655273, -16.58416175842285, -17.466455459594727, -17.898042678833008, -17.789409637451172, -19.30144691467285, -18.608783721923828, -19.09329605102539, -18.886524200439453, 0.0, -21.31679916381836, -18.863346099853516, -19.747465133666992, -22.344587326049805, -18.53745460510254, -17.685218811035156, -16.597583770751953, -16.02411651611328, -15.032670021057129, -13.578051567077637, -13.305366516113281, -12.015780448913574, -10.258106231689453, -9.422111511230469, -9.644896507263184, -8.67567253112793, -8.780938148498535, -7.950135707855225, -8.383803367614746, -6.199724197387695, -5.512608528137207, -5.261879920959473, -4.31482458114624, -3.725482940673828, -4.074253082275391, -6.155483245849609, -3.08258318901062, -3.166383743286133, -1.756510615348816, -0.6902199387550354, -1.0227307081222534, 0.19572557508945465, 0.3447043001651764, 0.0, 1.654032588005066, 4.405510425567627, 4.072216510772705, 4.573685646057129, -18.42954444885254, -18.638954162597656, -17.0374698638916, -15.717802047729492, -0.0, -0.0, -0.0, -13.717473983764648, -14.474112510681152, -12.722814559936523, -11.847622871398926, -11.449689865112305, -11.253194808959961, -10.702241897583008, -11.315225601196289, -10.4569730758667, -10.017416954040527, -10.43416690826416, -10.2477445602417, -11.04117202758789, -9.941940307617188, -10.443841934204102, -10.778473854064941, -12.491837501525879, -11.751379013061523, -11.978076934814453, -12.937244415283203, -12.40787124633789, -14.716331481933594, -13.42428970336914, -15.735204696655273, -16.58416175842285, -17.466455459594727, -17.898042678833008, -17.789409637451172, -19.30144691467285, -18.608783721923828, -19.09329605102539, -18.886524200439453, -0.0, -21.31679916381836, -18.863346099853516, -19.747465133666992, -22.344587326049805, -18.53745460510254, -17.685218811035156, -16.597583770751953, -16.02411651611328, -15.032670021057129, -13.578051567077637, -13.305366516113281, -12.015780448913574, -10.258106231689453, -9.422111511230469, -9.644896507263184, -8.67567253112793, -8.780938148498535, -7.950135707855225, -8.383803367614746, -6.199724197387695, -5.512608528137207, -5.261879920959473, -4.31482458114624, -3.725482940673828, -4.074253082275391, -6.155483245849609, -3.08258318901062, -3.166383743286133, -1.756510615348816, -0.6902199387550354, -1.0227307081222534, 0.19572557508945465, 0.3447043001651764, 0.0, 1.654032588005066, 4.405510425567627, 4.072216510772705, 4.573685646057129], [-19.354280471801758, -18.46143913269043, -17.379430770874023, -17.639169692993164, -15.16948127746582, 0.0, 0.0, 0.0, -14.742989540100098, -14.318092346191406, -13.320446014404297, -11.835330963134766, -11.028291702270508, -11.757619857788086, -10.79771900177002, -10.659558296203613, -10.203041076660156, -9.203895568847656, -10.658865928649902, -10.800971984863281, -10.585561752319336, -10.755577087402344, -12.380894660949707, -11.52995777130127, -12.29279613494873, -13.316486358642578, -12.95153522491455, -14.11661434173584, -14.100590705871582, -14.511516571044922, -15.815322875976562, -16.687660217285156, -17.37613296508789, -18.10611915588379, -19.21745491027832, -19.81949806213379, -18.792924880981445, -19.403844833374023, -20.25177001953125, -21.134546279907227, -20.65594482421875, -21.01922607421875, -19.81720733642578, -19.50191307067871, -19.382661819458008, -20.259111404418945, -17.20412826538086, -17.653833389282227, -16.807939529418945, -15.062247276306152, -14.986730575561523, -13.420653343200684, -12.696263313293457, -12.027190208435059, -11.373150825500488, -7.565096855163574, -9.449536323547363, -7.722959041595459, -7.486527442932129, -6.663307189941406, -5.820034503936768, -5.774390697479248, -4.716812610626221, -4.9922380447387695, -4.27949333190918, -2.0688986778259277, -2.7703440189361572, -3.36664080619812, -2.4716691970825195, -1.366451621055603, -1.3597958087921143, 0.028779707849025726, 0.9489027857780457, 0.0, 5.649827480316162, 3.1255249977111816, 3.292407989501953, 4.032455921173096, -19.354280471801758, -18.46143913269043, -17.379430770874023, -17.639169692993164, -15.16948127746582, -0.0, -0.0, -0.0, -14.742989540100098, -14.318092346191406, -13.320446014404297, -11.835330963134766, -11.028291702270508, -11.757619857788086, -10.79771900177002, -10.659558296203613, -10.203041076660156, -9.203895568847656, -10.658865928649902, -10.800971984863281, -10.585561752319336, -10.755577087402344, -12.380894660949707, -11.52995777130127, -12.29279613494873, -13.316486358642578, -12.95153522491455, -14.11661434173584, -14.100590705871582, -14.511516571044922, -15.815322875976562, -16.687660217285156, -17.37613296508789, -18.10611915588379, -19.21745491027832, -19.81949806213379, -18.792924880981445, -19.403844833374023, -20.25177001953125, -21.134546279907227, -20.65594482421875, -21.01922607421875, -19.81720733642578, -19.50191307067871, -19.382661819458008, -20.259111404418945, -17.20412826538086, -17.653833389282227, -16.807939529418945, -15.062247276306152, -14.986730575561523, -13.420653343200684, -12.696263313293457, -12.027190208435059, -11.373150825500488, -7.565096855163574, -9.449536323547363, -7.722959041595459, -7.486527442932129, -6.663307189941406, -5.820034503936768, -5.774390697479248, -4.716812610626221, -4.9922380447387695, -4.27949333190918, -2.0688986778259277, -2.7703440189361572, -3.36664080619812, -2.4716691970825195, -1.366451621055603, -1.3597958087921143, 0.028779707849025726, 0.9489027857780457, 0.0, 5.649827480316162, 3.1255249977111816, 3.292407989501953, 4.032455921173096], [-20.988128662109375, -18.014488220214844, -19.648128509521484, -18.869709014892578, -16.124286651611328, -15.696488380432129, 0.0, 0.0, 0.0, -14.066017150878906, -14.254753112792969, -12.524656295776367, -11.59489917755127, -10.891520500183105, -11.491193771362305, -11.495039939880371, -11.600454330444336, -10.214973449707031, -11.113039016723633, -10.952081680297852, -10.755995750427246, -12.03737735748291, -12.281807899475098, -12.50200366973877, -12.985757827758789, -12.194551467895508, -14.006169319152832, -13.982378005981445, -13.57416820526123, -15.828985214233398, -18.9887638092041, -17.457603454589844, -17.111452102661133, -19.12769317626953, -18.65899085998535, -20.330890655517578, -21.240137100219727, -21.02794075012207, -21.39579963684082, -20.847412109375, -20.32891273498535, -21.075063705444336, -21.48878288269043, -20.53759002685547, -21.548274993896484, -19.76038932800293, -19.125146865844727, -19.912687301635742, -17.291015625, -15.004136085510254, -15.99714183807373, -14.761438369750977, -12.957565307617188, -12.686553001403809, -11.094769477844238, -10.265750885009766, -10.234853744506836, -9.268416404724121, -7.522851943969727, -6.203653335571289, -7.092352867126465, -5.678802967071533, -5.74713659286499, -4.615743160247803, -5.017999649047852, -3.3536012172698975, -2.5895614624023438, -2.838883876800537, -2.623661518096924, -1.7504268884658813, -1.439502239227295, -0.5631894469261169, 0.0, 0.0, 5.689338684082031, 4.919743537902832, 4.032927513122559, 3.6477649211883545, -20.988128662109375, -18.014488220214844, -19.648128509521484, -18.869709014892578, -16.124286651611328, -15.696488380432129, -0.0, -0.0, -0.0, -14.066017150878906, -14.254753112792969, -12.524656295776367, -11.59489917755127, -10.891520500183105, -11.491193771362305, -11.495039939880371, -11.600454330444336, -10.214973449707031, -11.113039016723633, -10.952081680297852, -10.755995750427246, -12.03737735748291, -12.281807899475098, -12.50200366973877, -12.985757827758789, -12.194551467895508, -14.006169319152832, -13.982378005981445, -13.57416820526123, -15.828985214233398, -18.9887638092041, -17.457603454589844, -17.111452102661133, -19.12769317626953, -18.65899085998535, -20.330890655517578, -21.240137100219727, -21.02794075012207, -21.39579963684082, -20.847412109375, -20.32891273498535, -21.075063705444336, -21.48878288269043, -20.53759002685547, -21.548274993896484, -19.76038932800293, -19.125146865844727, -19.912687301635742, -17.291015625, -15.004136085510254, -15.99714183807373, -14.761438369750977, -12.957565307617188, -12.686553001403809, -11.094769477844238, -10.265750885009766, -10.234853744506836, -9.268416404724121, -7.522851943969727, -6.203653335571289, -7.092352867126465, -5.678802967071533, -5.74713659286499, -4.615743160247803, -5.017999649047852, -3.3536012172698975, -2.5895614624023438, -2.838883876800537, -2.623661518096924, -1.7504268884658813, -1.439502239227295, -0.5631894469261169, 0.0, 0.0, 5.689338684082031, 4.919743537902832, 4.032927513122559, 3.6477649211883545], [-19.664005279541016, -17.165822982788086, -18.03667640686035, -16.514476776123047, -16.09896469116211, -15.04196834564209, 0.0, 0.0, 0.0, 0.0, -10.408721923828125, -11.128008842468262, -12.056892395019531, -12.449078559875488, -11.237044334411621, -11.264751434326172, -11.927168846130371, -11.422711372375488, -11.336750030517578, -11.790166854858398, -11.445157051086426, -11.794260025024414, -12.760868072509766, -11.91637897491455, -12.876670837402344, -13.926474571228027, -14.157402992248535, -15.188714027404785, -14.79640007019043, -17.6939754486084, -17.357805252075195, -19.118431091308594, -19.437652587890625, -19.920223236083984, -21.322492599487305, -18.925106048583984, -20.934524536132812, -21.721529006958008, -22.120126724243164, -21.675426483154297, -22.382644653320312, -22.48693084716797, -22.101322174072266, -21.190553665161133, -21.14083480834961, -21.99793815612793, -19.819610595703125, -20.164043426513672, -17.794355392456055, -16.875518798828125, -16.584341049194336, -16.61690902709961, -14.016847610473633, -12.1424560546875, -11.618169784545898, -10.591009140014648, -9.807339668273926, -9.284664154052734, -8.847726821899414, -7.275637149810791, -7.76719856262207, -7.209073543548584, -5.34390926361084, -4.927458763122559, -4.569162845611572, -4.9793219566345215, -3.9605095386505127, -3.1278765201568604, -2.3279547691345215, -2.4303138256073, -1.068116307258606, -1.4152202606201172, 0.0, 5.124235153198242, 4.58066463470459, 4.489925384521484, 3.6640982627868652, 0.0, -19.664005279541016, -17.165822982788086, -18.03667640686035, -16.514476776123047, -16.09896469116211, -15.04196834564209, -0.0, -0.0, -0.0, -0.0, -10.408721923828125, -11.128008842468262, -12.056892395019531, -12.449078559875488, -11.237044334411621, -11.264751434326172, -11.927168846130371, -11.422711372375488, -11.336750030517578, -11.790166854858398, -11.445157051086426, -11.794260025024414, -12.760868072509766, -11.91637897491455, -12.876670837402344, -13.926474571228027, -14.157402992248535, -15.188714027404785, -14.79640007019043, -17.6939754486084, -17.357805252075195, -19.118431091308594, -19.437652587890625, -19.920223236083984, -21.322492599487305, -18.925106048583984, -20.934524536132812, -21.721529006958008, -22.120126724243164, -21.675426483154297, -22.382644653320312, -22.48693084716797, -22.101322174072266, -21.190553665161133, -21.14083480834961, -21.99793815612793, -19.819610595703125, -20.164043426513672, -17.794355392456055, -16.875518798828125, -16.584341049194336, -16.61690902709961, -14.016847610473633, -12.1424560546875, -11.618169784545898, -10.591009140014648, -9.807339668273926, -9.284664154052734, -8.847726821899414, -7.275637149810791, -7.76719856262207, -7.209073543548584, -5.34390926361084, -4.927458763122559, -4.569162845611572, -4.9793219566345215, -3.9605095386505127, -3.1278765201568604, -2.3279547691345215, -2.4303138256073, -1.068116307258606, -1.4152202606201172, 0.0, 5.124235153198242, 4.58066463470459, 4.489925384521484, 3.6640982627868652, 0.0], [-19.378032684326172, -19.283554077148438, -17.88719367980957, -15.81302547454834, -14.433914184570312, -14.944841384887695, -13.267646789550781, 0.0, 0.0, 0.0, -10.643739700317383, -11.02746295928955, -11.378913879394531, -11.379364967346191, -11.583539962768555, -11.778939247131348, -12.002815246582031, -10.450929641723633, -11.55154800415039, -12.344843864440918, -11.422978401184082, -12.862468719482422, -12.277908325195312, -14.094280242919922, -13.404609680175781, -14.801896095275879, -12.32310676574707, -14.577576637268066, -15.878173828125, -20.136737823486328, -17.560733795166016, -18.519853591918945, -20.086929321289062, -19.07411766052246, -19.991247177124023, -21.721267700195312, -22.169668197631836, -23.53595542907715, -23.27223014831543, -23.43674087524414, -23.41048240661621, -23.01609230041504, -23.017948150634766, -23.41680145263672, -22.481401443481445, -22.470611572265625, -20.00341033935547, -20.41634750366211, -18.392654418945312, -17.934505462646484, -16.642250061035156, -14.357723236083984, -13.451553344726562, -13.662994384765625, -12.361067771911621, -11.715767860412598, -9.424081802368164, -9.415365219116211, -7.9832987785339355, -7.7226481437683105, -7.551143169403076, -5.7803449630737305, -4.83858060836792, -5.6838698387146, -4.733442306518555, -3.8124985694885254, -3.0413246154785156, -1.7527344226837158, -2.6548666954040527, -2.103421926498413, -1.5187112092971802, 0.0, 0.0, 4.979879379272461, 4.192228317260742, 4.227651119232178, 2.7299227714538574, 5.591755390167236, -19.378032684326172, -19.283554077148438, -17.88719367980957, -15.81302547454834, -14.433914184570312, -14.944841384887695, -13.267646789550781, -0.0, -0.0, -0.0, -10.643739700317383, -11.02746295928955, -11.378913879394531, -11.379364967346191, -11.583539962768555, -11.778939247131348, -12.002815246582031, -10.450929641723633, -11.55154800415039, -12.344843864440918, -11.422978401184082, -12.862468719482422, -12.277908325195312, -14.094280242919922, -13.404609680175781, -14.801896095275879, -12.32310676574707, -14.577576637268066, -15.878173828125, -20.136737823486328, -17.560733795166016, -18.519853591918945, -20.086929321289062, -19.07411766052246, -19.991247177124023, -21.721267700195312, -22.169668197631836, -23.53595542907715, -23.27223014831543, -23.43674087524414, -23.41048240661621, -23.01609230041504, -23.017948150634766, -23.41680145263672, -22.481401443481445, -22.470611572265625, -20.00341033935547, -20.41634750366211, -18.392654418945312, -17.934505462646484, -16.642250061035156, -14.357723236083984, -13.451553344726562, -13.662994384765625, -12.361067771911621, -11.715767860412598, -9.424081802368164, -9.415365219116211, -7.9832987785339355, -7.7226481437683105, -7.551143169403076, -5.7803449630737305, -4.83858060836792, -5.6838698387146, -4.733442306518555, -3.8124985694885254, -3.0413246154785156, -1.7527344226837158, -2.6548666954040527, -2.103421926498413, -1.5187112092971802, -0.0, 0.0, 4.979879379272461, 4.192228317260742, 4.227651119232178, 2.7299227714538574, 5.591755390167236], [0.0, -19.660741806030273, -17.10188865661621, -15.503981590270996, -15.048717498779297, -14.168272018432617, -13.666692733764648, -11.810805320739746, 0.0, 0.0, -11.84353256225586, -11.24962329864502, -10.359945297241211, -10.533062934875488, -11.495372772216797, -11.961835861206055, -11.01820182800293, -11.577735900878906, -12.027960777282715, -11.793508529663086, -11.562338829040527, -11.734902381896973, -14.234947204589844, -14.285455703735352, -13.598748207092285, -14.428832054138184, -15.371152877807617, -15.336844444274902, -15.093592643737793, -18.38002586364746, -16.08946990966797, -18.224018096923828, -22.082847595214844, -21.365018844604492, -21.355056762695312, -22.55076026916504, -24.862735748291016, -24.105497360229492, -23.26523208618164, -22.76609230041504, -24.05076789855957, -23.85282325744629, -25.347105026245117, -25.049474716186523, -22.6862735748291, -22.249311447143555, -21.019855499267578, -20.079893112182617, -18.499099731445312, -18.220380783081055, -18.254844665527344, -17.26877212524414, -14.805129051208496, -13.882365226745605, -14.54317569732666, -12.836392402648926, -11.284093856811523, -9.025854110717773, -8.118327140808105, -7.866244792938232, -7.393723964691162, -6.758372783660889, -5.800461292266846, -5.44129753112793, -5.474447727203369, -4.646800518035889, -3.487560749053955, -3.6445119380950928, -3.495681047439575, -2.735551357269287, -2.1178150177001953, 0.0, 0.0, 3.689558267593384, 3.9858317375183105, 4.155635833740234, 0.0, 2.3152599334716797, -0.0, -19.660741806030273, -17.10188865661621, -15.503981590270996, -15.048717498779297, -14.168272018432617, -13.666692733764648, -11.810805320739746, -0.0, -0.0, -11.84353256225586, -11.24962329864502, -10.359945297241211, -10.533062934875488, -11.495372772216797, -11.961835861206055, -11.01820182800293, -11.577735900878906, -12.027960777282715, -11.793508529663086, -11.562338829040527, -11.734902381896973, -14.234947204589844, -14.285455703735352, -13.598748207092285, -14.428832054138184, -15.371152877807617, -15.336844444274902, -15.093592643737793, -18.38002586364746, -16.08946990966797, -18.224018096923828, -22.082847595214844, -21.365018844604492, -21.355056762695312, -22.55076026916504, -24.862735748291016, -24.105497360229492, -23.26523208618164, -22.76609230041504, -24.05076789855957, -23.85282325744629, -25.347105026245117, -25.049474716186523, -22.6862735748291, -22.249311447143555, -21.019855499267578, -20.079893112182617, -18.499099731445312, -18.220380783081055, -18.254844665527344, -17.26877212524414, -14.805129051208496, -13.882365226745605, -14.54317569732666, -12.836392402648926, -11.284093856811523, -9.025854110717773, -8.118327140808105, -7.866244792938232, -7.393723964691162, -6.758372783660889, -5.800461292266846, -5.44129753112793, -5.474447727203369, -4.646800518035889, -3.487560749053955, -3.6445119380950928, -3.495681047439575, -2.735551357269287, -2.1178150177001953, -0.0, 0.0, 3.689558267593384, 3.9858317375183105, 4.155635833740234, 0.0, 2.3152599334716797], [-24.188440322875977, 0.0, -19.798397064208984, -17.45530891418457, -16.13727569580078, -14.617267608642578, -13.62436580657959, -12.012145042419434, 0.0, 0.0, -13.11567497253418, -12.67721176147461, -9.386408805847168, -10.68202018737793, -9.740094184875488, -10.349023818969727, -10.64704704284668, -10.166254997253418, -11.517049789428711, -11.361310958862305, -13.043488502502441, -12.790603637695312, -12.463922500610352, -14.898696899414062, -15.02048397064209, -14.089293479919434, -15.792633056640625, -16.970821380615234, -16.644302368164062, -20.596105575561523, -19.114139556884766, -17.789817810058594, -20.838895797729492, -21.314706802368164, -21.587846755981445, -23.475780487060547, -23.475767135620117, -25.595426559448242, -25.06751251220703, -25.22877311706543, -25.3972110748291, -24.345373153686523, -25.533611297607422, -23.98323631286621, -24.03723907470703, -22.77054786682129, -22.73487091064453, -21.732322692871094, -20.385107040405273, -18.56607437133789, -16.638935089111328, -16.374738693237305, -15.159603118896484, -14.468328475952148, -14.172176361083984, -11.422961235046387, -8.91368293762207, -9.44542121887207, -7.064134120941162, -7.403236389160156, -6.740778923034668, -6.720139503479004, -5.533122539520264, -5.337990760803223, -5.219487190246582, -5.2589216232299805, -4.054598808288574, -3.403528928756714, -3.9874398708343506, -3.797386646270752, 0.0, 0.0, 1.0914885997772217, 3.445178508758545, 4.23457145690918, 0.0, 0.0, 0.0, -24.188440322875977, -0.0, -19.798397064208984, -17.45530891418457, -16.13727569580078, -14.617267608642578, -13.62436580657959, -12.012145042419434, -0.0, -0.0, -13.11567497253418, -12.67721176147461, -9.386408805847168, -10.68202018737793, -9.740094184875488, -10.349023818969727, -10.64704704284668, -10.166254997253418, -11.517049789428711, -11.361310958862305, -13.043488502502441, -12.790603637695312, -12.463922500610352, -14.898696899414062, -15.02048397064209, -14.089293479919434, -15.792633056640625, -16.970821380615234, -16.644302368164062, -20.596105575561523, -19.114139556884766, -17.789817810058594, -20.838895797729492, -21.314706802368164, -21.587846755981445, -23.475780487060547, -23.475767135620117, -25.595426559448242, -25.06751251220703, -25.22877311706543, -25.3972110748291, -24.345373153686523, -25.533611297607422, -23.98323631286621, -24.03723907470703, -22.77054786682129, -22.73487091064453, -21.732322692871094, -20.385107040405273, -18.56607437133789, -16.638935089111328, -16.374738693237305, -15.159603118896484, -14.468328475952148, -14.172176361083984, -11.422961235046387, -8.91368293762207, -9.44542121887207, -7.064134120941162, -7.403236389160156, -6.740778923034668, -6.720139503479004, -5.533122539520264, -5.337990760803223, -5.219487190246582, -5.2589216232299805, -4.054598808288574, -3.403528928756714, -3.9874398708343506, -3.797386646270752, -0.0, 0.0, 1.0914885997772217, 3.445178508758545, 4.23457145690918, 0.0, -0.0, -0.0], [-25.905414581298828, 0.0, -18.237939834594727, -16.49641990661621, -16.33233070373535, -15.170050621032715, -13.44231128692627, -13.49246597290039, -12.231825828552246, 0.0, 0.0, -11.073460578918457, -10.57438850402832, -9.878029823303223, -10.34273910522461, -10.80286693572998, -11.007035255432129, -11.123074531555176, -11.635148048400879, -12.443122863769531, -11.130603790283203, -12.440054893493652, -13.874530792236328, -14.759488105773926, -14.9056396484375, -14.8822603225708, -16.653623580932617, -17.621854782104492, -17.66181755065918, -18.969070434570312, -19.285900115966797, -20.342437744140625, -20.930593490600586, -23.290340423583984, -22.51922607421875, -23.409412384033203, -25.631366729736328, -24.81006622314453, -26.300758361816406, -25.49123764038086, -25.53075408935547, -25.18902587890625, -24.878938674926758, -24.088613510131836, -24.13510513305664, -23.980632781982422, -22.18976593017578, -22.90590476989746, -21.84320640563965, -19.71881675720215, -18.628734588623047, -18.266033172607422, -15.947040557861328, -15.953271865844727, -13.856334686279297, -12.389227867126465, -11.059586524963379, -9.857245445251465, -8.630880355834961, -7.509264945983887, -6.879539489746094, -6.193650722503662, -6.057617664337158, -5.834865093231201, -5.27107048034668, -4.988506317138672, -4.511731147766113, -3.8581326007843018, -3.7467544078826904, -3.483557939529419, 0.0, 0.0, 1.495732307434082, 3.0851752758026123, 3.133148431777954, -0.1786198914051056, -0.15047946572303772, 1.140952706336975, -25.905414581298828, -0.0, -18.237939834594727, -16.49641990661621, -16.33233070373535, -15.170050621032715, -13.44231128692627, -13.49246597290039, -12.231825828552246, -0.0, -0.0, -11.073460578918457, -10.57438850402832, -9.878029823303223, -10.34273910522461, -10.80286693572998, -11.007035255432129, -11.123074531555176, -11.635148048400879, -12.443122863769531, -11.130603790283203, -12.440054893493652, -13.874530792236328, -14.759488105773926, -14.9056396484375, -14.8822603225708, -16.653623580932617, -17.621854782104492, -17.66181755065918, -18.969070434570312, -19.285900115966797, -20.342437744140625, -20.930593490600586, -23.290340423583984, -22.51922607421875, -23.409412384033203, -25.631366729736328, -24.81006622314453, -26.300758361816406, -25.49123764038086, -25.53075408935547, -25.18902587890625, -24.878938674926758, -24.088613510131836, -24.13510513305664, -23.980632781982422, -22.18976593017578, -22.90590476989746, -21.84320640563965, -19.71881675720215, -18.628734588623047, -18.266033172607422, -15.947040557861328, -15.953271865844727, -13.856334686279297, -12.389227867126465, -11.059586524963379, -9.857245445251465, -8.630880355834961, -7.509264945983887, -6.879539489746094, -6.193650722503662, -6.057617664337158, -5.834865093231201, -5.27107048034668, -4.988506317138672, -4.511731147766113, -3.8581326007843018, -3.7467544078826904, -3.483557939529419, -0.0, 0.0, 1.495732307434082, 3.0851752758026123, 3.133148431777954, -0.1786198914051056, -0.15047946572303772, 1.140952706336975], [-24.498260498046875, -22.826433181762695, 0.0, -19.685882568359375, -16.833858489990234, -15.411722183227539, -13.969745635986328, -13.00167179107666, -11.594136238098145, 0.0, -10.224245071411133, -11.3944730758667, -9.558879852294922, -9.888736724853516, -11.574938774108887, -11.232613563537598, -11.191669464111328, -12.274892807006836, -11.722707748413086, -12.029500007629395, -12.212908744812012, -13.049372673034668, -13.299785614013672, -13.614180564880371, -15.272138595581055, -15.350970268249512, -17.07927894592285, -16.743301391601562, -18.44892120361328, -19.17405128479004, -19.513019561767578, -20.49979591369629, -22.394529342651367, -23.184886932373047, -21.9407901763916, -24.959461212158203, -25.43985366821289, -25.697864532470703, -25.910696029663086, -26.31709098815918, -26.51983642578125, -25.62272834777832, -25.12265968322754, -25.372665405273438, -25.019235610961914, -21.25546646118164, -22.21894645690918, -22.51299476623535, -22.806676864624023, -21.712913513183594, -18.915645599365234, -18.213315963745117, -17.27115249633789, -15.762818336486816, -14.084050178527832, -12.678662300109863, -12.008440971374512, -9.871939659118652, -8.732491493225098, -8.561635971069336, -6.859919548034668, -5.871964454650879, -5.710946083068848, -5.138049602508545, -4.434804439544678, -4.05487585067749, -3.9508156776428223, -4.080890655517578, -3.7540392875671387, -1.6051000356674194, 0.0, -0.04906950891017914, 2.2067642211914062, 3.3043289184570312, 0.0, -1.039690613746643, -1.1636223793029785, 0.0, -24.498260498046875, -22.826433181762695, -0.0, -19.685882568359375, -16.833858489990234, -15.411722183227539, -13.969745635986328, -13.00167179107666, -11.594136238098145, -0.0, -10.224245071411133, -11.3944730758667, -9.558879852294922, -9.888736724853516, -11.574938774108887, -11.232613563537598, -11.191669464111328, -12.274892807006836, -11.722707748413086, -12.029500007629395, -12.212908744812012, -13.049372673034668, -13.299785614013672, -13.614180564880371, -15.272138595581055, -15.350970268249512, -17.07927894592285, -16.743301391601562, -18.44892120361328, -19.17405128479004, -19.513019561767578, -20.49979591369629, -22.394529342651367, -23.184886932373047, -21.9407901763916, -24.959461212158203, -25.43985366821289, -25.697864532470703, -25.910696029663086, -26.31709098815918, -26.51983642578125, -25.62272834777832, -25.12265968322754, -25.372665405273438, -25.019235610961914, -21.25546646118164, -22.21894645690918, -22.51299476623535, -22.806676864624023, -21.712913513183594, -18.915645599365234, -18.213315963745117, -17.27115249633789, -15.762818336486816, -14.084050178527832, -12.678662300109863, -12.008440971374512, -9.871939659118652, -8.732491493225098, -8.561635971069336, -6.859919548034668, -5.871964454650879, -5.710946083068848, -5.138049602508545, -4.434804439544678, -4.05487585067749, -3.9508156776428223, -4.080890655517578, -3.7540392875671387, -1.6051000356674194, -0.0, -0.04906950891017914, 2.2067642211914062, 3.3043289184570312, 0.0, -1.039690613746643, -1.1636223793029785, -0.0], [-24.06342124938965, -23.90838050842285, 0.0, 0.0, -16.9073429107666, -16.027498245239258, -15.384109497070312, -13.769189834594727, -12.759617805480957, -11.418564796447754, 0.0, -13.126690864562988, -9.106712341308594, -10.686667442321777, -11.7993745803833, -12.472136497497559, -12.64145565032959, -11.232553482055664, -11.45775318145752, -11.671758651733398, -12.628782272338867, -12.87488079071045, -13.822736740112305, -14.445852279663086, -14.793743133544922, -16.536788940429688, -16.321279525756836, -18.154756546020508, -18.29884910583496, -18.8525447845459, -21.273120880126953, -21.174081802368164, -24.156543731689453, -23.483753204345703, -23.8577880859375, -25.733516693115234, -25.778860092163086, -25.695077896118164, -26.367034912109375, -26.1982421875, -26.180164337158203, -26.220417022705078, -26.406614303588867, -25.366497039794922, -25.387496948242188, -24.08719825744629, -24.0889835357666, -23.33802032470703, -21.650257110595703, -20.26007652282715, -19.46982192993164, -18.71805763244629, -17.612548828125, -16.882427215576172, -14.961743354797363, -12.957619667053223, -12.204386711120605, -10.555213928222656, -9.81753158569336, -7.824153900146484, -7.993043899536133, -6.495071887969971, -5.2677812576293945, -5.09169340133667, -4.0978474617004395, -3.5725765228271484, -3.3670530319213867, -3.906804323196411, -6.232968807220459, 0.0, 0.0, 1.0095012187957764, 1.2891747951507568, 1.0472922325134277, 0.0, -1.90438711643219, -0.5581609606742859, 0.0, -24.06342124938965, -23.90838050842285, -0.0, -0.0, -16.9073429107666, -16.027498245239258, -15.384109497070312, -13.769189834594727, -12.759617805480957, -11.418564796447754, -0.0, -13.126690864562988, -9.106712341308594, -10.686667442321777, -11.7993745803833, -12.472136497497559, -12.64145565032959, -11.232553482055664, -11.45775318145752, -11.671758651733398, -12.628782272338867, -12.87488079071045, -13.822736740112305, -14.445852279663086, -14.793743133544922, -16.536788940429688, -16.321279525756836, -18.154756546020508, -18.29884910583496, -18.8525447845459, -21.273120880126953, -21.174081802368164, -24.156543731689453, -23.483753204345703, -23.8577880859375, -25.733516693115234, -25.778860092163086, -25.695077896118164, -26.367034912109375, -26.1982421875, -26.180164337158203, -26.220417022705078, -26.406614303588867, -25.366497039794922, -25.387496948242188, -24.08719825744629, -24.0889835357666, -23.33802032470703, -21.650257110595703, -20.26007652282715, -19.46982192993164, -18.71805763244629, -17.612548828125, -16.882427215576172, -14.961743354797363, -12.957619667053223, -12.204386711120605, -10.555213928222656, -9.81753158569336, -7.824153900146484, -7.993043899536133, -6.495071887969971, -5.2677812576293945, -5.09169340133667, -4.0978474617004395, -3.5725765228271484, -3.3670530319213867, -3.906804323196411, -6.232968807220459, -0.0, 0.0, 1.0095012187957764, 1.2891747951507568, 1.0472922325134277, -0.0, -1.90438711643219, -0.5581609606742859, -0.0], [0.0, -23.867509841918945, -22.226076126098633, 0.0, 0.0, -16.74125099182129, -15.130044937133789, -14.339162826538086, -13.73277473449707, -15.998146057128906, 0.0, -14.518386840820312, -10.727075576782227, -11.720969200134277, -12.213674545288086, -12.377582550048828, -11.726722717285156, -11.626351356506348, -11.21619987487793, -11.758251190185547, -11.520545959472656, -12.350397109985352, -15.061896324157715, -14.851414680480957, -15.420875549316406, -16.678470611572266, -17.439929962158203, -19.231975555419922, -19.107803344726562, -20.539953231811523, -20.38287925720215, -21.353729248046875, -21.913570404052734, -22.601232528686523, -24.72909164428711, -25.382827758789062, -25.398258209228516, -27.22756004333496, -27.273902893066406, -27.25669288635254, -26.130104064941406, -26.981277465820312, -25.970121383666992, -25.388273239135742, -25.81082534790039, -25.803159713745117, -23.49905014038086, -24.248554229736328, -23.878280639648438, -20.047544479370117, -19.25161361694336, -16.290136337280273, -18.369413375854492, -16.416229248046875, -15.647589683532715, -14.110818862915039, -12.317643165588379, -10.815531730651855, -8.988264083862305, -10.701308250427246, -8.051319122314453, -7.572136402130127, -6.118470668792725, -7.523712635040283, -4.893585205078125, -4.637734889984131, -6.446569442749023, -5.570420265197754, 0.0, 0.0, -0.26677772402763367, 2.997770309448242, 1.9833637475967407, 0.0, 1.4649578332901, -3.26835560798645, -0.09846257418394089, 0.0, -0.0, -23.867509841918945, -22.226076126098633, -0.0, -0.0, -16.74125099182129, -15.130044937133789, -14.339162826538086, -13.73277473449707, -15.998146057128906, -0.0, -14.518386840820312, -10.727075576782227, -11.720969200134277, -12.213674545288086, -12.377582550048828, -11.726722717285156, -11.626351356506348, -11.21619987487793, -11.758251190185547, -11.520545959472656, -12.350397109985352, -15.061896324157715, -14.851414680480957, -15.420875549316406, -16.678470611572266, -17.439929962158203, -19.231975555419922, -19.107803344726562, -20.539953231811523, -20.38287925720215, -21.353729248046875, -21.913570404052734, -22.601232528686523, -24.72909164428711, -25.382827758789062, -25.398258209228516, -27.22756004333496, -27.273902893066406, -27.25669288635254, -26.130104064941406, -26.981277465820312, -25.970121383666992, -25.388273239135742, -25.81082534790039, -25.803159713745117, -23.49905014038086, -24.248554229736328, -23.878280639648438, -20.047544479370117, -19.25161361694336, -16.290136337280273, -18.369413375854492, -16.416229248046875, -15.647589683532715, -14.110818862915039, -12.317643165588379, -10.815531730651855, -8.988264083862305, -10.701308250427246, -8.051319122314453, -7.572136402130127, -6.118470668792725, -7.523712635040283, -4.893585205078125, -4.637734889984131, -6.446569442749023, -5.570420265197754, -0.0, -0.0, -0.26677772402763367, 2.997770309448242, 1.9833637475967407, 0.0, 1.4649578332901, -3.26835560798645, -0.09846257418394089, -0.0], [0.0, 0.0, 0.0, -17.729333877563477, -19.923734664916992, -21.395187377929688, -18.90381622314453, -15.008712768554688, -14.602479934692383, -13.490859985351562, -12.757905006408691, 0.0, -9.566617965698242, -13.059039115905762, -13.524187088012695, -12.042974472045898, -10.601282119750977, -10.196394920349121, -14.534570693969727, -9.800118446350098, -11.585046768188477, -13.121965408325195, -15.640738487243652, -15.570328712463379, -16.582202911376953, -15.714949607849121, -18.14133071899414, -18.51323127746582, -20.83861541748047, -21.113649368286133, -20.811260223388672, -21.396114349365234, -23.8238468170166, -23.648714065551758, -25.049997329711914, -26.560258865356445, -26.495126724243164, -29.099834442138672, -26.833951950073242, -26.645431518554688, -26.885282516479492, -26.816499710083008, -26.35335350036621, -26.074356079101562, -26.024229049682617, -25.296873092651367, -25.84845542907715, -25.0205078125, -24.301210403442383, -21.853242874145508, -20.312232971191406, -18.96490478515625, -18.70383644104004, -15.924981117248535, -14.741708755493164, -13.99913501739502, -12.281237602233887, -11.39908218383789, -10.701920509338379, -9.913362503051758, -8.499805450439453, -8.948055267333984, -8.330747604370117, -6.474361419677734, -5.807545185089111, 0.0, 0.0, 0.0, 0.0, 0.0, -0.5794842839241028, 1.5437664985656738, 0.8264389038085938, 0.0, 1.0144630670547485, 0.27154362201690674, 0.0, 0.0, -0.0, -0.0, -0.0, -17.729333877563477, -19.923734664916992, -21.395187377929688, -18.90381622314453, -15.008712768554688, -14.602479934692383, -13.490859985351562, -12.757905006408691, -0.0, -9.566617965698242, -13.059039115905762, -13.524187088012695, -12.042974472045898, -10.601282119750977, -10.196394920349121, -14.534570693969727, -9.800118446350098, -11.585046768188477, -13.121965408325195, -15.640738487243652, -15.570328712463379, -16.582202911376953, -15.714949607849121, -18.14133071899414, -18.51323127746582, -20.83861541748047, -21.113649368286133, -20.811260223388672, -21.396114349365234, -23.8238468170166, -23.648714065551758, -25.049997329711914, -26.560258865356445, -26.495126724243164, -29.099834442138672, -26.833951950073242, -26.645431518554688, -26.885282516479492, -26.816499710083008, -26.35335350036621, -26.074356079101562, -26.024229049682617, -25.296873092651367, -25.84845542907715, -25.0205078125, -24.301210403442383, -21.853242874145508, -20.312232971191406, -18.96490478515625, -18.70383644104004, -15.924981117248535, -14.741708755493164, -13.99913501739502, -12.281237602233887, -11.39908218383789, -10.701920509338379, -9.913362503051758, -8.499805450439453, -8.948055267333984, -8.330747604370117, -6.474361419677734, -5.807545185089111, -0.0, -0.0, -0.0, -0.0, -0.0, -0.5794842839241028, 1.5437664985656738, 0.8264389038085938, 0.0, 1.0144630670547485, 0.27154362201690674, -0.0, -0.0], [0.0, 0.0, -19.614118576049805, -21.359006881713867, -20.195310592651367, 0.0, -17.359865188598633, -16.094703674316406, -14.137494087219238, -14.030624389648438, -13.32998275756836, 0.0, -9.024806022644043, -12.429211616516113, -14.138654708862305, -10.860910415649414, -10.481382369995117, -10.4711275100708, -11.835823059082031, -10.935144424438477, -13.539856910705566, -14.080649375915527, -15.759610176086426, -17.601438522338867, -17.89451026916504, -21.016117095947266, -19.088064193725586, -19.894908905029297, -20.13078498840332, -20.42377281188965, -21.87378692626953, -22.423063278198242, -24.951770782470703, -25.43208122253418, -24.640501022338867, -26.12403678894043, -27.31501007080078, -26.738449096679688, -26.79045867919922, -27.441741943359375, -26.539051055908203, -26.278701782226562, -26.24805450439453, -27.11795997619629, -26.336332321166992, -26.151052474975586, -24.857868194580078, -23.395601272583008, -24.297346115112305, -22.906105041503906, -20.396007537841797, -22.779558181762695, -19.499149322509766, -17.776334762573242, -15.40732192993164, -14.044967651367188, -14.164612770080566, -11.6942720413208, -11.266290664672852, -11.173990249633789, -10.33547592163086, -9.463634490966797, -8.217212677001953, -6.675198554992676, -6.541498184204102, 0.0, 0.0, 0.0, 0.0, 0.0, 0.2428300827741623, 1.1386609077453613, 0.0, 0.0, -0.07182015478610992, -1.5654371976852417, 0.0, 0.0, -0.0, -0.0, -19.614118576049805, -21.359006881713867, -20.195310592651367, -0.0, -17.359865188598633, -16.094703674316406, -14.137494087219238, -14.030624389648438, -13.32998275756836, -0.0, -9.024806022644043, -12.429211616516113, -14.138654708862305, -10.860910415649414, -10.481382369995117, -10.4711275100708, -11.835823059082031, -10.935144424438477, -13.539856910705566, -14.080649375915527, -15.759610176086426, -17.601438522338867, -17.89451026916504, -21.016117095947266, -19.088064193725586, -19.894908905029297, -20.13078498840332, -20.42377281188965, -21.87378692626953, -22.423063278198242, -24.951770782470703, -25.43208122253418, -24.640501022338867, -26.12403678894043, -27.31501007080078, -26.738449096679688, -26.79045867919922, -27.441741943359375, -26.539051055908203, -26.278701782226562, -26.24805450439453, -27.11795997619629, -26.336332321166992, -26.151052474975586, -24.857868194580078, -23.395601272583008, -24.297346115112305, -22.906105041503906, -20.396007537841797, -22.779558181762695, -19.499149322509766, -17.776334762573242, -15.40732192993164, -14.044967651367188, -14.164612770080566, -11.6942720413208, -11.266290664672852, -11.173990249633789, -10.33547592163086, -9.463634490966797, -8.217212677001953, -6.675198554992676, -6.541498184204102, -0.0, -0.0, -0.0, 0.0, 0.0, 0.2428300827741623, 1.1386609077453613, 0.0, -0.0, -0.07182015478610992, -1.5654371976852417, -0.0, -0.0], [0.0, 0.0, -19.225290298461914, -20.643709182739258, -20.19169807434082, 0.0, 0.0, -16.315683364868164, -16.226699829101562, -15.22000789642334, -14.957378387451172, 0.0, 0.0, -15.555231094360352, -16.042760848999023, -12.149789810180664, -10.573081016540527, -10.462723731994629, -11.50980281829834, -12.458222389221191, -12.120088577270508, -15.887253761291504, -17.54643440246582, -18.76706314086914, -18.652833938598633, -19.311782836914062, -19.273216247558594, -19.942174911499023, -20.188966751098633, -21.5004825592041, -22.64425277709961, -23.504636764526367, -23.59734535217285, -24.34113883972168, -25.2747745513916, -26.443178176879883, -25.894926071166992, -26.383289337158203, -26.339595794677734, -25.917556762695312, -26.72563362121582, -26.430707931518555, -26.167673110961914, -26.50359535217285, -26.260868072509766, -26.44075584411621, -25.628801345825195, -25.43230438232422, -24.283946990966797, -22.378372192382812, -21.214012145996094, -20.29002571105957, -19.068090438842773, -16.41351318359375, -15.600412368774414, -14.56071662902832, -13.627779006958008, -11.523589134216309, -10.618953704833984, -12.983776092529297, -12.725887298583984, -10.916679382324219, -7.608145236968994, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.4064827561378479, -0.22432830929756165, 0.0, -1.1833577156066895, -2.621079921722412, -1.883202314376831, 0.0, 0.0, -0.0, -0.0, -19.225290298461914, -20.643709182739258, -20.19169807434082, -0.0, -0.0, -16.315683364868164, -16.226699829101562, -15.22000789642334, -14.957378387451172, -0.0, -0.0, -15.555231094360352, -16.042760848999023, -12.149789810180664, -10.573081016540527, -10.462723731994629, -11.50980281829834, -12.458222389221191, -12.120088577270508, -15.887253761291504, -17.54643440246582, -18.76706314086914, -18.652833938598633, -19.311782836914062, -19.273216247558594, -19.942174911499023, -20.188966751098633, -21.5004825592041, -22.64425277709961, -23.504636764526367, -23.59734535217285, -24.34113883972168, -25.2747745513916, -26.443178176879883, -25.894926071166992, -26.383289337158203, -26.339595794677734, -25.917556762695312, -26.72563362121582, -26.430707931518555, -26.167673110961914, -26.50359535217285, -26.260868072509766, -26.44075584411621, -25.628801345825195, -25.43230438232422, -24.283946990966797, -22.378372192382812, -21.214012145996094, -20.29002571105957, -19.068090438842773, -16.41351318359375, -15.600412368774414, -14.56071662902832, -13.627779006958008, -11.523589134216309, -10.618953704833984, -12.983776092529297, -12.725887298583984, -10.916679382324219, -7.608145236968994, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.4064827561378479, -0.22432830929756165, -0.0, -1.1833577156066895, -2.621079921722412, -1.883202314376831, -0.0, -0.0], [0.0, 0.0, 0.0, -20.268611907958984, -22.674705505371094, -24.16624641418457, 0.0, 0.0, -15.968643188476562, -15.747426986694336, -15.674552917480469, -14.66415786743164, 0.0, 0.0, 0.0, -8.850491523742676, -9.524168968200684, -11.199828147888184, -14.525822639465332, -15.362237930297852, -15.66529655456543, -18.730445861816406, -19.35931968688965, -19.477914810180664, -19.875402450561523, -20.073894500732422, -20.161846160888672, -20.928707122802734, -21.689882278442383, -21.228479385375977, -21.62721824645996, -22.0635986328125, -22.76044464111328, -23.97978973388672, -25.806917190551758, -26.81040382385254, -26.63806915283203, -26.112197875976562, -27.496021270751953, -27.093626022338867, -26.893537521362305, -26.68891143798828, -25.901533126831055, -25.546489715576172, -26.142988204956055, -27.92460823059082, -26.32975196838379, -24.11842155456543, -25.575044631958008, -21.51905059814453, -21.17642593383789, -20.379606246948242, -17.821304321289062, -16.419363021850586, -14.728775024414062, -15.849193572998047, -13.412935256958008, -11.809553146362305, -14.908082962036133, -13.81021785736084, -12.330809593200684, 0.0, -4.603103160858154, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.7806523442268372, 0.0, 0.0, -0.5173717737197876, -1.562123417854309, -0.4283917546272278, 0.0, 0.0, -0.0, -0.0, -0.0, -20.268611907958984, -22.674705505371094, -24.16624641418457, -0.0, -0.0, -15.968643188476562, -15.747426986694336, -15.674552917480469, -14.66415786743164, -0.0, -0.0, -0.0, -8.850491523742676, -9.524168968200684, -11.199828147888184, -14.525822639465332, -15.362237930297852, -15.66529655456543, -18.730445861816406, -19.35931968688965, -19.477914810180664, -19.875402450561523, -20.073894500732422, -20.161846160888672, -20.928707122802734, -21.689882278442383, -21.228479385375977, -21.62721824645996, -22.0635986328125, -23.30841636657715, -24.409961700439453, -25.926891326904297, -26.795564651489258, -26.840938568115234, -26.538759231567383, -27.409006118774414, -27.094722747802734, -26.901981353759766, -26.67919158935547, -26.102428436279297, -25.88043212890625, -26.250972747802734, -27.3441104888916, -26.235618591308594, -24.55853843688965, -24.954246520996094, -22.287931442260742, -21.17642593383789, -20.379606246948242, -17.821304321289062, -16.419363021850586, -14.728775024414062, -15.849193572998047, -13.412935256958008, -11.809553146362305, -14.908082962036133, -13.81021785736084, -12.330809593200684, -0.0, -4.603103160858154, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.7806523442268372, -0.0, -0.0, -0.5173717737197876, -1.562123417854309, -0.4283917546272278, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.622386932373047, -17.895109176635742, -17.83577537536621, -15.903948783874512, -14.800390243530273, 0.0, 0.0, 0.0, -7.538931369781494, 0.0, -15.081241607666016, -15.8671293258667, -18.22482681274414, -18.753381729125977, -21.562437057495117, -21.162338256835938, -21.447072982788086, -20.949947357177734, -20.952035903930664, -21.32834243774414, -25.337221145629883, -24.6289119720459, -25.52726173400879, -26.579566955566406, -23.640295028686523, -25.90166473388672, -23.997526168823242, -25.220754623413086, -26.65806007385254, -26.874658584594727, -26.47074317932129, -25.774320602416992, -25.34989356994629, -25.718236923217773, -25.14399528503418, -26.312389373779297, -25.50629425048828, -25.854589462280273, -25.822189331054688, -26.870655059814453, -24.748092651367188, -24.057044982910156, -23.627986907958984, -19.78931999206543, -16.865854263305664, -13.438026428222656, -13.71630573272705, -13.542202949523926, -15.633270263671875, 0.0, 0.0, 0.0, 0.0, 0.0, -2.4561147689819336, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.526057243347168, -4.195257186889648, 0.0, -3.69258189201355, -2.559619665145874, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.622386932373047, -17.895109176635742, -17.83577537536621, -15.903948783874512, -14.800390243530273, -0.0, -0.0, -0.0, -7.538931369781494, -0.0, -15.081241607666016, -15.8671293258667, -18.22482681274414, -18.753381729125977, -21.562437057495117, -21.162338256835938, -21.447072982788086, -20.949947357177734, -20.952035903930664, -21.32834243774414, -25.337221145629883, -24.6289119720459, -25.52726173400879, -26.579566955566406, -23.95697593688965, -25.400846481323242, -26.41789436340332, -26.98143196105957, -27.10128402709961, -27.050254821777344, -27.124292373657227, -26.91421127319336, -26.632915496826172, -26.33744239807129, -26.028474807739258, -25.93997573852539, -26.14174461364746, -26.39796257019043, -26.020610809326172, -25.370180130004883, -24.897235870361328, -23.931795120239258, -23.627986907958984, -19.78931999206543, -16.865854263305664, -13.438026428222656, -13.71630573272705, -13.542202949523926, -15.633270263671875, -0.0, -0.0, -0.0, -0.0, -0.0, -2.4561147689819336, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.526057243347168, -4.195257186889648, -0.0, -3.69258189201355, -2.559619665145874, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.520116806030273, 0.0, 0.0, -18.110515594482422, -18.2353515625, -16.371917724609375, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.829239845275879, -13.221976280212402, -17.06416893005371, -16.108888626098633, -16.475252151489258, -17.11530303955078, -17.47304344177246, -16.616817474365234, -18.31840705871582, -19.629138946533203, -22.467483520507812, -26.37833023071289, -25.37447166442871, -24.435836791992188, -27.137712478637695, -29.968727111816406, -26.20242691040039, -26.535423278808594, -26.7257022857666, -25.60733413696289, -25.81149673461914, -25.96194839477539, -25.00808334350586, -24.649179458618164, -24.643638610839844, -25.65010643005371, -25.509231567382812, -25.66939926147461, -26.03999900817871, -25.159481048583984, -24.60806655883789, -24.29478645324707, -21.956457138061523, -19.77938461303711, -17.517656326293945, -14.998340606689453, -12.645068168640137, -11.400315284729004, -12.94443416595459, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.000017166137695, 0.0, -5.459575653076172, -4.67471981048584, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.520116806030273, -0.0, -0.0, -18.110515594482422, -18.2353515625, -16.371917724609375, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.829239845275879, -13.221976280212402, -17.06416893005371, -16.108888626098633, -16.475252151489258, -17.11530303955078, -17.47304344177246, -16.616817474365234, -18.31840705871582, -19.629138946533203, -22.467483520507812, -26.37833023071289, -25.37447166442871, -24.435836791992188, -26.6861515045166, -26.72311019897461, -27.103288650512695, -27.354110717773438, -27.38818359375, -27.27461814880371, -27.027841567993164, -26.697484970092773, -26.32843780517578, -26.000707626342773, -25.782894134521484, -25.725255966186523, -25.793527603149414, -25.813880920410156, -25.733360290527344, -25.600940704345703, -25.31696891784668, -24.36252784729004, -21.956457138061523, -19.77938461303711, -17.517656326293945, -14.998340606689453, -12.645068168640137, -11.400315284729004, -12.94443416595459, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.000017166137695, -0.0, -5.459575653076172, -4.67471981048584, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -21.610383987426758, -21.079833984375, 0.0, 0.0, -18.888534545898438, -18.498117446899414, -18.378894805908203, -16.247180938720703, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.974461555480957, -18.301265716552734, -17.266544342041016, 0.0, -18.72726058959961, 0.0, 0.0, 0.0, -24.04841423034668, -23.604475021362305, -28.00030517578125, -25.64120101928711, -29.127775192260742, -26.811389923095703, -29.649568557739258, -30.710582733154297, -28.700057983398438, -26.701086044311523, -26.47222137451172, -25.832725524902344, -25.791006088256836, -24.038803100585938, -23.56958770751953, -23.698551177978516, -23.69497299194336, -25.540449142456055, -23.922224044799805, 0.0, -28.282724380493164, -24.60513687133789, -28.10770034790039, -23.396808624267578, -22.15177345275879, 0.0, 0.0, 0.0, -13.226456642150879, -12.463935852050781, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.20964241027832, 0.0, -6.721044063568115, -4.619685173034668, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -21.610383987426758, -21.079833984375, -0.0, -0.0, -18.888534545898438, -18.498117446899414, -18.378894805908203, -16.247180938720703, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.974461555480957, -18.301265716552734, -17.266544342041016, -0.0, -18.72726058959961, -0.0, -0.0, -0.0, -24.04841423034668, -23.604475021362305, -28.00030517578125, -25.64120101928711, -29.127775192260742, -26.85752296447754, -27.492189407348633, -27.70747947692871, -27.699260711669922, -27.57354736328125, -27.29183006286621, -26.876220703125, -26.41041374206543, -25.93813705444336, -25.53811264038086, -25.246089935302734, -25.109119415283203, -25.103668212890625, -25.12395477294922, -0.0, -25.32823944091797, -25.819175720214844, -27.060649871826172, -23.396808624267578, -22.15177345275879, -0.0, -0.0, -0.0, -13.226456642150879, -12.463935852050781, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.20964241027832, -0.0, -6.721044063568115, -4.619685173034668, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -21.672788619995117, -21.802949905395508, -21.65505027770996, 0.0, -21.179780960083008, -19.92808723449707, -19.089990615844727, -20.8770809173584, 0.0, 0.0, 0.0, 0.0, 0.0, -18.283241271972656, -19.440134048461914, -18.257083892822266, -18.528423309326172, -19.491731643676758, -18.527742385864258, -18.833574295043945, -17.898880004882812, 0.0, 0.0, -26.615835189819336, -25.57257652282715, 0.0, -31.97468376159668, -30.050992965698242, -28.122913360595703, -30.515348434448242, -28.69906997680664, -24.62919807434082, -25.134279251098633, -24.66246795654297, -24.043228149414062, -22.86158561706543, -27.552610397338867, -26.927473068237305, -27.975475311279297, -28.145370483398438, -24.693632125854492, 0.0, 0.0, -25.299409866333008, -27.222885131835938, -25.69727325439453, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.070611000061035, -2.2825448513031006, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -21.672788619995117, -21.802949905395508, -21.65505027770996, -0.0, -21.179780960083008, -19.92808723449707, -19.089990615844727, -20.8770809173584, -0.0, -0.0, -0.0, -0.0, -0.0, -18.283241271972656, -19.440134048461914, -18.257083892822266, -18.528423309326172, -19.491731643676758, -18.527742385864258, -18.833574295043945, -17.898880004882812, -0.0, -0.0, -26.615835189819336, -25.57257652282715, -0.0, -31.97468376159668, -29.607786178588867, -28.167856216430664, -27.78888702392578, -27.711780548095703, -27.52127456665039, -27.059541702270508, -26.505029678344727, -25.95751190185547, -25.40813636779785, -24.91655158996582, -24.439855575561523, -24.087387084960938, -23.971973419189453, -24.07848358154297, -0.0, -0.0, -25.371883392333984, -26.290185928344727, -25.69727325439453, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.070611000061035, -2.2825448513031006, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -20.499258041381836, -23.870899200439453, -22.56791877746582, 0.0, 0.0, -19.9404239654541, -19.570600509643555, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.27756690979004, -18.241634368896484, -19.444290161132812, -19.240312576293945, -18.43760871887207, -20.748655319213867, -20.130521774291992, -17.616029739379883, -19.417455673217773, 0.0, 0.0, 0.0, 0.0, 0.0, -30.46957778930664, -27.607412338256836, -29.34494400024414, 0.0, -26.838075637817383, -25.20940399169922, -24.61949348449707, -22.51020050048828, -26.370912551879883, -26.115108489990234, -24.066768646240234, -27.099220275878906, -25.40584373474121, -26.465862274169922, -23.88812828063965, 0.0, -21.97653579711914, 0.0, -23.29813575744629, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -2.986602783203125, -2.986393690109253, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.499258041381836, -23.870899200439453, -22.56791877746582, -0.0, -0.0, -19.9404239654541, -19.570600509643555, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.27756690979004, -18.241634368896484, -19.444290161132812, -19.240312576293945, -18.43760871887207, -20.748655319213867, -20.130521774291992, -17.616029739379883, -19.417455673217773, -0.0, -0.0, -0.0, -0.0, -0.0, -29.74222755432129, -28.552143096923828, -27.703702926635742, -0.0, -27.180233001708984, -26.644813537597656, -25.98394012451172, -25.39224624633789, -24.81297492980957, -24.189817428588867, -23.51466178894043, -22.887067794799805, -22.69834327697754, -22.956336975097656, -23.59412384033203, -0.0, -24.92049789428711, -0.0, -23.29813575744629, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -2.986602783203125, -2.986393690109253, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.367605209350586, -23.504051208496094, -22.585956573486328, 0.0, -21.21192741394043, -21.180086135864258, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.342374801635742, -20.942005157470703, -18.322311401367188, -20.48974609375, -21.264087677001953, -20.21927833557129, -21.232437133789062, -23.050214767456055, -21.043500900268555, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.929189682006836, -30.19329261779785, -31.87528419494629, -29.43663787841797, -24.848512649536133, -23.296152114868164, -26.87235450744629, -25.709320068359375, -25.694475173950195, -22.95285415649414, -28.09023666381836, -25.236452102661133, -24.78888511657715, -21.08356475830078, -22.363080978393555, 0.0, -23.812360763549805, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -6.547934532165527, -3.1921491622924805, -4.7511396408081055, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.367605209350586, -23.504051208496094, -22.585956573486328, -0.0, -21.21192741394043, -21.180086135864258, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.342374801635742, -20.942005157470703, -18.322311401367188, -20.48974609375, -21.264087677001953, -20.21927833557129, -21.232437133789062, -23.050214767456055, -21.043500900268555, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.334089279174805, -27.746387481689453, -27.03603744506836, -26.742965698242188, -26.135217666625977, -25.371206283569336, -24.8560848236084, -24.224258422851562, -23.489824295043945, -22.790666580200195, -22.30358123779297, -22.23107147216797, -22.607791900634766, -23.426158905029297, -24.021318435668945, -0.0, -23.836124420166016, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -6.547934532165527, -3.1921491622924805, -4.7511396408081055, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -23.511381149291992, -25.397785186767578, -23.961292266845703, 0.0, -22.56610107421875, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.309329986572266, -20.71879768371582, -20.326324462890625, -19.785634994506836, -21.550525665283203, -21.29242515563965, -23.060546875, -20.632457733154297, -22.290334701538086, -22.6544132232666, 0.0, -19.86161994934082, 0.0, 0.0, -27.358482360839844, -25.418577194213867, -26.817644119262695, -24.823244094848633, 0.0, -28.256305694580078, -27.975072860717773, -26.11353874206543, -25.8450927734375, -25.929428100585938, -25.51361656188965, -27.148319244384766, -27.358551025390625, -23.809526443481445, -23.037017822265625, -22.700468063354492, -23.564973831176758, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.922403812408447, -8.525967597961426, -4.734255790710449, -3.662140369415283, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -23.511381149291992, -25.397785186767578, -23.961292266845703, -0.0, -22.56610107421875, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.309329986572266, -20.71879768371582, -20.326324462890625, -19.785634994506836, -21.550525665283203, -21.29242515563965, -23.060546875, -20.632457733154297, -22.290334701538086, -22.6544132232666, -0.0, -19.86161994934082, -0.0, -0.0, -27.358482360839844, -26.25484275817871, -27.012460708618164, -27.308053970336914, -0.0, -26.48006820678711, -25.678001403808594, -24.96077537536621, -24.496734619140625, -23.805103302001953, -23.101669311523438, -22.502090454101562, -22.23323631286621, -22.55035972595215, -23.14250946044922, -23.575626373291016, -23.998804092407227, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.922403812408447, -8.525967597961426, -4.734255790710449, -3.662140369415283, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -27.191736221313477, -25.87636947631836, -26.293466567993164, -25.841753005981445, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -21.166189193725586, -21.529457092285156, -21.483840942382812, -20.68742561340332, -24.336811065673828, -25.58600616455078, 0.0, 0.0, -19.709373474121094, -16.976680755615234, -18.312532424926758, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.617677688598633, -27.396183013916016, -28.02262306213379, -27.859668731689453, -29.35247039794922, -27.117734909057617, 0.0, -26.728796005249023, -26.73161506652832, -24.21366310119629, -25.377790451049805, -24.77667808532715, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.096923828125, -10.650432586669922, -6.882205009460449, -7.515881538391113, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.191736221313477, -25.87636947631836, -26.293466567993164, -25.841753005981445, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -21.166189193725586, -21.529457092285156, -21.483840942382812, -20.68742561340332, -24.336811065673828, -25.58600616455078, -0.0, -0.0, -19.709373474121094, -16.976680755615234, -18.312532424926758, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.879161834716797, -26.2694034576416, -25.34144401550293, -24.925317764282227, -24.39143943786621, -23.6002140045166, -0.0, -22.459613800048828, -22.484399795532227, -23.22440528869629, -23.8718204498291, -24.267311096191406, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.096923828125, -10.650432586669922, -6.882205009460449, -7.515881538391113, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, -25.638416290283203, 0.0, -26.23777961730957, -25.955549240112305, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.051830291748047, 0.0, -20.69144058227539, -20.844463348388672, -22.396121978759766, -25.757551193237305, -22.434350967407227, -27.04683494567871, -27.8499698638916, -28.78787612915039, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.106019973754883, 0.0, -29.192975997924805, -31.002126693725586, -28.56831169128418, -28.874910354614258, 0.0, 0.0, -25.192636489868164, -26.486066818237305, -27.932415008544922, -26.301576614379883, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.694976806640625, 0.0, -25.521421432495117, 0.0, -24.484943389892578, -24.59940528869629, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.000030517578125, -7.523420810699463, -7.869429588317871, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.638416290283203, -0.0, -26.23777961730957, -25.955549240112305, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.051830291748047, -0.0, -20.69144058227539, -20.844463348388672, -22.396121978759766, -25.757551193237305, -22.434350967407227, -27.04683494567871, -27.8499698638916, -28.78787612915039, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.316545486450195, -0.0, -25.4379940032959, -25.234230041503906, -24.62828254699707, -23.986610412597656, -0.0, -0.0, -23.280609130859375, -24.144838333129883, -24.816530227661133, -25.16818618774414, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.694976806640625, -0.0, -25.521421432495117, -0.0, -24.484943389892578, -24.59940528869629, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -9.000030517578125, -7.523420810699463, -7.869429588317871, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.321956634521484, -23.55900764465332, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -17.53725814819336, -18.949892044067383, -18.403350830078125, -22.34731674194336, -24.246780395507812, -26.71438217163086, -27.415441513061523, -28.121253967285156, -29.765981674194336, -30.294147491455078, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.086204528808594, -33.116756439208984, -30.320262908935547, -29.654329299926758, 0.0, 0.0, -27.97393226623535, -28.239091873168945, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -22.59609031677246, 0.0, -30.95050811767578, -27.645326614379883, 0.0, -27.01293182373047, -24.98027229309082, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.259392261505127, -6.574418067932129, -7.7484354972839355, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.321956634521484, -23.55900764465332, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -17.53725814819336, -18.949892044067383, -18.403350830078125, -22.34731674194336, -24.246780395507812, -26.71438217163086, -27.415441513061523, -28.121253967285156, -29.765981674194336, -30.294147491455078, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.44771957397461, -25.517187118530273, -25.166868209838867, -24.644227981567383, -0.0, -0.0, -24.354467391967773, -25.135778427124023, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -22.59609031677246, -0.0, -30.95050811767578, -27.645326614379883, -0.0, -27.01293182373047, -24.98027229309082, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.259392261505127, -6.574418067932129, -7.7484354972839355, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.91187858581543, -23.664020538330078, -22.25986671447754, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -19.582067489624023, -21.7218074798584, -24.21845245361328, -27.640642166137695, -27.074308395385742, -29.38228988647461, -31.5006046295166, -33.03792190551758, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.5407657623291, -29.560546875, -27.61189842224121, -26.520713806152344, -25.8814697265625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.527727127075195, 0.0, -26.708372116088867, -27.89689064025879, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -5.94936990737915, -9.586994171142578, -12.09361457824707, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.91187858581543, -23.664020538330078, -22.25986671447754, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -19.582067489624023, -21.7218074798584, -24.21845245361328, -27.640642166137695, -27.074308395385742, -29.38228988647461, -31.5006046295166, -33.03792190551758, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.374563217163086, -25.59316062927246, -25.507553100585938, -24.94114112854004, -24.514118194580078, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.527727127075195, -0.0, -26.708372116088867, -27.89689064025879, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -5.94936990737915, -9.586994171142578, -12.09361457824707, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -27.280492782592773, -26.059249877929688, -25.76728057861328, -25.10980987548828, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.926448822021484, 0.0, -22.977691650390625, -22.780803680419922, 0.0, 0.0, -30.080204010009766, -29.250993728637695, -32.20652389526367, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.723838806152344, -25.150426864624023, -24.694732666015625, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.430374145507812, -18.697763442993164, -28.480148315429688, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.713776588439941, -7.233938217163086, -9.070032119750977, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -27.280492782592773, -26.059249877929688, -25.76728057861328, -25.10980987548828, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.926448822021484, -0.0, -22.977691650390625, -22.780803680419922, -0.0, -0.0, -30.080204010009766, -29.250993728637695, -32.20652389526367, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.6442813873291, -25.46721839904785, -25.433204650878906, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.430374145507812, -18.697763442993164, -28.480148315429688, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -9.713776588439941, -7.233938217163086, -9.070032119750977, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.809797286987305, -27.05243682861328, -25.20136260986328, -26.3011417388916, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -18.6751766204834, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.72639274597168, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -24.56891632080078, -26.2692928314209, 0.0, -24.5087833404541, -25.100217819213867, -25.204410552978516, -25.59507179260254, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -15.550540924072266, -13.535439491271973, -14.278816223144531, -15.722213745117188, -19.745595932006836, -17.957027435302734, 0.0, -11.551660537719727, -12.561928749084473, -12.750372886657715, -10.148674964904785, -6.831939220428467, -10.633760452270508, -10.48829174041748, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.809797286987305, -27.05243682861328, -25.20136260986328, -26.3011417388916, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -18.6751766204834, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -29.72639274597168, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -25.239110946655273, -25.221702575683594, -0.0, -25.186437606811523, -25.672422409057617, -26.14327621459961, -26.458641052246094, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -15.550540924072266, -13.535439491271973, -14.278816223144531, -15.722213745117188, -19.745595932006836, -17.957027435302734, -0.0, -11.551660537719727, -12.561928749084473, -12.750372886657715, -10.148674964904785, -6.831939220428467, -10.633760452270508, -10.48829174041748, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.981157302856445, -27.97183609008789, -26.136140823364258, -27.348613739013672, -26.32438850402832, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.10434341430664, -25.686372756958008, -27.731178283691406, -26.910757064819336, -24.61321258544922, -22.8197021484375, -25.40185546875, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.749650001525879, -12.340404510498047, -13.955619812011719, -13.894222259521484, -13.427614212036133, -17.309734344482422, 0.0, 0.0, 0.0, -10.34908676147461, -9.478934288024902, 0.0, -9.285886764526367, -10.720940589904785, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.981157302856445, -27.97183609008789, -26.136140823364258, -27.348613739013672, -26.32438850402832, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.911144256591797, -24.7822208404541, -24.783809661865234, -25.273649215698242, -25.638294219970703, -25.920433044433594, -26.264808654785156, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.749650001525879, -12.340404510498047, -13.955619812011719, -13.894222259521484, -13.427614212036133, -17.309734344482422, -0.0, -0.0, -0.0, -10.34908676147461, -9.478934288024902, -0.0, -9.285886764526367, -10.720940589904785, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.73157501220703, -26.909923553466797, -26.778104782104492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.41486930847168, -28.000186920166016, -25.78249168395996, -27.261356353759766, -24.699068069458008, -25.95683479309082, -26.49790382385254, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -8.701274871826172, -9.383444786071777, -12.95277214050293, -13.10135555267334, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.162969589233398, 0.0, 0.0, 0.0, -10.796753883361816, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.73157501220703, -26.909923553466797, -26.778104782104492, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.714553833007812, -24.708356857299805, -24.870407104492188, -25.32659912109375, -25.679624557495117, -25.861291885375977, -26.09189796447754, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -8.701274871826172, -9.383444786071777, -12.95277214050293, -13.10135555267334, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.162969589233398, -0.0, -0.0, -0.0, -10.796753883361816, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -28.699874877929688, -27.361438751220703, -26.975746154785156, -23.56955337524414, -21.421703338623047, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -25.66482162475586, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -7.852406024932861, -7.191226959228516, -11.911859512329102, -16.904224395751953, -16.687875747680664, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -28.699874877929688, -27.361438751220703, -26.975746154785156, -23.56955337524414, -21.421703338623047, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -24.780439376831055, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -7.852406024932861, -7.191226959228516, -11.911859512329102, -16.904224395751953, -16.687875747680664, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -26.42966079711914, -27.83606719970703, -26.081518173217773, -24.827861785888672, -29.664823532104492, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.742980003356934, -10.756781578063965, -9.14773941040039, -13.9310884475708, -14.08503532409668, -15.34305477142334, -11.390375137329102, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -26.42966079711914, -27.83606719970703, -26.081518173217773, -24.827861785888672, -29.664823532104492, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.742980003356934, -10.756781578063965, -9.14773941040039, -13.9310884475708, -14.08503532409668, -15.34305477142334, -11.390375137329102, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.368927001953125, -26.601600646972656, -28.861257553100586, -31.33729362487793, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -9.236272811889648, -8.533905029296875, -9.221250534057617, -13.235320091247559, -12.581073760986328, 0.0, -12.511214256286621, -10.949108123779297, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -29.368927001953125, -26.601600646972656, -28.861257553100586, -31.33729362487793, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -9.236272811889648, -8.533905029296875, -9.221250534057617, -13.235320091247559, -12.581073760986328, -0.0, -12.511214256286621, -10.949108123779297, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -11.167121887207031, -10.635110855102539, -10.088141441345215, -11.185412406921387, -11.772910118103027, -14.18404769897461, -12.156195640563965, -14.449386596679688, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -11.167121887207031, -10.635110855102539, -10.088141441345215, -11.185412406921387, -11.772910118103027, -14.18404769897461, -12.156195640563965, -14.449386596679688, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.123527526855469, -12.821142196655273, -13.349459648132324, -10.877545356750488, 0.0, 0.0, 0.0, -13.171202659606934, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.123527526855469, -12.821142196655273, -13.349459648132324, -10.877545356750488, -0.0, -0.0, -0.0, -13.171202659606934, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -10.882688522338867, -14.743768692016602, -14.165749549865723, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -10.882688522338867, -14.743768692016602, -14.165749549865723, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -14.30544376373291, 0.0, 0.0, -12.069116592407227, -14.974672317504883, -14.468205451965332, -12.910873413085938, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -14.30544376373291, -0.0, -0.0, -12.069116592407227, -14.974672317504883, -14.468205451965332, -12.910873413085938, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -12.985057830810547, -16.616701126098633, -15.530447006225586, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -12.985057830810547, -16.616701126098633, -15.530447006225586, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -16.492366790771484, -18.581283569335938, -17.17460060119629, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -16.492366790771484, -18.581283569335938, -17.17460060119629, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -20.374032974243164, -21.506126403808594, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -20.374032974243164, -21.506126403808594, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0], [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0, -0.0]]}],                        {\"autosize\": false, \"height\": 640, \"margin\": {\"b\": 60, \"l\": 50, \"r\": 50, \"t\": 35}, \"showlegend\": false, \"sliders\": [{\"active\": 0, \"currentvalue\": {\"prefix\": \"Current slice is: <b>\"}, \"pad\": {\"b\": 10, \"t\": 50}, \"steps\": [{\"args\": [\"visible\", [true, false, false, false, false, false, false, false, false]], \"label\": \"1\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, true, false, false, false, false, false, false, false]], \"label\": \"2\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, true, false, false, false, false, false, false]], \"label\": \"3\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, true, false, false, false, false, false]], \"label\": \"4\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, true, false, false, false, false]], \"label\": \"5\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, true, false, false, false]], \"label\": \"6\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, true, false, false]], \"label\": \"7\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, true, false]], \"label\": \"8\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, true]], \"label\": \"9\", \"method\": \"restyle\"}]}], \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"pie\": [{\"automargin\": true, \"type\": \"pie\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"autotypenumbers\": \"strict\", \"coloraxis\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"\\t \\t \\t \\t \\t \\t \\t \\t \\t Prelude \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t Filtered\"}, \"width\": 780, \"xaxis\": {\"showgrid\": false, \"showticklabels\": false}, \"yaxis\": {\"showgrid\": false, \"showticklabels\": false}},                        {\"displayModeBar\": false, \"responsive\": true}                    )                };                            </script>        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "%use Python3\n",
    "\n",
    "###### Plotting \"output_nii_file\" heatmap with slider for navigating through slices\n",
    "import scipy.io as sio\n",
    "import plotly.graph_objs as go\n",
    "from ipywidgets import interactive, HBox, widgets, interact\n",
    "import numpy as np\n",
    "from plotly.offline import download_plotlyjs, init_notebook_mode, plot, iplot\n",
    "from IPython.core.display import display, HTML\n",
    "import nibabel as nib\n",
    "import os\n",
    "import numpy as np \n",
    "\n",
    "init_notebook_mode(connected=True)\n",
    "config={'showLink': False, 'displayModeBar': False}\n",
    "\n",
    "# If you run on your local machine comment out this line\n",
    "os.chdir(\"/home/jovyan/work/Phase_book/03/data\")\n",
    "\n",
    "\n",
    "# Load nifti files \n",
    "nii_left = nib.load('partiallyUnwrappedMap.nii').get_fdata()\n",
    "nii_list = [nib.load(f\"output{i}.nii\").get_fdata() for i in range(1,10)]\n",
    "\n",
    "# Concatenate files using list comprehension, along adequate axis \n",
    "newmap = [np.concatenate((nii[:,:,i], nii_left[:,:,i]), axis = 0) for i,nii in enumerate(nii_list)]\n",
    "\n",
    "# Get # of slices\n",
    "slices_z = np.shape(newmap)[0]\n",
    "\n",
    "# Create list of Heatmaps, one for every slice \n",
    "data = []\n",
    "for i in range(slices_z):\n",
    "    z_current = np.rot90(newmap[i],3)\n",
    "    data_c = go.Heatmap(z = z_current, \n",
    "                        visible = False,\n",
    "                        xtype = \"scaled\", \n",
    "                        ytype = \"scaled\",\n",
    "                        colorscale = \"hot\",\n",
    "                        name = \"comparison heatmap\",\n",
    "                        colorbar = dict(title = dict(text = \"B<sub>0</sub> (Hz)\")))\n",
    "    data.append(data_c)\n",
    "\n",
    "# Toggle frist slice to be visible\n",
    "data[0]['visible'] = True\n",
    "\n",
    "# Create steps and slider\n",
    "steps = []\n",
    "for i in range(slices_z):\n",
    "    step = dict(\n",
    "        method = 'restyle',  \n",
    "        args = ['visible', [False]*slices_z],\n",
    "        label = str(i+1)\n",
    "    )\n",
    "    step['args'][1][i] = True # Toggle i'th trace to \"visible\"\n",
    "    steps.append(step)\n",
    "\n",
    "sliders = [dict(\n",
    "    active = 0,\n",
    "    currentvalue = {'prefix':\"Current slice is: <b>\"},\n",
    "    pad = {\"t\": 50, \"b\": 10},\n",
    "    steps = steps\n",
    ")]\n",
    "\n",
    "# Setup the layout of the figure; NOTE this \\t, are tabs for the layout in the html render. You can delete some of them in order to see the \"Filtered\"\n",
    "layout = go.Layout(\n",
    "    title = \"\\t \\t \\t \\t \\t \\t \\t \\t \\t Prelude \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t \\t Filtered\", \n",
    "    width=780,\n",
    "    height=640,\n",
    "    margin=go.layout.Margin(\n",
    "        l=50,\n",
    "        r=50,\n",
    "        b=60,\n",
    "        t=35,\n",
    "    ),\n",
    "    showlegend = False,\n",
    "    autosize = False,\n",
    "    sliders=sliders,\n",
    "    xaxis = dict(showgrid = False,\n",
    "                 showticklabels= False),\n",
    "    yaxis = dict(showgrid = False,\n",
    "                 showticklabels = False),\n",
    ")\n",
    "\n",
    "# Plot function saves as html or with ipplot\n",
    "fig = dict(data=data, layout=layout)\n",
    "plot(fig, filename = 'fig.html', config = config)\n",
    "\n",
    "display(HTML('fig.html'))\n",
    "# Local offline use\n",
    "# iplot(fig, config=config)"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Edit Metadata",
  "kernelspec": {
   "display_name": "SoS",
   "language": "sos",
   "name": "sos"
  },
  "language_info": {
   "codemirror_mode": "sos",
   "file_extension": ".sos",
   "mimetype": "text/x-sos",
   "name": "sos",
   "nbconvert_exporter": "sos_notebook.converter.SoS_Exporter",
   "pygments_lexer": "sos"
  },
  "sos": {
   "kernels": [
    [
     "Julia",
     "julia-1.4",
     "Julia",
     "#ebd8eb",
     ""
    ],
    [
     "Python3",
     "python3",
     "Python3",
     "#FFD91A",
     {
      "name": "ipython",
      "version": 3
     }
    ]
   ],
   "panel": {
    "displayed": false,
    "height": 0
   },
   "version": "0.22.4"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
